Class: Google::Apis::AiplatformV1::CloudAiLargeModelsVisionPromptInputs
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::CloudAiLargeModelsVisionPromptInputs
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
"Direct" prompting for Experimental Video Generation. These will be sent directly to the LDM without being rewritten.
Instance Attribute Summary collapse
-
#audio_prompt ⇒ String
Description of audio content in the video, without speech.
-
#negative_audio_prompt ⇒ String
Negative description of audio content in the video.
-
#negative_prompt ⇒ String
Single negative prompt for what not to generate.
-
#prompt_chunks ⇒ Array<String>
2s, 256 tokens per chunk, 4 total chunks.
-
#transcript ⇒ String
Spoken transcript of the video for characters.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CloudAiLargeModelsVisionPromptInputs
constructor
A new instance of CloudAiLargeModelsVisionPromptInputs.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CloudAiLargeModelsVisionPromptInputs
Returns a new instance of CloudAiLargeModelsVisionPromptInputs.
490 491 492 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 490 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audio_prompt ⇒ String
Description of audio content in the video, without speech.
Corresponds to the JSON property audioPrompt
468 469 470 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 468 def audio_prompt @audio_prompt end |
#negative_audio_prompt ⇒ String
Negative description of audio content in the video.
Corresponds to the JSON property negativeAudioPrompt
473 474 475 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 473 def negative_audio_prompt @negative_audio_prompt end |
#negative_prompt ⇒ String
Single negative prompt for what not to generate.
Corresponds to the JSON property negativePrompt
478 479 480 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 478 def negative_prompt @negative_prompt end |
#prompt_chunks ⇒ Array<String>
2s, 256 tokens per chunk, 4 total chunks. Required.
Corresponds to the JSON property promptChunks
483 484 485 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 483 def prompt_chunks @prompt_chunks end |
#transcript ⇒ String
Spoken transcript of the video for characters.
Corresponds to the JSON property transcript
488 489 490 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 488 def transcript @transcript end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
495 496 497 498 499 500 501 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 495 def update!(**args) @audio_prompt = args[:audio_prompt] if args.key?(:audio_prompt) @negative_audio_prompt = args[:negative_audio_prompt] if args.key?(:negative_audio_prompt) @negative_prompt = args[:negative_prompt] if args.key?(:negative_prompt) @prompt_chunks = args[:prompt_chunks] if args.key?(:prompt_chunks) @transcript = args[:transcript] if args.key?(:transcript) end |