Class: Google::Apis::AiplatformV1::CloudAiLargeModelsVisionRaiInfoDetectedLabelsEntity

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The properties for a detected entity from the rai signal.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CloudAiLargeModelsVisionRaiInfoDetectedLabelsEntity

Returns a new instance of CloudAiLargeModelsVisionRaiInfoDetectedLabelsEntity.



810
811
812
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 810

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bounding_boxGoogle::Apis::AiplatformV1::CloudAiLargeModelsVisionRaiInfoDetectedLabelsBoundingBox

An integer bounding box of original pixels of the image for the detected labels. Corresponds to the JSON property boundingBox



788
789
790
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 788

def bounding_box
  @bounding_box
end

#descriptionString

Description of the label Corresponds to the JSON property description

Returns:

  • (String)


793
794
795
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 793

def description
  @description
end

#iou_scoreFloat

The intersection ratio between the detection bounding box and the mask. Corresponds to the JSON property iouScore

Returns:

  • (Float)


798
799
800
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 798

def iou_score
  @iou_score
end

#midString

MID of the label Corresponds to the JSON property mid

Returns:

  • (String)


803
804
805
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 803

def mid
  @mid
end

#scoreFloat

Confidence score of the label Corresponds to the JSON property score

Returns:

  • (Float)


808
809
810
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 808

def score
  @score
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



815
816
817
818
819
820
821
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 815

def update!(**args)
  @bounding_box = args[:bounding_box] if args.key?(:bounding_box)
  @description = args[:description] if args.key?(:description)
  @iou_score = args[:iou_score] if args.key?(:iou_score)
  @mid = args[:mid] if args.key?(:mid)
  @score = args[:score] if args.key?(:score)
end