Class: Google::Apis::AiplatformV1::CloudAiLargeModelsVisionSeamless

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CloudAiLargeModelsVisionSeamless

Returns a new instance of CloudAiLargeModelsVisionSeamless.



847
848
849
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 847

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#loopBoolean Also known as: loop?

If true, the generated video will be loopable (seamless time looping). Corresponds to the JSON property loop

Returns:

  • (Boolean)


831
832
833
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 831

def loop
  @loop
end

#tessellate_horizontalBoolean Also known as: tessellate_horizontal?

If true, the generated video will be tessellatable as a horizontal tessellation. Corresponds to the JSON property tessellateHorizontal

Returns:

  • (Boolean)


838
839
840
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 838

def tessellate_horizontal
  @tessellate_horizontal
end

#tessellate_verticalBoolean Also known as: tessellate_vertical?

If true, the generated video will be tessellatable as a vertical tessellation. Corresponds to the JSON property tessellateVertical

Returns:

  • (Boolean)


844
845
846
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 844

def tessellate_vertical
  @tessellate_vertical
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



852
853
854
855
856
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 852

def update!(**args)
  @loop = args[:loop] if args.key?(:loop)
  @tessellate_horizontal = args[:tessellate_horizontal] if args.key?(:tessellate_horizontal)
  @tessellate_vertical = args[:tessellate_vertical] if args.key?(:tessellate_vertical)
end