Class: Google::Apis::AiplatformV1::CloudAiNlLlmProtoServiceFact
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::CloudAiNlLlmProtoServiceFact
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A condense version of WorldFact (assistant/boq/lamda/factuality/proto/ factuality.proto) to propagate the essential information about the fact used in factuality to the upstream caller.
Instance Attribute Summary collapse
-
#query ⇒ String
Query that is used to retrieve this fact.
-
#summary ⇒ String
If present, the summary/snippet of the fact.
-
#title ⇒ String
If present, it refers to the title of this fact.
-
#url ⇒ String
If present, this URL links to the webpage of the fact.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CloudAiNlLlmProtoServiceFact
constructor
A new instance of CloudAiNlLlmProtoServiceFact.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CloudAiNlLlmProtoServiceFact
Returns a new instance of CloudAiNlLlmProtoServiceFact.
636 637 638 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 636 def initialize(**args) update!(**args) end |
Instance Attribute Details
#query ⇒ String
Query that is used to retrieve this fact.
Corresponds to the JSON property query
619 620 621 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 619 def query @query end |
#summary ⇒ String
If present, the summary/snippet of the fact.
Corresponds to the JSON property summary
624 625 626 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 624 def summary @summary end |
#title ⇒ String
If present, it refers to the title of this fact.
Corresponds to the JSON property title
629 630 631 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 629 def title @title end |
#url ⇒ String
If present, this URL links to the webpage of the fact.
Corresponds to the JSON property url
634 635 636 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 634 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
641 642 643 644 645 646 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 641 def update!(**args) @query = args[:query] if args.key?(:query) @summary = args[:summary] if args.key?(:summary) @title = args[:title] if args.key?(:title) @url = args[:url] if args.key?(:url) end |