Class: Google::Apis::AiplatformV1::CloudAiNlLlmProtoServicePartLmRootMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::CloudAiNlLlmProtoServicePartLmRootMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Metadata provides extra info for building the LM Root request.
Instance Attribute Summary collapse
-
#chunk_id ⇒ String
Chunk id that will be used when mapping the part to the LM Root's chunk.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CloudAiNlLlmProtoServicePartLmRootMetadata
constructor
A new instance of CloudAiNlLlmProtoServicePartLmRootMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CloudAiNlLlmProtoServicePartLmRootMetadata
Returns a new instance of CloudAiNlLlmProtoServicePartLmRootMetadata.
941 942 943 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 941 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chunk_id ⇒ String
Chunk id that will be used when mapping the part to the LM Root's chunk.
Corresponds to the JSON property chunkId
939 940 941 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 939 def chunk_id @chunk_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
946 947 948 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 946 def update!(**args) @chunk_id = args[:chunk_id] if args.key?(:chunk_id) end |