Class: Google::Apis::AiplatformV1::CloudAiNlLlmProtoServiceRaiSignal

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

An RAI signal for a single category.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CloudAiNlLlmProtoServiceRaiSignal

Returns a new instance of CloudAiNlLlmProtoServiceRaiSignal.



1122
1123
1124
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1122

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidenceString

The confidence level for the RAI category. Corresponds to the JSON property confidence

Returns:

  • (String)


1098
1099
1100
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1098

def confidence
  @confidence
end

#flaggedBoolean Also known as: flagged?

Whether the category is flagged as being present. Currently, this is set to true if score >= 0.5. Corresponds to the JSON property flagged

Returns:

  • (Boolean)


1104
1105
1106
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1104

def flagged
  @flagged
end

#influential_termsArray<Google::Apis::AiplatformV1::CloudAiNlLlmProtoServiceRaiSignalInfluentialTerm>

The influential terms that could potentially block the response. Corresponds to the JSON property influentialTerms



1110
1111
1112
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1110

def influential_terms
  @influential_terms
end

#rai_categoryString

The RAI category. Corresponds to the JSON property raiCategory

Returns:

  • (String)


1115
1116
1117
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1115

def rai_category
  @rai_category
end

#scoreFloat

The score for the category, in the range [0.0, 1.0]. Corresponds to the JSON property score

Returns:

  • (Float)


1120
1121
1122
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1120

def score
  @score
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1127
1128
1129
1130
1131
1132
1133
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1127

def update!(**args)
  @confidence = args[:confidence] if args.key?(:confidence)
  @flagged = args[:flagged] if args.key?(:flagged)
  @influential_terms = args[:influential_terms] if args.key?(:influential_terms)
  @rai_category = args[:rai_category] if args.key?(:rai_category)
  @score = args[:score] if args.key?(:score)
end