Class: Google::Apis::AiplatformV1::CloudAiNlLlmProtoServiceRaiSignalInfluentialTerm
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::CloudAiNlLlmProtoServiceRaiSignalInfluentialTerm
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The influential term that could potentially block the response.
Instance Attribute Summary collapse
-
#begin_offset ⇒ Fixnum
The beginning offset of the influential term.
-
#confidence ⇒ Float
The confidence score of the influential term.
-
#source ⇒ String
The source of the influential term, prompt or response.
-
#term ⇒ String
The influential term.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CloudAiNlLlmProtoServiceRaiSignalInfluentialTerm
constructor
A new instance of CloudAiNlLlmProtoServiceRaiSignalInfluentialTerm.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CloudAiNlLlmProtoServiceRaiSignalInfluentialTerm
Returns a new instance of CloudAiNlLlmProtoServiceRaiSignalInfluentialTerm.
1160 1161 1162 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1160 def initialize(**args) update!(**args) end |
Instance Attribute Details
#begin_offset ⇒ Fixnum
The beginning offset of the influential term.
Corresponds to the JSON property beginOffset
1143 1144 1145 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1143 def begin_offset @begin_offset end |
#confidence ⇒ Float
The confidence score of the influential term.
Corresponds to the JSON property confidence
1148 1149 1150 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1148 def confidence @confidence end |
#source ⇒ String
The source of the influential term, prompt or response.
Corresponds to the JSON property source
1153 1154 1155 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1153 def source @source end |
#term ⇒ String
The influential term.
Corresponds to the JSON property term
1158 1159 1160 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1158 def term @term end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1165 1166 1167 1168 1169 1170 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1165 def update!(**args) @begin_offset = args[:begin_offset] if args.key?(:begin_offset) @confidence = args[:confidence] if args.key?(:confidence) @source = args[:source] if args.key?(:source) @term = args[:term] if args.key?(:term) end |