Class: Google::Apis::AiplatformV1::CloudAiNlLlmProtoServiceSafetyRating
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::CloudAiNlLlmProtoServiceSafetyRating
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Safety rating corresponding to the generated content.
Instance Attribute Summary collapse
-
#blocked ⇒ Boolean
(also: #blocked?)
Indicates whether the content was filtered out because of this rating.
-
#category ⇒ String
Harm category.
-
#influential_terms ⇒ Array<Google::Apis::AiplatformV1::CloudAiNlLlmProtoServiceSafetyRatingInfluentialTerm>
The influential terms that could potentially block the response.
-
#probability ⇒ String
Harm probability levels in the content.
-
#probability_score ⇒ Float
Harm probability score.
-
#severity ⇒ String
Harm severity levels in the content.
-
#severity_score ⇒ Float
Harm severity score.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CloudAiNlLlmProtoServiceSafetyRating
constructor
A new instance of CloudAiNlLlmProtoServiceSafetyRating.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CloudAiNlLlmProtoServiceSafetyRating
Returns a new instance of CloudAiNlLlmProtoServiceSafetyRating.
1213 1214 1215 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1213 def initialize(**args) update!(**args) end |
Instance Attribute Details
#blocked ⇒ Boolean Also known as: blocked?
Indicates whether the content was filtered out because of this rating.
Corresponds to the JSON property blocked
1180 1181 1182 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1180 def blocked @blocked end |
#category ⇒ String
Harm category.
Corresponds to the JSON property category
1186 1187 1188 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1186 def category @category end |
#influential_terms ⇒ Array<Google::Apis::AiplatformV1::CloudAiNlLlmProtoServiceSafetyRatingInfluentialTerm>
The influential terms that could potentially block the response.
Corresponds to the JSON property influentialTerms
1191 1192 1193 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1191 def influential_terms @influential_terms end |
#probability ⇒ String
Harm probability levels in the content.
Corresponds to the JSON property probability
1196 1197 1198 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1196 def probability @probability end |
#probability_score ⇒ Float
Harm probability score.
Corresponds to the JSON property probabilityScore
1201 1202 1203 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1201 def probability_score @probability_score end |
#severity ⇒ String
Harm severity levels in the content.
Corresponds to the JSON property severity
1206 1207 1208 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1206 def severity @severity end |
#severity_score ⇒ Float
Harm severity score.
Corresponds to the JSON property severityScore
1211 1212 1213 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1211 def severity_score @severity_score end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1218 1219 1220 1221 1222 1223 1224 1225 1226 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1218 def update!(**args) @blocked = args[:blocked] if args.key?(:blocked) @category = args[:category] if args.key?(:category) @influential_terms = args[:influential_terms] if args.key?(:influential_terms) @probability = args[:probability] if args.key?(:probability) @probability_score = args[:probability_score] if args.key?(:probability_score) @severity = args[:severity] if args.key?(:severity) @severity_score = args[:severity_score] if args.key?(:severity_score) end |