Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AgentTool

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A tool provides a list of actions available to the Agent during the process of executing a task.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1AgentTool

Returns a new instance of GoogleCloudAiplatformV1AgentTool.



1362
1363
1364
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1362

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#headersHash<String,String>

Optional. The headers for the MCP server, such as for authentication. Only applicable when type is mcp_server. Corresponds to the JSON property headers

Returns:

  • (Hash<String,String>)


1342
1343
1344
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1342

def headers
  @headers
end

#nameString

Optional. The name of the MCP server. Only applicable when type is mcp_server. Corresponds to the JSON property name

Returns:

  • (String)


1348
1349
1350
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1348

def name
  @name
end

#typeString

Required. The type of the tool. Supported types: * code_execution * filesystem * google_search * mcp_server * url_context Corresponds to the JSON property type

Returns:

  • (String)


1354
1355
1356
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1354

def type
  @type
end

#urlString

Optional. The URL for the MCP server endpoint. Only applicable when type is mcp_server. Corresponds to the JSON property url

Returns:

  • (String)


1360
1361
1362
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1360

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1367
1368
1369
1370
1371
1372
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1367

def update!(**args)
  @headers = args[:headers] if args.key?(:headers)
  @name = args[:name] if args.key?(:name)
  @type = args[:type] if args.key?(:type)
  @url = args[:url] if args.key?(:url)
end