Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AssignNotebookRuntimeRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for NotebookService.AssignNotebookRuntime.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1AssignNotebookRuntimeRequest

Returns a new instance of GoogleCloudAiplatformV1AssignNotebookRuntimeRequest.



1438
1439
1440
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1438

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#notebook_runtimeGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookRuntime

A runtime is a virtual machine allocated to a particular user for a particular Notebook file on temporary basis with lifetime. Default runtimes have a lifetime of 18 hours, while custom runtimes last for 6 months from their creation or last upgrade. Corresponds to the JSON property notebookRuntime



1425
1426
1427
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1425

def notebook_runtime
  @notebook_runtime
end

#notebook_runtime_idString

Optional. User specified ID for the notebook runtime. Corresponds to the JSON property notebookRuntimeId

Returns:

  • (String)


1430
1431
1432
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1430

def notebook_runtime_id
  @notebook_runtime_id
end

#notebook_runtime_templateString

Required. The resource name of the NotebookRuntimeTemplate based on which a NotebookRuntime will be assigned (reuse or create a new one). Corresponds to the JSON property notebookRuntimeTemplate

Returns:

  • (String)


1436
1437
1438
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1436

def notebook_runtime_template
  @notebook_runtime_template
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1443
1444
1445
1446
1447
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1443

def update!(**args)
  @notebook_runtime = args[:notebook_runtime] if args.key?(:notebook_runtime)
  @notebook_runtime_id = args[:notebook_runtime_id] if args.key?(:notebook_runtime_id)
  @notebook_runtime_template = args[:notebook_runtime_template] if args.key?(:notebook_runtime_template)
end