Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AudioTranscriptionWordInfo
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AudioTranscriptionWordInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Information about a single recognized word.
Instance Attribute Summary collapse
-
#end_offset ⇒ String
Optional.
-
#start_offset ⇒ String
Optional.
-
#word ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1AudioTranscriptionWordInfo
constructor
A new instance of GoogleCloudAiplatformV1AudioTranscriptionWordInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1AudioTranscriptionWordInfo
Returns a new instance of GoogleCloudAiplatformV1AudioTranscriptionWordInfo.
2272 2273 2274 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2272 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_offset ⇒ String
Optional. End offset in time of the word relative to the start of the audio.
Corresponds to the JSON property endOffset
2260 2261 2262 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2260 def end_offset @end_offset end |
#start_offset ⇒ String
Optional. Start offset in time of the word relative to the start of the audio.
Corresponds to the JSON property startOffset
2265 2266 2267 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2265 def start_offset @start_offset end |
#word ⇒ String
Required. Transcript of the word.
Corresponds to the JSON property word
2270 2271 2272 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2270 def word @word end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2277 2278 2279 2280 2281 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2277 def update!(**args) @end_offset = args[:end_offset] if args.key?(:end_offset) @start_offset = args[:start_offset] if args.key?(:start_offset) @word = args[:word] if args.key?(:word) end |