Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AuthConfigGoogleServiceAccountConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Config for Google Service Account Authentication.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1AuthConfigGoogleServiceAccountConfig

Returns a new instance of GoogleCloudAiplatformV1AuthConfigGoogleServiceAccountConfig.



1376
1377
1378
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1376

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#service_accountString

Optional. The service account that the extension execution service runs as. - If the service account is specified, the iam.serviceAccounts.getAccessToken permission should be granted to Vertex AI Extension Service Agent (https:// cloud.google.com/vertex-ai/docs/general/access-control#service-agents) on the specified service account. - If not specified, the Vertex AI Extension Service Agent will be used to execute the Extension. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


1374
1375
1376
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1374

def 
  @service_account
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1381
1382
1383
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1381

def update!(**args)
  @service_account = args[:service_account] if args.key?(:service_account)
end