Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchCreateFeaturesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for FeaturestoreService.BatchCreateFeatures.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1BatchCreateFeaturesRequest

Returns a new instance of GoogleCloudAiplatformV1BatchCreateFeaturesRequest.



1174
1175
1176
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1174

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#requestsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CreateFeatureRequest>

Required. The request message specifying the Features to create. All Features must be created under the same parent EntityType. The parent field in each child request message can be omitted. If parent is set in a child request, then the value must match the parent value in this request message. Corresponds to the JSON property requests



1172
1173
1174
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1172

def requests
  @requests
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1179
1180
1181
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1179

def update!(**args)
  @requests = args[:requests] if args.key?(:requests)
end