Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchDedicatedResources

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A description of resources that are used for performing batch operations, are dedicated to a Model, and need manual configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1BatchDedicatedResources

Returns a new instance of GoogleCloudAiplatformV1BatchDedicatedResources.



2228
2229
2230
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2228

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#machine_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1MachineSpec

Specification of a single machine. Corresponds to the JSON property machineSpec



2213
2214
2215
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2213

def machine_spec
  @machine_spec
end

#max_replica_countFixnum

Immutable. The maximum number of machine replicas the batch operation may be scaled to. The default value is 10. Corresponds to the JSON property maxReplicaCount

Returns:

  • (Fixnum)


2219
2220
2221
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2219

def max_replica_count
  @max_replica_count
end

#starting_replica_countFixnum

Immutable. The number of machine replicas used at the start of the batch operation. If not set, Vertex AI decides starting number, not greater than max_replica_count Corresponds to the JSON property startingReplicaCount

Returns:

  • (Fixnum)


2226
2227
2228
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2226

def starting_replica_count
  @starting_replica_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2233
2234
2235
2236
2237
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2233

def update!(**args)
  @machine_spec = args[:machine_spec] if args.key?(:machine_spec)
  @max_replica_count = args[:max_replica_count] if args.key?(:max_replica_count)
  @starting_replica_count = args[:starting_replica_count] if args.key?(:starting_replica_count)
end