Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchMigrateResourcesOperationMetadataPartialResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents a partial result in batch migration operation for one MigrateResourceRequest.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1BatchMigrateResourcesOperationMetadataPartialResult

Returns a new instance of GoogleCloudAiplatformV1BatchMigrateResourcesOperationMetadataPartialResult.



3307
3308
3309
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3307

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#datasetString

Migrated dataset resource name. Corresponds to the JSON property dataset

Returns:

  • (String)


3284
3285
3286
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3284

def dataset
  @dataset
end

#errorGoogle::Apis::AiplatformV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



3294
3295
3296
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3294

def error
  @error
end

#modelString

Migrated model resource name. Corresponds to the JSON property model

Returns:

  • (String)


3299
3300
3301
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3299

def model
  @model
end

#requestGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1MigrateResourceRequest

Config of migrating one resource from automl.googleapis.com, datalabeling. googleapis.com and ml.googleapis.com to Vertex AI. Corresponds to the JSON property request



3305
3306
3307
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3305

def request
  @request
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3312
3313
3314
3315
3316
3317
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3312

def update!(**args)
  @dataset = args[:dataset] if args.key?(:dataset)
  @error = args[:error] if args.key?(:error)
  @model = args[:model] if args.key?(:model)
  @request = args[:request] if args.key?(:request)
end