Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CandidateResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Responses from model or agent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1CandidateResponse

Returns a new instance of GoogleCloudAiplatformV1CandidateResponse.



4722
4723
4724
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4722

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_dataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1AgentData

Represents data specific to multi-turn agent evaluations. Corresponds to the JSON property agentData



4695
4696
4697
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4695

def agent_data
  @agent_data
end

#candidateString

Required. The name of the candidate that produced the response. Corresponds to the JSON property candidate

Returns:

  • (String)


4700
4701
4702
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4700

def candidate
  @candidate
end

#errorGoogle::Apis::AiplatformV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



4710
4711
4712
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4710

def error
  @error
end

#textString

Text response. Corresponds to the JSON property text

Returns:

  • (String)


4715
4716
4717
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4715

def text
  @text
end

#valueObject

Fields and values that can be used to populate the response template. Corresponds to the JSON property value

Returns:

  • (Object)


4720
4721
4722
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4720

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4727
4728
4729
4730
4731
4732
4733
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4727

def update!(**args)
  @agent_data = args[:agent_data] if args.key?(:agent_data)
  @candidate = args[:candidate] if args.key?(:candidate)
  @error = args[:error] if args.key?(:error)
  @text = args[:text] if args.key?(:text)
  @value = args[:value] if args.key?(:value)
end