Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CandidateResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Result for a single candidate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1CandidateResult

Returns a new instance of GoogleCloudAiplatformV1CandidateResult.



4781
4782
4783
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4781

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_resultsObject

Optional. Additional results for the metric. Corresponds to the JSON property additionalResults

Returns:

  • (Object)


4743
4744
4745
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4743

def additional_results
  @additional_results
end

#candidateString

Required. The candidate that is being evaluated. The value is the same as the candidate name in the EvaluationRequest. Corresponds to the JSON property candidate

Returns:

  • (String)


4749
4750
4751
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4749

def candidate
  @candidate
end

#errorGoogle::Apis::AiplatformV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



4759
4760
4761
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4759

def error
  @error
end

#explanationString

Optional. The explanation for the metric. Corresponds to the JSON property explanation

Returns:

  • (String)


4764
4765
4766
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4764

def explanation
  @explanation
end

#metricString

Required. The metric that was evaluated. Corresponds to the JSON property metric

Returns:

  • (String)


4769
4770
4771
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4769

def metric
  @metric
end

#rubric_verdictsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricVerdict>

Optional. The rubric verdicts for the metric. Corresponds to the JSON property rubricVerdicts



4774
4775
4776
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4774

def rubric_verdicts
  @rubric_verdicts
end

#scoreFloat

Optional. The score for the metric. Corresponds to the JSON property score

Returns:

  • (Float)


4779
4780
4781
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4779

def score
  @score
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4786
4787
4788
4789
4790
4791
4792
4793
4794
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4786

def update!(**args)
  @additional_results = args[:additional_results] if args.key?(:additional_results)
  @candidate = args[:candidate] if args.key?(:candidate)
  @error = args[:error] if args.key?(:error)
  @explanation = args[:explanation] if args.key?(:explanation)
  @metric = args[:metric] if args.key?(:metric)
  @rubric_verdicts = args[:rubric_verdicts] if args.key?(:rubric_verdicts)
  @score = args[:score] if args.key?(:score)
end