Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Claim

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Claim that is extracted from the input text and facts that support it.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Claim

Returns a new instance of GoogleCloudAiplatformV1Claim.



4544
4545
4546
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4544

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_indexFixnum

Index in the input text where the claim ends (exclusive). Corresponds to the JSON property endIndex

Returns:

  • (Fixnum)


4527
4528
4529
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4527

def end_index
  @end_index
end

#fact_indexesArray<Fixnum>

Indexes of the facts supporting this claim. Corresponds to the JSON property factIndexes

Returns:

  • (Array<Fixnum>)


4532
4533
4534
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4532

def fact_indexes
  @fact_indexes
end

#scoreFloat

Confidence score of this corroboration. Corresponds to the JSON property score

Returns:

  • (Float)


4537
4538
4539
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4537

def score
  @score
end

#start_indexFixnum

Index in the input text where the claim starts (inclusive). Corresponds to the JSON property startIndex

Returns:

  • (Fixnum)


4542
4543
4544
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4542

def start_index
  @start_index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4549
4550
4551
4552
4553
4554
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4549

def update!(**args)
  @end_index = args[:end_index] if args.key?(:end_index)
  @fact_indexes = args[:fact_indexes] if args.key?(:fact_indexes)
  @score = args[:score] if args.key?(:score)
  @start_index = args[:start_index] if args.key?(:start_index)
end