Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CloudLoggingConfigTracingContext
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CloudLoggingConfigTracingContext
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Tracing context for Observability correlation.
Instance Attribute Summary collapse
-
#conversation_id ⇒ String
Optional.
-
#span_id ⇒ String
Optional.
-
#trace_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1CloudLoggingConfigTracingContext
constructor
A new instance of GoogleCloudAiplatformV1CloudLoggingConfigTracingContext.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1CloudLoggingConfigTracingContext
Returns a new instance of GoogleCloudAiplatformV1CloudLoggingConfigTracingContext.
4640 4641 4642 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4640 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversation_id ⇒ String
Optional. Unique identifier for a conversation (session thread), used to store
and correlate messages within a conversation. The value corresponds to the
gen_ai.conversation.id field in the the OpenTelemetry GenAI attributes.
Corresponds to the JSON property conversationId
4624 4625 4626 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4624 def conversation_id @conversation_id end |
#span_id ⇒ String
Optional. ID of the Cloud Trace span associated with the current operation in
which the log is being written. e.g., 7a2190356c3fc94b. If a span is being
evaluated, this field should be populated.
Corresponds to the JSON property spanId
4631 4632 4633 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4631 def span_id @span_id end |
#trace_id ⇒ String
Optional. Trace ID being written to Cloud Trace in association with this log
entry. e.g., 12345, the numeric ID from the resource name. If a trace or
span is being evaluated, this field should be populated.
Corresponds to the JSON property traceId
4638 4639 4640 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4638 def trace_id @trace_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4645 4646 4647 4648 4649 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4645 def update!(**args) @conversation_id = args[:conversation_id] if args.key?(:conversation_id) @span_id = args[:span_id] if args.key?(:span_id) @trace_id = args[:trace_id] if args.key?(:trace_id) end |