Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CodeExecutionResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Result of executing the [ExecutableCode]. Only generated when using the [ CodeExecution] tool, and always follows a part containing the [ ExecutableCode].

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1CodeExecutionResult

Returns a new instance of GoogleCloudAiplatformV1CodeExecutionResult.



3419
3420
3421
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3419

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#outcomeString

Required. Outcome of the code execution. Corresponds to the JSON property outcome

Returns:

  • (String)


3411
3412
3413
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3411

def outcome
  @outcome
end

#outputString

Optional. Contains stdout when code execution is successful, stderr or other description otherwise. Corresponds to the JSON property output

Returns:

  • (String)


3417
3418
3419
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3417

def output
  @output
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3424
3425
3426
3427
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3424

def update!(**args)
  @outcome = args[:outcome] if args.key?(:outcome)
  @output = args[:output] if args.key?(:output)
end