Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The structured data content of a message. A Content message contains a role
field, which indicates the producer of the content, and a parts field, which
contains the multi-part data of the message.
Instance Attribute Summary collapse
-
#parts ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Part>
Required.
-
#role ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Content
constructor
A new instance of GoogleCloudAiplatformV1Content.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Content
Returns a new instance of GoogleCloudAiplatformV1Content.
5743 5744 5745 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5743 def initialize(**args) update!(**args) end |
Instance Attribute Details
#parts ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Part>
Required. A list of Part objects that make up a single message. Parts of a
message can have different MIME types. A Content message must have at least
one Part.
Corresponds to the JSON property parts
5735 5736 5737 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5735 def parts @parts end |
#role ⇒ String
Optional. The producer of the content. Must be either 'user' or 'model'. If
not set, the service will default to 'user'.
Corresponds to the JSON property role
5741 5742 5743 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5741 def role @role end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5748 5749 5750 5751 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5748 def update!(**args) @parts = args[:parts] if args.key?(:parts) @role = args[:role] if args.key?(:role) end |