Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ConversationTurn

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents a single turn/invocation in the conversation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ConversationTurn

Returns a new instance of GoogleCloudAiplatformV1ConversationTurn.



5313
5314
5315
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5313

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#eventsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AgentEvent>

Optional. The list of events that occurred during this turn. Corresponds to the JSON property events



5300
5301
5302
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5300

def events
  @events
end

#turn_idString

Optional. A unique identifier for the turn. Useful for referencing specific turns across systems. Corresponds to the JSON property turnId

Returns:

  • (String)


5306
5307
5308
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5306

def turn_id
  @turn_id
end

#turn_indexFixnum

Required. The 0-based index of the turn in the conversation sequence. Corresponds to the JSON property turnIndex

Returns:

  • (Fixnum)


5311
5312
5313
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5311

def turn_index
  @turn_index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5318
5319
5320
5321
5322
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5318

def update!(**args)
  @events = args[:events] if args.key?(:events)
  @turn_id = args[:turn_id] if args.key?(:turn_id)
  @turn_index = args[:turn_index] if args.key?(:turn_index)
end