Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CountTokensResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Response message for PredictionService.CountTokens.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1CountTokensResponse

Returns a new instance of GoogleCloudAiplatformV1CountTokensResponse.



4957
4958
4959
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4957

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#prompt_tokens_detailsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModalityTokenCount>

Output only. List of modalities that were processed in the request input. Corresponds to the JSON property promptTokensDetails



4944
4945
4946
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4944

def prompt_tokens_details
  @prompt_tokens_details
end

#total_billable_charactersFixnum

The total number of billable characters counted across all instances from the request. Corresponds to the JSON property totalBillableCharacters

Returns:

  • (Fixnum)


4950
4951
4952
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4950

def total_billable_characters
  @total_billable_characters
end

#total_tokensFixnum

The total number of tokens counted across all instances from the request. Corresponds to the JSON property totalTokens

Returns:

  • (Fixnum)


4955
4956
4957
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4955

def total_tokens
  @total_tokens
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4962
4963
4964
4965
4966
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4962

def update!(**args)
  @prompt_tokens_details = args[:prompt_tokens_details] if args.key?(:prompt_tokens_details)
  @total_billable_characters = args[:total_billable_characters] if args.key?(:total_billable_characters)
  @total_tokens = args[:total_tokens] if args.key?(:total_tokens)
end