Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CreatePipelineJobRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for PipelineService.CreatePipelineJob.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1CreatePipelineJobRequest

Returns a new instance of GoogleCloudAiplatformV1CreatePipelineJobRequest.



6685
6686
6687
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6685

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#parentString

Required. The resource name of the Location to create the PipelineJob in. Format: projects/project/locations/location` Corresponds to the JSON propertyparent`

Returns:

  • (String)


6670
6671
6672
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6670

def parent
  @parent
end

#pipeline_jobGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineJob

An instance of a machine learning PipelineJob. Corresponds to the JSON property pipelineJob



6675
6676
6677
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6675

def pipeline_job
  @pipeline_job
end

#pipeline_job_idString

The ID to use for the PipelineJob, which will become the final component of the PipelineJob name. If not provided, an ID will be automatically generated. This value should be less than 128 characters, and valid characters are /a-z-/ . Corresponds to the JSON property pipelineJobId

Returns:

  • (String)


6683
6684
6685
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6683

def pipeline_job_id
  @pipeline_job_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6690
6691
6692
6693
6694
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6690

def update!(**args)
  @parent = args[:parent] if args.key?(:parent)
  @pipeline_job = args[:pipeline_job] if args.key?(:pipeline_job)
  @pipeline_job_id = args[:pipeline_job_id] if args.key?(:pipeline_job_id)
end