Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CreateTensorboardRunRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for TensorboardService.CreateTensorboardRun.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1CreateTensorboardRunRequest

Returns a new instance of GoogleCloudAiplatformV1CreateTensorboardRunRequest.



5722
5723
5724
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5722

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#parentString

Required. The resource name of the TensorboardExperiment to create the TensorboardRun in. Format: projects/project/locations/location/ tensorboards/tensorboard/experiments/experiment` Corresponds to the JSON propertyparent`

Returns:

  • (String)


5707
5708
5709
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5707

def parent
  @parent
end

#tensorboard_runGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardRun

TensorboardRun maps to a specific execution of a training job with a given set of hyperparameter values, model definition, dataset, etc Corresponds to the JSON property tensorboardRun



5713
5714
5715
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5713

def tensorboard_run
  @tensorboard_run
end

#tensorboard_run_idString

Required. The ID to use for the Tensorboard run, which becomes the final component of the Tensorboard run's resource name. This value should be 1-128 characters, and valid characters are /a-z-/. Corresponds to the JSON property tensorboardRunId

Returns:

  • (String)


5720
5721
5722
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5720

def tensorboard_run_id
  @tensorboard_run_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5727
5728
5729
5730
5731
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5727

def update!(**args)
  @parent = args[:parent] if args.key?(:parent)
  @tensorboard_run = args[:tensorboard_run] if args.key?(:tensorboard_run)
  @tensorboard_run_id = args[:tensorboard_run_id] if args.key?(:tensorboard_run_id)
end