Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeleteFeatureValuesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for FeaturestoreService.DeleteFeatureValues.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1DeleteFeatureValuesRequest

Returns a new instance of GoogleCloudAiplatformV1DeleteFeatureValuesRequest.



7974
7975
7976
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7974

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#select_entityGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1DeleteFeatureValuesRequestSelectEntity

Message to select entity. If an entity id is selected, all the feature values corresponding to the entity id will be deleted, including the entityId. Corresponds to the JSON property selectEntity



7962
7963
7964
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7962

def select_entity
  @select_entity
end

#select_time_range_and_featureGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1DeleteFeatureValuesRequestSelectTimeRangeAndFeature

Message to select time range and feature. Values of the selected feature generated within an inclusive time range will be deleted. Using this option permanently deletes the feature values from the specified feature IDs within the specified time range. This might include data from the online storage. If you want to retain any deleted historical data in the online storage, you must re-ingest it. Corresponds to the JSON property selectTimeRangeAndFeature



7972
7973
7974
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7972

def select_time_range_and_feature
  @select_time_range_and_feature
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7979
7980
7981
7982
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7979

def update!(**args)
  @select_entity = args[:select_entity] if args.key?(:select_entity)
  @select_time_range_and_feature = args[:select_time_range_and_feature] if args.key?(:select_time_range_and_feature)
end