Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeleteFeatureValuesRequestSelectTimeRangeAndFeature

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Message to select time range and feature. Values of the selected feature generated within an inclusive time range will be deleted. Using this option permanently deletes the feature values from the specified feature IDs within the specified time range. This might include data from the online storage. If you want to retain any deleted historical data in the online storage, you must re-ingest it.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1DeleteFeatureValuesRequestSelectTimeRangeAndFeature

Returns a new instance of GoogleCloudAiplatformV1DeleteFeatureValuesRequestSelectTimeRangeAndFeature.



8035
8036
8037
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8035

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#feature_selectorGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureSelector

Selector for Features of an EntityType. Corresponds to the JSON property featureSelector



8017
8018
8019
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8017

def feature_selector
  @feature_selector
end

#skip_online_storage_deleteBoolean Also known as: skip_online_storage_delete?

If set, data will not be deleted from online storage. When time range is older than the data in online storage, setting this to be true will make the deletion have no impact on online serving. Corresponds to the JSON property skipOnlineStorageDelete

Returns:

  • (Boolean)


8024
8025
8026
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8024

def skip_online_storage_delete
  @skip_online_storage_delete
end

#time_rangeGoogle::Apis::AiplatformV1::GoogleTypeInterval

Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive). The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time. Corresponds to the JSON property timeRange



8033
8034
8035
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8033

def time_range
  @time_range
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8040
8041
8042
8043
8044
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8040

def update!(**args)
  @feature_selector = args[:feature_selector] if args.key?(:feature_selector)
  @skip_online_storage_delete = args[:skip_online_storage_delete] if args.key?(:skip_online_storage_delete)
  @time_range = args[:time_range] if args.key?(:time_range)
end