Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeleteFeatureValuesResponseSelectEntity

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Response message if the request uses the SelectEntity option.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1DeleteFeatureValuesResponseSelectEntity

Returns a new instance of GoogleCloudAiplatformV1DeleteFeatureValuesResponseSelectEntity.



4330
4331
4332
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4330

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#offline_storage_deleted_entity_row_countFixnum

The count of deleted entity rows in the offline storage. Each row corresponds to the combination of an entity ID and a timestamp. One entity ID can have multiple rows in the offline storage. Corresponds to the JSON property offlineStorageDeletedEntityRowCount

Returns:

  • (Fixnum)


4322
4323
4324
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4322

def offline_storage_deleted_entity_row_count
  @offline_storage_deleted_entity_row_count
end

#online_storage_deleted_entity_countFixnum

The count of deleted entities in the online storage. Each entity ID corresponds to one entity. Corresponds to the JSON property onlineStorageDeletedEntityCount

Returns:

  • (Fixnum)


4328
4329
4330
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4328

def online_storage_deleted_entity_count
  @online_storage_deleted_entity_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4335
4336
4337
4338
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4335

def update!(**args)
  @offline_storage_deleted_entity_row_count = args[:offline_storage_deleted_entity_row_count] if args.key?(:offline_storage_deleted_entity_row_count)
  @online_storage_deleted_entity_count = args[:online_storage_deleted_entity_count] if args.key?(:online_storage_deleted_entity_count)
end