Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployRequestDeployConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The deploy config to use for the deployment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1DeployRequestDeployConfig

Returns a new instance of GoogleCloudAiplatformV1DeployRequestDeployConfig.



6782
6783
6784
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6782

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dedicated_resourcesGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1DedicatedResources

A description of resources that are dedicated to a DeployedModel or DeployedIndex, and that need a higher degree of manual configuration. Corresponds to the JSON property dedicatedResources



6767
6768
6769
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6767

def dedicated_resources
  @dedicated_resources
end

#fast_tryout_enabledBoolean Also known as: fast_tryout_enabled?

Optional. If true, enable the QMT fast tryout feature for this model if possible. Corresponds to the JSON property fastTryoutEnabled

Returns:

  • (Boolean)


6773
6774
6775
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6773

def fast_tryout_enabled
  @fast_tryout_enabled
end

#system_labelsHash<String,String>

Optional. System labels for Model Garden deployments. These labels are managed by Google and for tracking purposes only. Corresponds to the JSON property systemLabels

Returns:

  • (Hash<String,String>)


6780
6781
6782
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6780

def system_labels
  @system_labels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6787
6788
6789
6790
6791
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6787

def update!(**args)
  @dedicated_resources = args[:dedicated_resources] if args.key?(:dedicated_resources)
  @fast_tryout_enabled = args[:fast_tryout_enabled] if args.key?(:fast_tryout_enabled)
  @system_labels = args[:system_labels] if args.key?(:system_labels)
end