Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployedIndexAuthConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Used to set up the auth on the DeployedIndex's private endpoint.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1DeployedIndexAuthConfig

Returns a new instance of GoogleCloudAiplatformV1DeployedIndexAuthConfig.



8198
8199
8200
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8198

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auth_providerGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployedIndexAuthConfigAuthProvider

Configuration for an authentication provider, including support for JSON Web Token (JWT). Corresponds to the JSON property authProvider



8196
8197
8198
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8196

def auth_provider
  @auth_provider
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8203
8204
8205
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8203

def update!(**args)
  @auth_provider = args[:auth_provider] if args.key?(:auth_provider)
end