Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployedModelStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Runtime status of the deployed model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1DeployedModelStatus

Returns a new instance of GoogleCloudAiplatformV1DeployedModelStatus.



9083
9084
9085
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9083

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#available_replica_countFixnum

Output only. The number of available replicas of the deployed model. Corresponds to the JSON property availableReplicaCount

Returns:

  • (Fixnum)


9071
9072
9073
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9071

def available_replica_count
  @available_replica_count
end

#last_update_timeString

Output only. The time at which the status was last updated. Corresponds to the JSON property lastUpdateTime

Returns:

  • (String)


9076
9077
9078
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9076

def last_update_time
  @last_update_time
end

#messageString

Output only. The latest deployed model's status message (if any). Corresponds to the JSON property message

Returns:

  • (String)


9081
9082
9083
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9081

def message
  @message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9088
9089
9090
9091
9092
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9088

def update!(**args)
  @available_replica_count = args[:available_replica_count] if args.key?(:available_replica_count)
  @last_update_time = args[:last_update_time] if args.key?(:last_update_time)
  @message = args[:message] if args.key?(:message)
end