Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DynamicRetrievalConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Describes the options to customize dynamic retrieval.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1DynamicRetrievalConfig

Returns a new instance of GoogleCloudAiplatformV1DynamicRetrievalConfig.



8204
8205
8206
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8204

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dynamic_thresholdFloat

Optional. The threshold to be used in dynamic retrieval. If not set, a system default value is used. Corresponds to the JSON property dynamicThreshold

Returns:

  • (Float)


8197
8198
8199
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8197

def dynamic_threshold
  @dynamic_threshold
end

#modeString

The mode of the predictor to be used in dynamic retrieval. Corresponds to the JSON property mode

Returns:

  • (String)


8202
8203
8204
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8202

def mode
  @mode
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8209
8210
8211
8212
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8209

def update!(**args)
  @dynamic_threshold = args[:dynamic_threshold] if args.key?(:dynamic_threshold)
  @mode = args[:mode] if args.key?(:mode)
end