Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ErrorAnalysisAnnotation
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ErrorAnalysisAnnotation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Model error analysis for each annotation.
Instance Attribute Summary collapse
-
#attributed_items ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ErrorAnalysisAnnotationAttributedItem>
Attributed items for a given annotation, typically representing neighbors from the training sets constrained by the query type.
-
#outlier_score ⇒ Float
The outlier score of this annotated item.
-
#outlier_threshold ⇒ Float
The threshold used to determine if this annotation is an outlier or not.
-
#query_type ⇒ String
The query type used for finding the attributed items.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ErrorAnalysisAnnotation
constructor
A new instance of GoogleCloudAiplatformV1ErrorAnalysisAnnotation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ErrorAnalysisAnnotation
Returns a new instance of GoogleCloudAiplatformV1ErrorAnalysisAnnotation.
10018 10019 10020 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10018 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attributed_items ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ErrorAnalysisAnnotationAttributedItem>
Attributed items for a given annotation, typically representing neighbors from
the training sets constrained by the query type.
Corresponds to the JSON property attributedItems
10000 10001 10002 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10000 def attributed_items @attributed_items end |
#outlier_score ⇒ Float
The outlier score of this annotated item. Usually defined as the min of all
distances from attributed items.
Corresponds to the JSON property outlierScore
10006 10007 10008 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10006 def outlier_score @outlier_score end |
#outlier_threshold ⇒ Float
The threshold used to determine if this annotation is an outlier or not.
Corresponds to the JSON property outlierThreshold
10011 10012 10013 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10011 def outlier_threshold @outlier_threshold end |
#query_type ⇒ String
The query type used for finding the attributed items.
Corresponds to the JSON property queryType
10016 10017 10018 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10016 def query_type @query_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10023 10024 10025 10026 10027 10028 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10023 def update!(**args) @attributed_items = args[:attributed_items] if args.key?(:attributed_items) @outlier_score = args[:outlier_score] if args.key?(:outlier_score) @outlier_threshold = args[:outlier_threshold] if args.key?(:outlier_threshold) @query_type = args[:query_type] if args.key?(:query_type) end |