Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ErrorAnalysisAnnotationAttributedItem

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Attributed items for a given annotation, typically representing neighbors from the training sets constrained by the query type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ErrorAnalysisAnnotationAttributedItem

Returns a new instance of GoogleCloudAiplatformV1ErrorAnalysisAnnotationAttributedItem.



10046
10047
10048
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10046

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotation_resource_nameString

The unique ID for each annotation. Used by FE to allocate the annotation in DB. Corresponds to the JSON property annotationResourceName

Returns:

  • (String)


10039
10040
10041
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10039

def annotation_resource_name
  @annotation_resource_name
end

#distanceFloat

The distance of this item to the annotation. Corresponds to the JSON property distance

Returns:

  • (Float)


10044
10045
10046
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10044

def distance
  @distance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10051
10052
10053
10054
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10051

def update!(**args)
  @annotation_resource_name = args[:annotation_resource_name] if args.key?(:annotation_resource_name)
  @distance = args[:distance] if args.key?(:distance)
end