Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluateDatasetResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluateDatasetResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The results from an evaluation run performed by the EvaluationService.
Instance Attribute Summary collapse
-
#aggregation_output ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AggregationOutput
The aggregation result for the entire dataset and all metrics.
-
#output_info ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1OutputInfo
Describes the info for output of EvaluationService.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluateDatasetResponse
constructor
A new instance of GoogleCloudAiplatformV1EvaluateDatasetResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluateDatasetResponse
Returns a new instance of GoogleCloudAiplatformV1EvaluateDatasetResponse.
9310 9311 9312 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9310 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aggregation_output ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AggregationOutput
The aggregation result for the entire dataset and all metrics.
Corresponds to the JSON property aggregationOutput
9303 9304 9305 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9303 def aggregation_output @aggregation_output end |
#output_info ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1OutputInfo
Describes the info for output of EvaluationService.
Corresponds to the JSON property outputInfo
9308 9309 9310 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9308 def output_info @output_info end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9315 9316 9317 9318 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9315 def update!(**args) @aggregation_output = args[:aggregation_output] if args.key?(:aggregation_output) @output_info = args[:output_info] if args.key?(:output_info) end |