Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluateInstancesRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluateInstancesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Request message for EvaluationService.EvaluateInstances.
Instance Attribute Summary collapse
-
#autorater_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AutoraterConfig
The configs for autorater.
-
#bleu_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BleuInput
Input for bleu metric.
-
#coherence_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CoherenceInput
Input for coherence metric.
-
#comet_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CometInput
Input for Comet metric.
-
#exact_match_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExactMatchInput
Input for exact match metric.
-
#fluency_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FluencyInput
Input for fluency metric.
-
#fulfillment_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FulfillmentInput
Input for fulfillment metric.
-
#groundedness_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundednessInput
Input for groundedness metric.
-
#instance ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstance
A single instance to be evaluated.
-
#location ⇒ String
Required.
-
#metrics ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Metric>
The metrics used for evaluation.
-
#metricx_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetricxInput
Input for MetricX metric.
-
#pairwise_metric_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PairwiseMetricInput
Input for pairwise metric.
-
#pairwise_question_answering_quality_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PairwiseQuestionAnsweringQualityInput
Input for pairwise question answering quality metric.
-
#pairwise_summarization_quality_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PairwiseSummarizationQualityInput
Input for pairwise summarization quality metric.
-
#pointwise_metric_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PointwiseMetricInput
Input for pointwise metric.
-
#question_answering_correctness_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringCorrectnessInput
Input for question answering correctness metric.
-
#question_answering_helpfulness_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringHelpfulnessInput
Input for question answering helpfulness metric.
-
#question_answering_quality_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringQualityInput
Input for question answering quality metric.
-
#question_answering_relevance_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringRelevanceInput
Input for question answering relevance metric.
-
#rouge_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RougeInput
Input for rouge metric.
-
#rubric_based_instruction_following_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricBasedInstructionFollowingInput
Instance and metric spec for RubricBasedInstructionFollowing metric.
-
#safety_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetyInput
Input for safety metric.
-
#summarization_helpfulness_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SummarizationHelpfulnessInput
Input for summarization helpfulness metric.
-
#summarization_quality_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SummarizationQualityInput
Input for summarization quality metric.
-
#summarization_verbosity_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SummarizationVerbosityInput
Input for summarization verbosity metric.
-
#tool_call_valid_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolCallValidInput
Input for tool call valid metric.
-
#tool_name_match_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolNameMatchInput
Input for tool name match metric.
-
#tool_parameter_key_match_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolParameterKeyMatchInput
Input for tool parameter key match metric.
-
#tool_parameter_kv_match_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolParameterKvMatchInput
Input for tool parameter key value match metric.
-
#trajectory_any_order_match_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryAnyOrderMatchInput
Instances and metric spec for TrajectoryAnyOrderMatch metric.
-
#trajectory_exact_match_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryExactMatchInput
Instances and metric spec for TrajectoryExactMatch metric.
-
#trajectory_in_order_match_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryInOrderMatchInput
Instances and metric spec for TrajectoryInOrderMatch metric.
-
#trajectory_precision_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryPrecisionInput
Instances and metric spec for TrajectoryPrecision metric.
-
#trajectory_recall_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryRecallInput
Instances and metric spec for TrajectoryRecall metric.
-
#trajectory_single_tool_use_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectorySingleToolUseInput
Instances and metric spec for TrajectorySingleToolUse metric.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluateInstancesRequest
constructor
A new instance of GoogleCloudAiplatformV1EvaluateInstancesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluateInstancesRequest
Returns a new instance of GoogleCloudAiplatformV1EvaluateInstancesRequest.
8591 8592 8593 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8591 def initialize(**args) update!(**args) end |
Instance Attribute Details
#autorater_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AutoraterConfig
The configs for autorater. This is applicable to both EvaluateInstances and
EvaluateDataset.
Corresponds to the JSON property autoraterConfig
8409 8410 8411 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8409 def autorater_config @autorater_config end |
#bleu_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BleuInput
Input for bleu metric.
Corresponds to the JSON property bleuInput
8414 8415 8416 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8414 def bleu_input @bleu_input end |
#coherence_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CoherenceInput
Input for coherence metric.
Corresponds to the JSON property coherenceInput
8419 8420 8421 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8419 def coherence_input @coherence_input end |
#comet_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CometInput
Input for Comet metric.
Corresponds to the JSON property cometInput
8424 8425 8426 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8424 def comet_input @comet_input end |
#exact_match_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExactMatchInput
Input for exact match metric.
Corresponds to the JSON property exactMatchInput
8429 8430 8431 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8429 def exact_match_input @exact_match_input end |
#fluency_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FluencyInput
Input for fluency metric.
Corresponds to the JSON property fluencyInput
8434 8435 8436 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8434 def fluency_input @fluency_input end |
#fulfillment_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FulfillmentInput
Input for fulfillment metric.
Corresponds to the JSON property fulfillmentInput
8439 8440 8441 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8439 def fulfillment_input @fulfillment_input end |
#groundedness_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundednessInput
Input for groundedness metric.
Corresponds to the JSON property groundednessInput
8444 8445 8446 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8444 def groundedness_input @groundedness_input end |
#instance ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstance
A single instance to be evaluated. Instances are used to specify the input
data for evaluation, from simple string comparisons to complex, multi-turn
model evaluations
Corresponds to the JSON property instance
8451 8452 8453 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8451 def instance @instance end |
#location ⇒ String
Required. The resource name of the Location to evaluate the instances. Format:
projects/project/locations/location`
Corresponds to the JSON propertylocation`
8457 8458 8459 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8457 def location @location end |
#metrics ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Metric>
The metrics used for evaluation. Currently, we only support evaluating a
single metric. If multiple metrics are provided, only the first one will be
evaluated.
Corresponds to the JSON property metrics
8464 8465 8466 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8464 def metrics @metrics end |
#metricx_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetricxInput
Input for MetricX metric.
Corresponds to the JSON property metricxInput
8469 8470 8471 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8469 def metricx_input @metricx_input end |
#pairwise_metric_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PairwiseMetricInput
Input for pairwise metric.
Corresponds to the JSON property pairwiseMetricInput
8474 8475 8476 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8474 def pairwise_metric_input @pairwise_metric_input end |
#pairwise_question_answering_quality_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PairwiseQuestionAnsweringQualityInput
Input for pairwise question answering quality metric.
Corresponds to the JSON property pairwiseQuestionAnsweringQualityInput
8479 8480 8481 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8479 def pairwise_question_answering_quality_input @pairwise_question_answering_quality_input end |
#pairwise_summarization_quality_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PairwiseSummarizationQualityInput
Input for pairwise summarization quality metric.
Corresponds to the JSON property pairwiseSummarizationQualityInput
8484 8485 8486 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8484 def pairwise_summarization_quality_input @pairwise_summarization_quality_input end |
#pointwise_metric_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PointwiseMetricInput
Input for pointwise metric.
Corresponds to the JSON property pointwiseMetricInput
8489 8490 8491 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8489 def pointwise_metric_input @pointwise_metric_input end |
#question_answering_correctness_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringCorrectnessInput
Input for question answering correctness metric.
Corresponds to the JSON property questionAnsweringCorrectnessInput
8494 8495 8496 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8494 def question_answering_correctness_input @question_answering_correctness_input end |
#question_answering_helpfulness_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringHelpfulnessInput
Input for question answering helpfulness metric.
Corresponds to the JSON property questionAnsweringHelpfulnessInput
8499 8500 8501 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8499 def question_answering_helpfulness_input @question_answering_helpfulness_input end |
#question_answering_quality_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringQualityInput
Input for question answering quality metric.
Corresponds to the JSON property questionAnsweringQualityInput
8504 8505 8506 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8504 def question_answering_quality_input @question_answering_quality_input end |
#question_answering_relevance_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringRelevanceInput
Input for question answering relevance metric.
Corresponds to the JSON property questionAnsweringRelevanceInput
8509 8510 8511 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8509 def question_answering_relevance_input @question_answering_relevance_input end |
#rouge_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RougeInput
Input for rouge metric.
Corresponds to the JSON property rougeInput
8514 8515 8516 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8514 def rouge_input @rouge_input end |
#rubric_based_instruction_following_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricBasedInstructionFollowingInput
Instance and metric spec for RubricBasedInstructionFollowing metric.
Corresponds to the JSON property rubricBasedInstructionFollowingInput
8519 8520 8521 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8519 def rubric_based_instruction_following_input @rubric_based_instruction_following_input end |
#safety_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetyInput
Input for safety metric.
Corresponds to the JSON property safetyInput
8524 8525 8526 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8524 def safety_input @safety_input end |
#summarization_helpfulness_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SummarizationHelpfulnessInput
Input for summarization helpfulness metric.
Corresponds to the JSON property summarizationHelpfulnessInput
8529 8530 8531 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8529 def summarization_helpfulness_input @summarization_helpfulness_input end |
#summarization_quality_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SummarizationQualityInput
Input for summarization quality metric.
Corresponds to the JSON property summarizationQualityInput
8534 8535 8536 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8534 def summarization_quality_input @summarization_quality_input end |
#summarization_verbosity_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SummarizationVerbosityInput
Input for summarization verbosity metric.
Corresponds to the JSON property summarizationVerbosityInput
8539 8540 8541 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8539 def summarization_verbosity_input @summarization_verbosity_input end |
#tool_call_valid_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolCallValidInput
Input for tool call valid metric.
Corresponds to the JSON property toolCallValidInput
8544 8545 8546 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8544 def tool_call_valid_input @tool_call_valid_input end |
#tool_name_match_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolNameMatchInput
Input for tool name match metric.
Corresponds to the JSON property toolNameMatchInput
8549 8550 8551 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8549 def tool_name_match_input @tool_name_match_input end |
#tool_parameter_key_match_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolParameterKeyMatchInput
Input for tool parameter key match metric.
Corresponds to the JSON property toolParameterKeyMatchInput
8554 8555 8556 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8554 def tool_parameter_key_match_input @tool_parameter_key_match_input end |
#tool_parameter_kv_match_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolParameterKvMatchInput
Input for tool parameter key value match metric.
Corresponds to the JSON property toolParameterKvMatchInput
8559 8560 8561 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8559 def tool_parameter_kv_match_input @tool_parameter_kv_match_input end |
#trajectory_any_order_match_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryAnyOrderMatchInput
Instances and metric spec for TrajectoryAnyOrderMatch metric.
Corresponds to the JSON property trajectoryAnyOrderMatchInput
8564 8565 8566 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8564 def trajectory_any_order_match_input @trajectory_any_order_match_input end |
#trajectory_exact_match_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryExactMatchInput
Instances and metric spec for TrajectoryExactMatch metric.
Corresponds to the JSON property trajectoryExactMatchInput
8569 8570 8571 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8569 def trajectory_exact_match_input @trajectory_exact_match_input end |
#trajectory_in_order_match_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryInOrderMatchInput
Instances and metric spec for TrajectoryInOrderMatch metric.
Corresponds to the JSON property trajectoryInOrderMatchInput
8574 8575 8576 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8574 def trajectory_in_order_match_input @trajectory_in_order_match_input end |
#trajectory_precision_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryPrecisionInput
Instances and metric spec for TrajectoryPrecision metric.
Corresponds to the JSON property trajectoryPrecisionInput
8579 8580 8581 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8579 def trajectory_precision_input @trajectory_precision_input end |
#trajectory_recall_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryRecallInput
Instances and metric spec for TrajectoryRecall metric.
Corresponds to the JSON property trajectoryRecallInput
8584 8585 8586 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8584 def trajectory_recall_input @trajectory_recall_input end |
#trajectory_single_tool_use_input ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectorySingleToolUseInput
Instances and metric spec for TrajectorySingleToolUse metric.
Corresponds to the JSON property trajectorySingleToolUseInput
8589 8590 8591 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8589 def trajectory_single_tool_use_input @trajectory_single_tool_use_input end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8596 8597 8598 8599 8600 8601 8602 8603 8604 8605 8606 8607 8608 8609 8610 8611 8612 8613 8614 8615 8616 8617 8618 8619 8620 8621 8622 8623 8624 8625 8626 8627 8628 8629 8630 8631 8632 8633 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8596 def update!(**args) @autorater_config = args[:autorater_config] if args.key?(:autorater_config) @bleu_input = args[:bleu_input] if args.key?(:bleu_input) @coherence_input = args[:coherence_input] if args.key?(:coherence_input) @comet_input = args[:comet_input] if args.key?(:comet_input) @exact_match_input = args[:exact_match_input] if args.key?(:exact_match_input) @fluency_input = args[:fluency_input] if args.key?(:fluency_input) @fulfillment_input = args[:fulfillment_input] if args.key?(:fulfillment_input) @groundedness_input = args[:groundedness_input] if args.key?(:groundedness_input) @instance = args[:instance] if args.key?(:instance) @location = args[:location] if args.key?(:location) @metrics = args[:metrics] if args.key?(:metrics) @metricx_input = args[:metricx_input] if args.key?(:metricx_input) @pairwise_metric_input = args[:pairwise_metric_input] if args.key?(:pairwise_metric_input) @pairwise_question_answering_quality_input = args[:pairwise_question_answering_quality_input] if args.key?(:pairwise_question_answering_quality_input) @pairwise_summarization_quality_input = args[:pairwise_summarization_quality_input] if args.key?(:pairwise_summarization_quality_input) @pointwise_metric_input = args[:pointwise_metric_input] if args.key?(:pointwise_metric_input) @question_answering_correctness_input = args[:question_answering_correctness_input] if args.key?(:question_answering_correctness_input) @question_answering_helpfulness_input = args[:question_answering_helpfulness_input] if args.key?(:question_answering_helpfulness_input) @question_answering_quality_input = args[:question_answering_quality_input] if args.key?(:question_answering_quality_input) @question_answering_relevance_input = args[:question_answering_relevance_input] if args.key?(:question_answering_relevance_input) @rouge_input = args[:rouge_input] if args.key?(:rouge_input) @rubric_based_instruction_following_input = args[:rubric_based_instruction_following_input] if args.key?(:rubric_based_instruction_following_input) @safety_input = args[:safety_input] if args.key?(:safety_input) @summarization_helpfulness_input = args[:summarization_helpfulness_input] if args.key?(:summarization_helpfulness_input) @summarization_quality_input = args[:summarization_quality_input] if args.key?(:summarization_quality_input) @summarization_verbosity_input = args[:summarization_verbosity_input] if args.key?(:summarization_verbosity_input) @tool_call_valid_input = args[:tool_call_valid_input] if args.key?(:tool_call_valid_input) @tool_name_match_input = args[:tool_name_match_input] if args.key?(:tool_name_match_input) @tool_parameter_key_match_input = args[:tool_parameter_key_match_input] if args.key?(:tool_parameter_key_match_input) @tool_parameter_kv_match_input = args[:tool_parameter_kv_match_input] if args.key?(:tool_parameter_kv_match_input) @trajectory_any_order_match_input = args[:trajectory_any_order_match_input] if args.key?(:trajectory_any_order_match_input) @trajectory_exact_match_input = args[:trajectory_exact_match_input] if args.key?(:trajectory_exact_match_input) @trajectory_in_order_match_input = args[:trajectory_in_order_match_input] if args.key?(:trajectory_in_order_match_input) @trajectory_precision_input = args[:trajectory_precision_input] if args.key?(:trajectory_precision_input) @trajectory_recall_input = args[:trajectory_recall_input] if args.key?(:trajectory_recall_input) @trajectory_single_tool_use_input = args[:trajectory_single_tool_use_input] if args.key?(:trajectory_single_tool_use_input) end |