Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationDataset
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationDataset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The dataset used for evaluation.
Instance Attribute Summary collapse
-
#bigquery_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQuerySource
The BigQuery location for the input content.
-
#gcs_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsSource
The Google Cloud Storage location for the input content.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationDataset
constructor
A new instance of GoogleCloudAiplatformV1EvaluationDataset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationDataset
Returns a new instance of GoogleCloudAiplatformV1EvaluationDataset.
10798 10799 10800 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10798 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bigquery_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQuerySource
The BigQuery location for the input content.
Corresponds to the JSON property bigquerySource
10791 10792 10793 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10791 def bigquery_source @bigquery_source end |
#gcs_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsSource
The Google Cloud Storage location for the input content.
Corresponds to the JSON property gcsSource
10796 10797 10798 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10796 def gcs_source @gcs_source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10803 10804 10805 10806 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10803 def update!(**args) @bigquery_source = args[:bigquery_source] if args.key?(:bigquery_source) @gcs_source = args[:gcs_source] if args.key?(:gcs_source) end |