Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A single instance to be evaluated. Instances are used to specify the input data for evaluation, from simple string comparisons to complex, multi-turn model evaluations

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationInstance

Returns a new instance of GoogleCloudAiplatformV1EvaluationInstance.



10853
10854
10855
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10853

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_dataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentData

Deprecated: Use agent_eval_data instead. Contains data specific to agent evaluations. Corresponds to the JSON property agentData



10819
10820
10821
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10819

def agent_data
  @agent_data
end

#interactions_data_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInteractionsDataSource

Source for populating AgentData from an Interactions API interaction. Corresponds to the JSON property interactionsDataSource



10824
10825
10826
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10824

def interactions_data_source
  @interactions_data_source
end

#other_dataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceMapInstance

Instance data specified as a map. Corresponds to the JSON property otherData



10829
10830
10831
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10829

def other_data
  @other_data
end

#promptGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData

Instance data used to populate placeholders in a metric prompt template. Corresponds to the JSON property prompt



10834
10835
10836
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10834

def prompt
  @prompt
end

#referenceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData

Instance data used to populate placeholders in a metric prompt template. Corresponds to the JSON property reference



10839
10840
10841
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10839

def reference
  @reference
end

#responseGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData

Instance data used to populate placeholders in a metric prompt template. Corresponds to the JSON property response



10844
10845
10846
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10844

def response
  @response
end

#rubric_groupsHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricGroup>

Optional. Named groups of rubrics associated with the prompt. This is used for rubric-based evaluations where rubrics can be referenced by a key. The key could represent versions, associated metrics, etc. Corresponds to the JSON property rubricGroups



10851
10852
10853
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10851

def rubric_groups
  @rubric_groups
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10858
10859
10860
10861
10862
10863
10864
10865
10866
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10858

def update!(**args)
  @agent_data = args[:agent_data] if args.key?(:agent_data)
  @interactions_data_source = args[:interactions_data_source] if args.key?(:interactions_data_source)
  @other_data = args[:other_data] if args.key?(:other_data)
  @prompt = args[:prompt] if args.key?(:prompt)
  @reference = args[:reference] if args.key?(:reference)
  @response = args[:response] if args.key?(:response)
  @rubric_groups = args[:rubric_groups] if args.key?(:rubric_groups)
end