Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceAgentConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Configuration for an Agent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationInstanceAgentConfig

Returns a new instance of GoogleCloudAiplatformV1EvaluationInstanceAgentConfig.



9084
9085
9086
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9084

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_idString

Optional. Unique identifier of the agent. This ID is used to refer to this agent, e.g., in AgentEvent.author, or in the sub_agents field. It must be unique within the agents map. Corresponds to the JSON property agentId

Returns:

  • (String)


9047
9048
9049
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9047

def agent_id
  @agent_id
end

#agent_typeString

Optional. The type or class of the agent (e.g., "LlmAgent", "RouterAgent", " ToolUseAgent"). Useful for the autorater to understand the expected behavior of the agent. Corresponds to the JSON property agentType

Returns:

  • (String)


9054
9055
9056
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9054

def agent_type
  @agent_type
end

#descriptionString

Optional. A high-level description of the agent's role and responsibilities. Critical for evaluating if the agent is routing tasks correctly. Corresponds to the JSON property description

Returns:

  • (String)


9060
9061
9062
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9060

def description
  @description
end

#developer_instructionGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData

Instance data used to populate placeholders in a metric prompt template. Corresponds to the JSON property developerInstruction



9065
9066
9067
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9065

def developer_instruction
  @developer_instruction
end

#sub_agentsArray<String>

Optional. The list of valid agent IDs (names) that this agent can delegate to. This defines the directed edges in the agent system graph topology. Corresponds to the JSON property subAgents

Returns:

  • (Array<String>)


9071
9072
9073
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9071

def sub_agents
  @sub_agents
end

#toolsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceAgentConfigTools

Represents a list of tools for an agent. Corresponds to the JSON property tools



9076
9077
9078
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9076

def tools
  @tools
end

#tools_textString

A JSON string containing a list of tools available to an agent with info such as name, description, parameters and required parameters. Corresponds to the JSON property toolsText

Returns:

  • (String)


9082
9083
9084
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9082

def tools_text
  @tools_text
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9089
9090
9091
9092
9093
9094
9095
9096
9097
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9089

def update!(**args)
  @agent_id = args[:agent_id] if args.key?(:agent_id)
  @agent_type = args[:agent_type] if args.key?(:agent_type)
  @description = args[:description] if args.key?(:description)
  @developer_instruction = args[:developer_instruction] if args.key?(:developer_instruction)
  @sub_agents = args[:sub_agents] if args.key?(:sub_agents)
  @tools = args[:tools] if args.key?(:tools)
  @tools_text = args[:tools_text] if args.key?(:tools_text)
end