Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceAgentDataAgentEvent
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceAgentDataAgentEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A single event in the execution trace.
Instance Attribute Summary collapse
-
#active_tools ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tool>
Optional.
-
#author ⇒ String
Required.
-
#content ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content
The structured data content of a message.
-
#event_time ⇒ String
Optional.
-
#state_delta ⇒ Hash<String,Object>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationInstanceAgentDataAgentEvent
constructor
A new instance of GoogleCloudAiplatformV1EvaluationInstanceAgentDataAgentEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationInstanceAgentDataAgentEvent
Returns a new instance of GoogleCloudAiplatformV1EvaluationInstanceAgentDataAgentEvent.
9211 9212 9213 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9211 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active_tools ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tool>
Optional. The list of tools that were active/available to the agent at the
time of this event. This overrides the AgentConfig.tools if set.
Corresponds to the JSON property activeTools
9186 9187 9188 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9186 def active_tools @active_tools end |
#author ⇒ String
Required. The ID of the agent or entity that generated this event.
Corresponds to the JSON property author
9191 9192 9193 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9191 def @author end |
#content ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content
The structured data content of a message. A Content message contains a role
field, which indicates the producer of the content, and a parts field, which
contains the multi-part data of the message.
Corresponds to the JSON property content
9198 9199 9200 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9198 def content @content end |
#event_time ⇒ String
Optional. The timestamp when the event occurred.
Corresponds to the JSON property eventTime
9203 9204 9205 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9203 def event_time @event_time end |
#state_delta ⇒ Hash<String,Object>
Optional. The change in the session state caused by this event. This is a key-
value map of fields that were modified or added by the event.
Corresponds to the JSON property stateDelta
9209 9210 9211 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9209 def state_delta @state_delta end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9216 9217 9218 9219 9220 9221 9222 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9216 def update!(**args) @active_tools = args[:active_tools] if args.key?(:active_tools) @author = args[:author] if args.key?(:author) @content = args[:content] if args.key?(:content) @event_time = args[:event_time] if args.key?(:event_time) @state_delta = args[:state_delta] if args.key?(:state_delta) end |