Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceAgentDataConversationTurn

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents a single turn/invocation in the conversation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationInstanceAgentDataConversationTurn

Returns a new instance of GoogleCloudAiplatformV1EvaluationInstanceAgentDataConversationTurn.



9245
9246
9247
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9245

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#eventsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceAgentDataAgentEvent>

Optional. The list of events that occurred during this turn. Corresponds to the JSON property events



9232
9233
9234
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9232

def events
  @events
end

#turn_idString

Optional. A unique identifier for the turn. Useful for referencing specific turns across systems. Corresponds to the JSON property turnId

Returns:

  • (String)


9238
9239
9240
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9238

def turn_id
  @turn_id
end

#turn_indexFixnum

Required. The 0-based index of the turn in the conversation sequence. Corresponds to the JSON property turnIndex

Returns:

  • (Fixnum)


9243
9244
9245
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9243

def turn_index
  @turn_index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9250
9251
9252
9253
9254
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9250

def update!(**args)
  @events = args[:events] if args.key?(:events)
  @turn_id = args[:turn_id] if args.key?(:turn_id)
  @turn_index = args[:turn_index] if args.key?(:turn_index)
end