Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentDataAgentEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A single event in the execution trace.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentDataAgentEvent

Returns a new instance of GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentDataAgentEvent.



10234
10235
10236
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10234

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#active_toolsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tool>

Optional. The list of tools that were active/available to the agent at the time of this event. This overrides the AgentConfig.tools if set. Corresponds to the JSON property activeTools



10209
10210
10211
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10209

def active_tools
  @active_tools
end

#authorString

Required. The ID of the agent or entity that generated this event. Corresponds to the JSON property author

Returns:

  • (String)


10214
10215
10216
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10214

def author
  @author
end

#contentGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Content

The structured data content of a message. A Content message contains a role field, which indicates the producer of the content, and a parts field, which contains the multi-part data of the message. Corresponds to the JSON property content



10221
10222
10223
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10221

def content
  @content
end

#event_timeString

Optional. The timestamp when the event occurred. Corresponds to the JSON property eventTime

Returns:

  • (String)


10226
10227
10228
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10226

def event_time
  @event_time
end

#state_deltaHash<String,Object>

Optional. The change in the session state caused by this event. This is a key- value map of fields that were modified or added by the event. Corresponds to the JSON property stateDelta

Returns:

  • (Hash<String,Object>)


10232
10233
10234
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10232

def state_delta
  @state_delta
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10239
10240
10241
10242
10243
10244
10245
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10239

def update!(**args)
  @active_tools = args[:active_tools] if args.key?(:active_tools)
  @author = args[:author] if args.key?(:author)
  @content = args[:content] if args.key?(:content)
  @event_time = args[:event_time] if args.key?(:event_time)
  @state_delta = args[:state_delta] if args.key?(:state_delta)
end