Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationItem

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

EvaluationItem is a single evaluation request or result. The content of an EvaluationItem is immutable - it cannot be updated once created. EvaluationItems can be deleted when no longer needed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationItem

Returns a new instance of GoogleCloudAiplatformV1EvaluationItem.



11289
11290
11291
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11289

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this item was created. Corresponds to the JSON property createTime

Returns:

  • (String)


11230
11231
11232
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11230

def create_time
  @create_time
end

#display_nameString

Required. The display name of the EvaluationItem. Corresponds to the JSON property displayName

Returns:

  • (String)


11235
11236
11237
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11235

def display_name
  @display_name
end

#errorGoogle::Apis::AiplatformV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



11245
11246
11247
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11245

def error
  @error
end

#evaluation_item_typeString

Required. The type of the EvaluationItem. Corresponds to the JSON property evaluationItemType

Returns:

  • (String)


11250
11251
11252
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11250

def evaluation_item_type
  @evaluation_item_type
end

#evaluation_requestGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRequest

A single evaluation request supporting input for both single-turn model generation and multi-turn agent execution traces. Valid input modes: 1. Inference Mode: prompt is set (containing text or AgentData context). 2. Offline Eval Mode: prompt is unset, and candidate_responses contains agent_data (the completed execution trace). Validation Rule: Either prompt must be set, OR at least one of the candidate_responses must contain agent_data. Corresponds to the JSON property evaluationRequest



11261
11262
11263
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11261

def evaluation_request
  @evaluation_request
end

#evaluation_responseGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationResult

Evaluation result. Corresponds to the JSON property evaluationResponse



11266
11267
11268
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11266

def evaluation_response
  @evaluation_response
end

#gcs_uriString

The Cloud Storage object where the request or response is stored. Corresponds to the JSON property gcsUri

Returns:

  • (String)


11271
11272
11273
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11271

def gcs_uri
  @gcs_uri
end

#labelsHash<String,String>

Optional. Labels for the EvaluationItem. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


11276
11277
11278
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11276

def labels
  @labels
end

#metadataObject

Optional. Metadata for the EvaluationItem. Corresponds to the JSON property metadata

Returns:

  • (Object)


11281
11282
11283
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11281

def 
  @metadata
end

#nameString

Identifier. The resource name of the EvaluationItem. Format: projects/ project/locations/location/evaluationItems/evaluation_item` Corresponds to the JSON propertyname`

Returns:

  • (String)


11287
11288
11289
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11287

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11294
11295
11296
11297
11298
11299
11300
11301
11302
11303
11304
11305
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11294

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @error = args[:error] if args.key?(:error)
  @evaluation_item_type = args[:evaluation_item_type] if args.key?(:evaluation_item_type)
  @evaluation_request = args[:evaluation_request] if args.key?(:evaluation_request)
  @evaluation_response = args[:evaluation_response] if args.key?(:evaluation_response)
  @gcs_uri = args[:gcs_uri] if args.key?(:gcs_uri)
  @labels = args[:labels] if args.key?(:labels)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
end