Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationPrompt
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationPrompt
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Prompt to be evaluated. This can represent a single-turn prompt or a multi- turn conversation for agent evaluations.
Instance Attribute Summary collapse
-
#agent_data ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AgentData
Represents data specific to multi-turn agent evaluations.
-
#prompt_template_data ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationPromptPromptTemplateData
Message to hold a prompt template and the values to populate the template.
-
#text ⇒ String
Text prompt.
-
#user_scenario ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationPromptUserScenario
User scenario to help simulate multi-turn agent running results.
-
#value ⇒ Object
Fields and values that can be used to populate the prompt template.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationPrompt
constructor
A new instance of GoogleCloudAiplatformV1EvaluationPrompt.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationPrompt
Returns a new instance of GoogleCloudAiplatformV1EvaluationPrompt.
11080 11081 11082 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11080 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_data ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AgentData
Represents data specific to multi-turn agent evaluations.
Corresponds to the JSON property agentData
11058 11059 11060 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11058 def agent_data @agent_data end |
#prompt_template_data ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationPromptPromptTemplateData
Message to hold a prompt template and the values to populate the template.
Corresponds to the JSON property promptTemplateData
11063 11064 11065 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11063 def prompt_template_data @prompt_template_data end |
#text ⇒ String
Text prompt.
Corresponds to the JSON property text
11068 11069 11070 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11068 def text @text end |
#user_scenario ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationPromptUserScenario
User scenario to help simulate multi-turn agent running results.
Corresponds to the JSON property userScenario
11073 11074 11075 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11073 def user_scenario @user_scenario end |
#value ⇒ Object
Fields and values that can be used to populate the prompt template.
Corresponds to the JSON property value
11078 11079 11080 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11078 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11085 11086 11087 11088 11089 11090 11091 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11085 def update!(**args) @agent_data = args[:agent_data] if args.key?(:agent_data) @prompt_template_data = args[:prompt_template_data] if args.key?(:prompt_template_data) @text = args[:text] if args.key?(:text) @user_scenario = args[:user_scenario] if args.key?(:user_scenario) @value = args[:value] if args.key?(:value) end |