Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A single evaluation request supporting input for both single-turn model
generation and multi-turn agent execution traces. Valid input modes: 1.
Inference Mode: prompt is set (containing text or AgentData context). 2.
Offline Eval Mode: prompt is unset, and candidate_responses contains
agent_data (the completed execution trace). Validation Rule: Either prompt
must be set, OR at least one of the candidate_responses must contain
agent_data.
Instance Attribute Summary collapse
-
#candidate_responses ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CandidateResponse>
Optional.
-
#golden_response ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CandidateResponse
Responses from model or agent.
-
#prompt ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationPrompt
Prompt to be evaluated.
-
#rubrics ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricGroup>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationRequest
constructor
A new instance of GoogleCloudAiplatformV1EvaluationRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationRequest
Returns a new instance of GoogleCloudAiplatformV1EvaluationRequest.
11551 11552 11553 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11551 def initialize(**args) update!(**args) end |
Instance Attribute Details
#candidate_responses ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CandidateResponse>
Optional. Responses from model under test and other baseline models for
comparison.
Corresponds to the JSON property candidateResponses
11532 11533 11534 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11532 def candidate_responses @candidate_responses end |
#golden_response ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CandidateResponse
Responses from model or agent.
Corresponds to the JSON property goldenResponse
11537 11538 11539 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11537 def golden_response @golden_response end |
#prompt ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationPrompt
Prompt to be evaluated. This can represent a single-turn prompt or a multi-
turn conversation for agent evaluations.
Corresponds to the JSON property prompt
11543 11544 11545 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11543 def prompt @prompt end |
#rubrics ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricGroup>
Optional. Named groups of rubrics associated with this prompt. The key is a
user-defined name for the rubric group.
Corresponds to the JSON property rubrics
11549 11550 11551 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11549 def rubrics @rubrics end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11556 11557 11558 11559 11560 11561 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11556 def update!(**args) @candidate_responses = args[:candidate_responses] if args.key?(:candidate_responses) @golden_response = args[:golden_response] if args.key?(:golden_response) @prompt = args[:prompt] if args.key?(:prompt) @rubrics = args[:rubrics] if args.key?(:rubrics) end |