Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationResult
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Evaluation result.
Instance Attribute Summary collapse
-
#candidate_results ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CandidateResult>
Optional.
-
#evaluation_request ⇒ String
Required.
-
#evaluation_run ⇒ String
Required.
-
#metadata ⇒ Object
Optional.
-
#metric ⇒ String
Required.
-
#request ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRequest
A single evaluation request supporting input for both single-turn model generation and multi-turn agent execution traces.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationResult
constructor
A new instance of GoogleCloudAiplatformV1EvaluationResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationResult
Returns a new instance of GoogleCloudAiplatformV1EvaluationResult.
10142 10143 10144 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10142 def initialize(**args) update!(**args) end |
Instance Attribute Details
#candidate_results ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CandidateResult>
Optional. The results for the metric.
Corresponds to the JSON property candidateResults
10107 10108 10109 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10107 def candidate_results @candidate_results end |
#evaluation_request ⇒ String
Required. The request item that was evaluated. Format: projects/project/
locations/location/evaluationItems/evaluation_item
Corresponds to the JSON property evaluationRequest
10113 10114 10115 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10113 def evaluation_request @evaluation_request end |
#evaluation_run ⇒ String
Required. The evaluation run that was used to generate the result. Format:
projects/project/locations/location/evaluationRuns/evaluation_run
Corresponds to the JSON property evaluationRun
10119 10120 10121 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10119 def evaluation_run @evaluation_run end |
#metadata ⇒ Object
Optional. Metadata about the evaluation result.
Corresponds to the JSON property metadata
10124 10125 10126 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10124 def @metadata end |
#metric ⇒ String
Required. The metric that was evaluated.
Corresponds to the JSON property metric
10129 10130 10131 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10129 def metric @metric end |
#request ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRequest
A single evaluation request supporting input for both single-turn model
generation and multi-turn agent execution traces. Valid input modes: 1.
Inference Mode: prompt is set (containing text or AgentData context). 2.
Offline Eval Mode: prompt is unset, and candidate_responses contains
agent_data (the completed execution trace). Validation Rule: Either prompt
must be set, OR at least one of the candidate_responses must contain
agent_data.
Corresponds to the JSON property request
10140 10141 10142 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10140 def request @request end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10147 10148 10149 10150 10151 10152 10153 10154 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10147 def update!(**args) @candidate_results = args[:candidate_results] if args.key?(:candidate_results) @evaluation_request = args[:evaluation_request] if args.key?(:evaluation_request) @evaluation_run = args[:evaluation_run] if args.key?(:evaluation_run) @metadata = args[:metadata] if args.key?(:metadata) @metric = args[:metric] if args.key?(:metric) @request = args[:request] if args.key?(:request) end |