Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunEvaluationConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The Evalution configuration used for the evaluation run.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationRunEvaluationConfig

Returns a new instance of GoogleCloudAiplatformV1EvaluationRunEvaluationConfig.



10389
10390
10391
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10389

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#autorater_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunEvaluationConfigAutoraterConfig

The autorater config used for the evaluation run. Corresponds to the JSON property autoraterConfig



10356
10357
10358
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10356

def autorater_config
  @autorater_config
end

#dataset_custom_metricsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DatasetCustomMetric>

Optional. Specifications for custom dataset-level aggregations. Corresponds to the JSON property datasetCustomMetrics



10361
10362
10363
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10361

def dataset_custom_metrics
  @dataset_custom_metrics
end

#metricsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunMetric>

Required. The metrics to be calculated in the evaluation run. Corresponds to the JSON property metrics



10366
10367
10368
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10366

def metrics
  @metrics
end

#output_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunEvaluationConfigOutputConfig

The output config for the evaluation run. Corresponds to the JSON property outputConfig



10371
10372
10373
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10371

def output_config
  @output_config
end

#prompt_templateGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunEvaluationConfigPromptTemplate

Prompt template used for inference. Corresponds to the JSON property promptTemplate



10376
10377
10378
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10376

def prompt_template
  @prompt_template
end

#rubric_configsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRubricConfig>

Optional. The rubric configs for the evaluation run. They are used to generate rubrics which can be used by rubric-based metrics. Multiple rubric configs can be specified for rubric generation but only one rubric config can be used for a rubric-based metric. If more than one rubric config is provided, the evaluation metric must specify a rubric group key. Note that if a generation spec is specified on both a rubric config and an evaluation metric, the rubrics generated for the metric will be used for evaluation. Corresponds to the JSON property rubricConfigs



10387
10388
10389
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10387

def rubric_configs
  @rubric_configs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10394
10395
10396
10397
10398
10399
10400
10401
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10394

def update!(**args)
  @autorater_config = args[:autorater_config] if args.key?(:autorater_config)
  @dataset_custom_metrics = args[:dataset_custom_metrics] if args.key?(:dataset_custom_metrics)
  @metrics = args[:metrics] if args.key?(:metrics)
  @output_config = args[:output_config] if args.key?(:output_config)
  @prompt_template = args[:prompt_template] if args.key?(:prompt_template)
  @rubric_configs = args[:rubric_configs] if args.key?(:rubric_configs)
end