Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunInferenceConfigAgentRunConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Configuration for Agent Run.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationRunInferenceConfigAgentRunConfig

Returns a new instance of GoogleCloudAiplatformV1EvaluationRunInferenceConfigAgentRunConfig.



10776
10777
10778
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10776

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_engineString

Optional. The resource name of the Agent Engine. Format: projects/project/ locations/location/reasoningEngines/reasoning_engine For example: projects/ 123/locations/us-central1/reasoningEngines/456 Corresponds to the JSON property agentEngine

Returns:

  • (String)


10763
10764
10765
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10763

def agent_engine
  @agent_engine
end

#session_inputGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunInferenceConfigSessionInput

Session input to run an Agent. Corresponds to the JSON property sessionInput



10768
10769
10770
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10768

def session_input
  @session_input
end

#user_simulator_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunInferenceConfigAgentRunConfigUserSimulatorConfig

Used for multi-turn agent scraping. Contains configuration for a user simulator that uses an LLM to generate messages on behalf of the user. Corresponds to the JSON property userSimulatorConfig



10774
10775
10776
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10774

def user_simulator_config
  @user_simulator_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10781
10782
10783
10784
10785
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10781

def update!(**args)
  @agent_engine = args[:agent_engine] if args.key?(:agent_engine)
  @session_input = args[:session_input] if args.key?(:session_input)
  @user_simulator_config = args[:user_simulator_config] if args.key?(:user_simulator_config)
end