Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunInferenceConfigAgentRunConfigUserSimulatorConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Used for multi-turn agent scraping. Contains configuration for a user simulator that uses an LLM to generate messages on behalf of the user.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationRunInferenceConfigAgentRunConfigUserSimulatorConfig

Returns a new instance of GoogleCloudAiplatformV1EvaluationRunInferenceConfigAgentRunConfigUserSimulatorConfig.



12112
12113
12114
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12112

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_turnFixnum

Maximum number of invocations allowed by the multi-turn agent scraping. This property allows us to stop a run-off conversation, where the agent and the user simulator get into a never ending loop. The initial fixed prompt is also counted as an invocation. Corresponds to the JSON property maxTurn

Returns:

  • (Fixnum)


12097
12098
12099
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12097

def max_turn
  @max_turn
end

#model_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfig

Configuration for content generation. This message contains all the parameters that control how the model generates content. It allows you to influence the randomness, length, and structure of the output. Corresponds to the JSON property modelConfig



12104
12105
12106
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12104

def model_config
  @model_config
end

#model_nameString

The model name to use for multi-turn agent scraping to get next user message, e.g. "gemini-3-flash-preview". Corresponds to the JSON property modelName

Returns:

  • (String)


12110
12111
12112
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12110

def model_name
  @model_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12117
12118
12119
12120
12121
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12117

def update!(**args)
  @max_turn = args[:max_turn] if args.key?(:max_turn)
  @model_config = args[:model_config] if args.key?(:model_config)
  @model_name = args[:model_name] if args.key?(:model_name)
end