Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunMetricRubricBasedMetricSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunMetricRubricBasedMetricSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Specification for a metric that is based on rubrics.
Instance Attribute Summary collapse
-
#inline_rubrics ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunMetricRubricBasedMetricSpecRepeatedRubrics
Defines a list of rubrics, used when providing rubrics inline.
-
#judge_autorater_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunEvaluationConfigAutoraterConfig
The autorater config used for the evaluation run.
-
#metric_prompt_template ⇒ String
Optional.
-
#rubric_generation_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunMetricRubricGenerationSpec
Specification for how rubrics should be generated.
-
#rubric_group_key ⇒ String
Use a pre-defined group of rubrics associated with the input content.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationRunMetricRubricBasedMetricSpec
constructor
A new instance of GoogleCloudAiplatformV1EvaluationRunMetricRubricBasedMetricSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationRunMetricRubricBasedMetricSpec
Returns a new instance of GoogleCloudAiplatformV1EvaluationRunMetricRubricBasedMetricSpec.
11958 11959 11960 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11958 def initialize(**args) update!(**args) end |
Instance Attribute Details
#inline_rubrics ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunMetricRubricBasedMetricSpecRepeatedRubrics
Defines a list of rubrics, used when providing rubrics inline.
Corresponds to the JSON property inlineRubrics
11934 11935 11936 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11934 def inline_rubrics @inline_rubrics end |
#judge_autorater_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunEvaluationConfigAutoraterConfig
The autorater config used for the evaluation run.
Corresponds to the JSON property judgeAutoraterConfig
11939 11940 11941 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11939 def judge_autorater_config @judge_autorater_config end |
#metric_prompt_template ⇒ String
Optional. Template for the prompt used by the judge model to evaluate against
rubrics.
Corresponds to the JSON property metricPromptTemplate
11945 11946 11947 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11945 def metric_prompt_template @metric_prompt_template end |
#rubric_generation_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunMetricRubricGenerationSpec
Specification for how rubrics should be generated.
Corresponds to the JSON property rubricGenerationSpec
11950 11951 11952 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11950 def rubric_generation_spec @rubric_generation_spec end |
#rubric_group_key ⇒ String
Use a pre-defined group of rubrics associated with the input content. This
refers to a key in the rubric_groups map of RubricEnhancedContents.
Corresponds to the JSON property rubricGroupKey
11956 11957 11958 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11956 def rubric_group_key @rubric_group_key end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11963 11964 11965 11966 11967 11968 11969 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11963 def update!(**args) @inline_rubrics = args[:inline_rubrics] if args.key?(:inline_rubrics) @judge_autorater_config = args[:judge_autorater_config] if args.key?(:judge_autorater_config) @metric_prompt_template = args[:metric_prompt_template] if args.key?(:metric_prompt_template) @rubric_generation_spec = args[:rubric_generation_spec] if args.key?(:rubric_generation_spec) @rubric_group_key = args[:rubric_group_key] if args.key?(:rubric_group_key) end |