Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunMetricRubricGenerationSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Specification for how rubrics should be generated.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationRunMetricRubricGenerationSpec

Returns a new instance of GoogleCloudAiplatformV1EvaluationRunMetricRubricGenerationSpec.



10956
10957
10958
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10956

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#metric_resource_nameString

Optional. Resource name of the metric definition. Corresponds to the JSON property metricResourceName

Returns:

  • (String)


10931
10932
10933
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10931

def metric_resource_name
  @metric_resource_name
end

#model_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunEvaluationConfigAutoraterConfig

The autorater config used for the evaluation run. Corresponds to the JSON property modelConfig



10936
10937
10938
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10936

def model_config
  @model_config
end

#prompt_templateString

Optional. Template for the prompt used to generate rubrics. The details should be updated based on the most-recent recipe requirements. Corresponds to the JSON property promptTemplate

Returns:

  • (String)


10942
10943
10944
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10942

def prompt_template
  @prompt_template
end

#rubric_content_typeString

Optional. The type of rubric content to be generated. Corresponds to the JSON property rubricContentType

Returns:

  • (String)


10947
10948
10949
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10947

def rubric_content_type
  @rubric_content_type
end

#rubric_type_ontologyArray<String>

Optional. An optional, pre-defined list of allowed types for generated rubrics. If this field is provided, it implies include_rubric_type should be true, and the generated rubric types should be chosen from this ontology. Corresponds to the JSON property rubricTypeOntology

Returns:

  • (Array<String>)


10954
10955
10956
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10954

def rubric_type_ontology
  @rubric_type_ontology
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10961
10962
10963
10964
10965
10966
10967
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10961

def update!(**args)
  @metric_resource_name = args[:metric_resource_name] if args.key?(:metric_resource_name)
  @model_config = args[:model_config] if args.key?(:model_config)
  @prompt_template = args[:prompt_template] if args.key?(:prompt_template)
  @rubric_content_type = args[:rubric_content_type] if args.key?(:rubric_content_type)
  @rubric_type_ontology = args[:rubric_type_ontology] if args.key?(:rubric_type_ontology)
end