Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationSet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

EvaluationSet is a collection of related EvaluationItems that are evaluated together.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationSet

Returns a new instance of GoogleCloudAiplatformV1EvaluationSet.



12478
12479
12480
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12478

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_configsHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AgentConfig>

Optional. Static configurations for each agent associated with the items in this set. Key: agent_id (matches the author field in events). Value: The static configuration of the agent. Corresponds to the JSON property agentConfigs



12439
12440
12441
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12439

def agent_configs
  @agent_configs
end

#create_timeString

Output only. Timestamp when this item was created. Corresponds to the JSON property createTime

Returns:

  • (String)


12444
12445
12446
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12444

def create_time
  @create_time
end

#display_nameString

Required. The display name of the EvaluationSet. Corresponds to the JSON property displayName

Returns:

  • (String)


12449
12450
12451
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12449

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



12455
12456
12457
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12455

def encryption_spec
  @encryption_spec
end

#evaluation_itemsArray<String>

Required. The EvaluationItems that are part of this dataset. Corresponds to the JSON property evaluationItems

Returns:

  • (Array<String>)


12460
12461
12462
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12460

def evaluation_items
  @evaluation_items
end

#metadataObject

Optional. Metadata for the EvaluationSet. Corresponds to the JSON property metadata

Returns:

  • (Object)


12465
12466
12467
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12465

def 
  @metadata
end

#nameString

Identifier. The resource name of the EvaluationSet. Format: projects/project /locations/location/evaluationSets/evaluation_set` Corresponds to the JSON propertyname`

Returns:

  • (String)


12471
12472
12473
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12471

def name
  @name
end

#update_timeString

Output only. Timestamp when this item was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


12476
12477
12478
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12476

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12483
12484
12485
12486
12487
12488
12489
12490
12491
12492
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12483

def update!(**args)
  @agent_configs = args[:agent_configs] if args.key?(:agent_configs)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @evaluation_items = args[:evaluation_items] if args.key?(:evaluation_items)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end