Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExamplesExampleGcsSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The Cloud Storage input instances.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ExamplesExampleGcsSource

Returns a new instance of GoogleCloudAiplatformV1ExamplesExampleGcsSource.



12187
12188
12189
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12187

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_formatString

The format in which instances are given, if not specified, assume it's JSONL format. Currently only JSONL format is supported. Corresponds to the JSON property dataFormat

Returns:

  • (String)


12180
12181
12182
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12180

def data_format
  @data_format
end

#gcs_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsSource

The Google Cloud Storage location for the input content. Corresponds to the JSON property gcsSource



12185
12186
12187
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12185

def gcs_source
  @gcs_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12192
12193
12194
12195
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12192

def update!(**args)
  @data_format = args[:data_format] if args.key?(:data_format)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
end