Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExecutableCode

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Code generated by the model that is meant to be executed, and the result returned to the model. Generated when using the CodeExecution tool, in which the code will be automatically executed, and a corresponding CodeExecutionResult will also be generated.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ExecutableCode

Returns a new instance of GoogleCloudAiplatformV1ExecutableCode.



12949
12950
12951
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12949

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

Required. The code to be executed. Corresponds to the JSON property code

Returns:

  • (String)


12936
12937
12938
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12936

def code
  @code
end

#idString

Optional. Unique identifier of the ExecutableCode part. The server returns the CodeExecutionResult with the matching id. Corresponds to the JSON property id

Returns:

  • (String)


12942
12943
12944
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12942

def id
  @id
end

#languageString

Required. Programming language of the code. Corresponds to the JSON property language

Returns:

  • (String)


12947
12948
12949
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12947

def language
  @language
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12954
12955
12956
12957
12958
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12954

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @id = args[:id] if args.key?(:id)
  @language = args[:language] if args.key?(:language)
end