Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplainRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for PredictionService.Explain.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ExplainRequest

Returns a new instance of GoogleCloudAiplatformV1ExplainRequest.



13149
13150
13151
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13149

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deployed_model_idString

If specified, this ExplainRequest will be served by the chosen DeployedModel, overriding Endpoint.traffic_split. Corresponds to the JSON property deployedModelId

Returns:

  • (String)


13125
13126
13127
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13125

def deployed_model_id
  @deployed_model_id
end

#explanation_spec_overrideGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationSpecOverride

The ExplanationSpec entries that can be overridden at online explanation time. Corresponds to the JSON property explanationSpecOverride



13130
13131
13132
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13130

def explanation_spec_override
  @explanation_spec_override
end

#instancesArray<Object>

Required. The instances that are the input to the explanation call. A DeployedModel may have an upper limit on the number of instances it supports per request, and when it is exceeded the explanation call errors in case of AutoML Models, or, in case of customer created Models, the behaviour is as documented by that Model. The schema of any single instance may be specified via Endpoint's DeployedModels' Model's PredictSchemata's instance_schema_uri. Corresponds to the JSON property instances

Returns:

  • (Array<Object>)


13140
13141
13142
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13140

def instances
  @instances
end

#parametersObject

The parameters that govern the prediction. The schema of the parameters may be specified via Endpoint's DeployedModels' Model's PredictSchemata's parameters_schema_uri. Corresponds to the JSON property parameters

Returns:

  • (Object)


13147
13148
13149
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13147

def parameters
  @parameters
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13154
13155
13156
13157
13158
13159
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13154

def update!(**args)
  @deployed_model_id = args[:deployed_model_id] if args.key?(:deployed_model_id)
  @explanation_spec_override = args[:explanation_spec_override] if args.key?(:explanation_spec_override)
  @instances = args[:instances] if args.key?(:instances)
  @parameters = args[:parameters] if args.key?(:parameters)
end