Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Explanation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Explanation of a prediction (provided in PredictResponse.predictions) produced by the Model on a given instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Explanation

Returns a new instance of GoogleCloudAiplatformV1Explanation.



8129
8130
8131
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8129

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attributionsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Attribution>

Output only. Feature attributions grouped by predicted outputs. For Models that predict only one output, such as regression Models that predict only one score, there is only one attibution that explains the predicted output. For Models that predict multiple outputs, such as multiclass Models that predict multiple classes, each element explains one specific item. Attribution. output_index can be used to identify which output this attribution is explaining. By default, we provide Shapley values for the predicted class. However, you can configure the explanation request to generate Shapley values for any other classes too. For example, if a model predicts a probability of 0.4 for approving a loan application, the model's decision is to reject the application since p(reject) = 0.6 > p(approve) = 0.4, and the default Shapley values would be computed for rejection decision and not approval, even though the latter might be the positive class. If users set ExplanationParameters.top_k, the attributions are sorted by instance_output_value in descending order. If ExplanationParameters. output_indices is specified, the attributions are stored by Attribution. output_index in the same order as they appear in the output_indices. Corresponds to the JSON property attributions



8120
8121
8122
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8120

def attributions
  @attributions
end

#neighborsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Neighbor>

Output only. List of the nearest neighbors for example-based explanations. For models deployed with the examples explanations feature enabled, the attributions field is empty and instead the neighbors field is populated. Corresponds to the JSON property neighbors



8127
8128
8129
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8127

def neighbors
  @neighbors
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8134
8135
8136
8137
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8134

def update!(**args)
  @attributions = args[:attributions] if args.key?(:attributions)
  @neighbors = args[:neighbors] if args.key?(:neighbors)
end