Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationMetadataOutputMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationMetadataOutputMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Metadata of the prediction output to be explained.
Instance Attribute Summary collapse
-
#display_name_mapping_key ⇒ String
Specify a field name in the prediction to look for the display name.
-
#index_display_name_mapping ⇒ Object
Static mapping between the index and display name.
-
#output_tensor_name ⇒ String
Name of the output tensor.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExplanationMetadataOutputMetadata
constructor
A new instance of GoogleCloudAiplatformV1ExplanationMetadataOutputMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExplanationMetadataOutputMetadata
Returns a new instance of GoogleCloudAiplatformV1ExplanationMetadataOutputMetadata.
12133 12134 12135 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12133 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name_mapping_key ⇒ String
Specify a field name in the prediction to look for the display name. Use this
if the prediction contains the display names for the outputs. The display
names in the prediction must have the same shape of the outputs, so that it
can be located by Attribution.output_index for a specific output.
Corresponds to the JSON property displayNameMappingKey
12113 12114 12115 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12113 def display_name_mapping_key @display_name_mapping_key end |
#index_display_name_mapping ⇒ Object
Static mapping between the index and display name. Use this if the outputs are
a deterministic n-dimensional array, e.g. a list of scores of all the classes
in a pre-defined order for a multi-classification Model. It's not feasible if
the outputs are non-deterministic, e.g. the Model produces top-k classes or
sort the outputs by their values. The shape of the value must be an n-
dimensional array of strings. The number of dimensions must match that of the
outputs to be explained. The Attribution.output_display_name is populated by
locating in the mapping with Attribution.output_index.
Corresponds to the JSON property indexDisplayNameMapping
12125 12126 12127 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12125 def index_display_name_mapping @index_display_name_mapping end |
#output_tensor_name ⇒ String
Name of the output tensor. Required and is only applicable to Vertex AI
provided images for Tensorflow.
Corresponds to the JSON property outputTensorName
12131 12132 12133 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12131 def output_tensor_name @output_tensor_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12138 12139 12140 12141 12142 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12138 def update!(**args) @display_name_mapping_key = args[:display_name_mapping_key] if args.key?(:display_name_mapping_key) @index_display_name_mapping = args[:index_display_name_mapping] if args.key?(:index_display_name_mapping) @output_tensor_name = args[:output_tensor_name] if args.key?(:output_tensor_name) end |