Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportDataConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Describes what part of the Dataset is to be exported, the destination of the export and how to export.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ExportDataConfig

Returns a new instance of GoogleCloudAiplatformV1ExportDataConfig.



13141
13142
13143
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13141

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotation_schema_uriString

The Cloud Storage URI that points to a YAML file describing the annotation schema. The schema is defined as an OpenAPI 3.0.2 Schema Object. The schema files that can be used here are found in gs://google-cloud- aiplatform/schema/dataset/annotation/, note that the chosen schema must be consistent with metadata of the Dataset specified by ExportDataRequest.name. Only used for custom training data export use cases. Only applicable to Datasets that have DataItems and Annotations. Only Annotations that both match this schema and belong to DataItems not ignored by the split method are used in respectively training, validation or test role, depending on the role of the DataItem they are on. When used in conjunction with annotations_filter, the Annotations used for training are filtered by both annotations_filter and annotation_schema_uri. Corresponds to the JSON property annotationSchemaUri

Returns:

  • (String)


13090
13091
13092
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13090

def annotation_schema_uri
  @annotation_schema_uri
end

#annotations_filterString

An expression for filtering what part of the Dataset is to be exported. Only Annotations that match this filter will be exported. The filter syntax is the same as in ListAnnotations. Corresponds to the JSON property annotationsFilter

Returns:

  • (String)


13097
13098
13099
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13097

def annotations_filter
  @annotations_filter
end

#export_useString

Indicates the usage of the exported files. Corresponds to the JSON property exportUse

Returns:

  • (String)


13102
13103
13104
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13102

def export_use
  @export_use
end

#filter_splitGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportFilterSplit

Assigns input data to training, validation, and test sets based on the given filters, data pieces not matched by any filter are ignored. Currently only supported for Datasets containing DataItems. If any of the filters in this message are to match nothing, then they can be set as '-' (the minus sign). Supported only for unstructured Datasets. Corresponds to the JSON property filterSplit



13111
13112
13113
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13111

def filter_split
  @filter_split
end

#fraction_splitGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportFractionSplit

Assigns the input data to training, validation, and test sets as per the given fractions. Any of training_fraction, validation_fraction and test_fraction may optionally be provided, they must sum to up to 1. If the provided ones sum to less than 1, the remainder is assigned to sets as decided by Vertex AI. If none of the fractions are set, by default roughly 80% of data is used for training, 10% for validation, and 10% for test. Corresponds to the JSON property fractionSplit



13121
13122
13123
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13121

def fraction_split
  @fraction_split
end

#gcs_destinationGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsDestination

The Google Cloud Storage location where the output is to be written to. Corresponds to the JSON property gcsDestination



13126
13127
13128
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13126

def gcs_destination
  @gcs_destination
end

#saved_query_idString

The ID of a SavedQuery (annotation set) under the Dataset specified by ExportDataRequest.name used for filtering Annotations for training. Only used for custom training data export use cases. Only applicable to Datasets that have SavedQueries. Only Annotations that are associated with this SavedQuery are used in respectively training. When used in conjunction with annotations_filter, the Annotations used for training are filtered by both saved_query_id and annotations_filter. Only one of saved_query_id and annotation_schema_uri should be specified as both of them represent the same thing: problem type. Corresponds to the JSON property savedQueryId

Returns:

  • (String)


13139
13140
13141
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13139

def saved_query_id
  @saved_query_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13146
13147
13148
13149
13150
13151
13152
13153
13154
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13146

def update!(**args)
  @annotation_schema_uri = args[:annotation_schema_uri] if args.key?(:annotation_schema_uri)
  @annotations_filter = args[:annotations_filter] if args.key?(:annotations_filter)
  @export_use = args[:export_use] if args.key?(:export_use)
  @filter_split = args[:filter_split] if args.key?(:filter_split)
  @fraction_split = args[:fraction_split] if args.key?(:fraction_split)
  @gcs_destination = args[:gcs_destination] if args.key?(:gcs_destination)
  @saved_query_id = args[:saved_query_id] if args.key?(:saved_query_id)
end