Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportDataRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for DatasetService.ExportData.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ExportDataRequest

Returns a new instance of GoogleCloudAiplatformV1ExportDataRequest.



12434
12435
12436
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12434

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#export_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportDataConfig

Describes what part of the Dataset is to be exported, the destination of the export and how to export. Corresponds to the JSON property exportConfig



12432
12433
12434
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12432

def export_config
  @export_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12439
12440
12441
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12439

def update!(**args)
  @export_config = args[:export_config] if args.key?(:export_config)
end