Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportFeatureValuesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for FeaturestoreService.ExportFeatureValues.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ExportFeatureValuesRequest

Returns a new instance of GoogleCloudAiplatformV1ExportFeatureValuesRequest.



13561
13562
13563
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13561

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destinationGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureValueDestination

A destination location for Feature values and format. Corresponds to the JSON property destination



13537
13538
13539
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13537

def destination
  @destination
end

#feature_selectorGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureSelector

Selector for Features of an EntityType. Corresponds to the JSON property featureSelector



13542
13543
13544
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13542

def feature_selector
  @feature_selector
end

#full_exportGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportFeatureValuesRequestFullExport

Describes exporting all historical Feature values of all entities of the EntityType between [start_time, end_time]. Corresponds to the JSON property fullExport



13548
13549
13550
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13548

def full_export
  @full_export
end

#settingsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DestinationFeatureSetting>

Per-Feature export settings. Corresponds to the JSON property settings



13553
13554
13555
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13553

def settings
  @settings
end

#snapshot_exportGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportFeatureValuesRequestSnapshotExport

Describes exporting the latest Feature values of all entities of the EntityType between [start_time, snapshot_time]. Corresponds to the JSON property snapshotExport



13559
13560
13561
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13559

def snapshot_export
  @snapshot_export
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13566
13567
13568
13569
13570
13571
13572
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13566

def update!(**args)
  @destination = args[:destination] if args.key?(:destination)
  @feature_selector = args[:feature_selector] if args.key?(:feature_selector)
  @full_export = args[:full_export] if args.key?(:full_export)
  @settings = args[:settings] if args.key?(:settings)
  @snapshot_export = args[:snapshot_export] if args.key?(:snapshot_export)
end