Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportModelRequestOutputConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Output configuration for the Model export.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ExportModelRequestOutputConfig

Returns a new instance of GoogleCloudAiplatformV1ExportModelRequestOutputConfig.



14216
14217
14218
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14216

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_destinationGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsDestination

The Google Cloud Storage location where the output is to be written to. Corresponds to the JSON property artifactDestination



14202
14203
14204
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14202

def artifact_destination
  @artifact_destination
end

#export_format_idString

The ID of the format in which the Model must be exported. Each Model lists the export formats it supports. If no value is provided here, then the first from the list of the Model's supported formats is used by default. Corresponds to the JSON property exportFormatId

Returns:

  • (String)


14209
14210
14211
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14209

def export_format_id
  @export_format_id
end

#image_destinationGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ContainerRegistryDestination

The Container Registry location for the container image. Corresponds to the JSON property imageDestination



14214
14215
14216
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14214

def image_destination
  @image_destination
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14221
14222
14223
14224
14225
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14221

def update!(**args)
  @artifact_destination = args[:artifact_destination] if args.key?(:artifact_destination)
  @export_format_id = args[:export_format_id] if args.key?(:export_format_id)
  @image_destination = args[:image_destination] if args.key?(:image_destination)
end