Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExternalApi

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Retrieve from data source powered by external API for grounding. The external API is not owned by Google, but need to follow the pre-defined API spec.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ExternalApi

Returns a new instance of GoogleCloudAiplatformV1ExternalApi.



12820
12821
12822
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12820

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_authGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ApiAuth

The generic reusable api auth config. Deprecated. Please use AuthConfig ( google/cloud/aiplatform/master/auth.proto) instead. Corresponds to the JSON property apiAuth



12791
12792
12793
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12791

def api_auth
  @api_auth
end

#api_specString

The API spec that the external API implements. Corresponds to the JSON property apiSpec

Returns:

  • (String)


12796
12797
12798
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12796

def api_spec
  @api_spec
end

#auth_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1AuthConfig

Auth configuration to run the extension. Corresponds to the JSON property authConfig



12801
12802
12803
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12801

def auth_config
  @auth_config
end

#elastic_search_paramsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ExternalApiElasticSearchParams

The search parameters to use for the ELASTIC_SEARCH spec. Corresponds to the JSON property elasticSearchParams



12806
12807
12808
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12806

def elastic_search_params
  @elastic_search_params
end

#endpointString

The endpoint of the external API. The system will call the API at this endpoint to retrieve the data for grounding. Example: https://acme.com:443/ search Corresponds to the JSON property endpoint

Returns:

  • (String)


12813
12814
12815
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12813

def endpoint
  @endpoint
end

#simple_search_paramsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ExternalApiSimpleSearchParams

The search parameters to use for SIMPLE_SEARCH spec. Corresponds to the JSON property simpleSearchParams



12818
12819
12820
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12818

def simple_search_params
  @simple_search_params
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12825
12826
12827
12828
12829
12830
12831
12832
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12825

def update!(**args)
  @api_auth = args[:api_auth] if args.key?(:api_auth)
  @api_spec = args[:api_spec] if args.key?(:api_spec)
  @auth_config = args[:auth_config] if args.key?(:auth_config)
  @elastic_search_params = args[:elastic_search_params] if args.key?(:elastic_search_params)
  @endpoint = args[:endpoint] if args.key?(:endpoint)
  @simple_search_params = args[:simple_search_params] if args.key?(:simple_search_params)
end