Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureMonitoringStatsAnomaly
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureMonitoringStatsAnomaly
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A list of historical SnapshotAnalysis or ImportFeaturesAnalysis stats requested by user, sorted by FeatureStatsAnomaly.start_time descending.
Instance Attribute Summary collapse
-
#feature_stats_anomaly ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureStatsAnomaly
Stats and Anomaly generated at specific timestamp for specific Feature.
-
#objective ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureMonitoringStatsAnomaly
constructor
A new instance of GoogleCloudAiplatformV1FeatureMonitoringStatsAnomaly.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureMonitoringStatsAnomaly
Returns a new instance of GoogleCloudAiplatformV1FeatureMonitoringStatsAnomaly.
14384 14385 14386 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14384 def initialize(**args) update!(**args) end |
Instance Attribute Details
#feature_stats_anomaly ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureStatsAnomaly
Stats and Anomaly generated at specific timestamp for specific Feature. The
start_time and end_time are used to define the time range of the dataset that
current stats belongs to, e.g. prediction traffic is bucketed into prediction
datasets by time window. If the Dataset is not defined by time window,
start_time = end_time. Timestamp of the stats and anomalies always refers to
end_time. Raw stats and anomalies are stored in stats_uri or anomaly_uri in
the tensorflow defined protos. Field data_stats contains almost identical
information with the raw stats in Vertex AI defined proto, for UI to display.
Corresponds to the JSON property featureStatsAnomaly
14377 14378 14379 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14377 def feature_stats_anomaly @feature_stats_anomaly end |
#objective ⇒ String
Output only. The objective for each stats.
Corresponds to the JSON property objective
14382 14383 14384 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14382 def objective @objective end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14389 14390 14391 14392 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14389 def update!(**args) @feature_stats_anomaly = args[:feature_stats_anomaly] if args.key?(:feature_stats_anomaly) @objective = args[:objective] if args.key?(:objective) end |