Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureNoiseSigmaNoiseSigmaForFeature
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureNoiseSigmaNoiseSigmaForFeature
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Noise sigma for a single feature.
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the input feature for which noise sigma is provided.
-
#sigma ⇒ Float
This represents the standard deviation of the Gaussian kernel that will be used to add noise to the feature prior to computing gradients.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureNoiseSigmaNoiseSigmaForFeature
constructor
A new instance of GoogleCloudAiplatformV1FeatureNoiseSigmaNoiseSigmaForFeature.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureNoiseSigmaNoiseSigmaForFeature
Returns a new instance of GoogleCloudAiplatformV1FeatureNoiseSigmaNoiseSigmaForFeature.
9614 9615 9616 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9614 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
The name of the input feature for which noise sigma is provided. The features
are defined in explanation metadata inputs.
Corresponds to the JSON property name
9604 9605 9606 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9604 def name @name end |
#sigma ⇒ Float
This represents the standard deviation of the Gaussian kernel that will be
used to add noise to the feature prior to computing gradients. Similar to
noise_sigma but represents the noise added to the current feature. Defaults to
0.1.
Corresponds to the JSON property sigma
9612 9613 9614 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9612 def sigma @sigma end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9619 9620 9621 9622 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9619 def update!(**args) @name = args[:name] if args.key?(:name) @sigma = args[:sigma] if args.key?(:sigma) end |