Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStoreBigtable

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureOnlineStoreBigtable

Returns a new instance of GoogleCloudAiplatformV1FeatureOnlineStoreBigtable.



14967
14968
14969
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14967

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_scalingGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStoreBigtableAutoScaling

Required. Autoscaling config applied to Bigtable Instance. Corresponds to the JSON property autoScaling



14946
14947
14948
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14946

def auto_scaling
  @auto_scaling
end

#bigtable_metadataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStoreBigtableBigtableMetadata

Metadata of the Bigtable instance. This is used by direct read access to the Bigtable in tenant project. Corresponds to the JSON property bigtableMetadata



14952
14953
14954
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14952

def 
  @bigtable_metadata
end

#enable_direct_bigtable_accessBoolean Also known as: enable_direct_bigtable_access?

Optional. It true, enable direct access to the Bigtable instance. Corresponds to the JSON property enableDirectBigtableAccess

Returns:

  • (Boolean)


14957
14958
14959
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14957

def enable_direct_bigtable_access
  @enable_direct_bigtable_access
end

#zoneString

Optional. The zone where the underlying Bigtable cluster for the primary Bigtable instance will be provisioned. Only the zone must be provided. For example, only "us-central1-a" should be provided. Corresponds to the JSON property zone

Returns:

  • (String)


14965
14966
14967
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14965

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14972
14973
14974
14975
14976
14977
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14972

def update!(**args)
  @auto_scaling = args[:auto_scaling] if args.key?(:auto_scaling)
  @bigtable_metadata = args[:bigtable_metadata] if args.key?(:bigtable_metadata)
  @enable_direct_bigtable_access = args[:enable_direct_bigtable_access] if args.key?(:enable_direct_bigtable_access)
  @zone = args[:zone] if args.key?(:zone)
end