Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewBigtableMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewBigtableMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Metadata for the Cloud Bigtable that supports directly interacting Bigtable instances.
Instance Attribute Summary collapse
-
#read_app_profile ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureViewBigtableMetadata
constructor
A new instance of GoogleCloudAiplatformV1FeatureViewBigtableMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureViewBigtableMetadata
Returns a new instance of GoogleCloudAiplatformV1FeatureViewBigtableMetadata.
13992 13993 13994 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13992 def initialize(**args) update!(**args) end |
Instance Attribute Details
#read_app_profile ⇒ String
Output only. The Bigtable App Profile to use for reading from Bigtable.
Corresponds to the JSON property readAppProfile
13990 13991 13992 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13990 def read_app_profile @read_app_profile end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13997 13998 13999 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13997 def update!(**args) @read_app_profile = args[:read_app_profile] if args.key?(:read_app_profile) end |