Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewDirectWriteResponseWriteResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewDirectWriteResponseWriteResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Details about the write for each key.
Instance Attribute Summary collapse
-
#data_key ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewDataKey
Lookup key for a feature view.
-
#online_store_write_time ⇒ String
When the feature values were written to the online store.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureViewDirectWriteResponseWriteResponse
constructor
A new instance of GoogleCloudAiplatformV1FeatureViewDirectWriteResponseWriteResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureViewDirectWriteResponseWriteResponse
Returns a new instance of GoogleCloudAiplatformV1FeatureViewDirectWriteResponseWriteResponse.
13247 13248 13249 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13247 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_key ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewDataKey
Lookup key for a feature view.
Corresponds to the JSON property dataKey
13239 13240 13241 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13239 def data_key @data_key end |
#online_store_write_time ⇒ String
When the feature values were written to the online store. If
FeatureViewDirectWriteResponse.status is not OK, this field is not populated.
Corresponds to the JSON property onlineStoreWriteTime
13245 13246 13247 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13245 def online_store_write_time @online_store_write_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13252 13253 13254 13255 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13252 def update!(**args) @data_key = args[:data_key] if args.key?(:data_key) @online_store_write_time = args[:online_store_write_time] if args.key?(:online_store_write_time) end |