Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewFeatureRegistrySource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A Feature Registry source for features that need to be synced to Online Store.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureViewFeatureRegistrySource

Returns a new instance of GoogleCloudAiplatformV1FeatureViewFeatureRegistrySource.



10335
10336
10337
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10335

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#feature_groupsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewFeatureRegistrySourceFeatureGroup>

Required. List of features that need to be synced to Online Store. Corresponds to the JSON property featureGroups



10328
10329
10330
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10328

def feature_groups
  @feature_groups
end

#project_numberFixnum

Optional. The project number of the parent project of the Feature Groups. Corresponds to the JSON property projectNumber

Returns:

  • (Fixnum)


10333
10334
10335
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10333

def project_number
  @project_number
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10340
10341
10342
10343
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10340

def update!(**args)
  @feature_groups = args[:feature_groups] if args.key?(:feature_groups)
  @project_number = args[:project_number] if args.key?(:project_number)
end