Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewIndexConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewIndexConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Configuration for vector indexing.
Instance Attribute Summary collapse
-
#brute_force_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewIndexConfigBruteForceConfig
Configuration options for using brute force search.
-
#crowding_column ⇒ String
Optional.
-
#distance_measure_type ⇒ String
Optional.
-
#embedding_column ⇒ String
Optional.
-
#embedding_dimension ⇒ Fixnum
Optional.
-
#filter_columns ⇒ Array<String>
Optional.
-
#tree_ah_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewIndexConfigTreeAhConfig
Configuration options for the tree-AH algorithm.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureViewIndexConfig
constructor
A new instance of GoogleCloudAiplatformV1FeatureViewIndexConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureViewIndexConfig
Returns a new instance of GoogleCloudAiplatformV1FeatureViewIndexConfig.
11064 11065 11066 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11064 def initialize(**args) update!(**args) end |
Instance Attribute Details
#brute_force_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewIndexConfigBruteForceConfig
Configuration options for using brute force search.
Corresponds to the JSON property bruteForceConfig
11026 11027 11028 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11026 def brute_force_config @brute_force_config end |
#crowding_column ⇒ String
Optional. Column of crowding. This column contains crowding attribute which is
a constraint on a neighbor list produced by FeatureOnlineStoreService.
SearchNearestEntities to diversify search results. If NearestNeighborQuery.
per_crowding_attribute_neighbor_count is set to K in
SearchNearestEntitiesRequest, it's guaranteed that no more than K entities of
the same crowding attribute are returned in the response.
Corresponds to the JSON property crowdingColumn
11036 11037 11038 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11036 def crowding_column @crowding_column end |
#distance_measure_type ⇒ String
Optional. The distance measure used in nearest neighbor search.
Corresponds to the JSON property distanceMeasureType
11041 11042 11043 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11041 def distance_measure_type @distance_measure_type end |
#embedding_column ⇒ String
Optional. Column of embedding. This column contains the source data to create
index for vector search. embedding_column must be set when using vector search.
Corresponds to the JSON property embeddingColumn
11047 11048 11049 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11047 def @embedding_column end |
#embedding_dimension ⇒ Fixnum
Optional. The number of dimensions of the input embedding.
Corresponds to the JSON property embeddingDimension
11052 11053 11054 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11052 def @embedding_dimension end |
#filter_columns ⇒ Array<String>
Optional. Columns of features that're used to filter vector search results.
Corresponds to the JSON property filterColumns
11057 11058 11059 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11057 def filter_columns @filter_columns end |
#tree_ah_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewIndexConfigTreeAhConfig
Configuration options for the tree-AH algorithm.
Corresponds to the JSON property treeAhConfig
11062 11063 11064 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11062 def tree_ah_config @tree_ah_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11069 11070 11071 11072 11073 11074 11075 11076 11077 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11069 def update!(**args) @brute_force_config = args[:brute_force_config] if args.key?(:brute_force_config) @crowding_column = args[:crowding_column] if args.key?(:crowding_column) @distance_measure_type = args[:distance_measure_type] if args.key?(:distance_measure_type) @embedding_column = args[:embedding_column] if args.key?(:embedding_column) @embedding_dimension = args[:embedding_dimension] if args.key?(:embedding_dimension) @filter_columns = args[:filter_columns] if args.key?(:filter_columns) @tree_ah_config = args[:tree_ah_config] if args.key?(:tree_ah_config) end |