Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewSyncSyncSummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Summary from the Sync job. For continuous syncs, the summary is updated periodically. For batch syncs, it gets updated on completion of the sync.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureViewSyncSyncSummary

Returns a new instance of GoogleCloudAiplatformV1FeatureViewSyncSyncSummary.



14671
14672
14673
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14671

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#row_syncedFixnum

Output only. Total number of rows synced. Corresponds to the JSON property rowSynced

Returns:

  • (Fixnum)


14658
14659
14660
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14658

def row_synced
  @row_synced
end

#system_watermark_timeString

Lower bound of the system time watermark for the sync job. This is only set for continuously syncing feature views. Corresponds to the JSON property systemWatermarkTime

Returns:

  • (String)


14664
14665
14666
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14664

def system_watermark_time
  @system_watermark_time
end

#total_slotFixnum

Output only. BigQuery slot milliseconds consumed for the sync job. Corresponds to the JSON property totalSlot

Returns:

  • (Fixnum)


14669
14670
14671
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14669

def total_slot
  @total_slot
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14676
14677
14678
14679
14680
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14676

def update!(**args)
  @row_synced = args[:row_synced] if args.key?(:row_synced)
  @system_watermark_time = args[:system_watermark_time] if args.key?(:system_watermark_time)
  @total_slot = args[:total_slot] if args.key?(:total_slot)
end