Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewVertexRagSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A Vertex Rag source for features that need to be synced to Online Store.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureViewVertexRagSource

Returns a new instance of GoogleCloudAiplatformV1FeatureViewVertexRagSource.



15020
15021
15022
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15020

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#rag_corpus_idFixnum

Optional. The RAG corpus id corresponding to this FeatureView. Corresponds to the JSON property ragCorpusId

Returns:

  • (Fixnum)


15008
15009
15010
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15008

def rag_corpus_id
  @rag_corpus_id
end

#uriString

Required. The BigQuery view/table URI that will be materialized on each manual sync trigger. The table/view is expected to have the following columns and types at least: - corpus_id (STRING, NULLABLE/REQUIRED) - file_id (STRING, NULLABLE/REQUIRED) - chunk_id (STRING, NULLABLE/REQUIRED) - chunk_data_type (STRING, NULLABLE/REQUIRED) - chunk_data (STRING, NULLABLE/REQUIRED) - embeddings (FLOAT, REPEATED) - file_original_uri (STRING, NULLABLE/REQUIRED) Corresponds to the JSON property uri

Returns:

  • (String)


15018
15019
15020
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15018

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15025
15026
15027
15028
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15025

def update!(**args)
  @rag_corpus_id = args[:rag_corpus_id] if args.key?(:rag_corpus_id)
  @uri = args[:uri] if args.key?(:uri)
end