Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeaturestoreMonitoringConfigImportFeaturesAnalysis

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Configuration of the Featurestore's ImportFeature Analysis Based Monitoring. This type of analysis generates statistics for values of each Feature imported by every ImportFeatureValues operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FeaturestoreMonitoringConfigImportFeaturesAnalysis

Returns a new instance of GoogleCloudAiplatformV1FeaturestoreMonitoringConfigImportFeaturesAnalysis.



16190
16191
16192
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16190

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#anomaly_detection_baselineString

The baseline used to do anomaly detection for the statistics generated by import features analysis. Corresponds to the JSON property anomalyDetectionBaseline

Returns:

  • (String)


16182
16183
16184
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16182

def anomaly_detection_baseline
  @anomaly_detection_baseline
end

#stateString

Whether to enable / disable / inherite default hebavior for import features analysis. Corresponds to the JSON property state

Returns:

  • (String)


16188
16189
16190
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16188

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16195
16196
16197
16198
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16195

def update!(**args)
  @anomaly_detection_baseline = args[:anomaly_detection_baseline] if args.key?(:anomaly_detection_baseline)
  @state = args[:state] if args.key?(:state)
end