Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeaturestoreMonitoringConfigSnapshotAnalysis

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Configuration of the Featurestore's Snapshot Analysis Based Monitoring. This type of analysis generates statistics for each Feature based on a snapshot of the latest feature value of each entities every monitoring_interval.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FeaturestoreMonitoringConfigSnapshotAnalysis

Returns a new instance of GoogleCloudAiplatformV1FeaturestoreMonitoringConfigSnapshotAnalysis.



14801
14802
14803
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14801

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disabledBoolean Also known as: disabled?

The monitoring schedule for snapshot analysis. For EntityType-level config: unset / disabled = true indicates disabled by default for Features under it; otherwise by default enable snapshot analysis monitoring with monitoring_interval for Features under it. Feature-level config: disabled = true indicates disabled regardless of the EntityType-level config; unset monitoring_interval indicates going with EntityType-level config; otherwise run snapshot analysis monitoring with monitoring_interval regardless of the EntityType-level config. Explicitly Disable the snapshot analysis based monitoring. Corresponds to the JSON property disabled

Returns:

  • (Boolean)


14786
14787
14788
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14786

def disabled
  @disabled
end

#monitoring_interval_daysFixnum

Configuration of the snapshot analysis based monitoring pipeline running interval. The value indicates number of days. Corresponds to the JSON property monitoringIntervalDays

Returns:

  • (Fixnum)


14793
14794
14795
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14793

def monitoring_interval_days
  @monitoring_interval_days
end

#staleness_daysFixnum

Customized export features time window for snapshot analysis. Unit is one day. Default value is 3 weeks. Minimum value is 1 day. Maximum value is 4000 days. Corresponds to the JSON property stalenessDays

Returns:

  • (Fixnum)


14799
14800
14801
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14799

def staleness_days
  @staleness_days
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14806
14807
14808
14809
14810
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14806

def update!(**args)
  @disabled = args[:disabled] if args.key?(:disabled)
  @monitoring_interval_days = args[:monitoring_interval_days] if args.key?(:monitoring_interval_days)
  @staleness_days = args[:staleness_days] if args.key?(:staleness_days)
end