Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FindNeighborsResponseNeighbor
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FindNeighborsResponseNeighbor
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A neighbor of the query vector.
Instance Attribute Summary collapse
-
#datapoint ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapoint
A datapoint of Index.
-
#distance ⇒ Float
The distance between the neighbor and the dense embedding query.
-
#sparse_distance ⇒ Float
The distance between the neighbor and the query sparse_embedding.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1FindNeighborsResponseNeighbor
constructor
A new instance of GoogleCloudAiplatformV1FindNeighborsResponseNeighbor.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1FindNeighborsResponseNeighbor
Returns a new instance of GoogleCloudAiplatformV1FindNeighborsResponseNeighbor.
15436 15437 15438 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15436 def initialize(**args) update!(**args) end |
Instance Attribute Details
#datapoint ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapoint
A datapoint of Index.
Corresponds to the JSON property datapoint
15424 15425 15426 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15424 def datapoint @datapoint end |
#distance ⇒ Float
The distance between the neighbor and the dense embedding query.
Corresponds to the JSON property distance
15429 15430 15431 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15429 def distance @distance end |
#sparse_distance ⇒ Float
The distance between the neighbor and the query sparse_embedding.
Corresponds to the JSON property sparseDistance
15434 15435 15436 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15434 def sparse_distance @sparse_distance end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15441 15442 15443 15444 15445 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15441 def update!(**args) @datapoint = args[:datapoint] if args.key?(:datapoint) @distance = args[:distance] if args.key?(:distance) @sparse_distance = args[:sparse_distance] if args.key?(:sparse_distance) end |