Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateLossClustersRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for EvaluationAnalyticsService.GenerateLossClusters.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateLossClustersRequest

Returns a new instance of GoogleCloudAiplatformV1GenerateLossClustersRequest.



17970
17971
17972
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17970

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#configsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1LossAnalysisConfig>

Required. Configuration for the analysis algorithm. Analysis for multiple metrics and multiple candidates could be specified. Corresponds to the JSON property configs



17957
17958
17959
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17957

def configs
  @configs
end

#evaluation_setString

Reference to a persisted EvaluationSet. The service will read items from this set. Corresponds to the JSON property evaluationSet

Returns:

  • (String)


17963
17964
17965
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17963

def evaluation_set
  @evaluation_set
end

#inline_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateLossClustersRequestEvaluationResultList

A wrapper to allow providing a list of items inline. Corresponds to the JSON property inlineResults



17968
17969
17970
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17968

def inline_results
  @inline_results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17975
17976
17977
17978
17979
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17975

def update!(**args)
  @configs = args[:configs] if args.key?(:configs)
  @evaluation_set = args[:evaluation_set] if args.key?(:evaluation_set)
  @inline_results = args[:inline_results] if args.key?(:inline_results)
end