Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateMemoriesRequestDirectContentsSourceEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A single piece of conversation from which to generate memories.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateMemoriesRequestDirectContentsSourceEvent

Returns a new instance of GoogleCloudAiplatformV1GenerateMemoriesRequestDirectContentsSourceEvent.



16475
16476
16477
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16475

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Content

The structured data content of a message. A Content message contains a role field, which indicates the producer of the content, and a parts field, which contains the multi-part data of the message. Corresponds to the JSON property content



16473
16474
16475
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16473

def content
  @content
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16480
16481
16482
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16480

def update!(**args)
  @content = args[:content] if args.key?(:content)
end