Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateSyntheticDataRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for DataFoundryService.GenerateSyntheticData. It contains the settings and information needed to generate synthetic data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateSyntheticDataRequest

Returns a new instance of GoogleCloudAiplatformV1GenerateSyntheticDataRequest.



18255
18256
18257
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18255

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countFixnum

Required. The number of synthetic examples to generate. For this stateless API, you can generate up to 50 examples in a single request. Corresponds to the JSON property count

Returns:

  • (Fixnum)


18234
18235
18236
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18234

def count
  @count
end

#examplesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SyntheticExample>

Optional. A list of few-shot examples that help the model understand the desired style, tone, and format of the generated synthetic data. Providing these few-shot examples can significantly improve the quality and relevance of the output. Corresponds to the JSON property examples



18242
18243
18244
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18242

def examples
  @examples
end

#output_field_specsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1OutputFieldSpec>

Required. Defines the schema of each synthetic example to be generated, defined by a list of fields. Corresponds to the JSON property outputFieldSpecs



18248
18249
18250
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18248

def output_field_specs
  @output_field_specs
end

#task_descriptionGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TaskDescriptionStrategy

Defines a generation strategy based on a general task description. Corresponds to the JSON property taskDescription



18253
18254
18255
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18253

def task_description
  @task_description
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18260
18261
18262
18263
18264
18265
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18260

def update!(**args)
  @count = args[:count] if args.key?(:count)
  @examples = args[:examples] if args.key?(:examples)
  @output_field_specs = args[:output_field_specs] if args.key?(:output_field_specs)
  @task_description = args[:task_description] if args.key?(:task_description)
end