Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateSyntheticDataResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The response message for the GenerateSyntheticData method, containing the synthetic examples generated by the Gen AI evaluation service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateSyntheticDataResponse

Returns a new instance of GoogleCloudAiplatformV1GenerateSyntheticDataResponse.



16623
16624
16625
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16623

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#synthetic_examplesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SyntheticExample>

A list of generated synthetic examples, each containing a complete synthetic data instance generated based on your request. Corresponds to the JSON property syntheticExamples



16621
16622
16623
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16621

def synthetic_examples
  @synthetic_examples
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16628
16629
16630
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16628

def update!(**args)
  @synthetic_examples = args[:synthetic_examples] if args.key?(:synthetic_examples)
end