Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateVideoResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateVideoResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Generate video response.
Instance Attribute Summary collapse
-
#generated_samples ⇒ Array<String>
The cloud storage uris of the generated videos.
-
#rai_media_filtered_count ⇒ Fixnum
Returns if any videos were filtered due to RAI policies.
-
#rai_media_filtered_reasons ⇒ Array<String>
Returns rai failure reasons if any.
-
#videos ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateVideoResponseVideo>
List of video bytes or Cloud Storage URIs of the generated videos.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateVideoResponse
constructor
A new instance of GoogleCloudAiplatformV1GenerateVideoResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateVideoResponse
Returns a new instance of GoogleCloudAiplatformV1GenerateVideoResponse.
15663 15664 15665 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15663 def initialize(**args) update!(**args) end |
Instance Attribute Details
#generated_samples ⇒ Array<String>
The cloud storage uris of the generated videos.
Corresponds to the JSON property generatedSamples
15646 15647 15648 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15646 def generated_samples @generated_samples end |
#rai_media_filtered_count ⇒ Fixnum
Returns if any videos were filtered due to RAI policies.
Corresponds to the JSON property raiMediaFilteredCount
15651 15652 15653 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15651 def rai_media_filtered_count @rai_media_filtered_count end |
#rai_media_filtered_reasons ⇒ Array<String>
Returns rai failure reasons if any.
Corresponds to the JSON property raiMediaFilteredReasons
15656 15657 15658 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15656 def rai_media_filtered_reasons @rai_media_filtered_reasons end |
#videos ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateVideoResponseVideo>
List of video bytes or Cloud Storage URIs of the generated videos.
Corresponds to the JSON property videos
15661 15662 15663 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15661 def videos @videos end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15668 15669 15670 15671 15672 15673 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15668 def update!(**args) @generated_samples = args[:generated_samples] if args.key?(:generated_samples) @rai_media_filtered_count = args[:rai_media_filtered_count] if args.key?(:rai_media_filtered_count) @rai_media_filtered_reasons = args[:rai_media_filtered_reasons] if args.key?(:rai_media_filtered_reasons) @videos = args[:videos] if args.key?(:videos) end |