Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfigRoutingConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The configuration for routing the request to a specific model. This can be used to control which model is used for the generation, either automatically or by specifying a model name.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerationConfigRoutingConfig

Returns a new instance of GoogleCloudAiplatformV1GenerationConfigRoutingConfig.



18658
18659
18660
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18658

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_modeGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfigRoutingConfigAutoRoutingMode

The configuration for automated routing. When automated routing is specified, the routing will be determined by the pretrained routing model and customer provided model routing preference. Corresponds to the JSON property autoMode



18650
18651
18652
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18650

def auto_mode
  @auto_mode
end

#manual_modeGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfigRoutingConfigManualRoutingMode

The configuration for manual routing. When manual routing is specified, the model will be selected based on the model name provided. Corresponds to the JSON property manualMode



18656
18657
18658
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18656

def manual_mode
  @manual_mode
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18663
18664
18665
18666
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18663

def update!(**args)
  @auto_mode = args[:auto_mode] if args.key?(:auto_mode)
  @manual_mode = args[:manual_mode] if args.key?(:manual_mode)
end