Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfigThinkingConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Configuration for the model's thinking features. "Thinking" is a process where the model breaks down a complex task into smaller, manageable steps. This allows the model to reason about the task, plan its approach, and execute the plan to generate a high-quality response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerationConfigThinkingConfig

Returns a new instance of GoogleCloudAiplatformV1GenerationConfigThinkingConfig.



18739
18740
18741
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18739

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#include_thoughtsBoolean Also known as: include_thoughts?

Optional. If true, the model will include its thoughts in the response. " Thoughts" are the intermediate steps the model takes to arrive at the final response. They can provide insights into the model's reasoning process and help with debugging. If this is true, thoughts are returned only when available. Corresponds to the JSON property includeThoughts

Returns:

  • (Boolean)


18724
18725
18726
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18724

def include_thoughts
  @include_thoughts
end

#thinking_budgetFixnum

Optional. The token budget for the model's thinking process. The model will make a best effort to stay within this budget. This can be used to control the trade-off between response quality and latency. Corresponds to the JSON property thinkingBudget

Returns:

  • (Fixnum)


18732
18733
18734
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18732

def thinking_budget
  @thinking_budget
end

#thinking_levelString

Optional. The number of thoughts tokens that the model should generate. Corresponds to the JSON property thinkingLevel

Returns:

  • (String)


18737
18738
18739
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18737

def thinking_level
  @thinking_level
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18744
18745
18746
18747
18748
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18744

def update!(**args)
  @include_thoughts = args[:include_thoughts] if args.key?(:include_thoughts)
  @thinking_budget = args[:thinking_budget] if args.key?(:thinking_budget)
  @thinking_level = args[:thinking_level] if args.key?(:thinking_level)
end