Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GoogleMaps
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GoogleMaps
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Tool to retrieve public maps data for grounding, powered by Google.
Instance Attribute Summary collapse
-
#enable_widget ⇒ Boolean
(also: #enable_widget?)
Optional.
-
#grounding_types ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GoogleMapsGroundingTypes
Defines the types of Google Maps grounding that can be enabled and their configurations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GoogleMaps
constructor
A new instance of GoogleCloudAiplatformV1GoogleMaps.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GoogleMaps
Returns a new instance of GoogleCloudAiplatformV1GoogleMaps.
18888 18889 18890 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18888 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable_widget ⇒ Boolean Also known as: enable_widget?
Optional. Deprecated: The Google Maps contextual widget behavior in Grounding
with Google Maps is being deprecated; this field is planned for removal and no
longer has any effect once removed. If true, include the widget context token
in the response.
Corresponds to the JSON property enableWidget
18879 18880 18881 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18879 def @enable_widget end |
#grounding_types ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GoogleMapsGroundingTypes
Defines the types of Google Maps grounding that can be enabled and their
configurations.
Corresponds to the JSON property groundingTypes
18886 18887 18888 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18886 def grounding_types @grounding_types end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18893 18894 18895 18896 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18893 def update!(**args) @enable_widget = args[:enable_widget] if args.key?(:enable_widget) @grounding_types = args[:grounding_types] if args.key?(:grounding_types) end |