Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GoogleSearchRetrieval

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Tool to retrieve public web data for grounding, powered by Google.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GoogleSearchRetrieval

Returns a new instance of GoogleCloudAiplatformV1GoogleSearchRetrieval.



10153
10154
10155
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10153

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disable_attributionBoolean Also known as: disable_attribution?

Optional. Disable using the result from this tool in detecting grounding attribution. This does not affect how the result is given to the model for generation. Corresponds to the JSON property disableAttribution

Returns:

  • (Boolean)


10150
10151
10152
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10150

def disable_attribution
  @disable_attribution
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10158
10159
10160
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10158

def update!(**args)
  @disable_attribution = args[:disable_attribution] if args.key?(:disable_attribution)
end