Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSourcesAuthorAttribution
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSourcesAuthorAttribution
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Author attribution for a photo or review.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Name of the author of the Photo or Review.
-
#photo_uri ⇒ String
Profile photo URI of the author of the Photo or Review.
-
#uri ⇒ String
URI of the author of the Photo or Review.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSourcesAuthorAttribution
constructor
A new instance of GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSourcesAuthorAttribution.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSourcesAuthorAttribution
Returns a new instance of GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSourcesAuthorAttribution.
13640 13641 13642 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13640 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Name of the author of the Photo or Review.
Corresponds to the JSON property displayName
13628 13629 13630 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13628 def display_name @display_name end |
#photo_uri ⇒ String
Profile photo URI of the author of the Photo or Review.
Corresponds to the JSON property photoUri
13633 13634 13635 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13633 def photo_uri @photo_uri end |
#uri ⇒ String
URI of the author of the Photo or Review.
Corresponds to the JSON property uri
13638 13639 13640 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13638 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13645 13646 13647 13648 13649 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13645 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @photo_uri = args[:photo_uri] if args.key?(:photo_uri) @uri = args[:uri] if args.key?(:uri) end |