Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A review snippet that is used to generate the answer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet

Returns a new instance of GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet.



19234
19235
19236
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19234

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#google_maps_uriString

A link to show the review on Google Maps. Corresponds to the JSON property googleMapsUri

Returns:

  • (String)


19222
19223
19224
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19222

def google_maps_uri
  @google_maps_uri
end

#review_idString

The ID of the review that is being referenced. Corresponds to the JSON property reviewId

Returns:

  • (String)


19227
19228
19229
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19227

def review_id
  @review_id
end

#titleString

The title of the review. Corresponds to the JSON property title

Returns:

  • (String)


19232
19233
19234
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19232

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19239
19240
19241
19242
19243
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19239

def update!(**args)
  @google_maps_uri = args[:google_maps_uri] if args.key?(:google_maps_uri)
  @review_id = args[:review_id] if args.key?(:review_id)
  @title = args[:title] if args.key?(:title)
end