Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkWeb
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkWeb
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A Web chunk is a piece of evidence that comes from a web page. It contains
the URI of the web page, the title of the page, and the domain of the page.
This is used to provide the user with a link to the source of the information.
Instance Attribute Summary collapse
-
#domain ⇒ String
The domain of the web page that contains the evidence.
-
#title ⇒ String
The title of the web page that contains the evidence.
-
#uri ⇒ String
The URI of the web page that contains the evidence.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkWeb
constructor
A new instance of GoogleCloudAiplatformV1GroundingChunkWeb.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkWeb
Returns a new instance of GoogleCloudAiplatformV1GroundingChunkWeb.
19349 19350 19351 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19349 def initialize(**args) update!(**args) end |
Instance Attribute Details
#domain ⇒ String
The domain of the web page that contains the evidence. This can be used to
filter out low-quality sources.
Corresponds to the JSON property domain
19337 19338 19339 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19337 def domain @domain end |
#title ⇒ String
The title of the web page that contains the evidence.
Corresponds to the JSON property title
19342 19343 19344 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19342 def title @title end |
#uri ⇒ String
The URI of the web page that contains the evidence.
Corresponds to the JSON property uri
19347 19348 19349 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19347 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19354 19355 19356 19357 19358 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19354 def update!(**args) @domain = args[:domain] if args.key?(:domain) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) end |