Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Information about the sources that support the content of a response. When grounding is enabled, the model returns citations for claims in the response. This object contains the retrieved sources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingMetadata

Returns a new instance of GoogleCloudAiplatformV1GroundingMetadata.



19451
19452
19453
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19451

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#google_maps_widget_context_tokenString

Optional. Output only. Deprecated: The Google Maps contextual widget behavior in Grounding with Google Maps is being deprecated; this field is planned for removal and will no longer be populated once removed. A token that can be used to render a Google Maps widget with the contextual data. This field is populated only when the grounding source is Google Maps. Corresponds to the JSON property googleMapsWidgetContextToken

Returns:

  • (String)


19394
19395
19396
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19394

def google_maps_widget_context_token
  @google_maps_widget_context_token
end

#grounding_chunksArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunk>

A list of supporting references retrieved from the grounding source. This field is populated when the grounding source is Google Search, Vertex AI Search, or Google Maps. Corresponds to the JSON property groundingChunks



19401
19402
19403
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19401

def grounding_chunks
  @grounding_chunks
end

#grounding_supportsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingSupport>

Optional. A list of grounding supports that connect the generated content to the grounding chunks. This field is populated when the grounding source is Google Search or Vertex AI Search. Corresponds to the JSON property groundingSupports



19408
19409
19410
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19408

def grounding_supports
  @grounding_supports
end

#image_search_queriesArray<String>

Optional. The image search queries that were used to generate the content. This field is populated only when the grounding source is Google Search with the Image Search search_type enabled. Corresponds to the JSON property imageSearchQueries

Returns:

  • (Array<String>)


19415
19416
19417
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19415

def image_search_queries
  @image_search_queries
end

#retrieval_metadataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrievalMetadata

Metadata related to the retrieval grounding source. This is part of the GroundingMetadata returned when grounding is enabled. Corresponds to the JSON property retrievalMetadata



19421
19422
19423
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19421

def 
  @retrieval_metadata
end

#retrieval_queriesArray<String>

Optional. The queries that were executed by the retrieval tools. This field is populated only when the grounding source is a retrieval tool, such as Vertex AI Search. Corresponds to the JSON property retrievalQueries

Returns:

  • (Array<String>)


19428
19429
19430
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19428

def retrieval_queries
  @retrieval_queries
end

#search_entry_pointGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SearchEntryPoint

An entry point for displaying Google Search results. A SearchEntryPoint is populated when the grounding source for a model's response is Google Search. It provides information that you can use to display the search results in your application. Corresponds to the JSON property searchEntryPoint



19436
19437
19438
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19436

def search_entry_point
  @search_entry_point
end

#source_flagging_urisArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingMetadataSourceFlaggingUri>

Optional. Output only. A list of URIs that can be used to flag a place or review for inappropriate content. This field is populated only when the grounding source is Google Maps. Corresponds to the JSON property sourceFlaggingUris



19443
19444
19445
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19443

def source_flagging_uris
  @source_flagging_uris
end

#web_search_queriesArray<String>

Optional. The web search queries that were used to generate the content. This field is populated only when the grounding source is Google Search. Corresponds to the JSON property webSearchQueries

Returns:

  • (Array<String>)


19449
19450
19451
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19449

def web_search_queries
  @web_search_queries
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19456
19457
19458
19459
19460
19461
19462
19463
19464
19465
19466
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19456

def update!(**args)
  @google_maps_widget_context_token = args[:google_maps_widget_context_token] if args.key?(:google_maps_widget_context_token)
  @grounding_chunks = args[:grounding_chunks] if args.key?(:grounding_chunks)
  @grounding_supports = args[:grounding_supports] if args.key?(:grounding_supports)
  @image_search_queries = args[:image_search_queries] if args.key?(:image_search_queries)
  @retrieval_metadata = args[:retrieval_metadata] if args.key?(:retrieval_metadata)
  @retrieval_queries = args[:retrieval_queries] if args.key?(:retrieval_queries)
  @search_entry_point = args[:search_entry_point] if args.key?(:search_entry_point)
  @source_flagging_uris = args[:source_flagging_uris] if args.key?(:source_flagging_uris)
  @web_search_queries = args[:web_search_queries] if args.key?(:web_search_queries)
end