Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingSupport
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingSupport
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A collection of supporting references for a segment or part of the model's response.
Instance Attribute Summary collapse
-
#confidence_scores ⇒ Array<Float>
The confidence scores for the support references.
-
#grounding_chunk_indices ⇒ Array<Fixnum>
A list of indices into the
grounding_chunksfield of theGroundingMetadatamessage. -
#rendered_parts ⇒ Array<Fixnum>
Indices into the
rendered_partsfield of theGroundingMetadatamessage. -
#segment ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Segment
A segment of the content.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingSupport
constructor
A new instance of GoogleCloudAiplatformV1GroundingSupport.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingSupport
Returns a new instance of GoogleCloudAiplatformV1GroundingSupport.
17663 17664 17665 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17663 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence_scores ⇒ Array<Float>
The confidence scores for the support references. This list is parallel to the
grounding_chunk_indices list. A score is a value between 0.0 and 1.0, with a
higher score indicating a higher confidence that the reference supports the
claim. For Gemini 2.0 and before, this list has the same size as
grounding_chunk_indices. For Gemini 2.5 and later, this list is empty and
should be ignored.
Corresponds to the JSON property confidenceScores
17640 17641 17642 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17640 def confidence_scores @confidence_scores end |
#grounding_chunk_indices ⇒ Array<Fixnum>
A list of indices into the grounding_chunks field of the GroundingMetadata
message. These indices specify which grounding chunks support the claim made
in the content segment. For example, if this field has the values [1, 3], it
means that grounding_chunks[1] and grounding_chunks[3] are the sources for
the claim in the content segment.
Corresponds to the JSON property groundingChunkIndices
17649 17650 17651 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17649 def grounding_chunk_indices @grounding_chunk_indices end |
#rendered_parts ⇒ Array<Fixnum>
Indices into the rendered_parts field of the GroundingMetadata message.
These indices specify which rendered parts are associated with this support
message.
Corresponds to the JSON property renderedParts
17656 17657 17658 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17656 def rendered_parts @rendered_parts end |
#segment ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Segment
A segment of the content.
Corresponds to the JSON property segment
17661 17662 17663 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17661 def segment @segment end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17668 17669 17670 17671 17672 17673 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17668 def update!(**args) @confidence_scores = args[:confidence_scores] if args.key?(:confidence_scores) @grounding_chunk_indices = args[:grounding_chunk_indices] if args.key?(:grounding_chunk_indices) @rendered_parts = args[:rendered_parts] if args.key?(:rendered_parts) @segment = args[:segment] if args.key?(:segment) end |