Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1HyperparameterTuningJob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents a HyperparameterTuningJob. A HyperparameterTuningJob has a Study specification and multiple CustomJobs with identical CustomJob specification.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1HyperparameterTuningJob

Returns a new instance of GoogleCloudAiplatformV1HyperparameterTuningJob.



19657
19658
19659
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19657

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Time when the HyperparameterTuningJob was created. Corresponds to the JSON property createTime

Returns:

  • (String)


19552
19553
19554
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19552

def create_time
  @create_time
end

#display_nameString

Required. The display name of the HyperparameterTuningJob. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


19558
19559
19560
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19558

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



19564
19565
19566
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19564

def encryption_spec
  @encryption_spec
end

#end_timeString

Output only. Time when the HyperparameterTuningJob entered any of the following states: JOB_STATE_SUCCEEDED, JOB_STATE_FAILED, JOB_STATE_CANCELLED. Corresponds to the JSON property endTime

Returns:

  • (String)


19571
19572
19573
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19571

def end_time
  @end_time
end

#errorGoogle::Apis::AiplatformV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



19581
19582
19583
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19581

def error
  @error
end

#labelsHash<String,String>

The labels with user-defined metadata to organize HyperparameterTuningJobs. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


19590
19591
19592
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19590

def labels
  @labels
end

#max_failed_trial_countFixnum

The number of failed Trials that need to be seen before failing the HyperparameterTuningJob. If set to 0, Vertex AI decides how many Trials must fail before the whole job fails. Corresponds to the JSON property maxFailedTrialCount

Returns:

  • (Fixnum)


19597
19598
19599
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19597

def max_failed_trial_count
  @max_failed_trial_count
end

#max_trial_countFixnum

Required. The desired total number of Trials. Corresponds to the JSON property maxTrialCount

Returns:

  • (Fixnum)


19602
19603
19604
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19602

def max_trial_count
  @max_trial_count
end

#nameString

Output only. Resource name of the HyperparameterTuningJob. Corresponds to the JSON property name

Returns:

  • (String)


19607
19608
19609
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19607

def name
  @name
end

#parallel_trial_countFixnum

Required. The desired number of Trials to run in parallel. Corresponds to the JSON property parallelTrialCount

Returns:

  • (Fixnum)


19612
19613
19614
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19612

def parallel_trial_count
  @parallel_trial_count
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


19617
19618
19619
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19617

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


19623
19624
19625
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19623

def satisfies_pzs
  @satisfies_pzs
end

#start_timeString

Output only. Time when the HyperparameterTuningJob for the first time entered the JOB_STATE_RUNNING state. Corresponds to the JSON property startTime

Returns:

  • (String)


19630
19631
19632
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19630

def start_time
  @start_time
end

#stateString

Output only. The detailed state of the job. Corresponds to the JSON property state

Returns:

  • (String)


19635
19636
19637
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19635

def state
  @state
end

#study_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpec

Represents specification of a Study. Corresponds to the JSON property studySpec



19640
19641
19642
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19640

def study_spec
  @study_spec
end

#trial_job_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1CustomJobSpec

Represents the spec of a CustomJob. Corresponds to the JSON property trialJobSpec



19645
19646
19647
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19645

def trial_job_spec
  @trial_job_spec
end

#trialsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Trial>

Output only. Trials of the HyperparameterTuningJob. Corresponds to the JSON property trials



19650
19651
19652
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19650

def trials
  @trials
end

#update_timeString

Output only. Time when the HyperparameterTuningJob was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


19655
19656
19657
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19655

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19662
19663
19664
19665
19666
19667
19668
19669
19670
19671
19672
19673
19674
19675
19676
19677
19678
19679
19680
19681
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19662

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @end_time = args[:end_time] if args.key?(:end_time)
  @error = args[:error] if args.key?(:error)
  @labels = args[:labels] if args.key?(:labels)
  @max_failed_trial_count = args[:max_failed_trial_count] if args.key?(:max_failed_trial_count)
  @max_trial_count = args[:max_trial_count] if args.key?(:max_trial_count)
  @name = args[:name] if args.key?(:name)
  @parallel_trial_count = args[:parallel_trial_count] if args.key?(:parallel_trial_count)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @study_spec = args[:study_spec] if args.key?(:study_spec)
  @trial_job_spec = args[:trial_job_spec] if args.key?(:trial_job_spec)
  @trials = args[:trials] if args.key?(:trials)
  @update_time = args[:update_time] if args.key?(:update_time)
end