Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ImportFeatureValuesOperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Details of operations that perform import Feature values.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ImportFeatureValuesOperationMetadata

Returns a new instance of GoogleCloudAiplatformV1ImportFeatureValuesOperationMetadata.



19744
19745
19746
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19744

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blocking_operation_idsArray<Fixnum>

List of ImportFeatureValues operations running under a single EntityType that are blocking this operation. Corresponds to the JSON property blockingOperationIds

Returns:

  • (Array<Fixnum>)


19709
19710
19711
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19709

def blocking_operation_ids
  @blocking_operation_ids
end

#generic_metadataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GenericOperationMetadata

Generic Metadata shared by all operations. Corresponds to the JSON property genericMetadata



19714
19715
19716
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19714

def 
  @generic_metadata
end

#imported_entity_countFixnum

Number of entities that have been imported by the operation. Corresponds to the JSON property importedEntityCount

Returns:

  • (Fixnum)


19719
19720
19721
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19719

def imported_entity_count
  @imported_entity_count
end

#imported_feature_value_countFixnum

Number of Feature values that have been imported by the operation. Corresponds to the JSON property importedFeatureValueCount

Returns:

  • (Fixnum)


19724
19725
19726
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19724

def imported_feature_value_count
  @imported_feature_value_count
end

#invalid_row_countFixnum

The number of rows in input source that weren't imported due to either * Not having any featureValues. * Having a null entityId. * Having a null timestamp.

  • Not being parsable (applicable for CSV sources). Corresponds to the JSON property invalidRowCount

Returns:

  • (Fixnum)


19731
19732
19733
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19731

def invalid_row_count
  @invalid_row_count
end

#source_urisArray<String>

The source URI from where Feature values are imported. Corresponds to the JSON property sourceUris

Returns:

  • (Array<String>)


19736
19737
19738
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19736

def source_uris
  @source_uris
end

#timestamp_outside_retention_rows_countFixnum

The number rows that weren't ingested due to having timestamps outside the retention boundary. Corresponds to the JSON property timestampOutsideRetentionRowsCount

Returns:

  • (Fixnum)


19742
19743
19744
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19742

def timestamp_outside_retention_rows_count
  @timestamp_outside_retention_rows_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19749
19750
19751
19752
19753
19754
19755
19756
19757
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19749

def update!(**args)
  @blocking_operation_ids = args[:blocking_operation_ids] if args.key?(:blocking_operation_ids)
  @generic_metadata = args[:generic_metadata] if args.key?(:generic_metadata)
  @imported_entity_count = args[:imported_entity_count] if args.key?(:imported_entity_count)
  @imported_feature_value_count = args[:imported_feature_value_count] if args.key?(:imported_feature_value_count)
  @invalid_row_count = args[:invalid_row_count] if args.key?(:invalid_row_count)
  @source_uris = args[:source_uris] if args.key?(:source_uris)
  @timestamp_outside_retention_rows_count = args[:timestamp_outside_retention_rows_count] if args.key?(:timestamp_outside_retention_rows_count)
end