Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ImportFeatureValuesResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ImportFeatureValuesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Response message for FeaturestoreService.ImportFeatureValues.
Instance Attribute Summary collapse
-
#imported_entity_count ⇒ Fixnum
Number of entities that have been imported by the operation.
-
#imported_feature_value_count ⇒ Fixnum
Number of Feature values that have been imported by the operation.
-
#invalid_row_count ⇒ Fixnum
The number of rows in input source that weren't imported due to either * Not having any featureValues.
-
#timestamp_outside_retention_rows_count ⇒ Fixnum
The number rows that weren't ingested due to having feature timestamps outside the retention boundary.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ImportFeatureValuesResponse
constructor
A new instance of GoogleCloudAiplatformV1ImportFeatureValuesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ImportFeatureValuesResponse
Returns a new instance of GoogleCloudAiplatformV1ImportFeatureValuesResponse.
19186 19187 19188 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19186 def initialize(**args) update!(**args) end |
Instance Attribute Details
#imported_entity_count ⇒ Fixnum
Number of entities that have been imported by the operation.
Corresponds to the JSON property importedEntityCount
19166 19167 19168 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19166 def imported_entity_count @imported_entity_count end |
#imported_feature_value_count ⇒ Fixnum
Number of Feature values that have been imported by the operation.
Corresponds to the JSON property importedFeatureValueCount
19171 19172 19173 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19171 def imported_feature_value_count @imported_feature_value_count end |
#invalid_row_count ⇒ Fixnum
The number of rows in input source that weren't imported due to either * Not having any featureValues. * Having a null entityId. * Having a null timestamp.
- Not being parsable (applicable for CSV sources).
Corresponds to the JSON property
invalidRowCount
19178 19179 19180 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19178 def invalid_row_count @invalid_row_count end |
#timestamp_outside_retention_rows_count ⇒ Fixnum
The number rows that weren't ingested due to having feature timestamps outside
the retention boundary.
Corresponds to the JSON property timestampOutsideRetentionRowsCount
19184 19185 19186 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19184 def @timestamp_outside_retention_rows_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19191 19192 19193 19194 19195 19196 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19191 def update!(**args) @imported_entity_count = args[:imported_entity_count] if args.key?(:imported_entity_count) @imported_feature_value_count = args[:imported_feature_value_count] if args.key?(:imported_feature_value_count) @invalid_row_count = args[:invalid_row_count] if args.key?(:invalid_row_count) @timestamp_outside_retention_rows_count = args[:timestamp_outside_retention_rows_count] if args.key?(:timestamp_outside_retention_rows_count) end |