Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ImportModelEvaluationRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ImportModelEvaluationRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Request message for ModelService.ImportModelEvaluation
Instance Attribute Summary collapse
-
#model_evaluation ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelEvaluation
A collection of metrics calculated by comparing Model's predictions on all of the test data against annotations from the test data.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ImportModelEvaluationRequest
constructor
A new instance of GoogleCloudAiplatformV1ImportModelEvaluationRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ImportModelEvaluationRequest
Returns a new instance of GoogleCloudAiplatformV1ImportModelEvaluationRequest.
18291 18292 18293 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18291 def initialize(**args) update!(**args) end |
Instance Attribute Details
#model_evaluation ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelEvaluation
A collection of metrics calculated by comparing Model's predictions on all of
the test data against annotations from the test data.
Corresponds to the JSON property modelEvaluation
18289 18290 18291 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18289 def model_evaluation @model_evaluation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18296 18297 18298 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18296 def update!(**args) @model_evaluation = args[:model_evaluation] if args.key?(:model_evaluation) end |