Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapointSparseEmbedding

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Feature embedding vector for sparse index. An array of numbers whose values are located in the specified dimensions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1IndexDatapointSparseEmbedding

Returns a new instance of GoogleCloudAiplatformV1IndexDatapointSparseEmbedding.



20804
20805
20806
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20804

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dimensionsArray<Fixnum>

Required. The list of indexes for the embedding values of the sparse vector. Corresponds to the JSON property dimensions

Returns:

  • (Array<Fixnum>)


20797
20798
20799
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20797

def dimensions
  @dimensions
end

#valuesArray<Float>

Required. The list of embedding values of the sparse vector. Corresponds to the JSON property values

Returns:

  • (Array<Float>)


20802
20803
20804
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20802

def values
  @values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20809
20810
20811
20812
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20809

def update!(**args)
  @dimensions = args[:dimensions] if args.key?(:dimensions)
  @values = args[:values] if args.key?(:values)
end