Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexEndpoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Indexes are deployed into it. An IndexEndpoint can have multiple DeployedIndexes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1IndexEndpoint

Returns a new instance of GoogleCloudAiplatformV1IndexEndpoint.



20944
20945
20946
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20944

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this IndexEndpoint was created. Corresponds to the JSON property createTime

Returns:

  • (String)


20843
20844
20845
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20843

def create_time
  @create_time
end

#deployed_indexesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployedIndex>

Output only. The indexes deployed in this endpoint. Corresponds to the JSON property deployedIndexes



20848
20849
20850
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20848

def deployed_indexes
  @deployed_indexes
end

#descriptionString

The description of the IndexEndpoint. Corresponds to the JSON property description

Returns:

  • (String)


20853
20854
20855
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20853

def description
  @description
end

#display_nameString

Required. The display name of the IndexEndpoint. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


20859
20860
20861
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20859

def display_name
  @display_name
end

#enable_private_service_connectBoolean Also known as: enable_private_service_connect?

Optional. Deprecated: If true, expose the IndexEndpoint via private service connect. Only one of the fields, network or enable_private_service_connect, can be set. Corresponds to the JSON property enablePrivateServiceConnect

Returns:

  • (Boolean)


20866
20867
20868
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20866

def enable_private_service_connect
  @enable_private_service_connect
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



20873
20874
20875
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20873

def encryption_spec
  @encryption_spec
end

#etagString

Used to perform consistent read-modify-write updates. If not set, a blind " overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


20879
20880
20881
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20879

def etag
  @etag
end

#labelsHash<String,String>

The labels with user-defined metadata to organize your IndexEndpoints. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


20888
20889
20890
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20888

def labels
  @labels
end

#nameString

Output only. The resource name of the IndexEndpoint. Corresponds to the JSON property name

Returns:

  • (String)


20893
20894
20895
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20893

def name
  @name
end

#networkString

Optional. The full name of the Google Compute Engine network to which the IndexEndpoint should be peered. Private services access must already be configured for the network. If left unspecified, the Endpoint is not peered with any network. network and private_service_connect_config are mutually exclusive. Format: projects/project/global/networks/network`. Where projectis a project number, as in '12345', andnetworkis network name. Corresponds to the JSON propertynetwork`

Returns:

  • (String)


20905
20906
20907
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20905

def network
  @network
end

#private_service_connect_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PrivateServiceConnectConfig

Represents configuration for private service connect. Corresponds to the JSON property privateServiceConnectConfig



20910
20911
20912
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20910

def private_service_connect_config
  @private_service_connect_config
end

#public_endpoint_domain_nameString

Output only. If public_endpoint_enabled is true, this field will be populated with the domain name to use for this index endpoint. Corresponds to the JSON property publicEndpointDomainName

Returns:

  • (String)


20916
20917
20918
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20916

def public_endpoint_domain_name
  @public_endpoint_domain_name
end

#public_endpoint_enabledBoolean Also known as: public_endpoint_enabled?

Optional. If true, the deployed index will be accessible through public endpoint. Corresponds to the JSON property publicEndpointEnabled

Returns:

  • (Boolean)


20922
20923
20924
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20922

def public_endpoint_enabled
  @public_endpoint_enabled
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


20928
20929
20930
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20928

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


20934
20935
20936
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20934

def satisfies_pzs
  @satisfies_pzs
end

#update_timeString

Output only. Timestamp when this IndexEndpoint was last updated. This timestamp is not updated when the endpoint's DeployedIndexes are updated, e.g. due to updates of the original Indexes they are the deployments of. Corresponds to the JSON property updateTime

Returns:

  • (String)


20942
20943
20944
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20942

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20949
20950
20951
20952
20953
20954
20955
20956
20957
20958
20959
20960
20961
20962
20963
20964
20965
20966
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20949

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @deployed_indexes = args[:deployed_indexes] if args.key?(:deployed_indexes)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @enable_private_service_connect = args[:enable_private_service_connect] if args.key?(:enable_private_service_connect)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @private_service_connect_config = args[:private_service_connect_config] if args.key?(:private_service_connect_config)
  @public_endpoint_domain_name = args[:public_endpoint_domain_name] if args.key?(:public_endpoint_domain_name)
  @public_endpoint_enabled = args[:public_endpoint_enabled] if args.key?(:public_endpoint_enabled)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @update_time = args[:update_time] if args.key?(:update_time)
end