Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IngestionDirectContentsSourceEvent
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IngestionDirectContentsSourceEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A single event to ingest.
Instance Attribute Summary collapse
-
#content ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content
The structured data content of a message.
-
#event_id ⇒ String
Optional.
-
#event_time ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1IngestionDirectContentsSourceEvent
constructor
A new instance of GoogleCloudAiplatformV1IngestionDirectContentsSourceEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1IngestionDirectContentsSourceEvent
Returns a new instance of GoogleCloudAiplatformV1IngestionDirectContentsSourceEvent.
19950 19951 19952 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19950 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content
The structured data content of a message. A Content message contains a role
field, which indicates the producer of the content, and a parts field, which
contains the multi-part data of the message.
Corresponds to the JSON property content
19935 19936 19937 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19935 def content @content end |
#event_id ⇒ String
Optional. A unique identifier for the event. If an event with the same
event_id is ingested multiple times, it will be de-duplicated.
Corresponds to the JSON property eventId
19941 19942 19943 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19941 def event_id @event_id end |
#event_time ⇒ String
Optional. The time at which the event occurred. If provided, this timestamp
will be used for ordering events within a stream. If not provided, the server-
side ingestion time will be used.
Corresponds to the JSON property eventTime
19948 19949 19950 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19948 def event_time @event_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19955 19956 19957 19958 19959 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19955 def update!(**args) @content = args[:content] if args.key?(:content) @event_id = args[:event_id] if args.key?(:event_id) @event_time = args[:event_time] if args.key?(:event_time) end |