Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IntermediateExtractedMemory

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

An extracted memory that is the intermediate result before consolidation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1IntermediateExtractedMemory

Returns a new instance of GoogleCloudAiplatformV1IntermediateExtractedMemory.



21401
21402
21403
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21401

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contextString

Output only. Represents the explanation of why the information was extracted from the source content. Corresponds to the JSON property context

Returns:

  • (String)


21389
21390
21391
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21389

def context
  @context
end

#factString

Output only. Represents the fact of the extracted memory. Corresponds to the JSON property fact

Returns:

  • (String)


21394
21395
21396
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21394

def fact
  @fact
end

#structured_dataHash<String,Object>

Output only. Represents the structured value of the extracted memory. Corresponds to the JSON property structuredData

Returns:

  • (Hash<String,Object>)


21399
21400
21401
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21399

def structured_data
  @structured_data
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21406
21407
21408
21409
21410
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21406

def update!(**args)
  @context = args[:context] if args.key?(:context)
  @fact = args[:fact] if args.key?(:fact)
  @structured_data = args[:structured_data] if args.key?(:structured_data)
end