Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1LineageSubgraph
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1LineageSubgraph
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A subgraph of the overall lineage graph. Event edges connect Artifact and Execution nodes.
Instance Attribute Summary collapse
-
#artifacts ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Artifact>
The Artifact nodes in the subgraph.
-
#events ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Event>
The Event edges between Artifacts and Executions in the subgraph.
-
#executions ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Execution>
The Execution nodes in the subgraph.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1LineageSubgraph
constructor
A new instance of GoogleCloudAiplatformV1LineageSubgraph.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1LineageSubgraph
Returns a new instance of GoogleCloudAiplatformV1LineageSubgraph.
13985 13986 13987 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13985 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifacts ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Artifact>
The Artifact nodes in the subgraph.
Corresponds to the JSON property artifacts
13973 13974 13975 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13973 def artifacts @artifacts end |
#events ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Event>
The Event edges between Artifacts and Executions in the subgraph.
Corresponds to the JSON property events
13978 13979 13980 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13978 def events @events end |
#executions ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Execution>
The Execution nodes in the subgraph.
Corresponds to the JSON property executions
13983 13984 13985 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13983 def executions @executions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13990 13991 13992 13993 13994 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13990 def update!(**args) @artifacts = args[:artifacts] if args.key?(:artifacts) @events = args[:events] if args.key?(:events) @executions = args[:executions] if args.key?(:executions) end |