Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ListBatchPredictionJobsResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ListBatchPredictionJobsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Response message for JobService.ListBatchPredictionJobs
Instance Attribute Summary collapse
-
#batch_prediction_jobs ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchPredictionJob>
List of BatchPredictionJobs in the requested page.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ListBatchPredictionJobsResponse
constructor
A new instance of GoogleCloudAiplatformV1ListBatchPredictionJobsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ListBatchPredictionJobsResponse
Returns a new instance of GoogleCloudAiplatformV1ListBatchPredictionJobsResponse.
18536 18537 18538 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18536 def initialize(**args) update!(**args) end |
Instance Attribute Details
#batch_prediction_jobs ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchPredictionJob>
List of BatchPredictionJobs in the requested page.
Corresponds to the JSON property batchPredictionJobs
18528 18529 18530 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18528 def batch_prediction_jobs @batch_prediction_jobs end |
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass to
ListBatchPredictionJobsRequest.page_token to obtain that page.
Corresponds to the JSON property nextPageToken
18534 18535 18536 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18534 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18541 18542 18543 18544 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18541 def update!(**args) @batch_prediction_jobs = args[:batch_prediction_jobs] if args.key?(:batch_prediction_jobs) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |