Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ListDataLabelingJobsResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ListDataLabelingJobsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Response message for JobService.ListDataLabelingJobs.
Instance Attribute Summary collapse
-
#data_labeling_jobs ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DataLabelingJob>
A list of DataLabelingJobs that matches the specified filter in the request.
-
#next_page_token ⇒ String
The standard List next-page token.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ListDataLabelingJobsResponse
constructor
A new instance of GoogleCloudAiplatformV1ListDataLabelingJobsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ListDataLabelingJobsResponse
Returns a new instance of GoogleCloudAiplatformV1ListDataLabelingJobsResponse.
15491 15492 15493 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15491 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_labeling_jobs ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DataLabelingJob>
A list of DataLabelingJobs that matches the specified filter in the request.
Corresponds to the JSON property dataLabelingJobs
15484 15485 15486 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15484 def data_labeling_jobs @data_labeling_jobs end |
#next_page_token ⇒ String
The standard List next-page token.
Corresponds to the JSON property nextPageToken
15489 15490 15491 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15489 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15496 15497 15498 15499 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15496 def update!(**args) @data_labeling_jobs = args[:data_labeling_jobs] if args.key?(:data_labeling_jobs) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |