Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ListDatasetsResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ListDatasetsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Response message for DatasetService.ListDatasets.
Instance Attribute Summary collapse
-
#datasets ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Dataset>
A list of Datasets that matches the specified filter in the request.
-
#next_page_token ⇒ String
The standard List next-page token.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ListDatasetsResponse
constructor
A new instance of GoogleCloudAiplatformV1ListDatasetsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ListDatasetsResponse
Returns a new instance of GoogleCloudAiplatformV1ListDatasetsResponse.
14865 14866 14867 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14865 def initialize(**args) update!(**args) end |
Instance Attribute Details
#datasets ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Dataset>
A list of Datasets that matches the specified filter in the request.
Corresponds to the JSON property datasets
14858 14859 14860 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14858 def datasets @datasets end |
#next_page_token ⇒ String
The standard List next-page token.
Corresponds to the JSON property nextPageToken
14863 14864 14865 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14863 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14870 14871 14872 14873 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14870 def update!(**args) @datasets = args[:datasets] if args.key?(:datasets) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |