Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ListHyperparameterTuningJobsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Response message for JobService.ListHyperparameterTuningJobs

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ListHyperparameterTuningJobsResponse

Returns a new instance of GoogleCloudAiplatformV1ListHyperparameterTuningJobsResponse.



14733
14734
14735
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14733

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hyperparameter_tuning_jobsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1HyperparameterTuningJob>

List of HyperparameterTuningJobs in the requested page. HyperparameterTuningJob.trials of the jobs will be not be returned. Corresponds to the JSON property hyperparameterTuningJobs



14725
14726
14727
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14725

def hyperparameter_tuning_jobs
  @hyperparameter_tuning_jobs
end

#next_page_tokenString

A token to retrieve the next page of results. Pass to ListHyperparameterTuningJobsRequest.page_token to obtain that page. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


14731
14732
14733
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14731

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14738
14739
14740
14741
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14738

def update!(**args)
  @hyperparameter_tuning_jobs = args[:hyperparameter_tuning_jobs] if args.key?(:hyperparameter_tuning_jobs)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end