Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ListMemoriesResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ListMemoriesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Response message for MemoryBankService.ListMemories.
Instance Attribute Summary collapse
-
#memories ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Memory>
List of Memories in the requested page.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ListMemoriesResponse
constructor
A new instance of GoogleCloudAiplatformV1ListMemoriesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ListMemoriesResponse
Returns a new instance of GoogleCloudAiplatformV1ListMemoriesResponse.
21209 21210 21211 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21209 def initialize(**args) update!(**args) end |
Instance Attribute Details
#memories ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Memory>
List of Memories in the requested page.
Corresponds to the JSON property memories
21201 21202 21203 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21201 def memories @memories end |
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass to ListMemoriesRequest.
page_token to obtain that page.
Corresponds to the JSON property nextPageToken
21207 21208 21209 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21207 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21214 21215 21216 21217 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21214 def update!(**args) @memories = args[:memories] if args.key?(:memories) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |