Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ListMemoryRevisionsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Response message for MemoryBankService.ListMemoryRevisions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ListMemoryRevisionsResponse

Returns a new instance of GoogleCloudAiplatformV1ListMemoryRevisionsResponse.



20140
20141
20142
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20140

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#memory_revisionsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryRevision>

The list of Memory Revisions in the request page. Corresponds to the JSON property memoryRevisions



20132
20133
20134
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20132

def memory_revisions
  @memory_revisions
end

#next_page_tokenString

A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


20138
20139
20140
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20138

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20145
20146
20147
20148
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20145

def update!(**args)
  @memory_revisions = args[:memory_revisions] if args.key?(:memory_revisions)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end