Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ListModelVersionCheckpointsResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ListModelVersionCheckpointsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Response message for ModelService.ListModelVersionCheckpoints
Instance Attribute Summary collapse
-
#checkpoints ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelVersionCheckpoint>
List of Model Version checkpoints.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ListModelVersionCheckpointsResponse
constructor
A new instance of GoogleCloudAiplatformV1ListModelVersionCheckpointsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ListModelVersionCheckpointsResponse
Returns a new instance of GoogleCloudAiplatformV1ListModelVersionCheckpointsResponse.
19165 19166 19167 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19165 def initialize(**args) update!(**args) end |
Instance Attribute Details
#checkpoints ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelVersionCheckpoint>
List of Model Version checkpoints.
Corresponds to the JSON property checkpoints
19157 19158 19159 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19157 def checkpoints @checkpoints end |
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass to
ListModelVersionCheckpointsRequest.page_token to obtain that page.
Corresponds to the JSON property nextPageToken
19163 19164 19165 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19163 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19170 19171 19172 19173 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19170 def update!(**args) @checkpoints = args[:checkpoints] if args.key?(:checkpoints) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |