Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ListOptimalTrialsResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ListOptimalTrialsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Response message for VizierService.ListOptimalTrials.
Instance Attribute Summary collapse
-
#optimal_trials ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Trial>
The pareto-optimal Trials for multiple objective Study or the optimal trial for single objective Study.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ListOptimalTrialsResponse
constructor
A new instance of GoogleCloudAiplatformV1ListOptimalTrialsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ListOptimalTrialsResponse
Returns a new instance of GoogleCloudAiplatformV1ListOptimalTrialsResponse.
16274 16275 16276 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16274 def initialize(**args) update!(**args) end |
Instance Attribute Details
#optimal_trials ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Trial>
The pareto-optimal Trials for multiple objective Study or the optimal trial
for single objective Study. The definition of pareto-optimal can be checked in
wiki page. https://en.wikipedia.org/wiki/Pareto_efficiency
Corresponds to the JSON property optimalTrials
16272 16273 16274 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16272 def optimal_trials @optimal_trials end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16279 16280 16281 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16279 def update!(**args) @optimal_trials = args[:optimal_trials] if args.key?(:optimal_trials) end |