Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ListRagFilesResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ListRagFilesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Response message for VertexRagDataService.ListRagFiles.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
-
#rag_files ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagFile>
List of RagFiles in the requested page.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ListRagFilesResponse
constructor
A new instance of GoogleCloudAiplatformV1ListRagFilesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ListRagFilesResponse
Returns a new instance of GoogleCloudAiplatformV1ListRagFilesResponse.
16362 16363 16364 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16362 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass to ListRagFilesRequest.
page_token to obtain that page.
Corresponds to the JSON property nextPageToken
16355 16356 16357 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16355 def next_page_token @next_page_token end |
#rag_files ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagFile>
List of RagFiles in the requested page.
Corresponds to the JSON property ragFiles
16360 16361 16362 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16360 def rag_files @rag_files end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16367 16368 16369 16370 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16367 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @rag_files = args[:rag_files] if args.key?(:rag_files) end |