Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ListSavedQueriesResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ListSavedQueriesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Response message for DatasetService.ListSavedQueries.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
The standard List next-page token.
-
#saved_queries ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SavedQuery>
A list of SavedQueries that match the specified filter in the request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ListSavedQueriesResponse
constructor
A new instance of GoogleCloudAiplatformV1ListSavedQueriesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ListSavedQueriesResponse
Returns a new instance of GoogleCloudAiplatformV1ListSavedQueriesResponse.
19766 19767 19768 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19766 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
The standard List next-page token.
Corresponds to the JSON property nextPageToken
19759 19760 19761 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19759 def next_page_token @next_page_token end |
#saved_queries ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SavedQuery>
A list of SavedQueries that match the specified filter in the request.
Corresponds to the JSON property savedQueries
19764 19765 19766 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19764 def saved_queries @saved_queries end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19771 19772 19773 19774 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19771 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @saved_queries = args[:saved_queries] if args.key?(:saved_queries) end |