Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ListSemanticGovernancePoliciesResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ListSemanticGovernancePoliciesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Response message for SemanticGovernancePolicyService. ListSemanticGovernancePolicies.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
-
#semantic_governance_policies ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SemanticGovernancePolicy>
The list of SemanticGovernancePolicies.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ListSemanticGovernancePoliciesResponse
constructor
A new instance of GoogleCloudAiplatformV1ListSemanticGovernancePoliciesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ListSemanticGovernancePoliciesResponse
Returns a new instance of GoogleCloudAiplatformV1ListSemanticGovernancePoliciesResponse.
21925 21926 21927 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21925 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass to
ListSemanticGovernancePoliciesRequest.page_token to obtain that page.
Corresponds to the JSON property nextPageToken
21918 21919 21920 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21918 def next_page_token @next_page_token end |
#semantic_governance_policies ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SemanticGovernancePolicy>
The list of SemanticGovernancePolicies.
Corresponds to the JSON property semanticGovernancePolicies
21923 21924 21925 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21923 def semantic_governance_policies @semantic_governance_policies end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21930 21931 21932 21933 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21930 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @semantic_governance_policies = args[:semantic_governance_policies] if args.key?(:semantic_governance_policies) end |