Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ListSpecialistPoolsResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ListSpecialistPoolsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Response message for SpecialistPoolService.ListSpecialistPools.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
The standard List next-page token.
-
#specialist_pools ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SpecialistPool>
A list of SpecialistPools that matches the specified filter in the request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ListSpecialistPoolsResponse
constructor
A new instance of GoogleCloudAiplatformV1ListSpecialistPoolsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ListSpecialistPoolsResponse
Returns a new instance of GoogleCloudAiplatformV1ListSpecialistPoolsResponse.
20828 20829 20830 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20828 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
The standard List next-page token.
Corresponds to the JSON property nextPageToken
20821 20822 20823 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20821 def next_page_token @next_page_token end |
#specialist_pools ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SpecialistPool>
A list of SpecialistPools that matches the specified filter in the request.
Corresponds to the JSON property specialistPools
20826 20827 20828 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20826 def specialist_pools @specialist_pools end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20833 20834 20835 20836 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20833 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @specialist_pools = args[:specialist_pools] if args.key?(:specialist_pools) end |