Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ListTrialsResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ListTrialsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Response message for VizierService.ListTrials.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Pass this token as the
page_tokenfield of the request for a subsequent call. -
#trials ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Trial>
The Trials associated with the Study.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ListTrialsResponse
constructor
A new instance of GoogleCloudAiplatformV1ListTrialsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ListTrialsResponse
Returns a new instance of GoogleCloudAiplatformV1ListTrialsResponse.
23404 23405 23406 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23404 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Pass this token as the page_token field of the request for a subsequent call.
If this field is omitted, there are no subsequent pages.
Corresponds to the JSON property nextPageToken
23397 23398 23399 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23397 def next_page_token @next_page_token end |
#trials ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Trial>
The Trials associated with the Study.
Corresponds to the JSON property trials
23402 23403 23404 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23402 def trials @trials end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23409 23410 23411 23412 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23409 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @trials = args[:trials] if args.key?(:trials) end |