Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ListTuningJobsResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ListTuningJobsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Response message for GenAiTuningService.ListTuningJobs
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
-
#tuning_jobs ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TuningJob>
The tuning jobs that match the request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ListTuningJobsResponse
constructor
A new instance of GoogleCloudAiplatformV1ListTuningJobsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ListTuningJobsResponse
Returns a new instance of GoogleCloudAiplatformV1ListTuningJobsResponse.
20054 20055 20056 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20054 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass this token in a subsequent [
GenAiTuningService.ListTuningJobs] call to retrieve the next page of results.
Corresponds to the JSON property nextPageToken
20047 20048 20049 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20047 def next_page_token @next_page_token end |
#tuning_jobs ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TuningJob>
The tuning jobs that match the request.
Corresponds to the JSON property tuningJobs
20052 20053 20054 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20052 def tuning_jobs @tuning_jobs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20059 20060 20061 20062 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20059 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @tuning_jobs = args[:tuning_jobs] if args.key?(:tuning_jobs) end |