Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Measurement
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Measurement
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A message representing a Measurement of a Trial. A Measurement contains the Metrics got by executing a Trial using suggested hyperparameter values.
Instance Attribute Summary collapse
-
#elapsed_duration ⇒ String
Output only.
-
#metrics ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MeasurementMetric>
Output only.
-
#step_count ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Measurement
constructor
A new instance of GoogleCloudAiplatformV1Measurement.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Measurement
Returns a new instance of GoogleCloudAiplatformV1Measurement.
16497 16498 16499 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16497 def initialize(**args) update!(**args) end |
Instance Attribute Details
#elapsed_duration ⇒ String
Output only. Time that the Trial has been running at the point of this
Measurement.
Corresponds to the JSON property elapsedDuration
16483 16484 16485 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16483 def elapsed_duration @elapsed_duration end |
#metrics ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MeasurementMetric>
Output only. A list of metrics got by evaluating the objective functions using
suggested Parameter values.
Corresponds to the JSON property metrics
16489 16490 16491 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16489 def metrics @metrics end |
#step_count ⇒ Fixnum
Output only. The number of steps the machine learning model has been trained
for. Must be non-negative.
Corresponds to the JSON property stepCount
16495 16496 16497 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16495 def step_count @step_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16502 16503 16504 16505 16506 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16502 def update!(**args) @elapsed_duration = args[:elapsed_duration] if args.key?(:elapsed_duration) @metrics = args[:metrics] if args.key?(:metrics) @step_count = args[:step_count] if args.key?(:step_count) end |