Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Memory

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A memory.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Memory

Returns a new instance of GoogleCloudAiplatformV1Memory.



23877
23878
23879
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23877

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Represents the timestamp when this Memory was created. Corresponds to the JSON property createTime

Returns:

  • (String)


23789
23790
23791
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23789

def create_time
  @create_time
end

#descriptionString

Optional. Represents the description of the Memory. Corresponds to the JSON property description

Returns:

  • (String)


23794
23795
23796
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23794

def description
  @description
end

#disable_memory_revisionsBoolean Also known as: disable_memory_revisions?

Optional. Input only. Indicates whether no revision will be created for this request. Corresponds to the JSON property disableMemoryRevisions

Returns:

  • (Boolean)


23800
23801
23802
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23800

def disable_memory_revisions
  @disable_memory_revisions
end

#display_nameString

Optional. Represents the display name of the Memory. Corresponds to the JSON property displayName

Returns:

  • (String)


23806
23807
23808
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23806

def display_name
  @display_name
end

#expire_timeString

Optional. Represents the timestamp of when this resource is considered expired. This is always provided on output when expiration is set on input, regardless of whether expire_time or ttl was provided. Corresponds to the JSON property expireTime

Returns:

  • (String)


23813
23814
23815
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23813

def expire_time
  @expire_time
end

#factString

Optional. Represents semantic knowledge extracted from the source content. Corresponds to the JSON property fact

Returns:

  • (String)


23818
23819
23820
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23818

def fact
  @fact
end

#metadataHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryMetadataValue>

Optional. Represents user-provided metadata for the Memory. This information was provided when creating, updating, or generating the Memory. It was not generated by Memory Bank. Corresponds to the JSON property metadata



23825
23826
23827
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23825

def 
  @metadata
end

#nameString

Identifier. Represents the resource name of the Memory. Format: projects/ project/locations/location/reasoningEngines/reasoning_engine/memories/ memory` Corresponds to the JSON propertyname`

Returns:

  • (String)


23832
23833
23834
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23832

def name
  @name
end

#revision_expire_timeString

Optional. Input only. Represents the timestamp of when the revision is considered expired. If not set, the memory revision will be kept until manually deleted. Corresponds to the JSON property revisionExpireTime

Returns:

  • (String)


23839
23840
23841
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23839

def revision_expire_time
  @revision_expire_time
end

#revision_labelsHash<String,String>

Optional. Input only. Represents the labels to apply to the Memory Revision created as a result of this request. Corresponds to the JSON property revisionLabels

Returns:

  • (Hash<String,String>)


23845
23846
23847
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23845

def revision_labels
  @revision_labels
end

#revision_ttlString

Optional. Input only. Represents the TTL for the revision. The expiration time is computed: now + TTL. Corresponds to the JSON property revisionTtl

Returns:

  • (String)


23851
23852
23853
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23851

def revision_ttl
  @revision_ttl
end

#scopeHash<String,String>

Required. Immutable. Represents the scope of the Memory. Memories are isolated within their scope. The scope is defined when creating or generating memories. Scope values cannot contain the wildcard character '*'. Corresponds to the JSON property scope

Returns:

  • (Hash<String,String>)


23858
23859
23860
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23858

def scope
  @scope
end

#topicsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryTopicId>

Optional. Represents the Topics of the Memory. Corresponds to the JSON property topics



23863
23864
23865
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23863

def topics
  @topics
end

#ttlString

Optional. Input only. Represents the TTL for this resource. The expiration time is computed: now + TTL. Corresponds to the JSON property ttl

Returns:

  • (String)


23869
23870
23871
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23869

def ttl
  @ttl
end

#update_timeString

Output only. Represents the timestamp when this Memory was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


23875
23876
23877
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23875

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23882
23883
23884
23885
23886
23887
23888
23889
23890
23891
23892
23893
23894
23895
23896
23897
23898
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23882

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @disable_memory_revisions = args[:disable_memory_revisions] if args.key?(:disable_memory_revisions)
  @display_name = args[:display_name] if args.key?(:display_name)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @fact = args[:fact] if args.key?(:fact)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @revision_expire_time = args[:revision_expire_time] if args.key?(:revision_expire_time)
  @revision_labels = args[:revision_labels] if args.key?(:revision_labels)
  @revision_ttl = args[:revision_ttl] if args.key?(:revision_ttl)
  @scope = args[:scope] if args.key?(:scope)
  @topics = args[:topics] if args.key?(:topics)
  @ttl = args[:ttl] if args.key?(:ttl)
  @update_time = args[:update_time] if args.key?(:update_time)
end