Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryBankCustomizationConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents configuration for organizing natural language memories for a particular scope.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1MemoryBankCustomizationConfig

Returns a new instance of GoogleCloudAiplatformV1MemoryBankCustomizationConfig.



23949
23950
23951
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23949

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#consolidation_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryBankCustomizationConfigConsolidationConfig

Represents configuration for customizing how memories are consolidated. Corresponds to the JSON property consolidationConfig



23909
23910
23911
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23909

def consolidation_config
  @consolidation_config
end

#disable_natural_language_memoriesBoolean Also known as: disable_natural_language_memories?

Optional. Indicates whether natural language memory generation should be disabled for all requests. By default, natural language memory generation is enabled. Set this to true when you only want to generate structured memories. Corresponds to the JSON property disableNaturalLanguageMemories

Returns:

  • (Boolean)


23916
23917
23918
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23916

def disable_natural_language_memories
  @disable_natural_language_memories
end

#enable_third_person_memoriesBoolean Also known as: enable_third_person_memories?

Optional. Indicates whether the memories will be generated in the third person (i.e. "The user generates memories with Memory Bank."). By default, the memories will be generated in the first person (i.e. "I generate memories with Memory Bank.") Corresponds to the JSON property enableThirdPersonMemories

Returns:

  • (Boolean)


23925
23926
23927
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23925

def enable_third_person_memories
  @enable_third_person_memories
end

#generate_memories_examplesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryBankCustomizationConfigGenerateMemoriesExample>

Optional. Provides examples of how to generate memories for a particular scope. Corresponds to the JSON property generateMemoriesExamples



23931
23932
23933
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23931

def generate_memories_examples
  @generate_memories_examples
end

#memory_topicsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryBankCustomizationConfigMemoryTopic>

Optional. Represents topics of information that should be extracted from conversations and stored as memories. If not set, then Memory Bank's default topics will be used. Corresponds to the JSON property memoryTopics



23938
23939
23940
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23938

def memory_topics
  @memory_topics
end

#scope_keysArray<String>

Optional. Represents the scope keys (i.e. 'user_id') for which to use this config. A request's scope must include all of the provided keys for the config to be used (order does not matter). If empty, then the config will be used for all requests that do not have a more specific config. Only one default config is allowed per Memory Bank. Corresponds to the JSON property scopeKeys

Returns:

  • (Array<String>)


23947
23948
23949
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23947

def scope_keys
  @scope_keys
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23954
23955
23956
23957
23958
23959
23960
23961
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23954

def update!(**args)
  @consolidation_config = args[:consolidation_config] if args.key?(:consolidation_config)
  @disable_natural_language_memories = args[:disable_natural_language_memories] if args.key?(:disable_natural_language_memories)
  @enable_third_person_memories = args[:enable_third_person_memories] if args.key?(:enable_third_person_memories)
  @generate_memories_examples = args[:generate_memories_examples] if args.key?(:generate_memories_examples)
  @memory_topics = args[:memory_topics] if args.key?(:memory_topics)
  @scope_keys = args[:scope_keys] if args.key?(:scope_keys)
end