Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryBankCustomizationConfigGenerateMemoriesExampleConversationSourceEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A single conversation event.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1MemoryBankCustomizationConfigGenerateMemoriesExampleConversationSourceEvent

Returns a new instance of GoogleCloudAiplatformV1MemoryBankCustomizationConfigGenerateMemoriesExampleConversationSourceEvent.



21728
21729
21730
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21728

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Content

The structured data content of a message. A Content message contains a role field, which indicates the producer of the content, and a parts field, which contains the multi-part data of the message. Corresponds to the JSON property content



21726
21727
21728
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21726

def content
  @content
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21733
21734
21735
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21733

def update!(**args)
  @content = args[:content] if args.key?(:content)
end