Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryBankCustomizationConfigGenerateMemoriesExampleGeneratedMemory

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A memory generated by the operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1MemoryBankCustomizationConfigGenerateMemoriesExampleGeneratedMemory

Returns a new instance of GoogleCloudAiplatformV1MemoryBankCustomizationConfigGenerateMemoriesExampleGeneratedMemory.



23225
23226
23227
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23225

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#factString

Required. Represents the fact to generate a memory from. Corresponds to the JSON property fact

Returns:

  • (String)


23216
23217
23218
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23216

def fact
  @fact
end

#topicsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryTopicId>

Optional. Represents the list of topics that the memory should be associated with. For example, use custom_memory_topic_label = "jargon" if the extracted memory is an example of memory extraction for the custom topic jargon. Corresponds to the JSON property topics



23223
23224
23225
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23223

def topics
  @topics
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23230
23231
23232
23233
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23230

def update!(**args)
  @fact = args[:fact] if args.key?(:fact)
  @topics = args[:topics] if args.key?(:topics)
end