Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryGenerationTriggerConfigGenerationTriggerRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents the active rule that determines when to flush the buffer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1MemoryGenerationTriggerConfigGenerationTriggerRule

Returns a new instance of GoogleCloudAiplatformV1MemoryGenerationTriggerConfigGenerationTriggerRule.



24258
24259
24260
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24258

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#event_countFixnum

Optional. Specifies to trigger generation when the event count reaches this limit. Corresponds to the JSON property eventCount

Returns:

  • (Fixnum)


24238
24239
24240
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24238

def event_count
  @event_count
end

#fixed_intervalString

Optional. Specifies to trigger generation at a fixed interval. The duration must have a minute-level granularity. Corresponds to the JSON property fixedInterval

Returns:

  • (String)


24244
24245
24246
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24244

def fixed_interval
  @fixed_interval
end

#idle_durationString

Optional. Specifies to trigger generation if the stream is inactive for the specified duration after the most recent event. The duration must have a minute-level granularity. Corresponds to the JSON property idleDuration

Returns:

  • (String)


24251
24252
24253
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24251

def idle_duration
  @idle_duration
end

#overlap_event_countFixnum

Optional. Re-include the last N already-processed events in the next window. Corresponds to the JSON property overlapEventCount

Returns:

  • (Fixnum)


24256
24257
24258
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24256

def overlap_event_count
  @overlap_event_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24263
24264
24265
24266
24267
24268
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24263

def update!(**args)
  @event_count = args[:event_count] if args.key?(:event_count)
  @fixed_interval = args[:fixed_interval] if args.key?(:fixed_interval)
  @idle_duration = args[:idle_duration] if args.key?(:idle_duration)
  @overlap_event_count = args[:overlap_event_count] if args.key?(:overlap_event_count)
end