Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetadataSchema

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Instance of a general MetadataSchema.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1MetadataSchema

Returns a new instance of GoogleCloudAiplatformV1MetadataSchema.



15808
15809
15810
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15808

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this MetadataSchema was created. Corresponds to the JSON property createTime

Returns:

  • (String)


15774
15775
15776
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15774

def create_time
  @create_time
end

#descriptionString

Description of the Metadata Schema Corresponds to the JSON property description

Returns:

  • (String)


15779
15780
15781
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15779

def description
  @description
end

#nameString

Output only. The resource name of the MetadataSchema. Corresponds to the JSON property name

Returns:

  • (String)


15784
15785
15786
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15784

def name
  @name
end

#schemaString

Required. The raw YAML string representation of the MetadataSchema. The combination of [MetadataSchema.version] and the schema name given by title in [MetadataSchema.schema] must be unique within a MetadataStore. The schema is defined as an OpenAPI 3.0.2 MetadataSchema Object Corresponds to the JSON property schema

Returns:

  • (String)


15793
15794
15795
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15793

def schema
  @schema
end

#schema_typeString

The type of the MetadataSchema. This is a property that identifies which metadata types will use the MetadataSchema. Corresponds to the JSON property schemaType

Returns:

  • (String)


15799
15800
15801
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15799

def schema_type
  @schema_type
end

#schema_versionString

The version of the MetadataSchema. The version's format must match the following regular expression: ^[0-9]+.+.+$, which would allow to order/ compare different versions. Example: 1.0.0, 1.0.1, etc. Corresponds to the JSON property schemaVersion

Returns:

  • (String)


15806
15807
15808
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15806

def schema_version
  @schema_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15813
15814
15815
15816
15817
15818
15819
15820
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15813

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @name = args[:name] if args.key?(:name)
  @schema = args[:schema] if args.key?(:schema)
  @schema_type = args[:schema_type] if args.key?(:schema_type)
  @schema_version = args[:schema_version] if args.key?(:schema_version)
end