Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetadataStore
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetadataStore
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Instance of a metadata store. Contains a set of metadata that can be queried.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#dataplex_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetadataStoreDataplexConfig
Represents Dataplex integration settings.
-
#description ⇒ String
Description of the MetadataStore.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.
-
#name ⇒ String
Output only.
-
#state ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetadataStoreMetadataStoreState
Represents state information for a MetadataStore.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1MetadataStore
constructor
A new instance of GoogleCloudAiplatformV1MetadataStore.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1MetadataStore
Returns a new instance of GoogleCloudAiplatformV1MetadataStore.
24543 24544 24545 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24543 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this MetadataStore was created.
Corresponds to the JSON property createTime
24510 24511 24512 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24510 def create_time @create_time end |
#dataplex_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetadataStoreDataplexConfig
Represents Dataplex integration settings.
Corresponds to the JSON property dataplexConfig
24515 24516 24517 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24515 def dataplex_config @dataplex_config end |
#description ⇒ String
Description of the MetadataStore.
Corresponds to the JSON property description
24520 24521 24522 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24520 def description @description end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied
to a Vertex AI resource.
Corresponds to the JSON property encryptionSpec
24526 24527 24528 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24526 def encryption_spec @encryption_spec end |
#name ⇒ String
Output only. The resource name of the MetadataStore instance.
Corresponds to the JSON property name
24531 24532 24533 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24531 def name @name end |
#state ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetadataStoreMetadataStoreState
Represents state information for a MetadataStore.
Corresponds to the JSON property state
24536 24537 24538 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24536 def state @state end |
#update_time ⇒ String
Output only. Timestamp when this MetadataStore was last updated.
Corresponds to the JSON property updateTime
24541 24542 24543 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24541 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24548 24549 24550 24551 24552 24553 24554 24555 24556 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24548 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @dataplex_config = args[:dataplex_config] if args.key?(:dataplex_config) @description = args[:description] if args.key?(:description) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |