Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetricMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Metadata about the metric, used for visualization and organization.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1MetricMetadata

Returns a new instance of GoogleCloudAiplatformV1MetricMetadata.



23452
23453
23454
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23452

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#other_metadataHash<String,Object>

Optional. Flexible metadata for user-defined attributes. Corresponds to the JSON property otherMetadata

Returns:

  • (Hash<String,Object>)


23439
23440
23441
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23439

def 
  @other_metadata
end

#score_rangeGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1MetricMetadataScoreRange

The range of possible scores for this metric, used for plotting. Corresponds to the JSON property scoreRange



23444
23445
23446
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23444

def score_range
  @score_range
end

#titleString

Optional. The user-friendly name for the metric. If not set for a registered metric, it will default to the metric's display name. Corresponds to the JSON property title

Returns:

  • (String)


23450
23451
23452
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23450

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23457
23458
23459
23460
23461
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23457

def update!(**args)
  @other_metadata = args[:other_metadata] if args.key?(:other_metadata)
  @score_range = args[:score_range] if args.key?(:score_range)
  @title = args[:title] if args.key?(:title)
end