Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetricMetadataScoreRange

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The range of possible scores for this metric, used for plotting.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1MetricMetadataScoreRange

Returns a new instance of GoogleCloudAiplatformV1MetricMetadataScoreRange.



23893
23894
23895
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23893

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Optional. The description of the score explaining the directionality etc. Corresponds to the JSON property description

Returns:

  • (String)


23875
23876
23877
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23875

def description
  @description
end

#maxFloat

Required. The maximum value of the score range (inclusive). Corresponds to the JSON property max

Returns:

  • (Float)


23880
23881
23882
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23880

def max
  @max
end

#minFloat

Required. The minimum value of the score range (inclusive). Corresponds to the JSON property min

Returns:

  • (Float)


23885
23886
23887
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23885

def min
  @min
end

#stepFloat

Optional. The distance between discrete steps in the range. If unset, the range is assumed to be continuous. Corresponds to the JSON property step

Returns:

  • (Float)


23891
23892
23893
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23891

def step
  @step
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23898
23899
23900
23901
23902
23903
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23898

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @max = args[:max] if args.key?(:max)
  @min = args[:min] if args.key?(:min)
  @step = args[:step] if args.key?(:step)
end