Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetricResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Result for a single metric on a single instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1MetricResult

Returns a new instance of GoogleCloudAiplatformV1MetricResult.



24781
24782
24783
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24781

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::AiplatformV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



24763
24764
24765
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24763

def error
  @error
end

#explanationString

Output only. The explanation for the metric result. Corresponds to the JSON property explanation

Returns:

  • (String)


24768
24769
24770
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24768

def explanation
  @explanation
end

#rubric_verdictsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricVerdict>

Output only. For rubric-based metrics, the verdicts for each rubric. Corresponds to the JSON property rubricVerdicts



24773
24774
24775
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24773

def rubric_verdicts
  @rubric_verdicts
end

#scoreFloat

Output only. The score for the metric. Please refer to each metric's documentation for the meaning of the score. Corresponds to the JSON property score

Returns:

  • (Float)


24779
24780
24781
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24779

def score
  @score
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24786
24787
24788
24789
24790
24791
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24786

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @explanation = args[:explanation] if args.key?(:explanation)
  @rubric_verdicts = args[:rubric_verdicts] if args.key?(:rubric_verdicts)
  @score = args[:score] if args.key?(:score)
end