Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelEvaluationSliceSliceSliceSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Specification for how the data should be sliced.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelEvaluationSliceSliceSliceSpec

Returns a new instance of GoogleCloudAiplatformV1ModelEvaluationSliceSliceSliceSpec.



18176
18177
18178
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18176

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#configsHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelEvaluationSliceSliceSliceSpecSliceConfig>

Mapping configuration for this SliceSpec. The key is the name of the feature. By default, the key will be prefixed by "instance" as a dictionary prefix for Vertex Batch Predictions output format. Corresponds to the JSON property configs



18174
18175
18176
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18174

def configs
  @configs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18181
18182
18183
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18181

def update!(**args)
  @configs = args[:configs] if args.key?(:configs)
end