Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelMonitoringAlertConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The alert config for model monitoring.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelMonitoringAlertConfig

Returns a new instance of GoogleCloudAiplatformV1ModelMonitoringAlertConfig.



25977
25978
25979
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25977

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#email_alert_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelMonitoringAlertConfigEmailAlertConfig

The config for email alert. Corresponds to the JSON property emailAlertConfig



25961
25962
25963
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25961

def email_alert_config
  @email_alert_config
end

#enable_loggingBoolean Also known as: enable_logging?

Dump the anomalies to Cloud Logging. The anomalies will be put to json payload encoded from proto ModelMonitoringStatsAnomalies. This can be further synced to Pub/Sub or any other services supported by Cloud Logging. Corresponds to the JSON property enableLogging

Returns:

  • (Boolean)


25968
25969
25970
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25968

def enable_logging
  @enable_logging
end

#notification_channelsArray<String>

Resource names of the NotificationChannels to send alert. Must be of the format projects//notificationChannels/ Corresponds to the JSON property notificationChannels

Returns:

  • (Array<String>)


25975
25976
25977
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25975

def notification_channels
  @notification_channels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25982
25983
25984
25985
25986
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25982

def update!(**args)
  @email_alert_config = args[:email_alert_config] if args.key?(:email_alert_config)
  @enable_logging = args[:enable_logging] if args.key?(:enable_logging)
  @notification_channels = args[:notification_channels] if args.key?(:notification_channels)
end