Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelMonitoringStatsAnomalies

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Statistics and anomalies generated by Model Monitoring.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelMonitoringStatsAnomalies

Returns a new instance of GoogleCloudAiplatformV1ModelMonitoringStatsAnomalies.



27090
27091
27092
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27090

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#anomaly_countFixnum

Number of anomalies within all stats. Corresponds to the JSON property anomalyCount

Returns:

  • (Fixnum)


27073
27074
27075
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27073

def anomaly_count
  @anomaly_count
end

#deployed_model_idString

Deployed Model ID. Corresponds to the JSON property deployedModelId

Returns:

  • (String)


27078
27079
27080
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27078

def deployed_model_id
  @deployed_model_id
end

#feature_statsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelMonitoringStatsAnomaliesFeatureHistoricStatsAnomalies>

A list of historical Stats and Anomalies generated for all Features. Corresponds to the JSON property featureStats



27083
27084
27085
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27083

def feature_stats
  @feature_stats
end

#objectiveString

Model Monitoring Objective those stats and anomalies belonging to. Corresponds to the JSON property objective

Returns:

  • (String)


27088
27089
27090
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27088

def objective
  @objective
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27095
27096
27097
27098
27099
27100
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27095

def update!(**args)
  @anomaly_count = args[:anomaly_count] if args.key?(:anomaly_count)
  @deployed_model_id = args[:deployed_model_id] if args.key?(:deployed_model_id)
  @feature_stats = args[:feature_stats] if args.key?(:feature_stats)
  @objective = args[:objective] if args.key?(:objective)
end