Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NasJobSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents the spec of a NasJob.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1NasJobSpec

Returns a new instance of GoogleCloudAiplatformV1NasJobSpec.



19422
19423
19424
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19422

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#multi_trial_algorithm_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpec

The spec of multi-trial Neural Architecture Search (NAS). Corresponds to the JSON property multiTrialAlgorithmSpec



19408
19409
19410
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19408

def multi_trial_algorithm_spec
  @multi_trial_algorithm_spec
end

#resume_nas_job_idString

The ID of the existing NasJob in the same Project and Location which will be used to resume search. search_space_spec and nas_algorithm_spec are obtained from previous NasJob hence should not provide them again for this NasJob. Corresponds to the JSON property resumeNasJobId

Returns:

  • (String)


19415
19416
19417
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19415

def resume_nas_job_id
  @resume_nas_job_id
end

#search_space_specString

It defines the search space for Neural Architecture Search (NAS). Corresponds to the JSON property searchSpaceSpec

Returns:

  • (String)


19420
19421
19422
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19420

def search_space_spec
  @search_space_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19427
19428
19429
19430
19431
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19427

def update!(**args)
  @multi_trial_algorithm_spec = args[:multi_trial_algorithm_spec] if args.key?(:multi_trial_algorithm_spec)
  @resume_nas_job_id = args[:resume_nas_job_id] if args.key?(:resume_nas_job_id)
  @search_space_spec = args[:search_space_spec] if args.key?(:search_space_spec)
end