Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborQuery
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborQuery
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A query to find a number of similar entities.
Instance Attribute Summary collapse
-
#embedding ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborQueryEmbedding
The embedding vector.
-
#entity_id ⇒ String
Optional.
-
#neighbor_count ⇒ Fixnum
Optional.
-
#numeric_filters ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborQueryNumericFilter>
Optional.
-
#parameters ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborQueryParameters
Parameters that can be overrided in each query to tune query latency and recall.
-
#per_crowding_attribute_neighbor_count ⇒ Fixnum
Optional.
-
#string_filters ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborQueryStringFilter>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1NearestNeighborQuery
constructor
A new instance of GoogleCloudAiplatformV1NearestNeighborQuery.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1NearestNeighborQuery
Returns a new instance of GoogleCloudAiplatformV1NearestNeighborQuery.
25606 25607 25608 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25606 def initialize(**args) update!(**args) end |
Instance Attribute Details
#embedding ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborQueryEmbedding
The embedding vector.
Corresponds to the JSON property embedding
25568 25569 25570 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25568 def @embedding end |
#entity_id ⇒ String
Optional. The entity id whose similar entities should be searched for. If
embedding is set, search will use embedding instead of entity_id.
Corresponds to the JSON property entityId
25574 25575 25576 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25574 def entity_id @entity_id end |
#neighbor_count ⇒ Fixnum
Optional. The number of similar entities to be retrieved from feature view for
each query.
Corresponds to the JSON property neighborCount
25580 25581 25582 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25580 def neighbor_count @neighbor_count end |
#numeric_filters ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborQueryNumericFilter>
Optional. The list of numeric filters.
Corresponds to the JSON property numericFilters
25585 25586 25587 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25585 def numeric_filters @numeric_filters end |
#parameters ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborQueryParameters
Parameters that can be overrided in each query to tune query latency and
recall.
Corresponds to the JSON property parameters
25591 25592 25593 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25591 def parameters @parameters end |
#per_crowding_attribute_neighbor_count ⇒ Fixnum
Optional. Crowding is a constraint on a neighbor list produced by nearest
neighbor search requiring that no more than
sper_crowding_attribute_neighbor_count of the k neighbors returned have the
same value of crowding_attribute. It's used for improving result diversity.
Corresponds to the JSON property perCrowdingAttributeNeighborCount
25599 25600 25601 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25599 def per_crowding_attribute_neighbor_count @per_crowding_attribute_neighbor_count end |
#string_filters ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborQueryStringFilter>
Optional. The list of string filters.
Corresponds to the JSON property stringFilters
25604 25605 25606 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25604 def string_filters @string_filters end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25611 25612 25613 25614 25615 25616 25617 25618 25619 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25611 def update!(**args) @embedding = args[:embedding] if args.key?(:embedding) @entity_id = args[:entity_id] if args.key?(:entity_id) @neighbor_count = args[:neighbor_count] if args.key?(:neighbor_count) @numeric_filters = args[:numeric_filters] if args.key?(:numeric_filters) @parameters = args[:parameters] if args.key?(:parameters) @per_crowding_attribute_neighbor_count = args[:per_crowding_attribute_neighbor_count] if args.key?(:per_crowding_attribute_neighbor_count) @string_filters = args[:string_filters] if args.key?(:string_filters) end |