Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NetworkSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Network spec.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1NetworkSpec

Returns a new instance of GoogleCloudAiplatformV1NetworkSpec.



24364
24365
24366
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24364

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_internet_accessBoolean Also known as: enable_internet_access?

Whether to enable public internet access. Default false. Corresponds to the JSON property enableInternetAccess

Returns:

  • (Boolean)


24349
24350
24351
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24349

def enable_internet_access
  @enable_internet_access
end

#networkString

The full name of the Google Compute Engine network Corresponds to the JSON property network

Returns:

  • (String)


24356
24357
24358
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24356

def network
  @network
end

#subnetworkString

The name of the subnet that this instance is in. Format: projects/ project_id_or_number/regions/region/subnetworks/subnetwork_id` Corresponds to the JSON propertysubnetwork`

Returns:

  • (String)


24362
24363
24364
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24362

def subnetwork
  @subnetwork
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24369
24370
24371
24372
24373
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24369

def update!(**args)
  @enable_internet_access = args[:enable_internet_access] if args.key?(:enable_internet_access)
  @network = args[:network] if args.key?(:network)
  @subnetwork = args[:subnetwork] if args.key?(:subnetwork)
end