Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NfsMount

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents a mount configuration for Network File System (NFS) to mount.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1NfsMount

Returns a new instance of GoogleCloudAiplatformV1NfsMount.



27758
27759
27760
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27758

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#mount_pointString

Required. Destination mount path. The NFS will be mounted for the user under / mnt/nfs/ Corresponds to the JSON property mountPoint

Returns:

  • (String)


27744
27745
27746
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27744

def mount_point
  @mount_point
end

#pathString

Required. Source path exported from NFS server. Has to start with '/', and combined with the ip address, it indicates the source mount path in the form of server:path Corresponds to the JSON property path

Returns:

  • (String)


27751
27752
27753
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27751

def path
  @path
end

#serverString

Required. IP address of the NFS server. Corresponds to the JSON property server

Returns:

  • (String)


27756
27757
27758
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27756

def server
  @server
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27763
27764
27765
27766
27767
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27763

def update!(**args)
  @mount_point = args[:mount_point] if args.key?(:mount_point)
  @path = args[:path] if args.key?(:path)
  @server = args[:server] if args.key?(:server)
end