Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookExecutionJobCustomEnvironmentSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookExecutionJobCustomEnvironmentSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Compute configuration to use for an execution job.
Instance Attribute Summary collapse
-
#machine_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MachineSpec
Specification of a single machine.
-
#network_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NetworkSpec
Network spec.
-
#persistent_disk_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PersistentDiskSpec
Represents the spec of persistent disk and hyperdisk options.
-
#shielded_instance_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookExecutionJobCustomEnvironmentSpecShieldedInstanceConfig
A set of Shielded VM options for the execution VM.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1NotebookExecutionJobCustomEnvironmentSpec
constructor
A new instance of GoogleCloudAiplatformV1NotebookExecutionJobCustomEnvironmentSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1NotebookExecutionJobCustomEnvironmentSpec
Returns a new instance of GoogleCloudAiplatformV1NotebookExecutionJobCustomEnvironmentSpec.
28423 28424 28425 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28423 def initialize(**args) update!(**args) end |
Instance Attribute Details
#machine_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MachineSpec
Specification of a single machine.
Corresponds to the JSON property machineSpec
28404 28405 28406 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28404 def machine_spec @machine_spec end |
#network_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NetworkSpec
Network spec.
Corresponds to the JSON property networkSpec
28409 28410 28411 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28409 def network_spec @network_spec end |
#persistent_disk_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PersistentDiskSpec
Represents the spec of persistent disk and hyperdisk options.
Corresponds to the JSON property persistentDiskSpec
28414 28415 28416 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28414 def persistent_disk_spec @persistent_disk_spec end |
#shielded_instance_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookExecutionJobCustomEnvironmentSpecShieldedInstanceConfig
A set of Shielded VM options for the execution VM. Mirrors google.cloud.
notebooks.v2.ShieldedInstanceConfig. See https://cloud.google.com/compute/
docs/instances/modifying-shielded-vm.
Corresponds to the JSON property shieldedInstanceConfig
28421 28422 28423 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28421 def shielded_instance_config @shielded_instance_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28428 28429 28430 28431 28432 28433 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28428 def update!(**args) @machine_spec = args[:machine_spec] if args.key?(:machine_spec) @network_spec = args[:network_spec] if args.key?(:network_spec) @persistent_disk_spec = args[:persistent_disk_spec] if args.key?(:persistent_disk_spec) @shielded_instance_config = args[:shielded_instance_config] if args.key?(:shielded_instance_config) end |