Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookReservationAffinity

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Notebook Reservation Affinity for consuming Zonal reservation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1NotebookReservationAffinity

Returns a new instance of GoogleCloudAiplatformV1NotebookReservationAffinity.



24766
24767
24768
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24766

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#consume_reservation_typeString

Required. Specifies the type of reservation from which this instance can consume resources: RESERVATION_ANY (default), RESERVATION_SPECIFIC, or RESERVATION_NONE. See Consuming reserved instances for examples. Corresponds to the JSON property consumeReservationType

Returns:

  • (String)


24751
24752
24753
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24751

def consume_reservation_type
  @consume_reservation_type
end

#keyString

Optional. Corresponds to the label key of a reservation resource. To target a RESERVATION_SPECIFIC by name, use compute.googleapis.com/reservation-name as the key and specify the name of your reservation as its value. Corresponds to the JSON property key

Returns:

  • (String)


24758
24759
24760
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24758

def key
  @key
end

#valuesArray<String>

Optional. Corresponds to the label values of a reservation resource. This must be the full path name of Reservation. Corresponds to the JSON property values

Returns:

  • (Array<String>)


24764
24765
24766
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24764

def values
  @values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24771
24772
24773
24774
24775
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24771

def update!(**args)
  @consume_reservation_type = args[:consume_reservation_type] if args.key?(:consume_reservation_type)
  @key = args[:key] if args.key?(:key)
  @values = args[:values] if args.key?(:values)
end