Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookRuntime

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A runtime is a virtual machine allocated to a particular user for a particular Notebook file on temporary basis with lifetime. Default runtimes have a lifetime of 18 hours, while custom runtimes last for 6 months from their creation or last upgrade.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1NotebookRuntime

Returns a new instance of GoogleCloudAiplatformV1NotebookRuntime.



28898
28899
28900
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28898

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this NotebookRuntime was created. Corresponds to the JSON property createTime

Returns:

  • (String)


28730
28731
28732
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28730

def create_time
  @create_time
end

#data_persistent_disk_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PersistentDiskSpec

Represents the spec of persistent disk and hyperdisk options. Corresponds to the JSON property dataPersistentDiskSpec



28735
28736
28737
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28735

def data_persistent_disk_spec
  @data_persistent_disk_spec
end

#descriptionString

The description of the NotebookRuntime. Corresponds to the JSON property description

Returns:

  • (String)


28740
28741
28742
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28740

def description
  @description
end

#display_nameString

Required. The display name of the NotebookRuntime. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


28746
28747
28748
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28746

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



28752
28753
28754
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28752

def encryption_spec
  @encryption_spec
end

#euc_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookEucConfig

The euc configuration of NotebookRuntimeTemplate. Corresponds to the JSON property eucConfig



28757
28758
28759
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28757

def euc_config
  @euc_config
end

#expiration_timeString

Output only. Timestamp when this NotebookRuntime will be expired: 1. System Predefined NotebookRuntime: 24 hours after creation. After expiration, system predifined runtime will be deleted. 2. User created NotebookRuntime: 6 months after last upgrade. After expiration, user created runtime will be stopped and allowed for upgrade. Corresponds to the JSON property expirationTime

Returns:

  • (String)


28766
28767
28768
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28766

def expiration_time
  @expiration_time
end

#health_stateString

Output only. The health state of the NotebookRuntime. Corresponds to the JSON property healthState

Returns:

  • (String)


28771
28772
28773
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28771

def health_state
  @health_state
end

#idle_shutdown_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookIdleShutdownConfig

The idle shutdown configuration of NotebookRuntimeTemplate, which contains the idle_timeout as required field. Corresponds to the JSON property idleShutdownConfig



28777
28778
28779
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28777

def idle_shutdown_config
  @idle_shutdown_config
end

#is_upgradableBoolean Also known as: is_upgradable?

Output only. Whether NotebookRuntime is upgradable. Corresponds to the JSON property isUpgradable

Returns:

  • (Boolean)


28782
28783
28784
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28782

def is_upgradable
  @is_upgradable
end

#labelsHash<String,String>

The labels with user-defined metadata to organize your NotebookRuntime. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. No more than 64 user labels can be associated with one NotebookRuntime (System labels are excluded). See https:// goo.gl/xmQnxf for more information and examples of labels. System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable. Following system labels exist for NotebookRuntime: * "aiplatform.googleapis. com/notebook_runtime_gce_instance_id": output only, its value is the Compute Engine instance id. * "aiplatform.googleapis.com/ colab_enterprise_entry_service": its value is either "bigquery" or "vertex"; if absent, it should be "vertex". This is to describe the entry service, either BigQuery or Vertex. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


28800
28801
28802
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28800

def labels
  @labels
end

#machine_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1MachineSpec

Specification of a single machine. Corresponds to the JSON property machineSpec



28805
28806
28807
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28805

def machine_spec
  @machine_spec
end

#nameString

Output only. The resource name of the NotebookRuntime. Corresponds to the JSON property name

Returns:

  • (String)


28810
28811
28812
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28810

def name
  @name
end

#network_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1NetworkSpec

Network spec. Corresponds to the JSON property networkSpec



28815
28816
28817
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28815

def network_spec
  @network_spec
end

#network_tagsArray<String>

Optional. The Compute Engine tags to add to runtime (see Tagging instances). Corresponds to the JSON property networkTags

Returns:

  • (Array<String>)


28821
28822
28823
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28821

def network_tags
  @network_tags
end

#notebook_runtime_template_refGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookRuntimeTemplateRef

Points to a NotebookRuntimeTemplateRef. Corresponds to the JSON property notebookRuntimeTemplateRef



28826
28827
28828
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28826

def notebook_runtime_template_ref
  @notebook_runtime_template_ref
end

#notebook_runtime_typeString

Output only. The type of the notebook runtime. Corresponds to the JSON property notebookRuntimeType

Returns:

  • (String)


28831
28832
28833
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28831

def notebook_runtime_type
  @notebook_runtime_type
end

#proxy_uriString

Output only. The proxy endpoint used to access the NotebookRuntime. Corresponds to the JSON property proxyUri

Returns:

  • (String)


28836
28837
28838
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28836

def proxy_uri
  @proxy_uri
end

#reservation_affinityGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookReservationAffinity

Notebook Reservation Affinity for consuming Zonal reservation. Corresponds to the JSON property reservationAffinity



28841
28842
28843
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28841

def reservation_affinity
  @reservation_affinity
end

#runtime_stateString

Output only. The runtime (instance) state of the NotebookRuntime. Corresponds to the JSON property runtimeState

Returns:

  • (String)


28846
28847
28848
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28846

def runtime_state
  @runtime_state
end

#runtime_userString

Required. The user email of the NotebookRuntime. Corresponds to the JSON property runtimeUser

Returns:

  • (String)


28851
28852
28853
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28851

def runtime_user
  @runtime_user
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


28856
28857
28858
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28856

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


28862
28863
28864
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28862

def satisfies_pzs
  @satisfies_pzs
end

#service_accountString

Output only. Deprecated: This field is no longer used and the "Vertex AI Notebook Service Account" (service-PROJECT_NUMBER@gcp-sa-aiplatform-vm.iam. gserviceaccount.com) is used for the runtime workload identity. See https:// cloud.google.com/iam/docs/service-agents#vertex-ai-notebook-service-account for more details. The service account that the NotebookRuntime workload runs as. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


28873
28874
28875
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28873

def 
  @service_account
end

#shielded_vm_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ShieldedVmConfig

A set of Shielded Instance options. See Images using supported Shielded VM features. Corresponds to the JSON property shieldedVmConfig



28880
28881
28882
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28880

def shielded_vm_config
  @shielded_vm_config
end

#software_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookSoftwareConfig

Notebook Software Config. This is passed to the backend when user makes software configurations in UI. Corresponds to the JSON property softwareConfig



28886
28887
28888
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28886

def software_config
  @software_config
end

#update_timeString

Output only. Timestamp when this NotebookRuntime was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


28891
28892
28893
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28891

def update_time
  @update_time
end

#versionString

Output only. The VM os image version of NotebookRuntime. Corresponds to the JSON property version

Returns:

  • (String)


28896
28897
28898
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28896

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28903
28904
28905
28906
28907
28908
28909
28910
28911
28912
28913
28914
28915
28916
28917
28918
28919
28920
28921
28922
28923
28924
28925
28926
28927
28928
28929
28930
28931
28932
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28903

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_persistent_disk_spec = args[:data_persistent_disk_spec] if args.key?(:data_persistent_disk_spec)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @euc_config = args[:euc_config] if args.key?(:euc_config)
  @expiration_time = args[:expiration_time] if args.key?(:expiration_time)
  @health_state = args[:health_state] if args.key?(:health_state)
  @idle_shutdown_config = args[:idle_shutdown_config] if args.key?(:idle_shutdown_config)
  @is_upgradable = args[:is_upgradable] if args.key?(:is_upgradable)
  @labels = args[:labels] if args.key?(:labels)
  @machine_spec = args[:machine_spec] if args.key?(:machine_spec)
  @name = args[:name] if args.key?(:name)
  @network_spec = args[:network_spec] if args.key?(:network_spec)
  @network_tags = args[:network_tags] if args.key?(:network_tags)
  @notebook_runtime_template_ref = args[:notebook_runtime_template_ref] if args.key?(:notebook_runtime_template_ref)
  @notebook_runtime_type = args[:notebook_runtime_type] if args.key?(:notebook_runtime_type)
  @proxy_uri = args[:proxy_uri] if args.key?(:proxy_uri)
  @reservation_affinity = args[:reservation_affinity] if args.key?(:reservation_affinity)
  @runtime_state = args[:runtime_state] if args.key?(:runtime_state)
  @runtime_user = args[:runtime_user] if args.key?(:runtime_user)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @service_account = args[:service_account] if args.key?(:service_account)
  @shielded_vm_config = args[:shielded_vm_config] if args.key?(:shielded_vm_config)
  @software_config = args[:software_config] if args.key?(:software_config)
  @update_time = args[:update_time] if args.key?(:update_time)
  @version = args[:version] if args.key?(:version)
end