Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1OnlineEvaluatorCloudObservability

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Data source for the OnlineEvaluator, based on Google Cloud Observability stack (Cloud Trace & Cloud Logging).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1OnlineEvaluatorCloudObservability

Returns a new instance of GoogleCloudAiplatformV1OnlineEvaluatorCloudObservability.



29269
29270
29271
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29269

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#log_viewString

Optional. Optional log view that will be used to query logs. If empty, the _Default view will be used. Corresponds to the JSON property logView

Returns:

  • (String)


29243
29244
29245
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29243

def log_view
  @log_view
end

#open_telemetryGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1OnlineEvaluatorCloudObservabilityOpenTelemetry

Configuration for data source following OpenTelemetry. Corresponds to the JSON property openTelemetry



29248
29249
29250
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29248

def open_telemetry
  @open_telemetry
end

#session_scopeGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1OnlineEvaluatorCloudObservabilitySessionScope

If chosen, the online evaluator will evaluate sessions matching specified filter. A session is a group of traces with a common gen_ai.conversation.id. Corresponds to the JSON property sessionScope



29254
29255
29256
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29254

def session_scope
  @session_scope
end

#trace_scopeGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1OnlineEvaluatorCloudObservabilityTraceScope

If chosen, the online evaluator will evaluate single traces matching specified filter. Corresponds to the JSON property traceScope



29260
29261
29262
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29260

def trace_scope
  @trace_scope
end

#trace_viewString

Optional. Optional trace view that will be used to query traces. If empty, the _Default view will be used. NOTE: This field is not supported yet and will be ignored if set. Corresponds to the JSON property traceView

Returns:

  • (String)


29267
29268
29269
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29267

def trace_view
  @trace_view
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29274
29275
29276
29277
29278
29279
29280
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29274

def update!(**args)
  @log_view = args[:log_view] if args.key?(:log_view)
  @open_telemetry = args[:open_telemetry] if args.key?(:open_telemetry)
  @session_scope = args[:session_scope] if args.key?(:session_scope)
  @trace_scope = args[:trace_scope] if args.key?(:trace_scope)
  @trace_view = args[:trace_view] if args.key?(:trace_view)
end