Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1OutputConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1OutputConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Config for evaluation output.
Instance Attribute Summary collapse
-
#gcs_destination ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsDestination
The Google Cloud Storage location where the output is to be written to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1OutputConfig
constructor
A new instance of GoogleCloudAiplatformV1OutputConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1OutputConfig
Returns a new instance of GoogleCloudAiplatformV1OutputConfig.
19909 19910 19911 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19909 def initialize(**args) update!(**args) end |
Instance Attribute Details
#gcs_destination ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsDestination
The Google Cloud Storage location where the output is to be written to.
Corresponds to the JSON property gcsDestination
19907 19908 19909 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19907 def gcs_destination @gcs_destination end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19914 19915 19916 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19914 def update!(**args) @gcs_destination = args[:gcs_destination] if args.key?(:gcs_destination) end |