Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1OutputInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Describes the info for output of EvaluationService.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1OutputInfo

Returns a new instance of GoogleCloudAiplatformV1OutputInfo.



29612
29613
29614
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29612

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gcs_output_directoryString

Output only. The full path of the Cloud Storage directory created, into which the evaluation results and aggregation results are written. Corresponds to the JSON property gcsOutputDirectory

Returns:

  • (String)


29610
29611
29612
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29610

def gcs_output_directory
  @gcs_output_directory
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29617
29618
29619
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29617

def update!(**args)
  @gcs_output_directory = args[:gcs_output_directory] if args.key?(:gcs_output_directory)
end