Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PairwiseMetricInstance
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PairwiseMetricInstance
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Pairwise metric instance. Usually one instance corresponds to one row in an evaluation dataset.
Instance Attribute Summary collapse
-
#content_map_instance ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ContentMap
Map of placeholder in metric prompt template to contents of model input.
-
#json_instance ⇒ String
Instance specified as a json string.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1PairwiseMetricInstance
constructor
A new instance of GoogleCloudAiplatformV1PairwiseMetricInstance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1PairwiseMetricInstance
Returns a new instance of GoogleCloudAiplatformV1PairwiseMetricInstance.
25579 25580 25581 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25579 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content_map_instance ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ContentMap
Map of placeholder in metric prompt template to contents of model input.
Corresponds to the JSON property contentMapInstance
25571 25572 25573 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25571 def content_map_instance @content_map_instance end |
#json_instance ⇒ String
Instance specified as a json string. String key-value pairs are expected in
the json_instance to render PairwiseMetricSpec.instance_prompt_template.
Corresponds to the JSON property jsonInstance
25577 25578 25579 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25577 def json_instance @json_instance end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25584 25585 25586 25587 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25584 def update!(**args) @content_map_instance = args[:content_map_instance] if args.key?(:content_map_instance) @json_instance = args[:json_instance] if args.key?(:json_instance) end |