Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskExecutorDetailContainerDetail

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The detail of a container execution. It contains the job names of the lifecycle of a container execution.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1PipelineTaskExecutorDetailContainerDetail

Returns a new instance of GoogleCloudAiplatformV1PipelineTaskExecutorDetailContainerDetail.



30968
30969
30970
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30968

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#failed_main_jobsArray<String>

Output only. The names of the previously failed CustomJob for the main container executions. The list includes the all attempts in chronological order. Corresponds to the JSON property failedMainJobs

Returns:

  • (Array<String>)


30946
30947
30948
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30946

def failed_main_jobs
  @failed_main_jobs
end

#failed_pre_caching_check_jobsArray<String>

Output only. The names of the previously failed CustomJob for the pre-caching- check container executions. This job will be available if the PipelineJob. pipeline_spec specifies the pre_caching_check hook in the lifecycle events. The list includes the all attempts in chronological order. Corresponds to the JSON property failedPreCachingCheckJobs

Returns:

  • (Array<String>)


30954
30955
30956
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30954

def failed_pre_caching_check_jobs
  @failed_pre_caching_check_jobs
end

#main_jobString

Output only. The name of the CustomJob for the main container execution. Corresponds to the JSON property mainJob

Returns:

  • (String)


30959
30960
30961
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30959

def main_job
  @main_job
end

#pre_caching_check_jobString

Output only. The name of the CustomJob for the pre-caching-check container execution. This job will be available if the PipelineJob.pipeline_spec specifies the pre_caching_check hook in the lifecycle events. Corresponds to the JSON property preCachingCheckJob

Returns:

  • (String)


30966
30967
30968
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30966

def pre_caching_check_job
  @pre_caching_check_job
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30973
30974
30975
30976
30977
30978
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30973

def update!(**args)
  @failed_main_jobs = args[:failed_main_jobs] if args.key?(:failed_main_jobs)
  @failed_pre_caching_check_jobs = args[:failed_pre_caching_check_jobs] if args.key?(:failed_pre_caching_check_jobs)
  @main_job = args[:main_job] if args.key?(:main_job)
  @pre_caching_check_job = args[:pre_caching_check_job] if args.key?(:pre_caching_check_job)
end