Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PointwiseMetricInstance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Pointwise metric instance. Usually one instance corresponds to one row in an evaluation dataset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1PointwiseMetricInstance

Returns a new instance of GoogleCloudAiplatformV1PointwiseMetricInstance.



28103
28104
28105
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28103

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#content_map_instanceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ContentMap

Map of placeholder in metric prompt template to contents of model input. Corresponds to the JSON property contentMapInstance



28095
28096
28097
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28095

def content_map_instance
  @content_map_instance
end

#json_instanceString

Instance specified as a json string. String key-value pairs are expected in the json_instance to render PointwiseMetricSpec.instance_prompt_template. Corresponds to the JSON property jsonInstance

Returns:

  • (String)


28101
28102
28103
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28101

def json_instance
  @json_instance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28108
28109
28110
28111
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28108

def update!(**args)
  @content_map_instance = args[:content_map_instance] if args.key?(:content_map_instance)
  @json_instance = args[:json_instance] if args.key?(:json_instance)
end