Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Port
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Port
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Represents a network port in a container.
Instance Attribute Summary collapse
-
#container_port ⇒ Fixnum
The number of the port to expose on the pod's IP address.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Port
constructor
A new instance of GoogleCloudAiplatformV1Port.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Port
Returns a new instance of GoogleCloudAiplatformV1Port.
20544 20545 20546 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20544 def initialize(**args) update!(**args) end |
Instance Attribute Details
#container_port ⇒ Fixnum
The number of the port to expose on the pod's IP address. Must be a valid port
number, between 1 and 65535 inclusive.
Corresponds to the JSON property containerPort
20542 20543 20544 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20542 def container_port @container_port end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20549 20550 20551 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20549 def update!(**args) @container_port = args[:container_port] if args.key?(:container_port) end |