Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PreTunedModel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A pre-tuned model for continuous tuning.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1PreTunedModel

Returns a new instance of GoogleCloudAiplatformV1PreTunedModel.



28472
28473
28474
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28472

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_modelString

Output only. The name of the base model this PreTunedModel was tuned from. Corresponds to the JSON property baseModel

Returns:

  • (String)


28455
28456
28457
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28455

def base_model
  @base_model
end

#checkpoint_idString

Optional. The source checkpoint id. If not specified, the default checkpoint will be used. Corresponds to the JSON property checkpointId

Returns:

  • (String)


28461
28462
28463
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28461

def checkpoint_id
  @checkpoint_id
end

#tuned_model_nameString

The resource name of the Model. E.g., a model resource name with a specified version id or alias: projects/project/locations/location/models/model@ version_id`projects/`project`/locations/`location`/models/`model`@`alias Or, omit the version id to use the default version: projects/project/ locations/location/models/model` Corresponds to the JSON propertytunedModelName`

Returns:

  • (String)


28470
28471
28472
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28470

def tuned_model_name
  @tuned_model_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28477
28478
28479
28480
28481
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28477

def update!(**args)
  @base_model = args[:base_model] if args.key?(:base_model)
  @checkpoint_id = args[:checkpoint_id] if args.key?(:checkpoint_id)
  @tuned_model_name = args[:tuned_model_name] if args.key?(:tuned_model_name)
end