Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PreferenceOptimizationSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PreferenceOptimizationSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Tuning Spec for Preference Optimization.
Instance Attribute Summary collapse
-
#export_last_checkpoint_only ⇒ Boolean
(also: #export_last_checkpoint_only?)
Optional.
-
#hyper_parameters ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PreferenceOptimizationHyperParameters
Hyperparameters for Preference Optimization.
-
#training_dataset_uri ⇒ String
Required.
-
#validation_dataset_uri ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1PreferenceOptimizationSpec
constructor
A new instance of GoogleCloudAiplatformV1PreferenceOptimizationSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1PreferenceOptimizationSpec
Returns a new instance of GoogleCloudAiplatformV1PreferenceOptimizationSpec.
31667 31668 31669 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31667 def initialize(**args) update!(**args) end |
Instance Attribute Details
#export_last_checkpoint_only ⇒ Boolean Also known as: export_last_checkpoint_only?
Optional. If set to true, disable intermediate checkpoints for Preference
Optimization and only the last checkpoint will be exported. Otherwise, enable
intermediate checkpoints for Preference Optimization. Default is false.
Corresponds to the JSON property exportLastCheckpointOnly
31647 31648 31649 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31647 def export_last_checkpoint_only @export_last_checkpoint_only end |
#hyper_parameters ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PreferenceOptimizationHyperParameters
Hyperparameters for Preference Optimization.
Corresponds to the JSON property hyperParameters
31653 31654 31655 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31653 def hyper_parameters @hyper_parameters end |
#training_dataset_uri ⇒ String
Required. Cloud Storage path to file containing training dataset for
preference optimization tuning. The dataset must be formatted as a JSONL file.
Corresponds to the JSON property trainingDatasetUri
31659 31660 31661 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31659 def training_dataset_uri @training_dataset_uri end |
#validation_dataset_uri ⇒ String
Optional. Cloud Storage path to file containing validation dataset for
preference optimization tuning. The dataset must be formatted as a JSONL file.
Corresponds to the JSON property validationDatasetUri
31665 31666 31667 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31665 def validation_dataset_uri @validation_dataset_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31672 31673 31674 31675 31676 31677 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31672 def update!(**args) @export_last_checkpoint_only = args[:export_last_checkpoint_only] if args.key?(:export_last_checkpoint_only) @hyper_parameters = args[:hyper_parameters] if args.key?(:hyper_parameters) @training_dataset_uri = args[:training_dataset_uri] if args.key?(:training_dataset_uri) @validation_dataset_uri = args[:validation_dataset_uri] if args.key?(:validation_dataset_uri) end |