Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Presets

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Preset configuration for example-based explanations

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Presets

Returns a new instance of GoogleCloudAiplatformV1Presets.



31124
31125
31126
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31124

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#modalityString

The modality of the uploaded model, which automatically configures the distance measurement and feature normalization for the underlying example index and queries. If your model does not precisely fit one of these types, it is okay to choose the closest type. Corresponds to the JSON property modality

Returns:

  • (String)


31116
31117
31118
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31116

def modality
  @modality
end

#queryString

Preset option controlling parameters for speed-precision trade-off when querying for examples. If omitted, defaults to PRECISE. Corresponds to the JSON property query

Returns:

  • (String)


31122
31123
31124
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31122

def query
  @query
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31129
31130
31131
31132
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31129

def update!(**args)
  @modality = args[:modality] if args.key?(:modality)
  @query = args[:query] if args.key?(:query)
end