Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeGrpcAction
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeGrpcAction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
GrpcAction checks the health of a container using a gRPC service.
Instance Attribute Summary collapse
-
#port ⇒ Fixnum
Port number of the gRPC service.
-
#service ⇒ String
Service is the name of the service to place in the gRPC HealthCheckRequest.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ProbeGrpcAction
constructor
A new instance of GoogleCloudAiplatformV1ProbeGrpcAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ProbeGrpcAction
Returns a new instance of GoogleCloudAiplatformV1ProbeGrpcAction.
22849 22850 22851 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22849 def initialize(**args) update!(**args) end |
Instance Attribute Details
#port ⇒ Fixnum
Port number of the gRPC service. Number must be in the range 1 to 65535.
Corresponds to the JSON property port
22840 22841 22842 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22840 def port @port end |
#service ⇒ String
Service is the name of the service to place in the gRPC HealthCheckRequest.
See https://github.com/grpc/grpc/blob/master/doc/health-checking.md. If this
is not specified, the default behavior is defined by gRPC.
Corresponds to the JSON property service
22847 22848 22849 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22847 def service @service end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22854 22855 22856 22857 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22854 def update!(**args) @port = args[:port] if args.key?(:port) @service = args[:service] if args.key?(:service) end |