Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeTcpSocketAction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

TcpSocketAction probes the health of a container by opening a TCP socket connection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ProbeTcpSocketAction

Returns a new instance of GoogleCloudAiplatformV1ProbeTcpSocketAction.



30938
30939
30940
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30938

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hostString

Optional: Host name to connect to, defaults to the model serving container's IP. Corresponds to the JSON property host

Returns:

  • (String)


30930
30931
30932
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30930

def host
  @host
end

#portFixnum

Number of the port to access on the container. Number must be in the range 1 to 65535. Corresponds to the JSON property port

Returns:

  • (Fixnum)


30936
30937
30938
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30936

def port
  @port
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30943
30944
30945
30946
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30943

def update!(**args)
  @host = args[:host] if args.key?(:host)
  @port = args[:port] if args.key?(:port)
end