Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PurgeArtifactsRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PurgeArtifactsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Request message for MetadataService.PurgeArtifacts.
Instance Attribute Summary collapse
-
#filter ⇒ String
Required.
-
#force ⇒ Boolean
(also: #force?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1PurgeArtifactsRequest
constructor
A new instance of GoogleCloudAiplatformV1PurgeArtifactsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1PurgeArtifactsRequest
Returns a new instance of GoogleCloudAiplatformV1PurgeArtifactsRequest.
31565 31566 31567 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31565 def initialize(**args) update!(**args) end |
Instance Attribute Details
#filter ⇒ String
Required. A required filter matching the Artifacts to be purged. E.g.,
update_time <= 2020-11-19T11:30:00-04:00.
Corresponds to the JSON property filter
31556 31557 31558 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31556 def filter @filter end |
#force ⇒ Boolean Also known as: force?
Optional. Flag to indicate to actually perform the purge. If force is set to
false, the method will return a sample of Artifact names that would be deleted.
Corresponds to the JSON property force
31562 31563 31564 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31562 def force @force end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31570 31571 31572 31573 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31570 def update!(**args) @filter = args[:filter] if args.key?(:filter) @force = args[:force] if args.key?(:force) end |