Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PurgeExecutionsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for MetadataService.PurgeExecutions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1PurgeExecutionsRequest

Returns a new instance of GoogleCloudAiplatformV1PurgeExecutionsRequest.



31703
31704
31705
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31703

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#filterString

Required. A required filter matching the Executions to be purged. E.g., update_time <= 2020-11-19T11:30:00-04:00. Corresponds to the JSON property filter

Returns:

  • (String)


31693
31694
31695
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31693

def filter
  @filter
end

#forceBoolean Also known as: force?

Optional. Flag to indicate to actually perform the purge. If force is set to false, the method will return a sample of Execution names that would be deleted. Corresponds to the JSON property force

Returns:

  • (Boolean)


31700
31701
31702
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31700

def force
  @force
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31708
31709
31710
31711
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31708

def update!(**args)
  @filter = args[:filter] if args.key?(:filter)
  @force = args[:force] if args.key?(:force)
end