Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PurgeMemoriesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for MemoryBankService.PurgeMemories.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1PurgeMemoriesRequest

Returns a new instance of GoogleCloudAiplatformV1PurgeMemoriesRequest.



30105
30106
30107
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30105

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#filterString

Required. The standard list filter to determine which memories to purge. More detail in AIP-160. Corresponds to the JSON property filter

Returns:

  • (String)


30085
30086
30087
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30085

def filter
  @filter
end

#filter_groupsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryConjunctionFilter>

Optional. Metadata filters that will be applied to the memories to be purged. Filters are defined using disjunctive normal form (OR of ANDs). For example: filter_groups: [filters: [key: "author", value:string_value: "agent 123", op: EQUAL],filters: [key: "label", value:string_value: "travel", op: EQUAL, key: "author", value:string_value: "agent 321", op: EQUAL]] would be equivalent to the logical expression: (metadata.author = "agent 123" OR (metadata.label = "travel" AND metadata.author = "agent 321")). Corresponds to the JSON property filterGroups



30096
30097
30098
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30096

def filter_groups
  @filter_groups
end

#forceBoolean Also known as: force?

Optional. If true, the memories will actually be purged. If false, the purge request will be validated but not executed. Corresponds to the JSON property force

Returns:

  • (Boolean)


30102
30103
30104
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30102

def force
  @force
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30110
30111
30112
30113
30114
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30110

def update!(**args)
  @filter = args[:filter] if args.key?(:filter)
  @filter_groups = args[:filter_groups] if args.key?(:filter_groups)
  @force = args[:force] if args.key?(:force)
end