Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagEmbeddingModelConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Config for the embedding model to use for RAG.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1RagEmbeddingModelConfig

Returns a new instance of GoogleCloudAiplatformV1RagEmbeddingModelConfig.



32213
32214
32215
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32213

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#vertex_prediction_endpointGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RagEmbeddingModelConfigVertexPredictionEndpoint

Config representing a model hosted on Vertex Prediction Endpoint. Corresponds to the JSON property vertexPredictionEndpoint



32211
32212
32213
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32211

def vertex_prediction_endpoint
  @vertex_prediction_endpoint
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32218
32219
32220
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32218

def update!(**args)
  @vertex_prediction_endpoint = args[:vertex_prediction_endpoint] if args.key?(:vertex_prediction_endpoint)
end