Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagEmbeddingModelConfigVertexPredictionEndpoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Config representing a model hosted on Vertex Prediction Endpoint.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1RagEmbeddingModelConfigVertexPredictionEndpoint

Returns a new instance of GoogleCloudAiplatformV1RagEmbeddingModelConfigVertexPredictionEndpoint.



24615
24616
24617
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24615

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#endpointString

Required. The endpoint resource name. Format: projects/project/locations/ location/publishers/publisher/models/modelor `projects/`project`/ locations/`location`/endpoints/`endpoint Corresponds to the JSON property endpoint

Returns:

  • (String)


24600
24601
24602
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24600

def endpoint
  @endpoint
end

#modelString

Output only. The resource name of the model that is deployed on the endpoint. Present only when the endpoint is not a publisher model. Pattern: projects/ project/locations/location/models/model` Corresponds to the JSON propertymodel`

Returns:

  • (String)


24607
24608
24609
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24607

def model
  @model
end

#model_version_idString

Output only. Version ID of the model that is deployed on the endpoint. Present only when the endpoint is not a publisher model. Corresponds to the JSON property modelVersionId

Returns:

  • (String)


24613
24614
24615
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24613

def model_version_id
  @model_version_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24620
24621
24622
24623
24624
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24620

def update!(**args)
  @endpoint = args[:endpoint] if args.key?(:endpoint)
  @model = args[:model] if args.key?(:model)
  @model_version_id = args[:model_version_id] if args.key?(:model_version_id)
end