Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagFileTransformationConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagFileTransformationConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Specifies the transformation config for RagFiles.
Instance Attribute Summary collapse
-
#rag_file_chunking_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagFileChunkingConfig
Specifies the size and overlap of chunks for RagFiles.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1RagFileTransformationConfig
constructor
A new instance of GoogleCloudAiplatformV1RagFileTransformationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1RagFileTransformationConfig
Returns a new instance of GoogleCloudAiplatformV1RagFileTransformationConfig.
22661 22662 22663 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22661 def initialize(**args) update!(**args) end |
Instance Attribute Details
#rag_file_chunking_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagFileChunkingConfig
Specifies the size and overlap of chunks for RagFiles.
Corresponds to the JSON property ragFileChunkingConfig
22659 22660 22661 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22659 def rag_file_chunking_config @rag_file_chunking_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22666 22667 22668 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22666 def update!(**args) @rag_file_chunking_config = args[:rag_file_chunking_config] if args.key?(:rag_file_chunking_config) end |