Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigBasic

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Basic tier is a cost-effective and low compute tier suitable for the following cases: * Experimenting with RagManagedDb. * Small data size. * Latency insensitive workload. * Only using RAG Engine with external vector DBs. NOTE: This is the default tier under Spanner mode if not explicitly chosen.

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1RagManagedDbConfigBasic

Returns a new instance of GoogleCloudAiplatformV1RagManagedDbConfigBasic.



31111
31112
31113
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31111

def initialize(**args)
   update!(**args)
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31116
31117
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31116

def update!(**args)
end