Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagVectorDbConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagVectorDbConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Config for the Vector DB to use for RAG.
Instance Attribute Summary collapse
-
#api_auth ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ApiAuth
The generic reusable api auth config.
-
#pinecone ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagVectorDbConfigPinecone
The config for the Pinecone.
-
#rag_embedding_model_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagEmbeddingModelConfig
Config for the embedding model to use for RAG.
-
#rag_managed_db ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagVectorDbConfigRagManagedDb
The config for the default RAG-managed Vector DB.
-
#vertex_vector_search ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagVectorDbConfigVertexVectorSearch
The config for the Vertex Vector Search.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1RagVectorDbConfig
constructor
A new instance of GoogleCloudAiplatformV1RagVectorDbConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1RagVectorDbConfig
Returns a new instance of GoogleCloudAiplatformV1RagVectorDbConfig.
25045 25046 25047 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25045 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_auth ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ApiAuth
The generic reusable api auth config. Deprecated. Please use AuthConfig (
google/cloud/aiplatform/master/auth.proto) instead.
Corresponds to the JSON property apiAuth
25023 25024 25025 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25023 def api_auth @api_auth end |
#pinecone ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagVectorDbConfigPinecone
The config for the Pinecone.
Corresponds to the JSON property pinecone
25028 25029 25030 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25028 def pinecone @pinecone end |
#rag_embedding_model_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagEmbeddingModelConfig
Config for the embedding model to use for RAG.
Corresponds to the JSON property ragEmbeddingModelConfig
25033 25034 25035 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25033 def @rag_embedding_model_config end |
#rag_managed_db ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagVectorDbConfigRagManagedDb
The config for the default RAG-managed Vector DB.
Corresponds to the JSON property ragManagedDb
25038 25039 25040 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25038 def rag_managed_db @rag_managed_db end |
#vertex_vector_search ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagVectorDbConfigVertexVectorSearch
The config for the Vertex Vector Search.
Corresponds to the JSON property vertexVectorSearch
25043 25044 25045 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25043 def vertex_vector_search @vertex_vector_search end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25050 25051 25052 25053 25054 25055 25056 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25050 def update!(**args) @api_auth = args[:api_auth] if args.key?(:api_auth) @pinecone = args[:pinecone] if args.key?(:pinecone) @rag_embedding_model_config = args[:rag_embedding_model_config] if args.key?(:rag_embedding_model_config) @rag_managed_db = args[:rag_managed_db] if args.key?(:rag_managed_db) @vertex_vector_search = args[:vertex_vector_search] if args.key?(:vertex_vector_search) end |