Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RawPredictRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for PredictionService.RawPredict.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1RawPredictRequest

Returns a new instance of GoogleCloudAiplatformV1RawPredictRequest.



23778
23779
23780
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23778

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#http_bodyGoogle::Apis::AiplatformV1::GoogleApiHttpBody

Message that represents an arbitrary HTTP body. It should only be used for payload formats that can't be represented as JSON, such as raw binary or an HTML page. This message can be used both in streaming and non-streaming API methods in the request as well as the response. It can be used as a top-level request field, which is convenient if one wants to extract parameters from either the URL or HTTP template into the request fields and also want access to the raw HTTP body. Example: message GetResourceRequest // A unique request id. string request_id = 1; // The raw HTTP body is bound to this field. google.api.HttpBody http_body = 2; service ResourceService rpc GetResource(GetResourceRequest) returns (google.api.HttpBody); rpc UpdateResource(google.api.HttpBody) returns (google.protobuf.Empty); Example with streaming methods: service CaldavService rpc GetCalendar(stream google. api.HttpBody) returns (stream google.api.HttpBody); rpc UpdateCalendar(stream google.api.HttpBody) returns (stream google.api.HttpBody); Use of this type only changes how the request and response bodies are handled, all other features will continue to work unchanged. Corresponds to the JSON property httpBody



23776
23777
23778
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23776

def http_body
  @http_body
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23783
23784
23785
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23783

def update!(**args)
  @http_body = args[:http_body] if args.key?(:http_body)
end