Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RayClusterAutoscalingSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Ray cluster level autoscaling configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1RayClusterAutoscalingSpec

Returns a new instance of GoogleCloudAiplatformV1RayClusterAutoscalingSpec.



34573
34574
34575
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34573

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idle_timeout_minutesFixnum

Optional. The number of minutes that need to pass before an idle worker node is removed by the autoscaler. Default is 5 mins. Corresponds to the JSON property idleTimeoutMinutes

Returns:

  • (Fixnum)


34563
34564
34565
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34563

def idle_timeout_minutes
  @idle_timeout_minutes
end

#upscaling_speedFixnum

Optional. The number of nodes allowed to be pending as a multiple of the current number of nodes. OSS Ray reference Corresponds to the JSON property upscalingSpeed

Returns:

  • (Fixnum)


34571
34572
34573
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34571

def upscaling_speed
  @upscaling_speed
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34578
34579
34580
34581
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34578

def update!(**args)
  @idle_timeout_minutes = args[:idle_timeout_minutes] if args.key?(:idle_timeout_minutes)
  @upscaling_speed = args[:upscaling_speed] if args.key?(:upscaling_speed)
end