Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReadTensorboardUsageResponsePerUserUsageData
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReadTensorboardUsageResponsePerUserUsageData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Per user usage data.
Instance Attribute Summary collapse
-
#username ⇒ String
User's username Corresponds to the JSON property
username. -
#view_count ⇒ Fixnum
Number of times the user has read data within the Tensorboard.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ReadTensorboardUsageResponsePerUserUsageData
constructor
A new instance of GoogleCloudAiplatformV1ReadTensorboardUsageResponsePerUserUsageData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ReadTensorboardUsageResponsePerUserUsageData
Returns a new instance of GoogleCloudAiplatformV1ReadTensorboardUsageResponsePerUserUsageData.
25780 25781 25782 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25780 def initialize(**args) update!(**args) end |
Instance Attribute Details
#username ⇒ String
User's username
Corresponds to the JSON property username
25773 25774 25775 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25773 def username @username end |
#view_count ⇒ Fixnum
Number of times the user has read data within the Tensorboard.
Corresponds to the JSON property viewCount
25778 25779 25780 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25778 def view_count @view_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25785 25786 25787 25788 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25785 def update!(**args) @username = args[:username] if args.key?(:username) @view_count = args[:view_count] if args.key?(:view_count) end |