Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngine
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngine
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
ReasoningEngine provides a customizable runtime for models to determine which actions to take and in which order.
Instance Attribute Summary collapse
-
#context_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineContextSpec
Configuration for how Agent Engine sub-resources should manage context.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Required.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.
-
#etag ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Labels for the ReasoningEngine.
-
#name ⇒ String
Identifier.
-
#spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpec
ReasoningEngine configurations Corresponds to the JSON property
spec. -
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngine
constructor
A new instance of GoogleCloudAiplatformV1ReasoningEngine.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngine
Returns a new instance of GoogleCloudAiplatformV1ReasoningEngine.
35071 35072 35073 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35071 def initialize(**args) update!(**args) end |
Instance Attribute Details
#context_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineContextSpec
Configuration for how Agent Engine sub-resources should manage context.
Corresponds to the JSON property contextSpec
35021 35022 35023 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35021 def context_spec @context_spec end |
#create_time ⇒ String
Output only. Timestamp when this ReasoningEngine was created.
Corresponds to the JSON property createTime
35026 35027 35028 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35026 def create_time @create_time end |
#description ⇒ String
Optional. The description of the ReasoningEngine.
Corresponds to the JSON property description
35031 35032 35033 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35031 def description @description end |
#display_name ⇒ String
Required. The display name of the ReasoningEngine.
Corresponds to the JSON property displayName
35036 35037 35038 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35036 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied
to a Vertex AI resource.
Corresponds to the JSON property encryptionSpec
35042 35043 35044 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35042 def encryption_spec @encryption_spec end |
#etag ⇒ String
Optional. Used to perform consistent read-modify-write updates. If not set, a
blind "overwrite" update happens.
Corresponds to the JSON property etag
35048 35049 35050 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35048 def etag @etag end |
#labels ⇒ Hash<String,String>
Labels for the ReasoningEngine.
Corresponds to the JSON property labels
35053 35054 35055 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35053 def labels @labels end |
#name ⇒ String
Identifier. The resource name of the ReasoningEngine. Format: projects/
project/locations/location/reasoningEngines/reasoning_engine`
Corresponds to the JSON propertyname`
35059 35060 35061 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35059 def name @name end |
#spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpec
ReasoningEngine configurations
Corresponds to the JSON property spec
35064 35065 35066 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35064 def spec @spec end |
#update_time ⇒ String
Output only. Timestamp when this ReasoningEngine was most recently updated.
Corresponds to the JSON property updateTime
35069 35070 35071 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35069 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35076 35077 35078 35079 35080 35081 35082 35083 35084 35085 35086 35087 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35076 def update!(**args) @context_spec = args[:context_spec] if args.key?(:context_spec) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @spec = args[:spec] if args.key?(:spec) @update_time = args[:update_time] if args.key?(:update_time) end |