Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecBuildSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Specification for building container image.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngineSpecBuildSpec

Returns a new instance of GoogleCloudAiplatformV1ReasoningEngineSpecBuildSpec.



34754
34755
34756
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34754

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#service_accountString

Optional. The service account that Cloud Build uses to run the build. This field is only applicable when worker_pool is specified (i.e., for custom worker pools). If worker_pool is not specified, this field is ignored and the build runs using the Google-managed service agent. Format: projects/ project/serviceAccounts/service_accountorservice_account@project. iam.gserviceaccount.com Corresponds to the JSON property serviceAccount

Returns:

  • (String)


34745
34746
34747
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34745

def 
  @service_account
end

#worker_poolString

Optional. Identifier. The resource name of the Cloud Build WorkerPool to use for the build. Format: projects/project/locations/location/workerPools/ worker_pool` Corresponds to the JSON propertyworkerPool`

Returns:

  • (String)


34752
34753
34754
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34752

def worker_pool
  @worker_pool
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34759
34760
34761
34762
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34759

def update!(**args)
  @service_account = args[:service_account] if args.key?(:service_account)
  @worker_pool = args[:worker_pool] if args.key?(:worker_pool)
end