Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecDeploymentSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecDeploymentSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The specification of a Reasoning Engine deployment.
Instance Attribute Summary collapse
-
#agent_gateway_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecDeploymentSpecAgentGatewayConfig
Agent Gateway configuration for a Reasoning Engine deployment.
-
#container_concurrency ⇒ Fixnum
Optional.
-
#env ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EnvVar>
Optional.
-
#keep_alive_probe ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1KeepAliveProbe
Represents the configuration for keep-alive probe.
-
#max_instances ⇒ Fixnum
Optional.
-
#min_instances ⇒ Fixnum
Optional.
-
#psc_interface_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PscInterfaceConfig
Configuration for PSC-I.
-
#resource_limits ⇒ Hash<String,String>
Optional.
-
#secret_env ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SecretEnvVar>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngineSpecDeploymentSpec
constructor
A new instance of GoogleCloudAiplatformV1ReasoningEngineSpecDeploymentSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngineSpecDeploymentSpec
Returns a new instance of GoogleCloudAiplatformV1ReasoningEngineSpecDeploymentSpec.
35300 35301 35302 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35300 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_gateway_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecDeploymentSpecAgentGatewayConfig
Agent Gateway configuration for a Reasoning Engine deployment.
Corresponds to the JSON property agentGatewayConfig
35242 35243 35244 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35242 def agent_gateway_config @agent_gateway_config end |
#container_concurrency ⇒ Fixnum
Optional. Concurrency for each container and agent server. Recommended value:
2 * cpu + 1. Defaults to 9.
Corresponds to the JSON property containerConcurrency
35248 35249 35250 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35248 def container_concurrency @container_concurrency end |
#env ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EnvVar>
Optional. Environment variables to be set with the Reasoning Engine deployment.
The environment variables can be updated through the UpdateReasoningEngine
API.
Corresponds to the JSON property env
35255 35256 35257 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35255 def env @env end |
#keep_alive_probe ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1KeepAliveProbe
Represents the configuration for keep-alive probe. Contains configuration on a
specified endpoint that a deployment host should use to keep the container
alive based on the probe settings.
Corresponds to the JSON property keepAliveProbe
35262 35263 35264 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35262 def keep_alive_probe @keep_alive_probe end |
#max_instances ⇒ Fixnum
Optional. The maximum number of application instances that can be launched to
handle increased traffic. Defaults to 100. Range: [1, 1000]. If VPC-SC or PSC-
I is enabled, the acceptable range is [1, 100].
Corresponds to the JSON property maxInstances
35269 35270 35271 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35269 def max_instances @max_instances end |
#min_instances ⇒ Fixnum
Optional. The minimum number of application instances that will be kept
running at all times. Defaults to 1. Range: [0, 75].
Corresponds to the JSON property minInstances
35275 35276 35277 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35275 def min_instances @min_instances end |
#psc_interface_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PscInterfaceConfig
Configuration for PSC-I.
Corresponds to the JSON property pscInterfaceConfig
35280 35281 35282 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35280 def psc_interface_config @psc_interface_config end |
#resource_limits ⇒ Hash<String,String>
Optional. Resource limits for each container. Only 'cpu' and 'memory' keys are
supported. Defaults to "cpu": "4", "memory": "4Gi". * The only supported
values for CPU are '1', '2', '4', '6' and '8'. For more information, go to
https://cloud.google.com/run/docs/configuring/cpu. * The only supported values
for memory are '1Gi', '2Gi', ... '32 Gi'. * For required cpu on different
memory values, go to https://cloud.google.com/run/docs/configuring/memory-
limits
Corresponds to the JSON property resourceLimits
35291 35292 35293 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35291 def resource_limits @resource_limits end |
#secret_env ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SecretEnvVar>
Optional. Environment variables where the value is a secret in Cloud Secret
Manager. To use this feature, add 'Secret Manager Secret Accessor' role (roles/
secretmanager.secretAccessor) to AI Platform Reasoning Engine Service Agent.
Corresponds to the JSON property secretEnv
35298 35299 35300 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35298 def secret_env @secret_env end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35305 35306 35307 35308 35309 35310 35311 35312 35313 35314 35315 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35305 def update!(**args) @agent_gateway_config = args[:agent_gateway_config] if args.key?(:agent_gateway_config) @container_concurrency = args[:container_concurrency] if args.key?(:container_concurrency) @env = args[:env] if args.key?(:env) @keep_alive_probe = args[:keep_alive_probe] if args.key?(:keep_alive_probe) @max_instances = args[:max_instances] if args.key?(:max_instances) @min_instances = args[:min_instances] if args.key?(:min_instances) @psc_interface_config = args[:psc_interface_config] if args.key?(:psc_interface_config) @resource_limits = args[:resource_limits] if args.key?(:resource_limits) @secret_env = args[:secret_env] if args.key?(:secret_env) end |