Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Specification for deploying from source code.
Instance Attribute Summary collapse
-
#agent_config_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecAgentConfigSource
Specification for the deploying from agent config.
-
#developer_connect_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecDeveloperConnectSource
Specifies source code to be fetched from a Git repository managed through the Developer Connect service.
-
#image_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecImageSpec
The image spec for building an image (within a single build step), based on the config file (i.e. Dockerfile) in the source directory.
-
#inline_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecInlineSource
Specifies source code provided as a byte stream.
-
#python_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecPythonSpec
Specification for running a Python application from source.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpec
constructor
A new instance of GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpec
Returns a new instance of GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpec.
34488 34489 34490 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34488 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_config_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecAgentConfigSource
Specification for the deploying from agent config.
Corresponds to the JSON property agentConfigSource
34464 34465 34466 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34464 def agent_config_source @agent_config_source end |
#developer_connect_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecDeveloperConnectSource
Specifies source code to be fetched from a Git repository managed through the
Developer Connect service.
Corresponds to the JSON property developerConnectSource
34470 34471 34472 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34470 def developer_connect_source @developer_connect_source end |
#image_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecImageSpec
The image spec for building an image (within a single build step), based on
the config file (i.e. Dockerfile) in the source directory.
Corresponds to the JSON property imageSpec
34476 34477 34478 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34476 def image_spec @image_spec end |
#inline_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecInlineSource
Specifies source code provided as a byte stream.
Corresponds to the JSON property inlineSource
34481 34482 34483 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34481 def inline_source @inline_source end |
#python_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecPythonSpec
Specification for running a Python application from source.
Corresponds to the JSON property pythonSpec
34486 34487 34488 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34486 def python_spec @python_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34493 34494 34495 34496 34497 34498 34499 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34493 def update!(**args) @agent_config_source = args[:agent_config_source] if args.key?(:agent_config_source) @developer_connect_source = args[:developer_connect_source] if args.key?(:developer_connect_source) @image_spec = args[:image_spec] if args.key?(:image_spec) @inline_source = args[:inline_source] if args.key?(:inline_source) @python_spec = args[:python_spec] if args.key?(:python_spec) end |