Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RebaseTunedModelRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for GenAiTuningService.RebaseTunedModel.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1RebaseTunedModelRequest

Returns a new instance of GoogleCloudAiplatformV1RebaseTunedModelRequest.



31409
31410
31411
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31409

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_destinationGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsDestination

The Google Cloud Storage location where the output is to be written to. Corresponds to the JSON property artifactDestination



31388
31389
31390
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31388

def artifact_destination
  @artifact_destination
end

#deploy_to_same_endpointBoolean Also known as: deploy_to_same_endpoint?

Optional. By default, rebasing a model creates a new endpoint for the new model. If this flag is set to true, the new model will be deployed to the same endpoint as the original model. WARNING: If you deploy to the same endpoint, the original model will be un-deployed and replaced by the new model. Corresponds to the JSON property deployToSameEndpoint

Returns:

  • (Boolean)


31396
31397
31398
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31396

def deploy_to_same_endpoint
  @deploy_to_same_endpoint
end

#tuned_model_refGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TunedModelRef

TunedModel Reference for legacy model migration. Corresponds to the JSON property tunedModelRef



31402
31403
31404
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31402

def tuned_model_ref
  @tuned_model_ref
end

#tuning_jobGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TuningJob

Represents a TuningJob that runs with Google owned models. Corresponds to the JSON property tuningJob



31407
31408
31409
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31407

def tuning_job
  @tuning_job
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31414
31415
31416
31417
31418
31419
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31414

def update!(**args)
  @artifact_destination = args[:artifact_destination] if args.key?(:artifact_destination)
  @deploy_to_same_endpoint = args[:deploy_to_same_endpoint] if args.key?(:deploy_to_same_endpoint)
  @tuned_model_ref = args[:tuned_model_ref] if args.key?(:tuned_model_ref)
  @tuning_job = args[:tuning_job] if args.key?(:tuning_job)
end