Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReservationAffinity

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A ReservationAffinity can be used to configure a Vertex AI resource (e.g., a DeployedModel) to draw its Compute Engine resources from a Shared Reservation, or exclusively from on-demand capacity.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ReservationAffinity

Returns a new instance of GoogleCloudAiplatformV1ReservationAffinity.



35855
35856
35857
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35855

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#keyString

Optional. Corresponds to the label key of a reservation resource. To target a SPECIFIC_RESERVATION by name, use compute.googleapis.com/reservation-name as the key and specify the name of your reservation as its value. Corresponds to the JSON property key

Returns:

  • (String)


35841
35842
35843
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35841

def key
  @key
end

#reservation_affinity_typeString

Required. Specifies the reservation affinity type. Corresponds to the JSON property reservationAffinityType

Returns:

  • (String)


35846
35847
35848
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35846

def reservation_affinity_type
  @reservation_affinity_type
end

#valuesArray<String>

Optional. Corresponds to the label values of a reservation resource. This must be the resource name of the reservation, reservation block, or reservation sub- block. Corresponds to the JSON property values

Returns:

  • (Array<String>)


35853
35854
35855
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35853

def values
  @values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35860
35861
35862
35863
35864
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35860

def update!(**args)
  @key = args[:key] if args.key?(:key)
  @reservation_affinity_type = args[:reservation_affinity_type] if args.key?(:reservation_affinity_type)
  @values = args[:values] if args.key?(:values)
end