Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ResourcePool

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents the spec of a group of resources of the same type, for example machine type, disk, and accelerators, in a PersistentResource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ResourcePool

Returns a new instance of GoogleCloudAiplatformV1ResourcePool.



34935
34936
34937
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34935

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#autoscaling_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ResourcePoolAutoscalingSpec

The min/max number of replicas allowed if enabling autoscaling Corresponds to the JSON property autoscalingSpec



34905
34906
34907
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34905

def autoscaling_spec
  @autoscaling_spec
end

#disk_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1DiskSpec

Represents the spec of disk options. Corresponds to the JSON property diskSpec



34910
34911
34912
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34910

def disk_spec
  @disk_spec
end

#idString

Immutable. The unique ID in a PersistentResource for referring to this resource pool. User can specify it if necessary. Otherwise, it's generated automatically. Corresponds to the JSON property id

Returns:

  • (String)


34917
34918
34919
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34917

def id
  @id
end

#machine_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1MachineSpec

Specification of a single machine. Corresponds to the JSON property machineSpec



34922
34923
34924
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34922

def machine_spec
  @machine_spec
end

#replica_countFixnum

Optional. The total number of machines to use for this resource pool. Corresponds to the JSON property replicaCount

Returns:

  • (Fixnum)


34927
34928
34929
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34927

def replica_count
  @replica_count
end

#used_replica_countFixnum

Output only. The number of machines currently in use by training jobs for this resource pool. Will replace idle_replica_count. Corresponds to the JSON property usedReplicaCount

Returns:

  • (Fixnum)


34933
34934
34935
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34933

def used_replica_count
  @used_replica_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34940
34941
34942
34943
34944
34945
34946
34947
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34940

def update!(**args)
  @autoscaling_spec = args[:autoscaling_spec] if args.key?(:autoscaling_spec)
  @disk_spec = args[:disk_spec] if args.key?(:disk_spec)
  @id = args[:id] if args.key?(:id)
  @machine_spec = args[:machine_spec] if args.key?(:machine_spec)
  @replica_count = args[:replica_count] if args.key?(:replica_count)
  @used_replica_count = args[:used_replica_count] if args.key?(:used_replica_count)
end