Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Retrieval

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Defines a retrieval tool that model can call to access external knowledge.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Retrieval

Returns a new instance of GoogleCloudAiplatformV1Retrieval.



35186
35187
35188
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35186

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disable_attributionBoolean Also known as: disable_attribution?

Optional. Deprecated. This option is no longer supported. Corresponds to the JSON property disableAttribution

Returns:

  • (Boolean)


35165
35166
35167
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35165

def disable_attribution
  @disable_attribution
end

#external_apiGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ExternalApi

Retrieve from data source powered by external API for grounding. The external API is not owned by Google, but need to follow the pre-defined API spec. Corresponds to the JSON property externalApi



35172
35173
35174
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35172

def external_api
  @external_api
end

#vertex_ai_searchGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexAiSearch

Retrieve from Vertex AI Search datastore or engine for grounding. datastore and engine are mutually exclusive. See https://cloud.google.com/products/agent- builder Corresponds to the JSON property vertexAiSearch



35179
35180
35181
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35179

def vertex_ai_search
  @vertex_ai_search
end

#vertex_rag_storeGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexRagStore

Retrieve from Vertex RAG Store for grounding. Corresponds to the JSON property vertexRagStore



35184
35185
35186
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35184

def vertex_rag_store
  @vertex_rag_store
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35191
35192
35193
35194
35195
35196
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35191

def update!(**args)
  @disable_attribution = args[:disable_attribution] if args.key?(:disable_attribution)
  @external_api = args[:external_api] if args.key?(:external_api)
  @vertex_ai_search = args[:vertex_ai_search] if args.key?(:vertex_ai_search)
  @vertex_rag_store = args[:vertex_rag_store] if args.key?(:vertex_rag_store)
end