Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrieveMemoriesResponseRetrievedMemory
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrieveMemoriesResponseRetrievedMemory
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A retrieved memory.
Instance Attribute Summary collapse
-
#distance ⇒ Float
The distance between the query and the retrieved Memory.
-
#memory ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Memory
A memory.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1RetrieveMemoriesResponseRetrievedMemory
constructor
A new instance of GoogleCloudAiplatformV1RetrieveMemoriesResponseRetrievedMemory.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1RetrieveMemoriesResponseRetrievedMemory
Returns a new instance of GoogleCloudAiplatformV1RetrieveMemoriesResponseRetrievedMemory.
36672 36673 36674 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36672 def initialize(**args) update!(**args) end |
Instance Attribute Details
#distance ⇒ Float
The distance between the query and the retrieved Memory. Smaller values
indicate more similar memories. This is only set if similarity search was used
for retrieval.
Corresponds to the JSON property distance
36665 36666 36667 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36665 def distance @distance end |
#memory ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Memory
A memory.
Corresponds to the JSON property memory
36670 36671 36672 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36670 def memory @memory end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36677 36678 36679 36680 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36677 def update!(**args) @distance = args[:distance] if args.key?(:distance) @memory = args[:memory] if args.key?(:memory) end |