Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricBasedInstructionFollowingInput

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Instance and metric spec for RubricBasedInstructionFollowing metric.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1RubricBasedInstructionFollowingInput

Returns a new instance of GoogleCloudAiplatformV1RubricBasedInstructionFollowingInput.



36252
36253
36254
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36252

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instanceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricBasedInstructionFollowingInstance

Instance for RubricBasedInstructionFollowing metric - one instance corresponds to one row in an evaluation dataset. Corresponds to the JSON property instance



36244
36245
36246
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36244

def instance
  @instance
end

#metric_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricBasedInstructionFollowingSpec

Spec for RubricBasedInstructionFollowing metric - returns rubrics and verdicts corresponding to rubrics along with overall score. Corresponds to the JSON property metricSpec



36250
36251
36252
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36250

def metric_spec
  @metric_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36257
36258
36259
36260
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36257

def update!(**args)
  @instance = args[:instance] if args.key?(:instance)
  @metric_spec = args[:metric_spec] if args.key?(:metric_spec)
end