Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A group of rubrics, used for grouping rubrics based on a metric or a version.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1RubricGroup

Returns a new instance of GoogleCloudAiplatformV1RubricGroup.



33936
33937
33938
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33936

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Human-readable name for the group. This should be unique within a given context if used for display or selection. Example: "Instruction Following V1", "Content Quality - Summarization Task". Corresponds to the JSON property displayName

Returns:

  • (String)


33924
33925
33926
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33924

def display_name
  @display_name
end

#group_idString

Unique identifier for the group. Corresponds to the JSON property groupId

Returns:

  • (String)


33929
33930
33931
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33929

def group_id
  @group_id
end

#rubricsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Rubric>

Rubrics that are part of this group. Corresponds to the JSON property rubrics



33934
33935
33936
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33934

def rubrics
  @rubrics
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33941
33942
33943
33944
33945
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33941

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @group_id = args[:group_id] if args.key?(:group_id)
  @rubrics = args[:rubrics] if args.key?(:rubrics)
end