Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricVerdict
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricVerdict
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Represents the verdict of an evaluation against a single rubric.
Instance Attribute Summary collapse
-
#evaluated_rubric ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Rubric
Message representing a single testable criterion for evaluation.
-
#reasoning ⇒ String
Optional.
-
#verdict ⇒ Boolean
(also: #verdict?)
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1RubricVerdict
constructor
A new instance of GoogleCloudAiplatformV1RubricVerdict.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1RubricVerdict
Returns a new instance of GoogleCloudAiplatformV1RubricVerdict.
36932 36933 36934 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36932 def initialize(**args) update!(**args) end |
Instance Attribute Details
#evaluated_rubric ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Rubric
Message representing a single testable criterion for evaluation. One input
prompt could have multiple rubrics.
Corresponds to the JSON property evaluatedRubric
36916 36917 36918 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36916 def evaluated_rubric @evaluated_rubric end |
#reasoning ⇒ String
Optional. Human-readable reasoning or explanation for the verdict. This can
include specific examples or details from the evaluated content that justify
the given verdict.
Corresponds to the JSON property reasoning
36923 36924 36925 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36923 def reasoning @reasoning end |
#verdict ⇒ Boolean Also known as: verdict?
Required. Outcome of the evaluation against the rubric, represented as a
boolean. true indicates a "Pass", false indicates a "Fail".
Corresponds to the JSON property verdict
36929 36930 36931 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36929 def verdict @verdict end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36937 36938 36939 36940 36941 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36937 def update!(**args) @evaluated_rubric = args[:evaluated_rubric] if args.key?(:evaluated_rubric) @reasoning = args[:reasoning] if args.key?(:reasoning) @verdict = args[:verdict] if args.key?(:verdict) end |