Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetySetting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A safety setting that affects the safety-blocking behavior. A SafetySetting consists of a harm category and a threshold for that category.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SafetySetting

Returns a new instance of GoogleCloudAiplatformV1SafetySetting.



36143
36144
36145
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36143

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#categoryString

Required. The harm category to be blocked. Corresponds to the JSON property category

Returns:

  • (String)


36129
36130
36131
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36129

def category
  @category
end

#method_propString

Optional. The method for blocking content. If not specified, the default behavior is to use the probability score. Corresponds to the JSON property method

Returns:

  • (String)


36135
36136
36137
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36135

def method_prop
  @method_prop
end

#thresholdString

Required. The threshold for blocking content. If the harm probability exceeds this threshold, the content will be blocked. Corresponds to the JSON property threshold

Returns:

  • (String)


36141
36142
36143
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36141

def threshold
  @threshold
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36148
36149
36150
36151
36152
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36148

def update!(**args)
  @category = args[:category] if args.key?(:category)
  @method_prop = args[:method_prop] if args.key?(:method_prop)
  @threshold = args[:threshold] if args.key?(:threshold)
end