Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SandboxEnvironmentSnapshot

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

SandboxEnvironmentSnapshot is a snapshot of the SandboxEnvironment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SandboxEnvironmentSnapshot

Returns a new instance of GoogleCloudAiplatformV1SandboxEnvironmentSnapshot.



37633
37634
37635
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37633

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The timestamp when this SandboxEnvironmentSnapshot was created. Corresponds to the JSON property createTime

Returns:

  • (String)


37568
37569
37570
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37568

def create_time
  @create_time
end

#display_nameString

Required. The display name of the SandboxEnvironmentSnapshot. Corresponds to the JSON property displayName

Returns:

  • (String)


37573
37574
37575
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37573

def display_name
  @display_name
end

#expire_timeString

Optional. Timestamp in UTC of when this SandboxEnvironmentSnapshot is considered expired. This is always provided on output, regardless of what expiration was sent on input. Corresponds to the JSON property expireTime

Returns:

  • (String)


37580
37581
37582
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37580

def expire_time
  @expire_time
end

#nameString

Identifier. The resource name of the SandboxEnvironmentSnapshot. Format: projects/project/locations/location/reasoningEngines/reasoning_engine/ sandboxEnvironmentSnapshots/sandbox_environment_snapshot` Corresponds to the JSON propertyname`

Returns:

  • (String)


37587
37588
37589
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37587

def name
  @name
end

#ownerString

Optional. Owner information for this sandbox snapshot. Different owners will have isolations on snapshot storage and identity. If not set, snapshot will be created as the default owner. Corresponds to the JSON property owner

Returns:

  • (String)


37594
37595
37596
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37594

def owner
  @owner
end

#parent_snapshotString

Output only. The resource name of the parent SandboxEnvironmentSnapshot. Empty if this is a root Snapshot (the first snapshot from a newly created sandbox). Can be used to reconstruct the whole ancestry tree of snapshots. Corresponds to the JSON property parentSnapshot

Returns:

  • (String)


37601
37602
37603
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37601

def parent_snapshot
  @parent_snapshot
end

#post_snapshot_actionString

Optional. Input only. Action to take on the source SandboxEnvironment after the snapshot is taken. This field is only used in CreateSandboxEnvironmentSnapshotRequest and it is not stored in the resource. Corresponds to the JSON property postSnapshotAction

Returns:

  • (String)


37608
37609
37610
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37608

def post_snapshot_action
  @post_snapshot_action
end

#size_bytesFixnum

Optional. Output only. Size of the snapshot data in bytes. Corresponds to the JSON property sizeBytes

Returns:

  • (Fixnum)


37613
37614
37615
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37613

def size_bytes
  @size_bytes
end

#source_sandbox_environmentString

Required. The resource name of the source SandboxEnvironment this snapshot was taken from. Corresponds to the JSON property sourceSandboxEnvironment

Returns:

  • (String)


37619
37620
37621
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37619

def source_sandbox_environment
  @source_sandbox_environment
end

#ttlString

Optional. Input only. The TTL for the sandbox environment snapshot. The expiration time is computed: now + TTL. Corresponds to the JSON property ttl

Returns:

  • (String)


37625
37626
37627
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37625

def ttl
  @ttl
end

#update_timeString

Output only. The timestamp when this SandboxEnvironment was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


37631
37632
37633
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37631

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37638
37639
37640
37641
37642
37643
37644
37645
37646
37647
37648
37649
37650
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37638

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @name = args[:name] if args.key?(:name)
  @owner = args[:owner] if args.key?(:owner)
  @parent_snapshot = args[:parent_snapshot] if args.key?(:parent_snapshot)
  @post_snapshot_action = args[:post_snapshot_action] if args.key?(:post_snapshot_action)
  @size_bytes = args[:size_bytes] if args.key?(:size_bytes)
  @source_sandbox_environment = args[:source_sandbox_environment] if args.key?(:source_sandbox_environment)
  @ttl = args[:ttl] if args.key?(:ttl)
  @update_time = args[:update_time] if args.key?(:update_time)
end