Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Scheduling

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

All parameters related to queuing and scheduling of custom jobs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Scheduling

Returns a new instance of GoogleCloudAiplatformV1Scheduling.



35063
35064
35065
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35063

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disable_retriesBoolean Also known as: disable_retries?

Optional. Indicates if the job should retry for internal errors after the job starts running. If true, overrides Scheduling.restart_job_on_worker_restart to false. Corresponds to the JSON property disableRetries

Returns:

  • (Boolean)


35034
35035
35036
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35034

def disable_retries
  @disable_retries
end

#max_wait_durationString

Optional. This is the maximum duration that a job will wait for the requested resources to be provisioned if the scheduling strategy is set to [Strategy. DWS_FLEX_START]. If set to 0, the job will wait indefinitely. The default is 24 hours. Corresponds to the JSON property maxWaitDuration

Returns:

  • (String)


35043
35044
35045
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35043

def max_wait_duration
  @max_wait_duration
end

#restart_job_on_worker_restartBoolean Also known as: restart_job_on_worker_restart?

Optional. Restarts the entire CustomJob if a worker gets restarted. This feature can be used by distributed training jobs that are not resilient to workers leaving and joining a job. Corresponds to the JSON property restartJobOnWorkerRestart

Returns:

  • (Boolean)


35050
35051
35052
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35050

def restart_job_on_worker_restart
  @restart_job_on_worker_restart
end

#strategyString

Optional. This determines which type of scheduling strategy to use. Corresponds to the JSON property strategy

Returns:

  • (String)


35056
35057
35058
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35056

def strategy
  @strategy
end

#timeoutString

Optional. The maximum job running time. The default is 7 days. Corresponds to the JSON property timeout

Returns:

  • (String)


35061
35062
35063
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35061

def timeout
  @timeout
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35068
35069
35070
35071
35072
35073
35074
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35068

def update!(**args)
  @disable_retries = args[:disable_retries] if args.key?(:disable_retries)
  @max_wait_duration = args[:max_wait_duration] if args.key?(:max_wait_duration)
  @restart_job_on_worker_restart = args[:restart_job_on_worker_restart] if args.key?(:restart_job_on_worker_restart)
  @strategy = args[:strategy] if args.key?(:strategy)
  @timeout = args[:timeout] if args.key?(:timeout)
end