Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaImageDataItem

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Payload of Image DataItem.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaImageDataItem

Returns a new instance of GoogleCloudAiplatformV1SchemaImageDataItem.



35468
35469
35470
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35468

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gcs_uriString

Required. Google Cloud Storage URI points to the original image in user's bucket. The image is up to 30MB in size. Corresponds to the JSON property gcsUri

Returns:

  • (String)


35459
35460
35461
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35459

def gcs_uri
  @gcs_uri
end

#mime_typeString

Output only. The mime type of the content of the image. Only the images in below listed mime types are supported. - image/jpeg - image/gif - image/png - image/webp - image/bmp - image/tiff - image/vnd.microsoft.icon Corresponds to the JSON property mimeType

Returns:

  • (String)


35466
35467
35468
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35466

def mime_type
  @mime_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35473
35474
35475
35476
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35473

def update!(**args)
  @gcs_uri = args[:gcs_uri] if args.key?(:gcs_uri)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
end