Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaImageDatasetMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaImageDatasetMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The metadata of Datasets that contain Image DataItems.
Instance Attribute Summary collapse
-
#data_item_schema_uri ⇒ String
Points to a YAML file stored on Google Cloud Storage describing payload of the Image DataItems that belong to this Dataset.
-
#gcs_bucket ⇒ String
Google Cloud Storage Bucket name that contains the blob data of this Dataset.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaImageDatasetMetadata
constructor
A new instance of GoogleCloudAiplatformV1SchemaImageDatasetMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaImageDatasetMetadata
Returns a new instance of GoogleCloudAiplatformV1SchemaImageDatasetMetadata.
26678 26679 26680 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26678 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_item_schema_uri ⇒ String
Points to a YAML file stored on Google Cloud Storage describing payload of the
Image DataItems that belong to this Dataset.
Corresponds to the JSON property dataItemSchemaUri
26671 26672 26673 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26671 def data_item_schema_uri @data_item_schema_uri end |
#gcs_bucket ⇒ String
Google Cloud Storage Bucket name that contains the blob data of this Dataset.
Corresponds to the JSON property gcsBucket
26676 26677 26678 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26676 def gcs_bucket @gcs_bucket end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26683 26684 26685 26686 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26683 def update!(**args) @data_item_schema_uri = args[:data_item_schema_uri] if args.key?(:data_item_schema_uri) @gcs_bucket = args[:gcs_bucket] if args.key?(:gcs_bucket) end |