Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsBoundingBoxMetrics
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsBoundingBoxMetrics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Bounding box matching model metrics for a single intersection-over-union threshold and multiple label match confidence thresholds.
Instance Attribute Summary collapse
-
#confidence_metrics ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsBoundingBoxMetricsConfidenceMetrics>
Metrics for each label-match confidence_threshold from 0.05,0.10,...,0.95,0.96, 0.97,0.98,0.99.
-
#iou_threshold ⇒ Float
The intersection-over-union threshold value used to compute this metrics entry.
-
#mean_average_precision ⇒ Float
The mean average precision, most often close to
auPrc.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaModelevaluationMetricsBoundingBoxMetrics
constructor
A new instance of GoogleCloudAiplatformV1SchemaModelevaluationMetricsBoundingBoxMetrics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaModelevaluationMetricsBoundingBoxMetrics
Returns a new instance of GoogleCloudAiplatformV1SchemaModelevaluationMetricsBoundingBoxMetrics.
38222 38223 38224 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38222 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence_metrics ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsBoundingBoxMetricsConfidenceMetrics>
Metrics for each label-match confidence_threshold from 0.05,0.10,...,0.95,0.96,
0.97,0.98,0.99. Precision-recall curve is derived from them.
Corresponds to the JSON property confidenceMetrics
38210 38211 38212 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38210 def confidence_metrics @confidence_metrics end |
#iou_threshold ⇒ Float
The intersection-over-union threshold value used to compute this metrics entry.
Corresponds to the JSON property iouThreshold
38215 38216 38217 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38215 def iou_threshold @iou_threshold end |
#mean_average_precision ⇒ Float
The mean average precision, most often close to auPrc.
Corresponds to the JSON property meanAveragePrecision
38220 38221 38222 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38220 def mean_average_precision @mean_average_precision end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38227 38228 38229 38230 38231 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38227 def update!(**args) @confidence_metrics = args[:confidence_metrics] if args.key?(:confidence_metrics) @iou_threshold = args[:iou_threshold] if args.key?(:iou_threshold) @mean_average_precision = args[:mean_average_precision] if args.key?(:mean_average_precision) end |