Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsBoundingBoxMetricsConfidenceMetrics
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsBoundingBoxMetricsConfidenceMetrics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Metrics for a single confidence threshold.
Instance Attribute Summary collapse
-
#confidence_threshold ⇒ Float
The confidence threshold value used to compute the metrics.
-
#f1_score ⇒ Float
The harmonic mean of recall and precision.
-
#precision ⇒ Float
Precision under the given confidence threshold.
-
#recall ⇒ Float
Recall under the given confidence threshold.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaModelevaluationMetricsBoundingBoxMetricsConfidenceMetrics
constructor
A new instance of GoogleCloudAiplatformV1SchemaModelevaluationMetricsBoundingBoxMetricsConfidenceMetrics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaModelevaluationMetricsBoundingBoxMetricsConfidenceMetrics
Returns a new instance of GoogleCloudAiplatformV1SchemaModelevaluationMetricsBoundingBoxMetricsConfidenceMetrics.
33665 33666 33667 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33665 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence_threshold ⇒ Float
The confidence threshold value used to compute the metrics.
Corresponds to the JSON property confidenceThreshold
33648 33649 33650 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33648 def confidence_threshold @confidence_threshold end |
#f1_score ⇒ Float
The harmonic mean of recall and precision.
Corresponds to the JSON property f1Score
33653 33654 33655 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33653 def f1_score @f1_score end |
#precision ⇒ Float
Precision under the given confidence threshold.
Corresponds to the JSON property precision
33658 33659 33660 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33658 def precision @precision end |
#recall ⇒ Float
Recall under the given confidence threshold.
Corresponds to the JSON property recall
33663 33664 33665 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33663 def recall @recall end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33670 33671 33672 33673 33674 33675 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33670 def update!(**args) @confidence_threshold = args[:confidence_threshold] if args.key?(:confidence_threshold) @f1_score = args[:f1_score] if args.key?(:f1_score) @precision = args[:precision] if args.key?(:precision) @recall = args[:recall] if args.key?(:recall) end |