Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsTrackMetrics
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsTrackMetrics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
UNIMPLEMENTED. Track matching model metrics for a single track match threshold and multiple label match confidence thresholds.
Instance Attribute Summary collapse
-
#confidence_metrics ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsTrackMetricsConfidenceMetrics>
Metrics for each label-match
confidenceThresholdfrom 0.05,0.10,...,0.95,0. -
#iou_threshold ⇒ Float
The intersection-over-union threshold value between bounding boxes across frames used to compute this metric entry.
-
#mean_bounding_box_iou ⇒ Float
The mean bounding box iou over all confidence thresholds.
-
#mean_mismatch_rate ⇒ Float
The mean mismatch rate over all confidence thresholds.
-
#mean_tracking_average_precision ⇒ Float
The mean average precision over all confidence thresholds.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaModelevaluationMetricsTrackMetrics
constructor
A new instance of GoogleCloudAiplatformV1SchemaModelevaluationMetricsTrackMetrics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaModelevaluationMetricsTrackMetrics
Returns a new instance of GoogleCloudAiplatformV1SchemaModelevaluationMetricsTrackMetrics.
39549 39550 39551 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39549 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence_metrics ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsTrackMetricsConfidenceMetrics>
Metrics for each label-match confidenceThreshold from 0.05,0.10,...,0.95,0.
96,0.97,0.98,0.99. Precision-recall curve is derived from them.
Corresponds to the JSON property confidenceMetrics
39526 39527 39528 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39526 def confidence_metrics @confidence_metrics end |
#iou_threshold ⇒ Float
The intersection-over-union threshold value between bounding boxes across
frames used to compute this metric entry.
Corresponds to the JSON property iouThreshold
39532 39533 39534 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39532 def iou_threshold @iou_threshold end |
#mean_bounding_box_iou ⇒ Float
The mean bounding box iou over all confidence thresholds.
Corresponds to the JSON property meanBoundingBoxIou
39537 39538 39539 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39537 def mean_bounding_box_iou @mean_bounding_box_iou end |
#mean_mismatch_rate ⇒ Float
The mean mismatch rate over all confidence thresholds.
Corresponds to the JSON property meanMismatchRate
39542 39543 39544 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39542 def mean_mismatch_rate @mean_mismatch_rate end |
#mean_tracking_average_precision ⇒ Float
The mean average precision over all confidence thresholds.
Corresponds to the JSON property meanTrackingAveragePrecision
39547 39548 39549 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39547 def mean_tracking_average_precision @mean_tracking_average_precision end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39554 39555 39556 39557 39558 39559 39560 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39554 def update!(**args) @confidence_metrics = args[:confidence_metrics] if args.key?(:confidence_metrics) @iou_threshold = args[:iou_threshold] if args.key?(:iou_threshold) @mean_bounding_box_iou = args[:mean_bounding_box_iou] if args.key?(:mean_bounding_box_iou) @mean_mismatch_rate = args[:mean_mismatch_rate] if args.key?(:mean_mismatch_rate) @mean_tracking_average_precision = args[:mean_tracking_average_precision] if args.key?(:mean_tracking_average_precision) end |