Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictInstanceTextExtractionPredictionInstance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Prediction input format for Text Extraction.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictInstanceTextExtractionPredictionInstance

Returns a new instance of GoogleCloudAiplatformV1SchemaPredictInstanceTextExtractionPredictionInstance.



40121
40122
40123
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40121

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentString

The text snippet to make the predictions on. Corresponds to the JSON property content

Returns:

  • (String)


40104
40105
40106
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40104

def content
  @content
end

#keyString

This field is only used for batch prediction. If a key is provided, the batch prediction result will by mapped to this key. If omitted, then the batch prediction result will contain the entire input instance. Vertex AI will not check if keys in the request are duplicates, so it is up to the caller to ensure the keys are unique. Corresponds to the JSON property key

Returns:

  • (String)


40113
40114
40115
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40113

def key
  @key
end

#mime_typeString

The MIME type of the text snippet. The supported MIME types are listed below. - text/plain Corresponds to the JSON property mimeType

Returns:

  • (String)


40119
40120
40121
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40119

def mime_type
  @mime_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40126
40127
40128
40129
40130
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40126

def update!(**args)
  @content = args[:content] if args.key?(:content)
  @key = args[:key] if args.key?(:key)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
end