Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictInstanceVideoClassificationPredictionInstance
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictInstanceVideoClassificationPredictionInstance
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Prediction input format for Video Classification.
Instance Attribute Summary collapse
-
#content ⇒ String
The Google Cloud Storage location of the video on which to perform the prediction.
-
#mime_type ⇒ String
The MIME type of the content of the video.
-
#time_segment_end ⇒ String
The end, exclusive, of the video's time segment on which to perform the prediction.
-
#time_segment_start ⇒ String
The beginning, inclusive, of the video's time segment on which to perform the prediction.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictInstanceVideoClassificationPredictionInstance
constructor
A new instance of GoogleCloudAiplatformV1SchemaPredictInstanceVideoClassificationPredictionInstance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictInstanceVideoClassificationPredictionInstance
Returns a new instance of GoogleCloudAiplatformV1SchemaPredictInstanceVideoClassificationPredictionInstance.
21379 21380 21381 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21379 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content ⇒ String
The Google Cloud Storage location of the video on which to perform the
prediction.
Corresponds to the JSON property content
21354 21355 21356 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21354 def content @content end |
#mime_type ⇒ String
The MIME type of the content of the video. Only the following are supported:
video/mp4 video/avi video/quicktime
Corresponds to the JSON property mimeType
21360 21361 21362 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21360 def mime_type @mime_type end |
#time_segment_end ⇒ String
The end, exclusive, of the video's time segment on which to perform the
prediction. Expressed as a number of seconds as measured from the start of the
video, with "s" appended at the end. Fractions are allowed, up to a
microsecond precision, and "inf" or "Infinity" is allowed, which means the end
of the video.
Corresponds to the JSON property timeSegmentEnd
21369 21370 21371 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21369 def time_segment_end @time_segment_end end |
#time_segment_start ⇒ String
The beginning, inclusive, of the video's time segment on which to perform the
prediction. Expressed as a number of seconds as measured from the start of the
video, with "s" appended at the end. Fractions are allowed, up to a
microsecond precision.
Corresponds to the JSON property timeSegmentStart
21377 21378 21379 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21377 def time_segment_start @time_segment_start end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21384 21385 21386 21387 21388 21389 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21384 def update!(**args) @content = args[:content] if args.key?(:content) @mime_type = args[:mime_type] if args.key?(:mime_type) @time_segment_end = args[:time_segment_end] if args.key?(:time_segment_end) @time_segment_start = args[:time_segment_start] if args.key?(:time_segment_start) end |