Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictInstanceVideoObjectTrackingPredictionInstance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Prediction input format for Video Object Tracking.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictInstanceVideoObjectTrackingPredictionInstance

Returns a new instance of GoogleCloudAiplatformV1SchemaPredictInstanceVideoObjectTrackingPredictionInstance.



40078
40079
40080
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40078

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentString

The Google Cloud Storage location of the video on which to perform the prediction. Corresponds to the JSON property content

Returns:

  • (String)


40053
40054
40055
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40053

def content
  @content
end

#mime_typeString

The MIME type of the content of the video. Only the following are supported: video/mp4 video/avi video/quicktime Corresponds to the JSON property mimeType

Returns:

  • (String)


40059
40060
40061
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40059

def mime_type
  @mime_type
end

#time_segment_endString

The end, exclusive, of the video's time segment on which to perform the prediction. Expressed as a number of seconds as measured from the start of the video, with "s" appended at the end. Fractions are allowed, up to a microsecond precision, and "inf" or "Infinity" is allowed, which means the end of the video. Corresponds to the JSON property timeSegmentEnd

Returns:

  • (String)


40068
40069
40070
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40068

def time_segment_end
  @time_segment_end
end

#time_segment_startString

The beginning, inclusive, of the video's time segment on which to perform the prediction. Expressed as a number of seconds as measured from the start of the video, with "s" appended at the end. Fractions are allowed, up to a microsecond precision. Corresponds to the JSON property timeSegmentStart

Returns:

  • (String)


40076
40077
40078
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40076

def time_segment_start
  @time_segment_start
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40083
40084
40085
40086
40087
40088
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40083

def update!(**args)
  @content = args[:content] if args.key?(:content)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
  @time_segment_end = args[:time_segment_end] if args.key?(:time_segment_end)
  @time_segment_start = args[:time_segment_start] if args.key?(:time_segment_start)
end