Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictParamsImageClassificationPredictionParams

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Prediction model parameters for Image Classification.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictParamsImageClassificationPredictionParams

Returns a new instance of GoogleCloudAiplatformV1SchemaPredictParamsImageClassificationPredictionParams.



40379
40380
40381
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40379

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidence_thresholdFloat

The Model only returns predictions with at least this confidence score. Default value is 0.0 Corresponds to the JSON property confidenceThreshold

Returns:

  • (Float)


40370
40371
40372
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40370

def confidence_threshold
  @confidence_threshold
end

#max_predictionsFixnum

The Model only returns up to that many top, by confidence score, predictions per instance. If this number is very high, the Model may return fewer predictions. Default value is 10. Corresponds to the JSON property maxPredictions

Returns:

  • (Fixnum)


40377
40378
40379
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40377

def max_predictions
  @max_predictions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40384
40385
40386
40387
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40384

def update!(**args)
  @confidence_threshold = args[:confidence_threshold] if args.key?(:confidence_threshold)
  @max_predictions = args[:max_predictions] if args.key?(:max_predictions)
end