Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictPredictionTextExtractionPredictionResult
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictPredictionTextExtractionPredictionResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Prediction output format for Text Extraction.
Instance Attribute Summary collapse
-
#confidences ⇒ Array<Float>
The Model's confidences in correctness of the predicted IDs, higher value means higher confidence.
-
#display_names ⇒ Array<String>
The display names of the AnnotationSpecs that had been identified, order matches the IDs.
-
#ids ⇒ Array<Fixnum>
The resource IDs of the AnnotationSpecs that had been identified, ordered by the confidence score descendingly.
-
#text_segment_end_offsets ⇒ Array<Fixnum>
The end offsets, inclusive, of the text segment in which the AnnotationSpec has been identified.
-
#text_segment_start_offsets ⇒ Array<Fixnum>
The start offsets, inclusive, of the text segment in which the AnnotationSpec has been identified.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictPredictionTextExtractionPredictionResult
constructor
A new instance of GoogleCloudAiplatformV1SchemaPredictPredictionTextExtractionPredictionResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictPredictionTextExtractionPredictionResult
Returns a new instance of GoogleCloudAiplatformV1SchemaPredictPredictionTextExtractionPredictionResult.
40575 40576 40577 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40575 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidences ⇒ Array<Float>
The Model's confidences in correctness of the predicted IDs, higher value
means higher confidence. Order matches the Ids.
Corresponds to the JSON property confidences
40547 40548 40549 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40547 def confidences @confidences end |
#display_names ⇒ Array<String>
The display names of the AnnotationSpecs that had been identified, order
matches the IDs.
Corresponds to the JSON property displayNames
40553 40554 40555 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40553 def display_names @display_names end |
#ids ⇒ Array<Fixnum>
The resource IDs of the AnnotationSpecs that had been identified, ordered by
the confidence score descendingly.
Corresponds to the JSON property ids
40559 40560 40561 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40559 def ids @ids end |
#text_segment_end_offsets ⇒ Array<Fixnum>
The end offsets, inclusive, of the text segment in which the AnnotationSpec
has been identified. Expressed as a zero-based number of characters as
measured from the start of the text snippet.
Corresponds to the JSON property textSegmentEndOffsets
40566 40567 40568 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40566 def text_segment_end_offsets @text_segment_end_offsets end |
#text_segment_start_offsets ⇒ Array<Fixnum>
The start offsets, inclusive, of the text segment in which the AnnotationSpec
has been identified. Expressed as a zero-based number of characters as
measured from the start of the text snippet.
Corresponds to the JSON property textSegmentStartOffsets
40573 40574 40575 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40573 def text_segment_start_offsets @text_segment_start_offsets end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40580 40581 40582 40583 40584 40585 40586 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40580 def update!(**args) @confidences = args[:confidences] if args.key?(:confidences) @display_names = args[:display_names] if args.key?(:display_names) @ids = args[:ids] if args.key?(:ids) @text_segment_end_offsets = args[:text_segment_end_offsets] if args.key?(:text_segment_end_offsets) @text_segment_start_offsets = args[:text_segment_start_offsets] if args.key?(:text_segment_start_offsets) end |