Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictPredictionVideoClassificationPredictionResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Prediction output format for Video Classification.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictPredictionVideoClassificationPredictionResult

Returns a new instance of GoogleCloudAiplatformV1SchemaPredictPredictionVideoClassificationPredictionResult.



40797
40798
40799
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40797

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidenceFloat

The Model's confidence in correction of this prediction, higher value means higher confidence. Corresponds to the JSON property confidence

Returns:

  • (Float)


40757
40758
40759
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40757

def confidence
  @confidence
end

#display_nameString

The display name of the AnnotationSpec that had been identified. Corresponds to the JSON property displayName

Returns:

  • (String)


40762
40763
40764
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40762

def display_name
  @display_name
end

#idString

The resource ID of the AnnotationSpec that had been identified. Corresponds to the JSON property id

Returns:

  • (String)


40767
40768
40769
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40767

def id
  @id
end

#time_segment_endString

The end, exclusive, of the video's time segment in which the AnnotationSpec has been identified. Expressed as a number of seconds as measured from the start of the video, with fractions up to a microsecond precision, and with "s" appended at the end. Note that for 'segment-classification' prediction type, this equals the original 'timeSegmentEnd' from the input instance, for other types it is the end of a shot or a 1 second interval respectively. Corresponds to the JSON property timeSegmentEnd

Returns:

  • (String)


40777
40778
40779
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40777

def time_segment_end
  @time_segment_end
end

#time_segment_startString

The beginning, inclusive, of the video's time segment in which the AnnotationSpec has been identified. Expressed as a number of seconds as measured from the start of the video, with fractions up to a microsecond precision, and with "s" appended at the end. Note that for 'segment- classification' prediction type, this equals the original 'timeSegmentStart' from the input instance, for other types it is the start of a shot or a 1 second interval respectively. Corresponds to the JSON property timeSegmentStart

Returns:

  • (String)


40788
40789
40790
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40788

def time_segment_start
  @time_segment_start
end

#typeString

The type of the prediction. The requested types can be configured via parameters. This will be one of - segment-classification - shot-classification

  • one-sec-interval-classification Corresponds to the JSON property type

Returns:

  • (String)


40795
40796
40797
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40795

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40802
40803
40804
40805
40806
40807
40808
40809
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40802

def update!(**args)
  @confidence = args[:confidence] if args.key?(:confidence)
  @display_name = args[:display_name] if args.key?(:display_name)
  @id = args[:id] if args.key?(:id)
  @time_segment_end = args[:time_segment_end] if args.key?(:time_segment_end)
  @time_segment_start = args[:time_segment_start] if args.key?(:time_segment_start)
  @type = args[:type] if args.key?(:type)
end