Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictPredictionVideoObjectTrackingPredictionResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Prediction output format for Video Object Tracking.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictPredictionVideoObjectTrackingPredictionResult

Returns a new instance of GoogleCloudAiplatformV1SchemaPredictPredictionVideoObjectTrackingPredictionResult.



41060
41061
41062
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41060

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidenceFloat

The Model's confidence in correction of this prediction, higher value means higher confidence. Corresponds to the JSON property confidence

Returns:

  • (Float)


41026
41027
41028
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41026

def confidence
  @confidence
end

#display_nameString

The display name of the AnnotationSpec that had been identified. Corresponds to the JSON property displayName

Returns:

  • (String)


41031
41032
41033
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41031

def display_name
  @display_name
end

#framesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictPredictionVideoObjectTrackingPredictionResultFrame>

All of the frames of the video in which a single object instance has been detected. The bounding boxes in the frames identify the same object. Corresponds to the JSON property frames



41037
41038
41039
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41037

def frames
  @frames
end

#idString

The resource ID of the AnnotationSpec that had been identified. Corresponds to the JSON property id

Returns:

  • (String)


41042
41043
41044
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41042

def id
  @id
end

#time_segment_endString

The end, inclusive, of the video's time segment in which the object instance has been detected. Expressed as a number of seconds as measured from the start of the video, with fractions up to a microsecond precision, and with "s" appended at the end. Corresponds to the JSON property timeSegmentEnd

Returns:

  • (String)


41050
41051
41052
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41050

def time_segment_end
  @time_segment_end
end

#time_segment_startString

The beginning, inclusive, of the video's time segment in which the object instance has been detected. Expressed as a number of seconds as measured from the start of the video, with fractions up to a microsecond precision, and with "s" appended at the end. Corresponds to the JSON property timeSegmentStart

Returns:

  • (String)


41058
41059
41060
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41058

def time_segment_start
  @time_segment_start
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41065
41066
41067
41068
41069
41070
41071
41072
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41065

def update!(**args)
  @confidence = args[:confidence] if args.key?(:confidence)
  @display_name = args[:display_name] if args.key?(:display_name)
  @frames = args[:frames] if args.key?(:frames)
  @id = args[:id] if args.key?(:id)
  @time_segment_end = args[:time_segment_end] if args.key?(:time_segment_end)
  @time_segment_start = args[:time_segment_start] if args.key?(:time_segment_start)
end