Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptInstanceVariableValue
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptInstanceVariableValue
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The value of a variable in prompt.
Instance Attribute Summary collapse
-
#part_list ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecPartList
A list of elements and information that make up a portion of prompt.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPromptInstanceVariableValue
constructor
A new instance of GoogleCloudAiplatformV1SchemaPromptInstanceVariableValue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPromptInstanceVariableValue
Returns a new instance of GoogleCloudAiplatformV1SchemaPromptInstanceVariableValue.
25309 25310 25311 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25309 def initialize(**args) update!(**args) end |
Instance Attribute Details
#part_list ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecPartList
A list of elements and information that make up a portion of prompt.
Corresponds to the JSON property partList
25307 25308 25309 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25307 def part_list @part_list end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25314 25315 25316 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25314 def update!(**args) @part_list = args[:part_list] if args.key?(:part_list) end |