Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecAppBuilderData

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Defines data for an application builder.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPromptSpecAppBuilderData

Returns a new instance of GoogleCloudAiplatformV1SchemaPromptSpecAppBuilderData.



41298
41299
41300
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41298

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#code_repository_stateString

Serialized state of the code repository. This string will typically contain a JSON representation of the UI's CodeRepositoryService state (files, folders, content, and any metadata). The UI is responsible for serialization and deserialization. Corresponds to the JSON property codeRepositoryState

Returns:

  • (String)


41279
41280
41281
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41279

def code_repository_state
  @code_repository_state
end

#deployed_regionsArray<String>

Optional. The Cloud Run regions in which the application is currently deployed. Used to rediscover and redeploy the app in the regions it already runs in, which may differ from the prompt's location. Corresponds to the JSON property deployedRegions

Returns:

  • (Array<String>)


41286
41287
41288
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41286

def deployed_regions
  @deployed_regions
end

#frameworkString

Optional. Framework used to build the application. Corresponds to the JSON property framework

Returns:

  • (String)


41291
41292
41293
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41291

def framework
  @framework
end

#linked_resourcesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecAppBuilderDataLinkedResource>

Linked resources attached to the application by the user. Corresponds to the JSON property linkedResources



41296
41297
41298
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41296

def linked_resources
  @linked_resources
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41303
41304
41305
41306
41307
41308
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41303

def update!(**args)
  @code_repository_state = args[:code_repository_state] if args.key?(:code_repository_state)
  @deployed_regions = args[:deployed_regions] if args.key?(:deployed_regions)
  @framework = args[:framework] if args.key?(:framework)
  @linked_resources = args[:linked_resources] if args.key?(:linked_resources)
end