Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecAppBuilderDataLinkedResource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A linked resource attached to the application by the user.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPromptSpecAppBuilderDataLinkedResource

Returns a new instance of GoogleCloudAiplatformV1SchemaPromptSpecAppBuilderDataLinkedResource.



36354
36355
36356
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36354

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

A user-friendly name for the data source shown in the UI. Corresponds to the JSON property displayName

Returns:

  • (String)


36336
36337
36338
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36336

def display_name
  @display_name
end

#nameString

The unique resource name of the data source. The format is determined by the ' type' field. For type "SAVED_PROMPT": projects/project/locations/location/ datasets/dataset For type "AI_AGENT": projects/project/locations/location /agents/agent Corresponds to the JSON property name

Returns:

  • (String)


36344
36345
36346
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36344

def name
  @name
end

#typeString

The type of the linked resource. e.g., "SAVED_PROMPT", "AI_AGENT" This string corresponds to the name of the LinkedResourceType enum member. See: google3/ cloud/console/web/ai/platform/llm/prompts/build/services/ specs_repository_service/linked_resources/linked_resource.ts Corresponds to the JSON property type

Returns:

  • (String)


36352
36353
36354
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36352

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36359
36360
36361
36362
36363
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36359

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @type = args[:type] if args.key?(:type)
end