Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecMultimodalPrompt
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecMultimodalPrompt
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Prompt variation that embeds preambles to prompt string.
Instance Attribute Summary collapse
-
#prompt_message ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecPromptMessage
The prompt message that aligns with the prompt message in google.cloud.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPromptSpecMultimodalPrompt
constructor
A new instance of GoogleCloudAiplatformV1SchemaPromptSpecMultimodalPrompt.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPromptSpecMultimodalPrompt
Returns a new instance of GoogleCloudAiplatformV1SchemaPromptSpecMultimodalPrompt.
29831 29832 29833 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29831 def initialize(**args) update!(**args) end |
Instance Attribute Details
#prompt_message ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecPromptMessage
The prompt message that aligns with the prompt message in google.cloud.
aiplatform.master.GenerateContentRequest.
Corresponds to the JSON property promptMessage
29829 29830 29831 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29829 def @prompt_message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29836 29837 29838 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29836 def update!(**args) @prompt_message = args[:prompt_message] if args.key?(:prompt_message) end |