Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTextDatasetMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The metadata of Datasets that contain Text DataItems.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTextDatasetMetadata

Returns a new instance of GoogleCloudAiplatformV1SchemaTextDatasetMetadata.



30259
30260
30261
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30259

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_item_schema_uriString

Points to a YAML file stored on Google Cloud Storage describing payload of the Text DataItems that belong to this Dataset. Corresponds to the JSON property dataItemSchemaUri

Returns:

  • (String)


30252
30253
30254
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30252

def data_item_schema_uri
  @data_item_schema_uri
end

#gcs_bucketString

Google Cloud Storage Bucket name that contains the blob data of this Dataset. Corresponds to the JSON property gcsBucket

Returns:

  • (String)


30257
30258
30259
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30257

def gcs_bucket
  @gcs_bucket
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30264
30265
30266
30267
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30264

def update!(**args)
  @data_item_schema_uri = args[:data_item_schema_uri] if args.key?(:data_item_schema_uri)
  @gcs_bucket = args[:gcs_bucket] if args.key?(:gcs_bucket)
end