Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTextSegment
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTextSegment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The text segment inside of DataItem.
Instance Attribute Summary collapse
-
#content ⇒ String
The text content in the segment for output only.
-
#end_offset ⇒ Fixnum
Zero-based character index of the first character past the end of the text segment (counting character from the beginning of the text).
-
#start_offset ⇒ Fixnum
Zero-based character index of the first character of the text segment ( counting characters from the beginning of the text).
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTextSegment
constructor
A new instance of GoogleCloudAiplatformV1SchemaTextSegment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTextSegment
Returns a new instance of GoogleCloudAiplatformV1SchemaTextSegment.
36809 36810 36811 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36809 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content ⇒ String
The text content in the segment for output only.
Corresponds to the JSON property content
36794 36795 36796 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36794 def content @content end |
#end_offset ⇒ Fixnum
Zero-based character index of the first character past the end of the text
segment (counting character from the beginning of the text). The character at
the end_offset is NOT included in the text segment.
Corresponds to the JSON property endOffset
36801 36802 36803 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36801 def end_offset @end_offset end |
#start_offset ⇒ Fixnum
Zero-based character index of the first character of the text segment (
counting characters from the beginning of the text).
Corresponds to the JSON property startOffset
36807 36808 36809 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36807 def start_offset @start_offset end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36814 36815 36816 36817 36818 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36814 def update!(**args) @content = args[:content] if args.key?(:content) @end_offset = args[:end_offset] if args.key?(:end_offset) @start_offset = args[:start_offset] if args.key?(:start_offset) end |