Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformationNumericTransformation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Training pipeline will perform following transformation functions. * The value converted to float32. * The z_score of the value. * log(value+1) when the value is greater than or equal to 0. Otherwise, this transformation is not applied and the value is considered a missing value. * z_score of log(value+1) when the value is greater than or equal to 0. Otherwise, this transformation is not applied and the value is considered a missing value. * A boolean value that indicates whether the value is valid.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformationNumericTransformation

Returns a new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformationNumericTransformation.



42001
42002
42003
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42001

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#column_nameString

Corresponds to the JSON property columnName

Returns:

  • (String)


41999
42000
42001
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41999

def column_name
  @column_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42006
42007
42008
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42006

def update!(**args)
  @column_name = args[:column_name] if args.key?(:column_name)
end