Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformationTextTransformation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Training pipeline will perform following transformation functions. * The text as is--no change to case, punctuation, spelling, tense, and so on. * Convert the category name to a dictionary lookup index and generate an embedding for each index.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformationTextTransformation

Returns a new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformationTextTransformation.



41441
41442
41443
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41441

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#column_nameString

Corresponds to the JSON property columnName

Returns:

  • (String)


41439
41440
41441
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41439

def column_name
  @column_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41446
41447
41448
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41446

def update!(**args)
  @column_name = args[:column_name] if args.key?(:column_name)
end