Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageClassificationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageClassificationMetadata

Returns a new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageClassificationMetadata.



31324
31325
31326
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31324

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cost_milli_node_hoursFixnum

The actual training cost of creating this model, expressed in milli node hours, i.e. 1,000 value in this field means 1 node hour. Guaranteed to not exceed inputs.budgetMilliNodeHours. Corresponds to the JSON property costMilliNodeHours

Returns:

  • (Fixnum)


31317
31318
31319
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31317

def cost_milli_node_hours
  @cost_milli_node_hours
end

#successful_stop_reasonString

For successful job completions, this is the reason why the job has finished. Corresponds to the JSON property successfulStopReason

Returns:

  • (String)


31322
31323
31324
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31322

def successful_stop_reason
  @successful_stop_reason
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31329
31330
31331
31332
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31329

def update!(**args)
  @cost_milli_node_hours = args[:cost_milli_node_hours] if args.key?(:cost_milli_node_hours)
  @successful_stop_reason = args[:successful_stop_reason] if args.key?(:successful_stop_reason)
end