Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationNumericArrayTransformation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Treats the column as numerical array and performs following transformation functions. * All transformations for Numerical types applied to the average of the all elements. * The average of empty arrays is treated as zero.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationNumericArrayTransformation

Returns a new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationNumericArrayTransformation.



31874
31875
31876
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31874

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#column_nameString

Corresponds to the JSON property columnName

Returns:

  • (String)


31864
31865
31866
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31864

def column_name
  @column_name
end

#invalid_values_allowedBoolean Also known as: invalid_values_allowed?

If invalid values is allowed, the training pipeline will create a boolean feature that indicated whether the value is valid. Otherwise, the training pipeline will discard the input row from trainining data. Corresponds to the JSON property invalidValuesAllowed

Returns:

  • (Boolean)


31871
31872
31873
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31871

def invalid_values_allowed
  @invalid_values_allowed
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31879
31880
31881
31882
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31879

def update!(**args)
  @column_name = args[:column_name] if args.key?(:column_name)
  @invalid_values_allowed = args[:invalid_values_allowed] if args.key?(:invalid_values_allowed)
end