Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTextSentimentInputs

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTextSentimentInputs

Returns a new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTextSentimentInputs.



26039
26040
26041
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26039

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#sentiment_maxFixnum

A sentiment is expressed as an integer ordinal, where higher value means a more positive sentiment. The range of sentiments that will be used is between 0 and sentimentMax (inclusive on both ends), and all the values in the range must be represented in the dataset before a model can be created. Only the Annotations with this sentimentMax will be used for training. sentimentMax value must be between 1 and 10 (inclusive). Corresponds to the JSON property sentimentMax

Returns:

  • (Fixnum)


26037
26038
26039
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26037

def sentiment_max
  @sentiment_max
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26044
26045
26046
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26044

def update!(**args)
  @sentiment_max = args[:sentiment_max] if args.key?(:sentiment_max)
end