Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutomlImageTrainingTunableParameter
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutomlImageTrainingTunableParameter
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A wrapper class which contains the tunable parameters in an AutoML Image training job.
Instance Attribute Summary collapse
-
#checkpoint_name ⇒ String
Optional.
-
#dataset_config ⇒ Hash<String,String>
Customizable dataset settings, used in the
model_garden_trainer. -
#study_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpec
Represents specification of a Study.
-
#trainer_config ⇒ Hash<String,String>
Customizable trainer settings, used in the
model_garden_trainer. -
#trainer_type ⇒ String
Corresponds to the JSON property
trainerType.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutomlImageTrainingTunableParameter
constructor
A new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutomlImageTrainingTunableParameter.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutomlImageTrainingTunableParameter
Returns a new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutomlImageTrainingTunableParameter.
40786 40787 40788 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40786 def initialize(**args) update!(**args) end |
Instance Attribute Details
#checkpoint_name ⇒ String
Optional. An unique name of pretrained model checkpoint provided in model
garden, it will be mapped to a GCS location internally.
Corresponds to the JSON property checkpointName
40764 40765 40766 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40764 def checkpoint_name @checkpoint_name end |
#dataset_config ⇒ Hash<String,String>
Customizable dataset settings, used in the model_garden_trainer.
Corresponds to the JSON property datasetConfig
40769 40770 40771 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40769 def dataset_config @dataset_config end |
#study_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpec
Represents specification of a Study.
Corresponds to the JSON property studySpec
40774 40775 40776 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40774 def study_spec @study_spec end |
#trainer_config ⇒ Hash<String,String>
Customizable trainer settings, used in the model_garden_trainer.
Corresponds to the JSON property trainerConfig
40779 40780 40781 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40779 def trainer_config @trainer_config end |
#trainer_type ⇒ String
Corresponds to the JSON property trainerType
40784 40785 40786 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40784 def trainer_type @trainer_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40791 40792 40793 40794 40795 40796 40797 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40791 def update!(**args) @checkpoint_name = args[:checkpoint_name] if args.key?(:checkpoint_name) @dataset_config = args[:dataset_config] if args.key?(:dataset_config) @study_spec = args[:study_spec] if args.key?(:study_spec) @trainer_config = args[:trainer_config] if args.key?(:trainer_config) @trainer_type = args[:trainer_type] if args.key?(:trainer_type) end |