Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionHierarchyConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Configuration that defines the hierarchical relationship of time series and parameters for hierarchical forecasting strategies.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionHierarchyConfig

Returns a new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionHierarchyConfig.



32957
32958
32959
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32957

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#group_columnsArray<String>

A list of time series attribute column names that define the time series hierarchy. Only one level of hierarchy is supported, ex. 'region' for a hierarchy of stores or 'department' for a hierarchy of products. If multiple columns are specified, time series will be grouped by their combined values, ex. ('blue', 'large') for 'color' and 'size', up to 5 columns are accepted. If no group columns are specified, all time series are considered to be part of the same group. Corresponds to the JSON property groupColumns

Returns:

  • (Array<String>)


32937
32938
32939
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32937

def group_columns
  @group_columns
end

#group_temporal_total_weightFloat

The weight of the loss for predictions aggregated over both the horizon and time series in the same hierarchy group. Corresponds to the JSON property groupTemporalTotalWeight

Returns:

  • (Float)


32943
32944
32945
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32943

def group_temporal_total_weight
  @group_temporal_total_weight
end

#group_total_weightFloat

The weight of the loss for predictions aggregated over time series in the same group. Corresponds to the JSON property groupTotalWeight

Returns:

  • (Float)


32949
32950
32951
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32949

def group_total_weight
  @group_total_weight
end

#temporal_total_weightFloat

The weight of the loss for predictions aggregated over the horizon for a single time series. Corresponds to the JSON property temporalTotalWeight

Returns:

  • (Float)


32955
32956
32957
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32955

def temporal_total_weight
  @temporal_total_weight
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32962
32963
32964
32965
32966
32967
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32962

def update!(**args)
  @group_columns = args[:group_columns] if args.key?(:group_columns)
  @group_temporal_total_weight = args[:group_temporal_total_weight] if args.key?(:group_temporal_total_weight)
  @group_total_weight = args[:group_total_weight] if args.key?(:group_total_weight)
  @temporal_total_weight = args[:temporal_total_weight] if args.key?(:temporal_total_weight)
end