Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionHyperparameterTuningJobMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionHyperparameterTuningJobMetadata

Returns a new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionHyperparameterTuningJobMetadata.



40745
40746
40747
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40745

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backing_hyperparameter_tuning_jobString

The resource name of the HyperparameterTuningJob that has been created to carry out this HyperparameterTuning task. Corresponds to the JSON property backingHyperparameterTuningJob

Returns:

  • (String)


40737
40738
40739
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40737

def backing_hyperparameter_tuning_job
  @backing_hyperparameter_tuning_job
end

#best_trial_backing_custom_jobString

The resource name of the CustomJob that has been created to run the best Trial of this HyperparameterTuning task. Corresponds to the JSON property bestTrialBackingCustomJob

Returns:

  • (String)


40743
40744
40745
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40743

def best_trial_backing_custom_job
  @best_trial_backing_custom_job
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40750
40751
40752
40753
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40750

def update!(**args)
  @backing_hyperparameter_tuning_job = args[:backing_hyperparameter_tuning_job] if args.key?(:backing_hyperparameter_tuning_job)
  @best_trial_backing_custom_job = args[:best_trial_backing_custom_job] if args.key?(:best_trial_backing_custom_job)
end