Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaVertex

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents a 2D point in the image. Vertex coordinates are normalized to be relative to the original image dimensions and range from 0 to 1. The origin of the coordinate system (0,0) is the top-left corner of the image. x increases to the right, and y increases to the bottom.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaVertex

Returns a new instance of GoogleCloudAiplatformV1SchemaVertex.



43804
43805
43806
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 43804

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#xFloat

X coordinate of the vertex, normalized to [0.0, 1.0]. Corresponds to the JSON property x

Returns:

  • (Float)


43797
43798
43799
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 43797

def x
  @x
end

#yFloat

Y coordinate of the vertex, normalized to [0.0, 1.0]. Corresponds to the JSON property y

Returns:

  • (Float)


43802
43803
43804
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 43802

def y
  @y
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43809
43810
43811
43812
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 43809

def update!(**args)
  @x = args[:x] if args.key?(:x)
  @y = args[:y] if args.key?(:y)
end