Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaVideoDataItem

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Payload of Video DataItem.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaVideoDataItem

Returns a new instance of GoogleCloudAiplatformV1SchemaVideoDataItem.



44476
44477
44478
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44476

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gcs_uriString

Required. Google Cloud Storage URI points to the original video in user's bucket. The video is up to 50 GB in size and up to 3 hour in duration. Corresponds to the JSON property gcsUri

Returns:

  • (String)


44467
44468
44469
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44467

def gcs_uri
  @gcs_uri
end

#mime_typeString

Output only. The mime type of the content of the video. Only the videos in below listed mime types are supported. Supported mime_type: - video/mp4 - video/avi - video/quicktime Corresponds to the JSON property mimeType

Returns:

  • (String)


44474
44475
44476
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44474

def mime_type
  @mime_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44481
44482
44483
44484
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44481

def update!(**args)
  @gcs_uri = args[:gcs_uri] if args.key?(:gcs_uri)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
end