Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaVideoDatasetMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaVideoDatasetMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The metadata of Datasets that contain Video DataItems.
Instance Attribute Summary collapse
-
#data_item_schema_uri ⇒ String
Points to a YAML file stored on Google Cloud Storage describing payload of the Video DataItems that belong to this Dataset.
-
#gcs_bucket ⇒ String
Google Cloud Storage Bucket name that contains the blob data of this Dataset.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaVideoDatasetMetadata
constructor
A new instance of GoogleCloudAiplatformV1SchemaVideoDatasetMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaVideoDatasetMetadata
Returns a new instance of GoogleCloudAiplatformV1SchemaVideoDatasetMetadata.
43920 43921 43922 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 43920 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_item_schema_uri ⇒ String
Points to a YAML file stored on Google Cloud Storage describing payload of the
Video DataItems that belong to this Dataset.
Corresponds to the JSON property dataItemSchemaUri
43913 43914 43915 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 43913 def data_item_schema_uri @data_item_schema_uri end |
#gcs_bucket ⇒ String
Google Cloud Storage Bucket name that contains the blob data of this Dataset.
Corresponds to the JSON property gcsBucket
43918 43919 43920 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 43918 def gcs_bucket @gcs_bucket end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
43925 43926 43927 43928 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 43925 def update!(**args) @data_item_schema_uri = args[:data_item_schema_uri] if args.key?(:data_item_schema_uri) @gcs_bucket = args[:gcs_bucket] if args.key?(:gcs_bucket) end |