Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SearchMigratableResourcesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for MigrationService.SearchMigratableResources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SearchMigratableResourcesRequest

Returns a new instance of GoogleCloudAiplatformV1SearchMigratableResourcesRequest.



34152
34153
34154
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34152

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#filterString

A filter for your search. You can use the following types of filters: * Resource type filters. The following strings filter for a specific type of MigratableResource: * ml_engine_model_version:* * automl_model:* * automl_dataset:* * data_labeling_dataset:* * "Migrated or not" filters. The following strings filter for resources that either have or have not already been migrated: * last_migrate_time:* filters for migrated resources. * NOT last_migrate_time:* filters for not yet migrated resources. Corresponds to the JSON property filter

Returns:

  • (String)


34140
34141
34142
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34140

def filter
  @filter
end

#page_sizeFixnum

The standard page size. The default and maximum value is 100. Corresponds to the JSON property pageSize

Returns:

  • (Fixnum)


34145
34146
34147
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34145

def page_size
  @page_size
end

#page_tokenString

The standard page token. Corresponds to the JSON property pageToken

Returns:

  • (String)


34150
34151
34152
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34150

def page_token
  @page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34157
34158
34159
34160
34161
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34157

def update!(**args)
  @filter = args[:filter] if args.key?(:filter)
  @page_size = args[:page_size] if args.key?(:page_size)
  @page_token = args[:page_token] if args.key?(:page_token)
end