Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SemanticGovernancePolicy
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SemanticGovernancePolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Represents a governance policy applied to a specific Agent and optionally a specific Tool within that Agent.
Instance Attribute Summary collapse
-
#agent ⇒ String
Required.
-
#agent_identity ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Optional.
-
#etag ⇒ String
Optional.
-
#mcp_tools ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SemanticGovernancePolicyMcpTool>
Optional.
-
#name ⇒ String
Identifier.
-
#natural_language_constraint ⇒ String
Required.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SemanticGovernancePolicy
constructor
A new instance of GoogleCloudAiplatformV1SemanticGovernancePolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SemanticGovernancePolicy
Returns a new instance of GoogleCloudAiplatformV1SemanticGovernancePolicy.
45760 45761 45762 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45760 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent ⇒ String
Required. The name of the agent in Agent Registry that is affected by this
policy.
Corresponds to the JSON property agent
45706 45707 45708 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45706 def agent @agent end |
#agent_identity ⇒ String
Output only. Represents the principal of the agent, used by the Policy
Decision Point (PDP) for governance checks. For more information, see https://
docs.cloud.google.com/agent-builder/agent-engine/agent-identity Format:
principal://TRUST_DOMAIN/NAMESPACE/AGENT_NAME Example: principal://agents.
global.org-ORGANIZATION_ID.system.id.goog/resources/aiplatform/projects/
PROJECT_NUMBER/locations/LOCATION/reasoningEngines/AGENT_ENGINE_ID
Corresponds to the JSON property agentIdentity
45716 45717 45718 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45716 def agent_identity @agent_identity end |
#create_time ⇒ String
Output only. Timestamp when this SemanticGovernancePolicy was created.
Corresponds to the JSON property createTime
45721 45722 45723 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45721 def create_time @create_time end |
#description ⇒ String
Optional. The description of the SemanticGovernancePolicy.
Corresponds to the JSON property description
45726 45727 45728 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45726 def description @description end |
#display_name ⇒ String
Optional. The user-defined name of the SemanticGovernancePolicy.
Corresponds to the JSON property displayName
45731 45732 45733 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45731 def display_name @display_name end |
#etag ⇒ String
Optional. Used to perform consistent read-modify-write transactions. If
provided, the request will only succeed if the etag matches the current value.
Otherwise, an ABORTED error will be returned.
Corresponds to the JSON property etag
45738 45739 45740 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45738 def etag @etag end |
#mcp_tools ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SemanticGovernancePolicyMcpTool>
Optional. The McpTools that are affected by this policy.
Corresponds to the JSON property mcpTools
45743 45744 45745 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45743 def mcp_tools @mcp_tools end |
#name ⇒ String
Identifier. Resource name of the SemanticGovernancePolicy.
Corresponds to the JSON property name
45748 45749 45750 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45748 def name @name end |
#natural_language_constraint ⇒ String
Required. The natural language constraint of the SemanticGovernancePolicy.
Corresponds to the JSON property naturalLanguageConstraint
45753 45754 45755 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45753 def natural_language_constraint @natural_language_constraint end |
#update_time ⇒ String
Output only. Timestamp when this SemanticGovernancePolicy was last updated.
Corresponds to the JSON property updateTime
45758 45759 45760 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45758 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45765 45766 45767 45768 45769 45770 45771 45772 45773 45774 45775 45776 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45765 def update!(**args) @agent = args[:agent] if args.key?(:agent) @agent_identity = args[:agent_identity] if args.key?(:agent_identity) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @mcp_tools = args[:mcp_tools] if args.key?(:mcp_tools) @name = args[:name] if args.key?(:name) @natural_language_constraint = args[:natural_language_constraint] if args.key?(:natural_language_constraint) @update_time = args[:update_time] if args.key?(:update_time) end |