Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Session

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A session contains a set of actions between users and Vertex agents.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Session

Returns a new instance of GoogleCloudAiplatformV1Session.



45966
45967
45968
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45966

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when the session was created. Corresponds to the JSON property createTime

Returns:

  • (String)


45917
45918
45919
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45917

def create_time
  @create_time
end

#display_nameString

Optional. The display name of the session. Corresponds to the JSON property displayName

Returns:

  • (String)


45922
45923
45924
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45922

def display_name
  @display_name
end

#expire_timeString

Optional. Timestamp of when this session is considered expired. This is * always* provided on output, regardless of what was sent on input. The minimum value is 24 hours from the time of creation. Corresponds to the JSON property expireTime

Returns:

  • (String)


45929
45930
45931
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45929

def expire_time
  @expire_time
end

#labelsHash<String,String>

The labels with user-defined metadata to organize your Sessions. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


45938
45939
45940
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45938

def labels
  @labels
end

#nameString

Identifier. The resource name of the session. Format: 'projects/project/ locations/location/reasoningEngines/reasoning_engine/sessions/session'. Corresponds to the JSON property name

Returns:

  • (String)


45944
45945
45946
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45944

def name
  @name
end

#session_stateHash<String,Object>

Optional. Session specific memory which stores key conversation points. Corresponds to the JSON property sessionState

Returns:

  • (Hash<String,Object>)


45949
45950
45951
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45949

def session_state
  @session_state
end

#ttlString

Optional. Input only. The TTL for this session. The minimum value is 24 hours. Corresponds to the JSON property ttl

Returns:

  • (String)


45954
45955
45956
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45954

def ttl
  @ttl
end

#update_timeString

Output only. Timestamp when the session was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


45959
45960
45961
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45959

def update_time
  @update_time
end

#user_idString

Required. Immutable. String id provided by the user Corresponds to the JSON property userId

Returns:

  • (String)


45964
45965
45966
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45964

def user_id
  @user_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45971
45972
45973
45974
45975
45976
45977
45978
45979
45980
45981
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45971

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @session_state = args[:session_state] if args.key?(:session_state)
  @ttl = args[:ttl] if args.key?(:ttl)
  @update_time = args[:update_time] if args.key?(:update_time)
  @user_id = args[:user_id] if args.key?(:user_id)
end