Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SessionEvent
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SessionEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
An event represents a message from either the user or agent.
Instance Attribute Summary collapse
-
#actions ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EventActions
Actions are parts of events that are executed by the agent.
-
#author ⇒ String
Required.
-
#content ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content
The structured data content of a message.
-
#error_code ⇒ String
Optional.
-
#error_message ⇒ String
Optional.
-
#event_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EventMetadata
Metadata relating to a LLM response event.
-
#invocation_id ⇒ String
Required.
-
#name ⇒ String
Identifier.
-
#raw_event ⇒ Hash<String,Object>
Optional.
-
#timestamp ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SessionEvent
constructor
A new instance of GoogleCloudAiplatformV1SessionEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SessionEvent
Returns a new instance of GoogleCloudAiplatformV1SessionEvent.
44801 44802 44803 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44801 def initialize(**args) update!(**args) end |
Instance Attribute Details
#actions ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EventActions
Actions are parts of events that are executed by the agent.
Corresponds to the JSON property actions
44749 44750 44751 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44749 def actions @actions end |
#author ⇒ String
Required. The name of the agent that sent the event, or user.
Corresponds to the JSON property author
44754 44755 44756 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44754 def @author end |
#content ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content
The structured data content of a message. A Content message contains a role
field, which indicates the producer of the content, and a parts field, which
contains the multi-part data of the message.
Corresponds to the JSON property content
44761 44762 44763 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44761 def content @content end |
#error_code ⇒ String
Optional. Error code if the response is an error. Code varies by model.
Corresponds to the JSON property errorCode
44766 44767 44768 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44766 def error_code @error_code end |
#error_message ⇒ String
Optional. Error message if the response is an error.
Corresponds to the JSON property errorMessage
44771 44772 44773 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44771 def @error_message end |
#event_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EventMetadata
Metadata relating to a LLM response event.
Corresponds to the JSON property eventMetadata
44776 44777 44778 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44776 def @event_metadata end |
#invocation_id ⇒ String
Required. The invocation id of the event, multiple events can have the same
invocation id.
Corresponds to the JSON property invocationId
44782 44783 44784 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44782 def invocation_id @invocation_id end |
#name ⇒ String
Identifier. The resource name of the event. Format:projects/project/
locations/location/reasoningEngines/reasoning_engine/sessions/session/
events/event`.
Corresponds to the JSON propertyname`
44789 44790 44791 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44789 def name @name end |
#raw_event ⇒ Hash<String,Object>
Optional. Weakly typed raw event data in proto struct format.
Corresponds to the JSON property rawEvent
44794 44795 44796 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44794 def raw_event @raw_event end |
#timestamp ⇒ String
Required. Timestamp when the event was created on client side.
Corresponds to the JSON property timestamp
44799 44800 44801 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44799 def @timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
44806 44807 44808 44809 44810 44811 44812 44813 44814 44815 44816 44817 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44806 def update!(**args) @actions = args[:actions] if args.key?(:actions) @author = args[:author] if args.key?(:author) @content = args[:content] if args.key?(:content) @error_code = args[:error_code] if args.key?(:error_code) @error_message = args[:error_message] if args.key?(:error_message) @event_metadata = args[:event_metadata] if args.key?(:event_metadata) @invocation_id = args[:invocation_id] if args.key?(:invocation_id) @name = args[:name] if args.key?(:name) @raw_event = args[:raw_event] if args.key?(:raw_event) @timestamp = args[:timestamp] if args.key?(:timestamp) end |