Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StreamQueryReasoningEngineRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for ReasoningEngineExecutionService.StreamQuery.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1StreamQueryReasoningEngineRequest

Returns a new instance of GoogleCloudAiplatformV1StreamQueryReasoningEngineRequest.



34079
34080
34081
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34079

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#class_methodString

Optional. Class method to be used for the stream query. It is optional and defaults to "stream_query" if unspecified. Corresponds to the JSON property classMethod

Returns:

  • (String)


34071
34072
34073
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34071

def class_method
  @class_method
end

#inputHash<String,Object>

Optional. Input content provided by users in JSON object format. Examples include text query, function calling parameters, media bytes, etc. Corresponds to the JSON property input

Returns:

  • (Hash<String,Object>)


34077
34078
34079
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34077

def input
  @input
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34084
34085
34086
34087
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34084

def update!(**args)
  @class_method = args[:class_method] if args.key?(:class_method)
  @input = args[:input] if args.key?(:input)
end