Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Study

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A message representing a Study.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Study

Returns a new instance of GoogleCloudAiplatformV1Study.



46168
46169
46170
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46168

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Time at which the study was created. Corresponds to the JSON property createTime

Returns:

  • (String)


46139
46140
46141
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46139

def create_time
  @create_time
end

#display_nameString

Required. Describes the Study, default value is empty string. Corresponds to the JSON property displayName

Returns:

  • (String)


46144
46145
46146
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46144

def display_name
  @display_name
end

#inactive_reasonString

Output only. A human readable reason why the Study is inactive. This should be empty if a study is ACTIVE or COMPLETED. Corresponds to the JSON property inactiveReason

Returns:

  • (String)


46150
46151
46152
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46150

def inactive_reason
  @inactive_reason
end

#nameString

Output only. The name of a study. The study's globally unique identifier. Format: projects/project/locations/location/studies/study` Corresponds to the JSON propertyname`

Returns:

  • (String)


46156
46157
46158
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46156

def name
  @name
end

#stateString

Output only. The detailed state of a Study. Corresponds to the JSON property state

Returns:

  • (String)


46161
46162
46163
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46161

def state
  @state
end

#study_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpec

Represents specification of a Study. Corresponds to the JSON property studySpec



46166
46167
46168
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46166

def study_spec
  @study_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46173
46174
46175
46176
46177
46178
46179
46180
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46173

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @inactive_reason = args[:inactive_reason] if args.key?(:inactive_reason)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @study_spec = args[:study_spec] if args.key?(:study_spec)
end