Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SuggestTrialsMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Details of operations that perform Trials suggestion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SuggestTrialsMetadata

Returns a new instance of GoogleCloudAiplatformV1SuggestTrialsMetadata.



34988
34989
34990
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34988

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_idString

The identifier of the client that is requesting the suggestion. If multiple SuggestTrialsRequests have the same client_id, the service will return the identical suggested Trial if the Trial is pending, and provide a new Trial if the last suggested Trial was completed. Corresponds to the JSON property clientId

Returns:

  • (String)


34981
34982
34983
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34981

def client_id
  @client_id
end

#generic_metadataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GenericOperationMetadata

Generic Metadata shared by all operations. Corresponds to the JSON property genericMetadata



34986
34987
34988
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34986

def 
  @generic_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34993
34994
34995
34996
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34993

def update!(**args)
  @client_id = args[:client_id] if args.key?(:client_id)
  @generic_metadata = args[:generic_metadata] if args.key?(:generic_metadata)
end