Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SuggestTrialsRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SuggestTrialsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Request message for VizierService.SuggestTrials.
Instance Attribute Summary collapse
-
#client_id ⇒ String
Required.
-
#contexts ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrialContext>
Optional.
-
#suggestion_count ⇒ Fixnum
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SuggestTrialsRequest
constructor
A new instance of GoogleCloudAiplatformV1SuggestTrialsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SuggestTrialsRequest
Returns a new instance of GoogleCloudAiplatformV1SuggestTrialsRequest.
36185 36186 36187 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36185 def initialize(**args) update!(**args) end |
Instance Attribute Details
#client_id ⇒ String
Required. The identifier of the client that is requesting the suggestion. If
multiple SuggestTrialsRequests have the same client_id, the service will
return the identical suggested Trial if the Trial is pending, and provide a
new Trial if the last suggested Trial was completed.
Corresponds to the JSON property clientId
36148 36149 36150 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36148 def client_id @client_id end |
#contexts ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrialContext>
Optional. This allows you to specify the "context" for a Trial; a context is a
slice (a subspace) of the search space. Typical uses for contexts: 1) You are
using Vizier to tune a server for best performance, but there's a strong
weekly cycle. The context specifies the day-of-week. This allows Tuesday to
generalize from Wednesday without assuming that everything is identical. 2)
Imagine you're optimizing some medical treatment for people. As they walk in
the door, you know certain facts about them (e.g. sex, weight, height, blood-
pressure). Put that information in the context, and Vizier will adapt its
suggestions to the patient. 3) You want to do a fair A/B test efficiently.
Specify the "A" and "B" conditions as contexts, and Vizier will generalize
between "A" and "B" conditions. If they are similar, this will allow Vizier to
converge to the optimum faster than if "A" and "B" were separate Studies. NOTE:
You can also enter contexts as REQUESTED Trials, e.g. via the CreateTrial()
RPC; that's the asynchronous option where you don't need a close association
between contexts and suggestions. NOTE: All the Parameters you set in a
context MUST be defined in the Study. NOTE: You must supply 0 or $
suggestion_count contexts. If you don't supply any contexts, Vizier will make
suggestions from the full search space specified in the StudySpec; if you
supply a full set of context, each suggestion will match the corresponding
context. NOTE: A Context with no features set matches anything, and allows
suggestions from the full search space. NOTE: Contexts MUST lie within the
search space specified in the StudySpec. It's an error if they don't. NOTE:
Contexts preferentially match ACTIVE then REQUESTED trials before new
suggestions are generated. NOTE: Generation of suggestions involves a match
between a Context and (optionally) a REQUESTED trial; if that match is not
fully specified, a suggestion will be geneated in the merged subspace.
Corresponds to the JSON property contexts
36178 36179 36180 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36178 def contexts @contexts end |
#suggestion_count ⇒ Fixnum
Required. The number of suggestions requested. It must be positive.
Corresponds to the JSON property suggestionCount
36183 36184 36185 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36183 def suggestion_count @suggestion_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36190 36191 36192 36193 36194 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36190 def update!(**args) @client_id = args[:client_id] if args.key?(:client_id) @contexts = args[:contexts] if args.key?(:contexts) @suggestion_count = args[:suggestion_count] if args.key?(:suggestion_count) end |