Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDataStats

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Tuning data statistics for Supervised Tuning.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SupervisedTuningDataStats

Returns a new instance of GoogleCloudAiplatformV1SupervisedTuningDataStats.



48123
48124
48125
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48123

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dropped_example_reasonsArray<String>

Output only. For each index in truncated_example_indices, the user-facing reason why the example was dropped. Corresponds to the JSON property droppedExampleReasons

Returns:

  • (Array<String>)


48063
48064
48065
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48063

def dropped_example_reasons
  @dropped_example_reasons
end

#total_billable_character_countFixnum

Output only. Number of billable characters in the tuning dataset. Corresponds to the JSON property totalBillableCharacterCount

Returns:

  • (Fixnum)


48068
48069
48070
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48068

def total_billable_character_count
  @total_billable_character_count
end

#total_billable_token_countFixnum

Output only. Number of billable tokens in the tuning dataset. Corresponds to the JSON property totalBillableTokenCount

Returns:

  • (Fixnum)


48073
48074
48075
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48073

def total_billable_token_count
  @total_billable_token_count
end

#total_truncated_example_countFixnum

Output only. The number of examples in the dataset that have been dropped. An example can be dropped for reasons including: too many tokens, contains an invalid image, contains too many images, etc. Corresponds to the JSON property totalTruncatedExampleCount

Returns:

  • (Fixnum)


48080
48081
48082
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48080

def total_truncated_example_count
  @total_truncated_example_count
end

#total_tuning_character_countFixnum

Output only. Number of tuning characters in the tuning dataset. Corresponds to the JSON property totalTuningCharacterCount

Returns:

  • (Fixnum)


48085
48086
48087
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48085

def total_tuning_character_count
  @total_tuning_character_count
end

#truncated_example_indicesArray<Fixnum>

Output only. A partial sample of the indices (starting from 1) of the dropped examples. Corresponds to the JSON property truncatedExampleIndices

Returns:

  • (Array<Fixnum>)


48091
48092
48093
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48091

def truncated_example_indices
  @truncated_example_indices
end

#tuning_dataset_example_countFixnum

Output only. Number of examples in the tuning dataset. Corresponds to the JSON property tuningDatasetExampleCount

Returns:

  • (Fixnum)


48096
48097
48098
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48096

def tuning_dataset_example_count
  @tuning_dataset_example_count
end

#tuning_step_countFixnum

Output only. Number of tuning steps for this Tuning Job. Corresponds to the JSON property tuningStepCount

Returns:

  • (Fixnum)


48101
48102
48103
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48101

def tuning_step_count
  @tuning_step_count
end

#user_dataset_examplesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content>

Output only. Sample user messages in the training dataset uri. Corresponds to the JSON property userDatasetExamples



48106
48107
48108
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48106

def user_dataset_examples
  @user_dataset_examples
end

#user_input_token_distributionGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution

Dataset distribution for Supervised Tuning. Corresponds to the JSON property userInputTokenDistribution



48111
48112
48113
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48111

def user_input_token_distribution
  @user_input_token_distribution
end

#user_message_per_example_distributionGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution

Dataset distribution for Supervised Tuning. Corresponds to the JSON property userMessagePerExampleDistribution



48116
48117
48118
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48116

def user_message_per_example_distribution
  @user_message_per_example_distribution
end

#user_output_token_distributionGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution

Dataset distribution for Supervised Tuning. Corresponds to the JSON property userOutputTokenDistribution



48121
48122
48123
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48121

def user_output_token_distribution
  @user_output_token_distribution
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48128
48129
48130
48131
48132
48133
48134
48135
48136
48137
48138
48139
48140
48141
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48128

def update!(**args)
  @dropped_example_reasons = args[:dropped_example_reasons] if args.key?(:dropped_example_reasons)
  @total_billable_character_count = args[:total_billable_character_count] if args.key?(:total_billable_character_count)
  @total_billable_token_count = args[:total_billable_token_count] if args.key?(:total_billable_token_count)
  @total_truncated_example_count = args[:total_truncated_example_count] if args.key?(:total_truncated_example_count)
  @total_tuning_character_count = args[:total_tuning_character_count] if args.key?(:total_tuning_character_count)
  @truncated_example_indices = args[:truncated_example_indices] if args.key?(:truncated_example_indices)
  @tuning_dataset_example_count = args[:tuning_dataset_example_count] if args.key?(:tuning_dataset_example_count)
  @tuning_step_count = args[:tuning_step_count] if args.key?(:tuning_step_count)
  @user_dataset_examples = args[:user_dataset_examples] if args.key?(:user_dataset_examples)
  @user_input_token_distribution = args[:user_input_token_distribution] if args.key?(:user_input_token_distribution)
  @user_message_per_example_distribution = args[:user_message_per_example_distribution] if args.key?(:user_message_per_example_distribution)
  @user_output_token_distribution = args[:user_output_token_distribution] if args.key?(:user_output_token_distribution)
end