Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Dataset distribution for Supervised Tuning.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution

Returns a new instance of GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution.



48193
48194
48195
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48193

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#billable_sumFixnum

Output only. Sum of a given population of values that are billable. Corresponds to the JSON property billableSum

Returns:

  • (Fixnum)


48151
48152
48153
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48151

def billable_sum
  @billable_sum
end

#bucketsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistributionDatasetBucket>

Output only. Defines the histogram bucket. Corresponds to the JSON property buckets



48156
48157
48158
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48156

def buckets
  @buckets
end

#maxFloat

Output only. The maximum of the population values. Corresponds to the JSON property max

Returns:

  • (Float)


48161
48162
48163
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48161

def max
  @max
end

#meanFloat

Output only. The arithmetic mean of the values in the population. Corresponds to the JSON property mean

Returns:

  • (Float)


48166
48167
48168
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48166

def mean
  @mean
end

#medianFloat

Output only. The median of the values in the population. Corresponds to the JSON property median

Returns:

  • (Float)


48171
48172
48173
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48171

def median
  @median
end

#minFloat

Output only. The minimum of the population values. Corresponds to the JSON property min

Returns:

  • (Float)


48176
48177
48178
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48176

def min
  @min
end

#p5Float

Output only. The 5th percentile of the values in the population. Corresponds to the JSON property p5

Returns:

  • (Float)


48181
48182
48183
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48181

def p5
  @p5
end

#p95Float

Output only. The 95th percentile of the values in the population. Corresponds to the JSON property p95

Returns:

  • (Float)


48186
48187
48188
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48186

def p95
  @p95
end

#sumFixnum

Output only. Sum of a given population of values. Corresponds to the JSON property sum

Returns:

  • (Fixnum)


48191
48192
48193
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48191

def sum
  @sum
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48198
48199
48200
48201
48202
48203
48204
48205
48206
48207
48208
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48198

def update!(**args)
  @billable_sum = args[:billable_sum] if args.key?(:billable_sum)
  @buckets = args[:buckets] if args.key?(:buckets)
  @max = args[:max] if args.key?(:max)
  @mean = args[:mean] if args.key?(:mean)
  @median = args[:median] if args.key?(:median)
  @min = args[:min] if args.key?(:min)
  @p5 = args[:p5] if args.key?(:p5)
  @p95 = args[:p95] if args.key?(:p95)
  @sum = args[:sum] if args.key?(:sum)
end