Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardTimeSeriesMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardTimeSeriesMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Describes metadata for a TensorboardTimeSeries.
Instance Attribute Summary collapse
-
#max_blob_sequence_length ⇒ Fixnum
Output only.
-
#max_step ⇒ Fixnum
Output only.
-
#max_wall_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1TensorboardTimeSeriesMetadata
constructor
A new instance of GoogleCloudAiplatformV1TensorboardTimeSeriesMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1TensorboardTimeSeriesMetadata
Returns a new instance of GoogleCloudAiplatformV1TensorboardTimeSeriesMetadata.
37367 37368 37369 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37367 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_blob_sequence_length ⇒ Fixnum
Output only. The largest blob sequence length (number of blobs) of all data
points in this time series, if its ValueType is BLOB_SEQUENCE.
Corresponds to the JSON property maxBlobSequenceLength
37354 37355 37356 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37354 def max_blob_sequence_length @max_blob_sequence_length end |
#max_step ⇒ Fixnum
Output only. Max step index of all data points within a TensorboardTimeSeries.
Corresponds to the JSON property maxStep
37359 37360 37361 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37359 def max_step @max_step end |
#max_wall_time ⇒ String
Output only. Max wall clock timestamp of all data points within a
TensorboardTimeSeries.
Corresponds to the JSON property maxWallTime
37365 37366 37367 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37365 def max_wall_time @max_wall_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37372 37373 37374 37375 37376 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37372 def update!(**args) @max_blob_sequence_length = args[:max_blob_sequence_length] if args.key?(:max_blob_sequence_length) @max_step = args[:max_step] if args.key?(:max_step) @max_wall_time = args[:max_wall_time] if args.key?(:max_wall_time) end |