Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ThresholdConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The config for feature monitoring threshold.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ThresholdConfig

Returns a new instance of GoogleCloudAiplatformV1ThresholdConfig.



37820
37821
37822
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37820

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#valueFloat

Specify a threshold value that can trigger the alert. If this threshold config is for feature distribution distance: 1. For categorical feature, the distribution distance is calculated by L-inifinity norm. 2. For numerical feature, the distribution distance is calculated by Jensen–Shannon divergence. Each feature must have a non-zero threshold if they need to be monitored. Otherwise no alert will be triggered for that feature. Corresponds to the JSON property value

Returns:

  • (Float)


37818
37819
37820
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37818

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37825
37826
37827
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37825

def update!(**args)
  @value = args[:value] if args.key?(:value)
end