Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TimeSeriesDataPoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A TensorboardTimeSeries data point.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1TimeSeriesDataPoint

Returns a new instance of GoogleCloudAiplatformV1TimeSeriesDataPoint.



48889
48890
48891
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48889

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blobsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardBlobSequence

One point viewable on a blob metric plot, but mostly just a wrapper message to work around repeated fields can't be used directly within oneof fields. Corresponds to the JSON property blobs



48867
48868
48869
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48867

def blobs
  @blobs
end

#scalarGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Scalar

One point viewable on a scalar metric plot. Corresponds to the JSON property scalar



48872
48873
48874
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48872

def scalar
  @scalar
end

#stepFixnum

Step index of this data point within the run. Corresponds to the JSON property step

Returns:

  • (Fixnum)


48877
48878
48879
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48877

def step
  @step
end

#tensorGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardTensor

One point viewable on a tensor metric plot. Corresponds to the JSON property tensor



48882
48883
48884
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48882

def tensor
  @tensor
end

#wall_timeString

Wall clock timestamp when this data point is generated by the end user. Corresponds to the JSON property wallTime

Returns:

  • (String)


48887
48888
48889
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48887

def wall_time
  @wall_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48894
48895
48896
48897
48898
48899
48900
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48894

def update!(**args)
  @blobs = args[:blobs] if args.key?(:blobs)
  @scalar = args[:scalar] if args.key?(:scalar)
  @step = args[:step] if args.key?(:step)
  @tensor = args[:tensor] if args.key?(:tensor)
  @wall_time = args[:wall_time] if args.key?(:wall_time)
end