Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TokensInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Tokens info with a list of tokens and the corresponding list of token ids.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1TokensInfo

Returns a new instance of GoogleCloudAiplatformV1TokensInfo.



48507
48508
48509
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48507

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#roleString

Optional. Optional fields for the role from the corresponding Content. Corresponds to the JSON property role

Returns:

  • (String)


48495
48496
48497
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48495

def role
  @role
end

#token_idsArray<Fixnum>

A list of token ids from the input. Corresponds to the JSON property tokenIds

Returns:

  • (Array<Fixnum>)


48500
48501
48502
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48500

def token_ids
  @token_ids
end

#tokensArray<String>

A list of tokens from the input. Corresponds to the JSON property tokens

Returns:

  • (Array<String>)


48505
48506
48507
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48505

def tokens
  @tokens
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48512
48513
48514
48515
48516
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48512

def update!(**args)
  @role = args[:role] if args.key?(:role)
  @token_ids = args[:token_ids] if args.key?(:token_ids)
  @tokens = args[:tokens] if args.key?(:tokens)
end