Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolComputerUse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Tool to support computer use.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ToolComputerUse

Returns a new instance of GoogleCloudAiplatformV1ToolComputerUse.



46008
46009
46010
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46008

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#environmentString

Required. The environment being operated. Corresponds to the JSON property environment

Returns:

  • (String)


45996
45997
45998
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45996

def environment
  @environment
end

#excluded_predefined_functionsArray<String>

Optional. By default, predefined functions are included in the final model call. Some of them can be explicitly excluded from being automatically included. This can serve two purposes: 1. Using a more restricted / different action space. 2. Improving the definitions / instructions of predefined functions. Corresponds to the JSON property excludedPredefinedFunctions

Returns:

  • (Array<String>)


46006
46007
46008
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46006

def excluded_predefined_functions
  @excluded_predefined_functions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46013
46014
46015
46016
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46013

def update!(**args)
  @environment = args[:environment] if args.key?(:environment)
  @excluded_predefined_functions = args[:excluded_predefined_functions] if args.key?(:excluded_predefined_functions)
end