Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrainingPipeline

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The TrainingPipeline orchestrates tasks associated with training a Model. It always executes the training task, and optionally may also export data from Vertex AI's Dataset which becomes the training input, upload the Model to Vertex AI, and evaluate the Model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1TrainingPipeline

Returns a new instance of GoogleCloudAiplatformV1TrainingPipeline.



49897
49898
49899
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 49897

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Time when the TrainingPipeline was created. Corresponds to the JSON property createTime

Returns:

  • (String)


49786
49787
49788
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 49786

def create_time
  @create_time
end

#display_nameString

Required. The user-defined name of this TrainingPipeline. Corresponds to the JSON property displayName

Returns:

  • (String)


49791
49792
49793
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 49791

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



49797
49798
49799
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 49797

def encryption_spec
  @encryption_spec
end

#end_timeString

Output only. Time when the TrainingPipeline entered any of the following states: PIPELINE_STATE_SUCCEEDED, PIPELINE_STATE_FAILED, PIPELINE_STATE_CANCELLED. Corresponds to the JSON property endTime

Returns:

  • (String)


49804
49805
49806
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 49804

def end_time
  @end_time
end

#errorGoogle::Apis::AiplatformV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



49814
49815
49816
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 49814

def error
  @error
end

#input_data_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1InputDataConfig

Specifies Vertex AI owned input data to be used for training, and possibly evaluating, the Model. Corresponds to the JSON property inputDataConfig



49820
49821
49822
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 49820

def input_data_config
  @input_data_config
end

#labelsHash<String,String>

The labels with user-defined metadata to organize TrainingPipelines. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


49829
49830
49831
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 49829

def labels
  @labels
end

#model_idString

Optional. The ID to use for the uploaded Model, which will become the final component of the model resource name. This value may be up to 63 characters, and valid characters are [a-z0-9_-]. The first character cannot be a number or hyphen. Corresponds to the JSON property modelId

Returns:

  • (String)


49837
49838
49839
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 49837

def model_id
  @model_id
end

#model_to_uploadGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Model

A trained machine learning Model. Corresponds to the JSON property modelToUpload



49842
49843
49844
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 49842

def model_to_upload
  @model_to_upload
end

#nameString

Output only. Resource name of the TrainingPipeline. Corresponds to the JSON property name

Returns:

  • (String)


49847
49848
49849
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 49847

def name
  @name
end

#parent_modelString

Optional. When specify this field, the model_to_upload will not be uploaded as a new model, instead, it will become a new version of this parent_model. Corresponds to the JSON property parentModel

Returns:

  • (String)


49853
49854
49855
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 49853

def parent_model
  @parent_model
end

#start_timeString

Output only. Time when the TrainingPipeline for the first time entered the PIPELINE_STATE_RUNNING state. Corresponds to the JSON property startTime

Returns:

  • (String)


49859
49860
49861
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 49859

def start_time
  @start_time
end

#stateString

Output only. The detailed state of the pipeline. Corresponds to the JSON property state

Returns:

  • (String)


49864
49865
49866
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 49864

def state
  @state
end

#training_task_definitionString

Required. A Google Cloud Storage path to the YAML file that defines the training task which is responsible for producing the model artifact, and may also include additional auxiliary work. The definition files that can be used here are found in gs://google-cloud-aiplatform/schema/trainingjob/definition/. Note: The URI given on output will be immutable and probably different, including the URI scheme, than the one given on input. The output URI will point to a location where the user only has a read access. Corresponds to the JSON property trainingTaskDefinition

Returns:

  • (String)


49875
49876
49877
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 49875

def training_task_definition
  @training_task_definition
end

#training_task_inputsObject

Required. The training task's parameter(s), as specified in the training_task_definition's inputs. Corresponds to the JSON property trainingTaskInputs

Returns:

  • (Object)


49881
49882
49883
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 49881

def training_task_inputs
  @training_task_inputs
end

#training_task_metadataObject

Output only. The metadata information as specified in the training_task_definition's metadata. This metadata is an auxiliary runtime and final information about the training task. While the pipeline is running this information is populated only at a best effort basis. Only present if the pipeline's training_task_definition contains metadata object. Corresponds to the JSON property trainingTaskMetadata

Returns:

  • (Object)


49890
49891
49892
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 49890

def 
  @training_task_metadata
end

#update_timeString

Output only. Time when the TrainingPipeline was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


49895
49896
49897
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 49895

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49902
49903
49904
49905
49906
49907
49908
49909
49910
49911
49912
49913
49914
49915
49916
49917
49918
49919
49920
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 49902

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @end_time = args[:end_time] if args.key?(:end_time)
  @error = args[:error] if args.key?(:error)
  @input_data_config = args[:input_data_config] if args.key?(:input_data_config)
  @labels = args[:labels] if args.key?(:labels)
  @model_id = args[:model_id] if args.key?(:model_id)
  @model_to_upload = args[:model_to_upload] if args.key?(:model_to_upload)
  @name = args[:name] if args.key?(:name)
  @parent_model = args[:parent_model] if args.key?(:parent_model)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @training_task_definition = args[:training_task_definition] if args.key?(:training_task_definition)
  @training_task_inputs = args[:training_task_inputs] if args.key?(:training_task_inputs)
  @training_task_metadata = args[:training_task_metadata] if args.key?(:training_task_metadata)
  @update_time = args[:update_time] if args.key?(:update_time)
end