Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryAnyOrderMatchInput
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryAnyOrderMatchInput
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Instances and metric spec for TrajectoryAnyOrderMatch metric.
Instance Attribute Summary collapse
-
#instances ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryAnyOrderMatchInstance>
Required.
-
#metric_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryAnyOrderMatchSpec
Spec for TrajectoryAnyOrderMatch metric - returns 1 if all tool calls in the reference trajectory appear in the predicted trajectory in any order, else 0.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1TrajectoryAnyOrderMatchInput
constructor
A new instance of GoogleCloudAiplatformV1TrajectoryAnyOrderMatchInput.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1TrajectoryAnyOrderMatchInput
Returns a new instance of GoogleCloudAiplatformV1TrajectoryAnyOrderMatchInput.
49957 49958 49959 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 49957 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instances ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryAnyOrderMatchInstance>
Required. Repeated TrajectoryAnyOrderMatch instance.
Corresponds to the JSON property instances
49949 49950 49951 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 49949 def instances @instances end |
#metric_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryAnyOrderMatchSpec
Spec for TrajectoryAnyOrderMatch metric - returns 1 if all tool calls in the
reference trajectory appear in the predicted trajectory in any order, else 0.
Corresponds to the JSON property metricSpec
49955 49956 49957 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 49955 def metric_spec @metric_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
49962 49963 49964 49965 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 49962 def update!(**args) @instances = args[:instances] if args.key?(:instances) @metric_spec = args[:metric_spec] if args.key?(:metric_spec) end |