Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryExactMatchInput
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryExactMatchInput
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Instances and metric spec for TrajectoryExactMatch metric.
Instance Attribute Summary collapse
-
#instances ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryExactMatchInstance>
Required.
-
#metric_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryExactMatchSpec
Spec for TrajectoryExactMatch metric - returns 1 if tool calls in the reference trajectory exactly match the predicted trajectory, else 0.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1TrajectoryExactMatchInput
constructor
A new instance of GoogleCloudAiplatformV1TrajectoryExactMatchInput.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1TrajectoryExactMatchInput
Returns a new instance of GoogleCloudAiplatformV1TrajectoryExactMatchInput.
44893 44894 44895 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44893 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instances ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryExactMatchInstance>
Required. Repeated TrajectoryExactMatch instance.
Corresponds to the JSON property instances
44885 44886 44887 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44885 def instances @instances end |
#metric_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryExactMatchSpec
Spec for TrajectoryExactMatch metric - returns 1 if tool calls in the
reference trajectory exactly match the predicted trajectory, else 0.
Corresponds to the JSON property metricSpec
44891 44892 44893 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44891 def metric_spec @metric_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
44898 44899 44900 44901 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44898 def update!(**args) @instances = args[:instances] if args.key?(:instances) @metric_spec = args[:metric_spec] if args.key?(:metric_spec) end |