Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrialParameter

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A message representing a parameter to be tuned.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1TrialParameter

Returns a new instance of GoogleCloudAiplatformV1TrialParameter.



39173
39174
39175
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39173

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#parameter_idString

Output only. The ID of the parameter. The parameter should be defined in StudySpec's Parameters. Corresponds to the JSON property parameterId

Returns:

  • (String)


39163
39164
39165
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39163

def parameter_id
  @parameter_id
end

#valueObject

Output only. The value of the parameter. number_value will be set if a parameter defined in StudySpec is in type 'INTEGER', 'DOUBLE' or 'DISCRETE'. string_value will be set if a parameter defined in StudySpec is in type ' CATEGORICAL'. Corresponds to the JSON property value

Returns:

  • (Object)


39171
39172
39173
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39171

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39178
39179
39180
39181
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39178

def update!(**args)
  @parameter_id = args[:parameter_id] if args.key?(:parameter_id)
  @value = args[:value] if args.key?(:value)
end