Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TunedModelRef

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

TunedModel Reference for legacy model migration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1TunedModelRef

Returns a new instance of GoogleCloudAiplatformV1TunedModelRef.



50854
50855
50856
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 50854

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#pipeline_jobString

Support migration from tuning job list page, from bison model to gemini model. Corresponds to the JSON property pipelineJob

Returns:

  • (String)


50841
50842
50843
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 50841

def pipeline_job
  @pipeline_job
end

#tuned_modelString

Support migration from model registry. Corresponds to the JSON property tunedModel

Returns:

  • (String)


50846
50847
50848
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 50846

def tuned_model
  @tuned_model
end

#tuning_jobString

Support migration from tuning job list page, from gemini-1.0-pro-002 to 1.5 and above. Corresponds to the JSON property tuningJob

Returns:

  • (String)


50852
50853
50854
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 50852

def tuning_job
  @tuning_job
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50859
50860
50861
50862
50863
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 50859

def update!(**args)
  @pipeline_job = args[:pipeline_job] if args.key?(:pipeline_job)
  @tuned_model = args[:tuned_model] if args.key?(:tuned_model)
  @tuning_job = args[:tuning_job] if args.key?(:tuning_job)
end