Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TuningJob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents a TuningJob that runs with Google owned models.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1TuningJob

Returns a new instance of GoogleCloudAiplatformV1TuningJob.



51235
51236
51237
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 51235

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_modelString

The base model that is being tuned. See Supported models. Corresponds to the JSON property baseModel

Returns:

  • (String)


51114
51115
51116
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 51114

def base_model
  @base_model
end

#create_timeString

Output only. Time when the TuningJob was created. Corresponds to the JSON property createTime

Returns:

  • (String)


51119
51120
51121
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 51119

def create_time
  @create_time
end

#descriptionString

Optional. The description of the TuningJob. Corresponds to the JSON property description

Returns:

  • (String)


51124
51125
51126
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 51124

def description
  @description
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



51130
51131
51132
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 51130

def encryption_spec
  @encryption_spec
end

#end_timeString

Output only. Time when the TuningJob entered any of the following JobStates: JOB_STATE_SUCCEEDED, JOB_STATE_FAILED, JOB_STATE_CANCELLED, JOB_STATE_EXPIRED. Corresponds to the JSON property endTime

Returns:

  • (String)


51137
51138
51139
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 51137

def end_time
  @end_time
end

#errorGoogle::Apis::AiplatformV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



51147
51148
51149
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 51147

def error
  @error
end

#evaluate_dataset_runsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluateDatasetRun>

Output only. Evaluation runs for the Tuning Job. Corresponds to the JSON property evaluateDatasetRuns



51152
51153
51154
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 51152

def evaluate_dataset_runs
  @evaluate_dataset_runs
end

#experimentString

Output only. The Experiment associated with this TuningJob. Corresponds to the JSON property experiment

Returns:

  • (String)


51157
51158
51159
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 51157

def experiment
  @experiment
end

#labelsHash<String,String>

Optional. The labels with user-defined metadata to organize TuningJob and generated resources such as Model and Endpoint. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


51167
51168
51169
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 51167

def labels
  @labels
end

#nameString

Output only. Identifier. Resource name of a TuningJob. Format: projects/ project/locations/location/tuningJobs/tuning_job` Corresponds to the JSON propertyname`

Returns:

  • (String)


51173
51174
51175
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 51173

def name
  @name
end

#pre_tuned_modelGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PreTunedModel

A pre-tuned model for continuous tuning. Corresponds to the JSON property preTunedModel



51178
51179
51180
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 51178

def pre_tuned_model
  @pre_tuned_model
end

#preference_optimization_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PreferenceOptimizationSpec

Tuning Spec for Preference Optimization. Corresponds to the JSON property preferenceOptimizationSpec



51183
51184
51185
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 51183

def preference_optimization_spec
  @preference_optimization_spec
end

#service_accountString

The service account that the tuningJob workload runs as. If not specified, the Vertex AI Secure Fine-Tuned Service Agent in the project will be used. See https://cloud.google.com/iam/docs/service-agents#vertex-ai-secure-fine-tuning- service-agent Users starting the pipeline must have the iam.serviceAccounts. actAs permission on this service account. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


51192
51193
51194
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 51192

def 
  @service_account
end

#start_timeString

Output only. Time when the TuningJob for the first time entered the JOB_STATE_RUNNING state. Corresponds to the JSON property startTime

Returns:

  • (String)


51198
51199
51200
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 51198

def start_time
  @start_time
end

#stateString

Output only. The detailed state of the job. Corresponds to the JSON property state

Returns:

  • (String)


51203
51204
51205
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 51203

def state
  @state
end

#supervised_tuning_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningSpec

Tuning Spec for Supervised Tuning for first party models. Corresponds to the JSON property supervisedTuningSpec



51208
51209
51210
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 51208

def supervised_tuning_spec
  @supervised_tuning_spec
end

#tuned_modelGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TunedModel

The Model Registry Model and Online Prediction Endpoint associated with this TuningJob. Corresponds to the JSON property tunedModel



51214
51215
51216
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 51214

def tuned_model
  @tuned_model
end

#tuned_model_display_nameString

Optional. The display name of the TunedModel. The name can be up to 128 characters long and can consist of any UTF-8 characters. For continuous tuning, tuned_model_display_name will by default use the same display name as the pre- tuned model. If a new display name is provided, the tuning job will create a new model instead of a new version. Corresponds to the JSON property tunedModelDisplayName

Returns:

  • (String)


51223
51224
51225
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 51223

def tuned_model_display_name
  @tuned_model_display_name
end

#tuning_data_statsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TuningDataStats

The tuning data statistic values for TuningJob. Corresponds to the JSON property tuningDataStats



51228
51229
51230
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 51228

def tuning_data_stats
  @tuning_data_stats
end

#update_timeString

Output only. Time when the TuningJob was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


51233
51234
51235
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 51233

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51240
51241
51242
51243
51244
51245
51246
51247
51248
51249
51250
51251
51252
51253
51254
51255
51256
51257
51258
51259
51260
51261
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 51240

def update!(**args)
  @base_model = args[:base_model] if args.key?(:base_model)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @end_time = args[:end_time] if args.key?(:end_time)
  @error = args[:error] if args.key?(:error)
  @evaluate_dataset_runs = args[:evaluate_dataset_runs] if args.key?(:evaluate_dataset_runs)
  @experiment = args[:experiment] if args.key?(:experiment)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @pre_tuned_model = args[:pre_tuned_model] if args.key?(:pre_tuned_model)
  @preference_optimization_spec = args[:preference_optimization_spec] if args.key?(:preference_optimization_spec)
  @service_account = args[:service_account] if args.key?(:service_account)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @supervised_tuning_spec = args[:supervised_tuning_spec] if args.key?(:supervised_tuning_spec)
  @tuned_model = args[:tuned_model] if args.key?(:tuned_model)
  @tuned_model_display_name = args[:tuned_model_display_name] if args.key?(:tuned_model_display_name)
  @tuning_data_stats = args[:tuning_data_stats] if args.key?(:tuning_data_stats)
  @update_time = args[:update_time] if args.key?(:update_time)
end