Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1UpdateEndpointLongRunningRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1UpdateEndpointLongRunningRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Request message for EndpointService.UpdateEndpointLongRunning.
Instance Attribute Summary collapse
-
#endpoint ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Endpoint
Models are deployed into it, and afterwards Endpoint is called to obtain predictions and explanations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1UpdateEndpointLongRunningRequest
constructor
A new instance of GoogleCloudAiplatformV1UpdateEndpointLongRunningRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1UpdateEndpointLongRunningRequest
Returns a new instance of GoogleCloudAiplatformV1UpdateEndpointLongRunningRequest.
38330 38331 38332 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38330 def initialize(**args) update!(**args) end |
Instance Attribute Details
#endpoint ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Endpoint
Models are deployed into it, and afterwards Endpoint is called to obtain
predictions and explanations.
Corresponds to the JSON property endpoint
38328 38329 38330 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38328 def endpoint @endpoint end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38335 38336 38337 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38335 def update!(**args) @endpoint = args[:endpoint] if args.key?(:endpoint) end |