Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1UpsertDatapointsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for IndexService.UpsertDatapoints

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1UpsertDatapointsRequest

Returns a new instance of GoogleCloudAiplatformV1UpsertDatapointsRequest.



51284
51285
51286
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 51284

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#datapointsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapoint>

A list of datapoints to be created/updated. Corresponds to the JSON property datapoints



51274
51275
51276
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 51274

def datapoints
  @datapoints
end

#update_maskString

Optional. Update mask is used to specify the fields to be overwritten in the datapoints by the update. The fields specified in the update_mask are relative to each IndexDatapoint inside datapoints, not the full request. Updatable fields: * Use all_restricts to update both restricts and numeric_restricts. Corresponds to the JSON property updateMask

Returns:

  • (String)


51282
51283
51284
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 51282

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51289
51290
51291
51292
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 51289

def update!(**args)
  @datapoints = args[:datapoints] if args.key?(:datapoints)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end