Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexAiSearchDataStoreSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexAiSearchDataStoreSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Define data stores within engine to filter on in a search call and configurations for those data stores. For more information, see https://cloud. google.com/generative-ai-app-builder/docs/reference/rpc/google.cloud. discoveryengine.v1#datastorespec
Instance Attribute Summary collapse
-
#data_store ⇒ String
Full resource name of DataStore, such as Format:
projects/project/locations/location/collections/collection/dataStores/dataStore`Corresponds to the JSON propertydataStore`. -
#filter ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1VertexAiSearchDataStoreSpec
constructor
A new instance of GoogleCloudAiplatformV1VertexAiSearchDataStoreSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1VertexAiSearchDataStoreSpec
Returns a new instance of GoogleCloudAiplatformV1VertexAiSearchDataStoreSpec.
48689 48690 48691 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48689 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_store ⇒ String
Full resource name of DataStore, such as Format: projects/project/locations/
location/collections/collection/dataStores/dataStore`
Corresponds to the JSON propertydataStore`
48680 48681 48682 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48680 def data_store @data_store end |
#filter ⇒ String
Optional. Filter specification to filter documents in the data store specified
by data_store field. For more information on filtering, see Filtering
Corresponds to the JSON property filter
48687 48688 48689 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48687 def filter @filter end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
48694 48695 48696 48697 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48694 def update!(**args) @data_store = args[:data_store] if args.key?(:data_store) @filter = args[:filter] if args.key?(:filter) end |