Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VideoMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Provides metadata for a video, including the start and end offsets for clipping and the frame rate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1VideoMetadata

Returns a new instance of GoogleCloudAiplatformV1VideoMetadata.



52512
52513
52514
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 52512

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_offsetString

Optional. The end offset of the video. Corresponds to the JSON property endOffset

Returns:

  • (String)


52499
52500
52501
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 52499

def end_offset
  @end_offset
end

#fpsFloat

Optional. The frame rate of the video sent to the model. If not specified, the default value is 1.0. The valid range is (0.0, 24.0]. Corresponds to the JSON property fps

Returns:

  • (Float)


52505
52506
52507
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 52505

def fps
  @fps
end

#start_offsetString

Optional. The start offset of the video. Corresponds to the JSON property startOffset

Returns:

  • (String)


52510
52511
52512
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 52510

def start_offset
  @start_offset
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52517
52518
52519
52520
52521
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 52517

def update!(**args)
  @end_offset = args[:end_offset] if args.key?(:end_offset)
  @fps = args[:fps] if args.key?(:fps)
  @start_offset = args[:start_offset] if args.key?(:start_offset)
end