Class: Google::Apis::AiplatformV1::GoogleCloudLocationListLocationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudLocationListLocationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The response message for Locations.ListLocations.
Instance Attribute Summary collapse
-
#locations ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudLocationLocation>
A list of locations that matches the specified filter in the request.
-
#next_page_token ⇒ String
The standard List next-page token.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudLocationListLocationsResponse
constructor
A new instance of GoogleCloudLocationListLocationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudLocationListLocationsResponse
Returns a new instance of GoogleCloudLocationListLocationsResponse.
47290 47291 47292 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47290 def initialize(**args) update!(**args) end |
Instance Attribute Details
#locations ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudLocationLocation>
A list of locations that matches the specified filter in the request.
Corresponds to the JSON property locations
47283 47284 47285 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47283 def locations @locations end |
#next_page_token ⇒ String
The standard List next-page token.
Corresponds to the JSON property nextPageToken
47288 47289 47290 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47288 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47295 47296 47297 47298 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47295 def update!(**args) @locations = args[:locations] if args.key?(:locations) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |