Class: Google::Apis::AiplatformV1::GoogleCloudLocationLocation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A resource that represents a Google Cloud location.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudLocationLocation

Returns a new instance of GoogleCloudLocationLocation.



52886
52887
52888
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 52886

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

The friendly name for this location, typically a nearby city name. For example, "Tokyo". Corresponds to the JSON property displayName

Returns:

  • (String)


52861
52862
52863
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 52861

def display_name
  @display_name
end

#labelsHash<String,String>

Cross-service attributes for the location. For example "cloud.googleapis.com/ region": "us-east1" Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


52867
52868
52869
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 52867

def labels
  @labels
end

#location_idString

The canonical id for this location. For example: "us-east1". Corresponds to the JSON property locationId

Returns:

  • (String)


52872
52873
52874
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 52872

def location_id
  @location_id
end

#metadataHash<String,Object>

Service-specific metadata. For example the available capacity at the given location. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,Object>)


52878
52879
52880
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 52878

def 
  @metadata
end

#nameString

Resource name for the location, which may vary between implementations. For example: "projects/example-project/locations/us-east1" Corresponds to the JSON property name

Returns:

  • (String)


52884
52885
52886
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 52884

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52891
52892
52893
52894
52895
52896
52897
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 52891

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @labels = args[:labels] if args.key?(:labels)
  @location_id = args[:location_id] if args.key?(:location_id)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
end