Class: Google::Apis::AiplatformV1::GoogleProtobufEmpty

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs. A typical example is to use it as the request or the response type of an API method. For instance: service Foo rpc Bar(google. protobuf.Empty) returns (google.protobuf.Empty);

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleProtobufEmpty

Returns a new instance of GoogleProtobufEmpty.



39303
39304
39305
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39303

def initialize(**args)
   update!(**args)
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39308
39309
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39308

def update!(**args)
end