Class: Google::Apis::AiplatformV1::LanguageLabsAidaTrustRecitationProtoRecitationResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The recitation result for one input

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LanguageLabsAidaTrustRecitationProtoRecitationResult

Returns a new instance of LanguageLabsAidaTrustRecitationProtoRecitationResult.



29521
29522
29523
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29521

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dynamic_segment_resultsArray<Google::Apis::AiplatformV1::LanguageLabsAidaTrustRecitationProtoSegmentResult>

Corresponds to the JSON property dynamicSegmentResults



29506
29507
29508
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29506

def dynamic_segment_results
  @dynamic_segment_results
end

#recitation_actionString

The recitation action for one given input. When its segments contain different actions, the overall action will be returned in the precedence of BLOCK > CITE

NO_ACTION. When the given input is not found in any source, the recitation action will not be specified. Corresponds to the JSON property recitationAction

Returns:

  • (String)


29514
29515
29516
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29514

def recitation_action
  @recitation_action
end

#training_segment_resultsArray<Google::Apis::AiplatformV1::LanguageLabsAidaTrustRecitationProtoSegmentResult>

Corresponds to the JSON property trainingSegmentResults



29519
29520
29521
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29519

def training_segment_results
  @training_segment_results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29526
29527
29528
29529
29530
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29526

def update!(**args)
  @dynamic_segment_results = args[:dynamic_segment_results] if args.key?(:dynamic_segment_results)
  @recitation_action = args[:recitation_action] if args.key?(:recitation_action)
  @training_segment_results = args[:training_segment_results] if args.key?(:training_segment_results)
end