Class: Google::Apis::AiplatformV1::LanguageLabsAidaTrustRecitationProtoSegmentResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The recitation result for each segment in a given input.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LanguageLabsAidaTrustRecitationProtoSegmentResult

Returns a new instance of LanguageLabsAidaTrustRecitationProtoSegmentResult.



30864
30865
30866
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30864

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attribution_datasetString

The dataset the segment came from. Datasets change often as model evolves. Treat this field as informational only and avoid depending on it directly. Corresponds to the JSON property attributionDataset

Returns:

  • (String)


30812
30813
30814
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30812

def attribution_dataset
  @attribution_dataset
end

#display_attribution_messageString

human-friendly string that contains information from doc_attribution which could be shown by clients Corresponds to the JSON property displayAttributionMessage

Returns:

  • (String)


30818
30819
30820
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30818

def display_attribution_message
  @display_attribution_message
end

#doc_attributionGoogle::Apis::AiplatformV1::LanguageLabsAidaTrustRecitationProtoDocAttribution

The proto defines the attribution information for a document using whatever fields are most applicable for that document's datasource. For example, a Wikipedia article's attribution is in the form of its article title, a website is in the form of a URL, and a Github repo is in the form of a repo name. Next id: 30 Corresponds to the JSON property docAttribution



30827
30828
30829
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30827

def doc_attribution
  @doc_attribution
end

#doc_occurrencesFixnum

number of documents that contained this segment Corresponds to the JSON property docOccurrences

Returns:

  • (Fixnum)


30832
30833
30834
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30832

def doc_occurrences
  @doc_occurrences
end

#end_indexFixnum

Corresponds to the JSON property endIndex

Returns:

  • (Fixnum)


30837
30838
30839
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30837

def end_index
  @end_index
end

#raw_textString

The raw text in the given input that is corresponding to the segment. It will be available only when 'return_segment_raw_text' is enabled in the request options. Corresponds to the JSON property rawText

Returns:

  • (String)


30844
30845
30846
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30844

def raw_text
  @raw_text
end

#segment_recitation_actionString

Corresponds to the JSON property segmentRecitationAction

Returns:

  • (String)


30849
30850
30851
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30849

def segment_recitation_action
  @segment_recitation_action
end

#source_categoryString

The category of the source dataset where the segment came from. This is more stable than Dataset. Corresponds to the JSON property sourceCategory

Returns:

  • (String)


30855
30856
30857
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30855

def source_category
  @source_category
end

#start_indexFixnum

The segment boundary start (inclusive) and end index (exclusive) in the given text. In the streaming RPC, the indexes always start from the beginning of the first text in the entire stream. The indexes are measured in UTF-16 code units. Corresponds to the JSON property startIndex

Returns:

  • (Fixnum)


30862
30863
30864
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30862

def start_index
  @start_index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30869
30870
30871
30872
30873
30874
30875
30876
30877
30878
30879
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30869

def update!(**args)
  @attribution_dataset = args[:attribution_dataset] if args.key?(:attribution_dataset)
  @display_attribution_message = args[:display_attribution_message] if args.key?(:display_attribution_message)
  @doc_attribution = args[:doc_attribution] if args.key?(:doc_attribution)
  @doc_occurrences = args[:doc_occurrences] if args.key?(:doc_occurrences)
  @end_index = args[:end_index] if args.key?(:end_index)
  @raw_text = args[:raw_text] if args.key?(:raw_text)
  @segment_recitation_action = args[:segment_recitation_action] if args.key?(:segment_recitation_action)
  @source_category = args[:source_category] if args.key?(:source_category)
  @start_index = args[:start_index] if args.key?(:start_index)
end