Class: Google::Apis::AiplatformV1::LanguageLabsAidaTrustRecitationProtoStreamRecitationResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The recitation result for one stream input

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LanguageLabsAidaTrustRecitationProtoStreamRecitationResult

Returns a new instance of LanguageLabsAidaTrustRecitationProtoStreamRecitationResult.



30848
30849
30850
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30848

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dynamic_segment_resultsArray<Google::Apis::AiplatformV1::LanguageLabsAidaTrustRecitationProtoSegmentResult>

The recitation result against the given dynamic data source. Corresponds to the JSON property dynamicSegmentResults



30828
30829
30830
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30828

def dynamic_segment_results
  @dynamic_segment_results
end

#fully_checked_text_indexFixnum

Last index of input text fully checked for recitation in the entire streaming context. Would return -1 if no Input was checked for recitation. Corresponds to the JSON property fullyCheckedTextIndex

Returns:

  • (Fixnum)


30834
30835
30836
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30834

def fully_checked_text_index
  @fully_checked_text_index
end

#recitation_actionString

The recitation action for one given input. When its segments contain different actions, the overall action will be returned in the precedence of BLOCK > CITE

NO_ACTION. Corresponds to the JSON property recitationAction

Returns:

  • (String)


30841
30842
30843
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30841

def recitation_action
  @recitation_action
end

#training_segment_resultsArray<Google::Apis::AiplatformV1::LanguageLabsAidaTrustRecitationProtoSegmentResult>

The recitation result against model training data. Corresponds to the JSON property trainingSegmentResults



30846
30847
30848
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30846

def training_segment_results
  @training_segment_results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30853
30854
30855
30856
30857
30858
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30853

def update!(**args)
  @dynamic_segment_results = args[:dynamic_segment_results] if args.key?(:dynamic_segment_results)
  @fully_checked_text_index = args[:fully_checked_text_index] if args.key?(:fully_checked_text_index)
  @recitation_action = args[:recitation_action] if args.key?(:recitation_action)
  @training_segment_results = args[:training_segment_results] if args.key?(:training_segment_results)
end