Class: Google::Apis::AiplatformV1::LearningGenaiRecitationDocAttribution

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The proto defines the attribution information for a document using whatever fields are most applicable for that document's datasource. For example, a Wikipedia article's attribution is in the form of its article title, a website is in the form of a URL, and a Github repo is in the form of a repo name. Next id: 30

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LearningGenaiRecitationDocAttribution

Returns a new instance of LearningGenaiRecitationDocAttribution.



31096
31097
31098
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31096

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#amarna_idString

Corresponds to the JSON property amarnaId

Returns:

  • (String)


30933
30934
30935
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30933

def amarna_id
  @amarna_id
end

#arxiv_idString

Corresponds to the JSON property arxivId

Returns:

  • (String)


30938
30939
30940
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30938

def arxiv_id
  @arxiv_id
end

#authorString

Corresponds to the JSON property author

Returns:

  • (String)


30943
30944
30945
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30943

def author
  @author
end

#bibkeyString

Corresponds to the JSON property bibkey

Returns:

  • (String)


30948
30949
30950
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30948

def bibkey
  @bibkey
end

#biorxiv_idString

ID of the paper in bioarxiv like ddoi.org/biorxiv_id eg: https://doi.org/10. 1101/343517 Corresponds to the JSON property biorxivId

Returns:

  • (String)


30954
30955
30956
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30954

def biorxiv_id
  @biorxiv_id
end

#book_titleString

Corresponds to the JSON property bookTitle

Returns:

  • (String)


30959
30960
30961
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30959

def book_title
  @book_title
end

#book_volume_idFixnum

The Oceanographers full-view books dataset uses a 'volume id' as the unique ID of a book. There is a deterministic function from a volume id to a URL under the books.google.com domain. Marked as 'optional' since a volume ID of zero is potentially possible and we want to distinguish that from the volume ID not being set. Corresponds to the JSON property bookVolumeId

Returns:

  • (Fixnum)


30968
30969
30970
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30968

def book_volume_id
  @book_volume_id
end

#conversation_idString

Corresponds to the JSON property conversationId

Returns:

  • (String)


30973
30974
30975
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30973

def conversation_id
  @conversation_id
end

#datasetString

The dataset this document comes from. Corresponds to the JSON property dataset

Returns:

  • (String)


30978
30979
30980
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30978

def dataset
  @dataset
end

#filepathString

Corresponds to the JSON property filepath

Returns:

  • (String)


30983
30984
30985
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30983

def filepath
  @filepath
end

#gemini_idString

Corresponds to the JSON property geminiId

Returns:

  • (String)


30988
30989
30990
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30988

def gemini_id
  @gemini_id
end

#gnews_article_titleString

Corresponds to the JSON property gnewsArticleTitle

Returns:

  • (String)


30993
30994
30995
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30993

def gnews_article_title
  @gnews_article_title
end

#goodall_example_idString

Corresponds to the JSON property goodallExampleId

Returns:

  • (String)


30998
30999
31000
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30998

def goodall_example_id
  @goodall_example_id
end

#is_opt_outBoolean Also known as: is_opt_out?

Whether the document is opted out. Corresponds to the JSON property isOptOut

Returns:

  • (Boolean)


31003
31004
31005
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31003

def is_opt_out
  @is_opt_out
end

#is_promptBoolean Also known as: is_prompt?

When true, this attribution came from the user's prompt. Corresponds to the JSON property isPrompt

Returns:

  • (Boolean)


31009
31010
31011
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31009

def is_prompt
  @is_prompt
end

#lamda_example_idString

Corresponds to the JSON property lamdaExampleId

Returns:

  • (String)


31015
31016
31017
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31015

def lamda_example_id
  @lamda_example_id
end

#licenseString

Corresponds to the JSON property license

Returns:

  • (String)


31020
31021
31022
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31020

def license
  @license
end

#meena_conversation_idString

Corresponds to the JSON property meenaConversationId

Returns:

  • (String)


31025
31026
31027
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31025

def meena_conversation_id
  @meena_conversation_id
end

#natural_language_codeString

Natural (not programming) language of the document. Language code as defined by http://www.unicode.org/reports/tr35/#Identifiers and https://tools.ietf.org/ html/bcp47. Currently applicable to full-view books. Use docinfo-util.h to set & read language fields. See go/iii. Corresponds to the JSON property naturalLanguageCode

Returns:

  • (String)


31033
31034
31035
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31033

def natural_language_code
  @natural_language_code
end

#no_attributionBoolean Also known as: no_attribution?

True if this doc has no attribution information available. We use an explicit field for this instead of just implicitly leaving all the DocAttribution fields blank to distinguish a case where a bug/oversight has left the attribution information empty vs when we really have no attribution information available. Corresponds to the JSON property noAttribution

Returns:

  • (Boolean)


31042
31043
31044
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31042

def no_attribution
  @no_attribution
end

#podcast_utterance_idString

Corresponds to the JSON property podcastUtteranceId

Returns:

  • (String)


31048
31049
31050
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31048

def podcast_utterance_id
  @podcast_utterance_id
end

#publication_dateGoogle::Apis::AiplatformV1::GoogleTypeDate

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property publicationDate



31060
31061
31062
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31060

def publication_date
  @publication_date
end

#quality_score_experiment_onlyFloat

This field is for opt-out experiment only, MUST never be used during actual production/serving. Corresponds to the JSON property qualityScoreExperimentOnly

Returns:

  • (Float)


31066
31067
31068
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31066

def quality_score_experiment_only
  @quality_score_experiment_only
end

#repoString

Github repository Corresponds to the JSON property repo

Returns:

  • (String)


31071
31072
31073
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31071

def repo
  @repo
end

#urlString

URL of a webdoc Corresponds to the JSON property url

Returns:

  • (String)


31076
31077
31078
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31076

def url
  @url
end

#volume_idString

Corresponds to the JSON property volumeId

Returns:

  • (String)


31081
31082
31083
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31081

def volume_id
  @volume_id
end

#wikipedia_article_titleString

Wikipedia article title. The Wikipedia TFDS dataset includes article titles but not URLs. While a URL is to the best of our knowledge a deterministic function of the title, we store the original title to reflect the information in the original dataset. Corresponds to the JSON property wikipediaArticleTitle

Returns:

  • (String)


31089
31090
31091
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31089

def wikipedia_article_title
  @wikipedia_article_title
end

#youtube_video_idString

Corresponds to the JSON property youtubeVideoId

Returns:

  • (String)


31094
31095
31096
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31094

def youtube_video_id
  @youtube_video_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31101
31102
31103
31104
31105
31106
31107
31108
31109
31110
31111
31112
31113
31114
31115
31116
31117
31118
31119
31120
31121
31122
31123
31124
31125
31126
31127
31128
31129
31130
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31101

def update!(**args)
  @amarna_id = args[:amarna_id] if args.key?(:amarna_id)
  @arxiv_id = args[:arxiv_id] if args.key?(:arxiv_id)
  @author = args[:author] if args.key?(:author)
  @bibkey = args[:bibkey] if args.key?(:bibkey)
  @biorxiv_id = args[:biorxiv_id] if args.key?(:biorxiv_id)
  @book_title = args[:book_title] if args.key?(:book_title)
  @book_volume_id = args[:book_volume_id] if args.key?(:book_volume_id)
  @conversation_id = args[:conversation_id] if args.key?(:conversation_id)
  @dataset = args[:dataset] if args.key?(:dataset)
  @filepath = args[:filepath] if args.key?(:filepath)
  @gemini_id = args[:gemini_id] if args.key?(:gemini_id)
  @gnews_article_title = args[:gnews_article_title] if args.key?(:gnews_article_title)
  @goodall_example_id = args[:goodall_example_id] if args.key?(:goodall_example_id)
  @is_opt_out = args[:is_opt_out] if args.key?(:is_opt_out)
  @is_prompt = args[:is_prompt] if args.key?(:is_prompt)
  @lamda_example_id = args[:lamda_example_id] if args.key?(:lamda_example_id)
  @license = args[:license] if args.key?(:license)
  @meena_conversation_id = args[:meena_conversation_id] if args.key?(:meena_conversation_id)
  @natural_language_code = args[:natural_language_code] if args.key?(:natural_language_code)
  @no_attribution = args[:no_attribution] if args.key?(:no_attribution)
  @podcast_utterance_id = args[:podcast_utterance_id] if args.key?(:podcast_utterance_id)
  @publication_date = args[:publication_date] if args.key?(:publication_date)
  @quality_score_experiment_only = args[:quality_score_experiment_only] if args.key?(:quality_score_experiment_only)
  @repo = args[:repo] if args.key?(:repo)
  @url = args[:url] if args.key?(:url)
  @volume_id = args[:volume_id] if args.key?(:volume_id)
  @wikipedia_article_title = args[:wikipedia_article_title] if args.key?(:wikipedia_article_title)
  @youtube_video_id = args[:youtube_video_id] if args.key?(:youtube_video_id)
end