Class: Google::Apis::AiplatformV1::LearningGenaiRecitationRecitationResult
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::LearningGenaiRecitationRecitationResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The recitation result for one input
Instance Attribute Summary collapse
-
#dynamic_segment_results ⇒ Array<Google::Apis::AiplatformV1::LearningGenaiRecitationSegmentResult>
Corresponds to the JSON property
dynamicSegmentResults. -
#recitation_action ⇒ String
The recitation action for one given input.
-
#training_segment_results ⇒ Array<Google::Apis::AiplatformV1::LearningGenaiRecitationSegmentResult>
Corresponds to the JSON property
trainingSegmentResults.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LearningGenaiRecitationRecitationResult
constructor
A new instance of LearningGenaiRecitationRecitationResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LearningGenaiRecitationRecitationResult
Returns a new instance of LearningGenaiRecitationRecitationResult.
31155 31156 31157 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31155 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dynamic_segment_results ⇒ Array<Google::Apis::AiplatformV1::LearningGenaiRecitationSegmentResult>
Corresponds to the JSON property dynamicSegmentResults
31140 31141 31142 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31140 def dynamic_segment_results @dynamic_segment_results end |
#recitation_action ⇒ String
The recitation action for one given input. When its segments contain different actions, the overall action will be returned in the precedence of BLOCK > CITE
NO_ACTION. When the given input is not found in any source, the recitation action will be NO_ACTION. Corresponds to the JSON property
recitationAction
31148 31149 31150 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31148 def recitation_action @recitation_action end |
#training_segment_results ⇒ Array<Google::Apis::AiplatformV1::LearningGenaiRecitationSegmentResult>
Corresponds to the JSON property trainingSegmentResults
31153 31154 31155 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31153 def training_segment_results @training_segment_results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31160 31161 31162 31163 31164 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31160 def update!(**args) @dynamic_segment_results = args[:dynamic_segment_results] if args.key?(:dynamic_segment_results) @recitation_action = args[:recitation_action] if args.key?(:recitation_action) @training_segment_results = args[:training_segment_results] if args.key?(:training_segment_results) end |