Class: Google::Apis::AiplatformV1::LearningGenaiRecitationSegmentResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The recitation result for each segment in a given input.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LearningGenaiRecitationSegmentResult

Returns a new instance of LearningGenaiRecitationSegmentResult.



31227
31228
31229
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31227

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attribution_datasetString

The dataset the segment came from. Datasets change often as model evolves. Treat this field as informational only and avoid depending on it directly. Corresponds to the JSON property attributionDataset

Returns:

  • (String)


31175
31176
31177
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31175

def attribution_dataset
  @attribution_dataset
end

#display_attribution_messageString

human-friendly string that contains information from doc_attribution which could be shown by clients Corresponds to the JSON property displayAttributionMessage

Returns:

  • (String)


31181
31182
31183
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31181

def display_attribution_message
  @display_attribution_message
end

#doc_attributionGoogle::Apis::AiplatformV1::LearningGenaiRecitationDocAttribution

The proto defines the attribution information for a document using whatever fields are most applicable for that document's datasource. For example, a Wikipedia article's attribution is in the form of its article title, a website is in the form of a URL, and a Github repo is in the form of a repo name. Next id: 30 Corresponds to the JSON property docAttribution



31190
31191
31192
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31190

def doc_attribution
  @doc_attribution
end

#doc_occurrencesFixnum

number of documents that contained this segment Corresponds to the JSON property docOccurrences

Returns:

  • (Fixnum)


31195
31196
31197
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31195

def doc_occurrences
  @doc_occurrences
end

#end_indexFixnum

Corresponds to the JSON property endIndex

Returns:

  • (Fixnum)


31200
31201
31202
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31200

def end_index
  @end_index
end

#raw_textString

The raw text in the given input that is corresponding to the segment. It will be available only when 'return_segment_raw_text' is enabled in the request options. Corresponds to the JSON property rawText

Returns:

  • (String)


31207
31208
31209
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31207

def raw_text
  @raw_text
end

#segment_recitation_actionString

Corresponds to the JSON property segmentRecitationAction

Returns:

  • (String)


31212
31213
31214
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31212

def segment_recitation_action
  @segment_recitation_action
end

#source_categoryString

The category of the source dataset where the segment came from. This is more stable than Dataset. Corresponds to the JSON property sourceCategory

Returns:

  • (String)


31218
31219
31220
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31218

def source_category
  @source_category
end

#start_indexFixnum

The segment boundary start (inclusive) and end index (exclusive) in the given text. In the streaming RPC, the indexes always start from the beginning of the first text in the entire stream. The indexes are measured in UTF-16 code units. Corresponds to the JSON property startIndex

Returns:

  • (Fixnum)


31225
31226
31227
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31225

def start_index
  @start_index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31232
31233
31234
31235
31236
31237
31238
31239
31240
31241
31242
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31232

def update!(**args)
  @attribution_dataset = args[:attribution_dataset] if args.key?(:attribution_dataset)
  @display_attribution_message = args[:display_attribution_message] if args.key?(:display_attribution_message)
  @doc_attribution = args[:doc_attribution] if args.key?(:doc_attribution)
  @doc_occurrences = args[:doc_occurrences] if args.key?(:doc_occurrences)
  @end_index = args[:end_index] if args.key?(:end_index)
  @raw_text = args[:raw_text] if args.key?(:raw_text)
  @segment_recitation_action = args[:segment_recitation_action] if args.key?(:segment_recitation_action)
  @source_category = args[:source_category] if args.key?(:source_category)
  @start_index = args[:start_index] if args.key?(:start_index)
end