Class: Google::Apis::AiplatformV1::LearningGenaiRootCodeyChatMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::LearningGenaiRootCodeyChatMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Stores all metadata relating to AIDA DoConversation.
Instance Attribute Summary collapse
-
#code_language ⇒ String
Indicates the programming language of the code if the message is a code chunk.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LearningGenaiRootCodeyChatMetadata
constructor
A new instance of LearningGenaiRootCodeyChatMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LearningGenaiRootCodeyChatMetadata
Returns a new instance of LearningGenaiRootCodeyChatMetadata.
31305 31306 31307 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31305 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code_language ⇒ String
Indicates the programming language of the code if the message is a code chunk.
Corresponds to the JSON property codeLanguage
31303 31304 31305 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31303 def code_language @code_language end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31310 31311 31312 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31310 def update!(**args) @code_language = args[:code_language] if args.key?(:code_language) end |