Class: Google::Apis::AiplatformV1::LearningGenaiRootCodeyGenerationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::LearningGenaiRootCodeyGenerationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Stores all metadata relating to GenerateCode.
Instance Attribute Summary collapse
-
#output ⇒ String
Last state of the sample before getting dropped/returned.
-
#post_inference_step ⇒ String
Last Codey postprocessing step for this sample before getting dropped/returned.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LearningGenaiRootCodeyGenerationMetadata
constructor
A new instance of LearningGenaiRootCodeyGenerationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LearningGenaiRootCodeyGenerationMetadata
Returns a new instance of LearningGenaiRootCodeyGenerationMetadata.
31448 31449 31450 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31448 def initialize(**args) update!(**args) end |
Instance Attribute Details
#output ⇒ String
Last state of the sample before getting dropped/returned.
Corresponds to the JSON property output
31441 31442 31443 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31441 def output @output end |
#post_inference_step ⇒ String
Last Codey postprocessing step for this sample before getting dropped/returned.
Corresponds to the JSON property postInferenceStep
31446 31447 31448 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31446 def post_inference_step @post_inference_step end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31453 31454 31455 31456 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31453 def update!(**args) @output = args[:output] if args.key?(:output) @post_inference_step = args[:post_inference_step] if args.key?(:post_inference_step) end |