Class: Google::Apis::AiplatformV1::LearningGenaiRootGroundingMetadataCitation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LearningGenaiRootGroundingMetadataCitation

Returns a new instance of LearningGenaiRootGroundingMetadataCitation.



30405
30406
30407
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30405

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_indexFixnum

Index in the prediction output where the citation ends (exclusive). Must be > start_index and < len(output). Corresponds to the JSON property endIndex

Returns:

  • (Fixnum)


30385
30386
30387
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30385

def end_index
  @end_index
end

#fact_indexFixnum

Index of the fact supporting this claim. Should be within the range of the world_facts in the GenerateResponse. Corresponds to the JSON property factIndex

Returns:

  • (Fixnum)


30391
30392
30393
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30391

def fact_index
  @fact_index
end

#scoreFloat

Confidence score of this entailment. Value is [0,1] with 1 is the most confidence. Corresponds to the JSON property score

Returns:

  • (Float)


30397
30398
30399
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30397

def score
  @score
end

#start_indexFixnum

Index in the prediction output where the citation starts (inclusive). Must be > = 0 and < end_index. Corresponds to the JSON property startIndex

Returns:

  • (Fixnum)


30403
30404
30405
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30403

def start_index
  @start_index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30410
30411
30412
30413
30414
30415
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30410

def update!(**args)
  @end_index = args[:end_index] if args.key?(:end_index)
  @fact_index = args[:fact_index] if args.key?(:fact_index)
  @score = args[:score] if args.key?(:score)
  @start_index = args[:start_index] if args.key?(:start_index)
end