Class: Google::Apis::AiplatformV1::LearningGenaiRootRegexTakedownResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LearningGenaiRootRegexTakedownResult

Returns a new instance of LearningGenaiRootRegexTakedownResult.



32159
32160
32161
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32159

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowedBoolean Also known as: allowed?

False when query or response should be taken down due to match with a blocked regex, true otherwise. Corresponds to the JSON property allowed

Returns:

  • (Boolean)


32150
32151
32152
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32150

def allowed
  @allowed
end

#takedown_regexString

Regex used to decide that query or response should be taken down. Empty when query or response is kept. Corresponds to the JSON property takedownRegex

Returns:

  • (String)


32157
32158
32159
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32157

def takedown_regex
  @takedown_regex
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32164
32165
32166
32167
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32164

def update!(**args)
  @allowed = args[:allowed] if args.key?(:allowed)
  @takedown_regex = args[:takedown_regex] if args.key?(:takedown_regex)
end