Class: Google::Apis::AiplatformV1::LearningGenaiRootRequestResponseTakedownResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LearningGenaiRootRequestResponseTakedownResult

Returns a new instance of LearningGenaiRootRequestResponseTakedownResult.



32223
32224
32225
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32223

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowedBoolean Also known as: allowed?

False when response has to be taken down per above config. Corresponds to the JSON property allowed

Returns:

  • (Boolean)


32209
32210
32211
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32209

def allowed
  @allowed
end

#request_takedown_regexString

Regex used to match the request. Corresponds to the JSON property requestTakedownRegex

Returns:

  • (String)


32215
32216
32217
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32215

def request_takedown_regex
  @request_takedown_regex
end

#response_takedown_regexString

Regex used to decide that response should be taken down. Empty when response is kept. Corresponds to the JSON property responseTakedownRegex

Returns:

  • (String)


32221
32222
32223
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32221

def response_takedown_regex
  @response_takedown_regex
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32228
32229
32230
32231
32232
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32228

def update!(**args)
  @allowed = args[:allowed] if args.key?(:allowed)
  @request_takedown_regex = args[:request_takedown_regex] if args.key?(:request_takedown_regex)
  @response_takedown_regex = args[:response_takedown_regex] if args.key?(:response_takedown_regex)
end