Class: Google::Apis::AiplatformV1::LearningGenaiRootRoutingDecisionMetadataTokenLengthBasedModelInputTokenMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LearningGenaiRootRoutingDecisionMetadataTokenLengthBasedModelInputTokenMetadata

Returns a new instance of LearningGenaiRootRoutingDecisionMetadataTokenLengthBasedModelInputTokenMetadata.



32441
32442
32443
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32441

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#computed_input_token_lengthFixnum

The length computed by backends using the formatter & tokenizer specific to the model Corresponds to the JSON property computedInputTokenLength

Returns:

  • (Fixnum)


32422
32423
32424
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32422

def computed_input_token_length
  @computed_input_token_length
end

#model_idString

Corresponds to the JSON property modelId

Returns:

  • (String)


32427
32428
32429
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32427

def model_id
  @model_id
end

#picked_as_fallbackBoolean Also known as: picked_as_fallback?

If true, the model was selected as a fallback, since no model met requirements. Corresponds to the JSON property pickedAsFallback

Returns:

  • (Boolean)


32432
32433
32434
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32432

def picked_as_fallback
  @picked_as_fallback
end

#selectedBoolean Also known as: selected?

If true, the model was selected since it met the requriements. Corresponds to the JSON property selected

Returns:

  • (Boolean)


32438
32439
32440
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32438

def selected
  @selected
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32446
32447
32448
32449
32450
32451
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32446

def update!(**args)
  @computed_input_token_length = args[:computed_input_token_length] if args.key?(:computed_input_token_length)
  @model_id = args[:model_id] if args.key?(:model_id)
  @picked_as_fallback = args[:picked_as_fallback] if args.key?(:picked_as_fallback)
  @selected = args[:selected] if args.key?(:selected)
end