Class: Google::Apis::AiplatformV1::LearningGenaiRootScoreBasedRoutingConfigRule
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::LearningGenaiRootScoreBasedRoutingConfigRule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Instance Attribute Summary collapse
-
#equal_or_greater_than ⇒ Google::Apis::AiplatformV1::LearningGenaiRootScore
NOTE: Hardest examples have smaller values in their routing scores.
-
#less_than ⇒ Google::Apis::AiplatformV1::LearningGenaiRootScore
Corresponds to the JSON property
lessThan. -
#model_config_id ⇒ String
This model_config_id points to ModelConfig::id which allows us to find the ModelConfig to route to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LearningGenaiRootScoreBasedRoutingConfigRule
constructor
A new instance of LearningGenaiRootScoreBasedRoutingConfigRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LearningGenaiRootScoreBasedRoutingConfigRule
Returns a new instance of LearningGenaiRootScoreBasedRoutingConfigRule.
32577 32578 32579 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32577 def initialize(**args) update!(**args) end |
Instance Attribute Details
#equal_or_greater_than ⇒ Google::Apis::AiplatformV1::LearningGenaiRootScore
NOTE: Hardest examples have smaller values in their routing scores.
Corresponds to the JSON property equalOrGreaterThan
32563 32564 32565 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32563 def equal_or_greater_than @equal_or_greater_than end |
#less_than ⇒ Google::Apis::AiplatformV1::LearningGenaiRootScore
Corresponds to the JSON property lessThan
32568 32569 32570 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32568 def less_than @less_than end |
#model_config_id ⇒ String
This model_config_id points to ModelConfig::id which allows us to find the
ModelConfig to route to. This is part of the banks specified in the
ModelBankConfig.
Corresponds to the JSON property modelConfigId
32575 32576 32577 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32575 def model_config_id @model_config_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32582 32583 32584 32585 32586 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32582 def update!(**args) @equal_or_greater_than = args[:equal_or_greater_than] if args.key?(:equal_or_greater_than) @less_than = args[:less_than] if args.key?(:less_than) @model_config_id = args[:model_config_id] if args.key?(:model_config_id) end |