Class: Google::Apis::AiplatformV1::LearningGenaiRootScoredToken

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A token with its own score.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LearningGenaiRootScoredToken

Returns a new instance of LearningGenaiRootScoredToken.



32640
32641
32642
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32640

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_token_scoreFloat

Each end_token_score is a logprob for how well the completion would end at a particular token. See http://google3/labs/language/aida/config/proto/ model_config.proto;l=376;rcl=573039459 Corresponds to the JSON property endTokenScore

Returns:

  • (Float)


32628
32629
32630
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32628

def end_token_score
  @end_token_score
end

#scoreFloat

Each score is the logprob for the token in model response. Corresponds to the JSON property score

Returns:

  • (Float)


32633
32634
32635
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32633

def score
  @score
end

#tokenString

Corresponds to the JSON property token

Returns:

  • (String)


32638
32639
32640
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32638

def token
  @token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32645
32646
32647
32648
32649
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32645

def update!(**args)
  @end_token_score = args[:end_token_score] if args.key?(:end_token_score)
  @score = args[:score] if args.key?(:score)
  @token = args[:token] if args.key?(:token)
end