Class: Google::Apis::AiplatformV1::LearningGenaiRootSimilarityTakedownPhrase

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Each SimilarityTakedownPhrase treats a logical group of blocked and allowed phrases together along with a corresponding punt If the closest matching response is of the allowed type, we allow the response If the closest matching response is of the blocked type, we block the response. eg: Blocked phrase - " All lives matter"

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LearningGenaiRootSimilarityTakedownPhrase

Returns a new instance of LearningGenaiRootSimilarityTakedownPhrase.



32665
32666
32667
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32665

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blocked_phraseString

Corresponds to the JSON property blockedPhrase

Returns:

  • (String)


32663
32664
32665
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32663

def blocked_phrase
  @blocked_phrase
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32670
32671
32672
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32670

def update!(**args)
  @blocked_phrase = args[:blocked_phrase] if args.key?(:blocked_phrase)
end