Class: Google::Apis::AiplatformV1::LearningGenaiRootSimilarityTakedownResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LearningGenaiRootSimilarityTakedownResult

Returns a new instance of LearningGenaiRootSimilarityTakedownResult.



32691
32692
32693
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32691

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowedBoolean Also known as: allowed?

False when query or response should be taken down by any of the takedown rules, true otherwise. Corresponds to the JSON property allowed

Returns:

  • (Boolean)


32683
32684
32685
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32683

def allowed
  @allowed
end

#scored_phrasesArray<Google::Apis::AiplatformV1::LearningGenaiRootScoredSimilarityTakedownPhrase>

List of similar phrases with score. Set only if allowed=false. Corresponds to the JSON property scoredPhrases



32689
32690
32691
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32689

def scored_phrases
  @scored_phrases
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32696
32697
32698
32699
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32696

def update!(**args)
  @allowed = args[:allowed] if args.key?(:allowed)
  @scored_phrases = args[:scored_phrases] if args.key?(:scored_phrases)
end