Class: Google::Apis::AiplatformV1::LearningGenaiRootTakedownResult
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::LearningGenaiRootTakedownResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Instance Attribute Summary collapse
-
#allowed ⇒ Boolean
(also: #allowed?)
False when query or response should be taken down by any of the takedown rules, true otherwise.
-
#regex_takedown_result ⇒ Google::Apis::AiplatformV1::LearningGenaiRootRegexTakedownResult
Corresponds to the JSON property
regexTakedownResult. -
#request_response_takedown_result ⇒ Google::Apis::AiplatformV1::LearningGenaiRootRequestResponseTakedownResult
Corresponds to the JSON property
requestResponseTakedownResult. -
#similarity_takedown_result ⇒ Google::Apis::AiplatformV1::LearningGenaiRootSimilarityTakedownResult
Corresponds to the JSON property
similarityTakedownResult.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LearningGenaiRootTakedownResult
constructor
A new instance of LearningGenaiRootTakedownResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LearningGenaiRootTakedownResult
Returns a new instance of LearningGenaiRootTakedownResult.
32627 32628 32629 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32627 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowed ⇒ Boolean Also known as: allowed?
False when query or response should be taken down by any of the takedown rules,
true otherwise.
Corresponds to the JSON property allowed
32609 32610 32611 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32609 def allowed @allowed end |
#regex_takedown_result ⇒ Google::Apis::AiplatformV1::LearningGenaiRootRegexTakedownResult
Corresponds to the JSON property regexTakedownResult
32615 32616 32617 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32615 def regex_takedown_result @regex_takedown_result end |
#request_response_takedown_result ⇒ Google::Apis::AiplatformV1::LearningGenaiRootRequestResponseTakedownResult
Corresponds to the JSON property requestResponseTakedownResult
32620 32621 32622 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32620 def request_response_takedown_result @request_response_takedown_result end |
#similarity_takedown_result ⇒ Google::Apis::AiplatformV1::LearningGenaiRootSimilarityTakedownResult
Corresponds to the JSON property similarityTakedownResult
32625 32626 32627 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32625 def similarity_takedown_result @similarity_takedown_result end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32632 32633 32634 32635 32636 32637 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32632 def update!(**args) @allowed = args[:allowed] if args.key?(:allowed) @regex_takedown_result = args[:regex_takedown_result] if args.key?(:regex_takedown_result) @request_response_takedown_result = args[:request_response_takedown_result] if args.key?(:request_response_takedown_result) @similarity_takedown_result = args[:similarity_takedown_result] if args.key?(:similarity_takedown_result) end |