Class: Google::Apis::AiplatformV1::LearningGenaiRootTranslationRequestInfo
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::LearningGenaiRootTranslationRequestInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Each TranslationRequestInfo corresponds to a request sent to the translation server.
Instance Attribute Summary collapse
-
#detected_language_codes ⇒ Array<String>
The ISO-639 language code of source text in the initial request, detected automatically, if no source language was passed within the initial request.
-
#total_content_size ⇒ Fixnum
The sum of the size of all the contents in the request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LearningGenaiRootTranslationRequestInfo
constructor
A new instance of LearningGenaiRootTranslationRequestInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LearningGenaiRootTranslationRequestInfo
Returns a new instance of LearningGenaiRootTranslationRequestInfo.
32807 32808 32809 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32807 def initialize(**args) update!(**args) end |
Instance Attribute Details
#detected_language_codes ⇒ Array<String>
The ISO-639 language code of source text in the initial request, detected
automatically, if no source language was passed within the initial request. If
the source language was passed, auto-detection of the language does not occur
and this field is empty.
Corresponds to the JSON property detectedLanguageCodes
32800 32801 32802 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32800 def detected_language_codes @detected_language_codes end |
#total_content_size ⇒ Fixnum
The sum of the size of all the contents in the request.
Corresponds to the JSON property totalContentSize
32805 32806 32807 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32805 def total_content_size @total_content_size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32812 32813 32814 32815 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32812 def update!(**args) @detected_language_codes = args[:detected_language_codes] if args.key?(:detected_language_codes) @total_content_size = args[:total_content_size] if args.key?(:total_content_size) end |