Class: Google::Apis::AiplatformV1::LearningServingLlmMessageMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

LINT.IfChange This metadata contains additional information required for debugging.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LearningServingLlmMessageMetadata

Returns a new instance of LearningServingLlmMessageMetadata.



33059
33060
33061
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33059

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#classifier_summaryGoogle::Apis::AiplatformV1::LearningGenaiRootClassifierOutputSummary

Summary of classifier output. We attach this to all messages regardless of whether classification rules triggered or not. Corresponds to the JSON property classifierSummary



32928
32929
32930
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32928

def classifier_summary
  @classifier_summary
end

#codey_outputGoogle::Apis::AiplatformV1::LearningGenaiRootCodeyOutput

Top-level wrapper used to store all things codey-related. Corresponds to the JSON property codeyOutput



32933
32934
32935
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32933

def codey_output
  @codey_output
end

#current_stream_text_lengthFixnum

Corresponds to the JSON property currentStreamTextLength

Returns:

  • (Fixnum)


32938
32939
32940
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32938

def current_stream_text_length
  @current_stream_text_length
end

#deletedBoolean Also known as: deleted?

Whether the corresponding message has been deleted. Corresponds to the JSON property deleted

Returns:

  • (Boolean)


32943
32944
32945
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32943

def deleted
  @deleted
end

#filter_metaArray<Google::Apis::AiplatformV1::LearningGenaiRootFilterMetadata>

Metadata for filters that triggered. Corresponds to the JSON property filterMeta



32949
32950
32951
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32949

def filter_meta
  @filter_meta
end

#final_message_scoreGoogle::Apis::AiplatformV1::LearningGenaiRootScore

This score is finally used for ranking the message. This will be same as the score present in Message.score field. Corresponds to the JSON property finalMessageScore



32955
32956
32957
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32955

def final_message_score
  @final_message_score
end

#finish_reasonString

NOT YET IMPLEMENTED. Corresponds to the JSON property finishReason

Returns:

  • (String)


32960
32961
32962
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32960

def finish_reason
  @finish_reason
end

#grounding_metadataGoogle::Apis::AiplatformV1::LearningGenaiRootGroundingMetadata

Corresponds to the JSON property groundingMetadata



32965
32966
32967
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32965

def 
  @grounding_metadata
end

#is_codeBoolean Also known as: is_code?

Applies to streaming response message only. Whether the message is a code. Corresponds to the JSON property isCode

Returns:

  • (Boolean)


32970
32971
32972
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32970

def is_code
  @is_code
end

#is_fallbackBoolean Also known as: is_fallback?

Applies to Response message only. Indicates whether the message is a fallback and the response would have otherwise been empty. Corresponds to the JSON property isFallback

Returns:

  • (Boolean)


32977
32978
32979
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32977

def is_fallback
  @is_fallback
end

#langid_resultGoogle::Apis::AiplatformV1::NlpSaftLangIdResult

Result from nlp_saft DetectLanguage method. Currently the predicted language code and language probability is used. Corresponds to the JSON property langidResult



32984
32985
32986
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32984

def langid_result
  @langid_result
end

#languageString

Detected language. Corresponds to the JSON property language

Returns:

  • (String)


32989
32990
32991
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32989

def language
  @language
end

#lm_prefixString

The LM prefix used to generate this response. Corresponds to the JSON property lmPrefix

Returns:

  • (String)


32994
32995
32996
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32994

def lm_prefix
  @lm_prefix
end

#original_textString

The original text generated by LLM. This is the raw output for debugging purposes. Corresponds to the JSON property originalText

Returns:

  • (String)


33000
33001
33002
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33000

def original_text
  @original_text
end

#per_stream_decoded_token_countFixnum

NOT YET IMPLEMENTED. Applies to streaming only. Number of tokens decoded / emitted by the model as part of this stream. This may be different from token_count, which contains number of tokens returned in this response after any response rewriting / truncation. Corresponds to the JSON property perStreamDecodedTokenCount

Returns:

  • (Fixnum)


33008
33009
33010
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33008

def per_stream_decoded_token_count
  @per_stream_decoded_token_count
end

#rai_outputsArray<Google::Apis::AiplatformV1::LearningGenaiRootRaiOutput>

Results of running RAI on the query or this response candidate. One output per rai_config. It will be populated regardless of whether the threshold is exceeded or not. Corresponds to the JSON property raiOutputs



33015
33016
33017
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33015

def rai_outputs
  @rai_outputs
end

#recitation_resultGoogle::Apis::AiplatformV1::LearningGenaiRecitationRecitationResult

The recitation result for one input Corresponds to the JSON property recitationResult



33020
33021
33022
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33020

def recitation_result
  @recitation_result
end

#return_token_countFixnum

NOT YET IMPLEMENTED. Number of tokens returned as part of this candidate. Corresponds to the JSON property returnTokenCount

Returns:

  • (Fixnum)


33025
33026
33027
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33025

def return_token_count
  @return_token_count
end

#scoresArray<Google::Apis::AiplatformV1::LearningGenaiRootScore>

All the different scores for a message are logged here. Corresponds to the JSON property scores



33030
33031
33032
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33030

def scores
  @scores
end

#stream_terminatedBoolean Also known as: stream_terminated?

Whether the response is terminated during streaming return. Only used for streaming requests. Corresponds to the JSON property streamTerminated

Returns:

  • (Boolean)


33036
33037
33038
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33036

def stream_terminated
  @stream_terminated
end

#total_decoded_token_countFixnum

Total tokens decoded so far per response_candidate. For streaming: Count of all the tokens decoded so far (aggregated count). For unary: Count of all the tokens decoded per response_candidate. Corresponds to the JSON property totalDecodedTokenCount

Returns:

  • (Fixnum)


33044
33045
33046
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33044

def total_decoded_token_count
  @total_decoded_token_count
end

#translated_user_promptsArray<String>

Translated user-prompt used for RAI post processing. This is for internal processing only. We will translate in pre-processor and pass the translated text to the post processor using this field. It will be empty if non of the signals requested need translation. Corresponds to the JSON property translatedUserPrompts

Returns:

  • (Array<String>)


33052
33053
33054
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33052

def translated_user_prompts
  @translated_user_prompts
end

#vertex_rai_resultGoogle::Apis::AiplatformV1::CloudAiNlLlmProtoServiceRaiResult

The RAI results for a given text. Corresponds to the JSON property vertexRaiResult



33057
33058
33059
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33057

def vertex_rai_result
  @vertex_rai_result
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33064
33065
33066
33067
33068
33069
33070
33071
33072
33073
33074
33075
33076
33077
33078
33079
33080
33081
33082
33083
33084
33085
33086
33087
33088
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33064

def update!(**args)
  @classifier_summary = args[:classifier_summary] if args.key?(:classifier_summary)
  @codey_output = args[:codey_output] if args.key?(:codey_output)
  @current_stream_text_length = args[:current_stream_text_length] if args.key?(:current_stream_text_length)
  @deleted = args[:deleted] if args.key?(:deleted)
  @filter_meta = args[:filter_meta] if args.key?(:filter_meta)
  @final_message_score = args[:final_message_score] if args.key?(:final_message_score)
  @finish_reason = args[:finish_reason] if args.key?(:finish_reason)
  @grounding_metadata = args[:grounding_metadata] if args.key?(:grounding_metadata)
  @is_code = args[:is_code] if args.key?(:is_code)
  @is_fallback = args[:is_fallback] if args.key?(:is_fallback)
  @langid_result = args[:langid_result] if args.key?(:langid_result)
  @language = args[:language] if args.key?(:language)
  @lm_prefix = args[:lm_prefix] if args.key?(:lm_prefix)
  @original_text = args[:original_text] if args.key?(:original_text)
  @per_stream_decoded_token_count = args[:per_stream_decoded_token_count] if args.key?(:per_stream_decoded_token_count)
  @rai_outputs = args[:rai_outputs] if args.key?(:rai_outputs)
  @recitation_result = args[:recitation_result] if args.key?(:recitation_result)
  @return_token_count = args[:return_token_count] if args.key?(:return_token_count)
  @scores = args[:scores] if args.key?(:scores)
  @stream_terminated = args[:stream_terminated] if args.key?(:stream_terminated)
  @total_decoded_token_count = args[:total_decoded_token_count] if args.key?(:total_decoded_token_count)
  @translated_user_prompts = args[:translated_user_prompts] if args.key?(:translated_user_prompts)
  @vertex_rai_result = args[:vertex_rai_result] if args.key?(:vertex_rai_result)
end