Class: Google::Apis::AiplatformV1::NlpSaftLanguageSpan

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NlpSaftLanguageSpan

Returns a new instance of NlpSaftLanguageSpan.



33205
33206
33207
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33205

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#endFixnum

Corresponds to the JSON property end

Returns:

  • (Fixnum)


33179
33180
33181
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33179

def end
  @end
end

#language_codeString

A BCP 47 language code for this span. Corresponds to the JSON property languageCode

Returns:

  • (String)


33184
33185
33186
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33184

def language_code
  @language_code
end

#localesGoogle::Apis::AiplatformV1::NlpSaftLangIdLocalesResult

Optional field containing any information that was predicted about the specific locale(s) of the span. Corresponds to the JSON property locales



33190
33191
33192
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33190

def locales
  @locales
end

#probabilityFloat

A probability associated with this prediction. Corresponds to the JSON property probability

Returns:

  • (Float)


33195
33196
33197
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33195

def probability
  @probability
end

#startFixnum

Start and end byte offsets, inclusive, within the given input string. A value of -1 implies that this field is not set. Both fields must either be set with a nonnegative value or both are unset. If both are unset then this LanguageSpan applies to the entire input. Corresponds to the JSON property start

Returns:

  • (Fixnum)


33203
33204
33205
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33203

def start
  @start
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33210
33211
33212
33213
33214
33215
33216
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33210

def update!(**args)
  @end = args[:end] if args.key?(:end)
  @language_code = args[:language_code] if args.key?(:language_code)
  @locales = args[:locales] if args.key?(:locales)
  @probability = args[:probability] if args.key?(:probability)
  @start = args[:start] if args.key?(:start)
end