Class: Google::Apis::AiplatformV1::NlpSaftLanguageSpanSequence
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::NlpSaftLanguageSpanSequence
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Instance Attribute Summary collapse
-
#language_spans ⇒ Array<Google::Apis::AiplatformV1::NlpSaftLanguageSpan>
A sequence of LanguageSpan objects, each assigning a language to a subspan of the input.
-
#probability ⇒ Float
The probability of this sequence of LanguageSpans.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NlpSaftLanguageSpanSequence
constructor
A new instance of NlpSaftLanguageSpanSequence.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NlpSaftLanguageSpanSequence
Returns a new instance of NlpSaftLanguageSpanSequence.
33234 33235 33236 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33234 def initialize(**args) update!(**args) end |
Instance Attribute Details
#language_spans ⇒ Array<Google::Apis::AiplatformV1::NlpSaftLanguageSpan>
A sequence of LanguageSpan objects, each assigning a language to a subspan of
the input.
Corresponds to the JSON property languageSpans
33227 33228 33229 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33227 def language_spans @language_spans end |
#probability ⇒ Float
The probability of this sequence of LanguageSpans.
Corresponds to the JSON property probability
33232 33233 33234 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33232 def probability @probability end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33239 33240 33241 33242 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33239 def update!(**args) @language_spans = args[:language_spans] if args.key?(:language_spans) @probability = args[:probability] if args.key?(:probability) end |