Class: Google::Apis::AiplatformV1::CloudAiLargeModelsVisionGenerateVideoExperiments

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Experimental parameters for video generation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CloudAiLargeModelsVisionGenerateVideoExperiments

Returns a new instance of CloudAiLargeModelsVisionGenerateVideoExperiments.



145
146
147
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 145

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#anchor_last_frameBoolean Also known as: anchor_last_frame?

Optional. If true, anchors the last frame in video generation by generating a custom border mask. Corresponds to the JSON property anchorLastFrame

Returns:

  • (Boolean)


33
34
35
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33

def anchor_last_frame
  @anchor_last_frame
end

#cfg_scaleFloat

CFG scale for video-transform, perf-generation, a2v, video-textures models. Corresponds to the JSON property cfgScale

Returns:

  • (Float)


39
40
41
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39

def cfg_scale
  @cfg_scale
end

#codecString

Optional. Video codec to use for output. Corresponds to the JSON property codec

Returns:

  • (String)


44
45
46
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44

def codec
  @codec
end

#color_alignmentGoogle::Apis::AiplatformV1::CloudAiLargeModelsVisionGenerateVideoExperimentsColorAlignmentConfig

Configuration for color alignment. Corresponds to the JSON property colorAlignment



49
50
51
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 49

def color_alignment
  @color_alignment
end

#conditioning_framesArray<Google::Apis::AiplatformV1::CloudAiLargeModelsVisionGenerateVideoExperimentsConditioningFrame>

Conditioning frames for veo experimental models ONLY, not to be confused with keyframes (ID:31) in GenerateVideoRequest. Corresponds to the JSON property conditioningFrames



55
56
57
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 55

def conditioning_frames
  @conditioning_frames
end

#custom_parametersHash<String,Object>

Generic key-value pairs for experimental parameters. This allows adding new parameters without changing the dataplane binary. Corresponds to the JSON property customParameters

Returns:

  • (Hash<String,Object>)


61
62
63
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 61

def custom_parameters
  @custom_parameters
end

#exr_color_space_overrideString

Optional. Colorspace to be used for all EXR inputs. Corresponds to the JSON property exrColorSpaceOverride

Returns:

  • (String)


66
67
68
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 66

def exr_color_space_override
  @exr_color_space_override
end

#human_poseGoogle::Apis::AiplatformV1::CloudAiLargeModelsVisionHumanPose

Human pose parameters for Pose Control Corresponds to the JSON property humanPose



71
72
73
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 71

def human_pose
  @human_pose
end

#model_nameString

Model names, as defined in: xyz Corresponds to the JSON property modelName

Returns:

  • (String)


76
77
78
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 76

def model_name
  @model_name
end

#num_diffusion_stepsFixnum

Number of diffusion steps Corresponds to the JSON property numDiffusionSteps

Returns:

  • (Fixnum)


81
82
83
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 81

def num_diffusion_steps
  @num_diffusion_steps
end

#omni_rewriterGoogle::Apis::AiplatformV1::CloudAiLargeModelsVisionGenerateVideoExperimentsOmniRewriterConfig

Configuration for Omni Rewriter. Corresponds to the JSON property omniRewriter



86
87
88
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 86

def omni_rewriter
  @omni_rewriter
end

#original_request_jsonString

The original REST API request JSON sent by the user, in the instances/ parameters format. Preserved for saving alongside output artifacts so users can reproduce their requests. This field is populated by the API handler and is not user-settable. Corresponds to the JSON property originalRequestJson

Returns:

  • (String)


94
95
96
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 94

def original_request_json
  @original_request_json
end

#prompt_inputsGoogle::Apis::AiplatformV1::CloudAiLargeModelsVisionPromptInputs

"Direct" prompting for Experimental Video Generation. These will be sent directly to the LDM without being rewritten. Corresponds to the JSON property promptInputs



100
101
102
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 100

def prompt_inputs
  @prompt_inputs
end

#request_origin_tagString

Optional tag for tracking the source of this request. Allowed values: "colab", "comfyui", "curl", "flowresearch", "vertexstudio". Unrecognized tags are recorded as "unknown" in metrics. Tags do not affect video generation behavior. Up to 16 characters, ASCII alphanumeric, hyphens, and underscores only. Corresponds to the JSON property requestOriginTag

Returns:

  • (String)


108
109
110
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 108

def request_origin_tag
  @request_origin_tag
end

#scheduling_configGoogle::Apis::AiplatformV1::CloudAiLargeModelsVisionGenerateVideoExperimentsVeSchedulingConfig

Scheduling configuration for Veo Experimental. Corresponds to the JSON property schedulingConfig



113
114
115
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 113

def scheduling_config
  @scheduling_config
end

#seamlessGoogle::Apis::AiplatformV1::CloudAiLargeModelsVisionSeamless

Parameters for seamless (edge-continuous) video generation, enabling temporal looping and/or spatial tessellation. Corresponds to the JSON property seamless



119
120
121
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 119

def seamless
  @seamless
end

#spatial_alignmentGoogle::Apis::AiplatformV1::CloudAiLargeModelsVisionGenerateVideoExperimentsSpatialAlignmentConfig

Configuration for spatial alignment. Corresponds to the JSON property spatialAlignment



124
125
126
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 124

def spatial_alignment
  @spatial_alignment
end

#truncate_input_videoBoolean Also known as: truncate_input_video?

If true (default), truncate input videos that exceed the model's maximum frame count by applying a frame_selection_config to video_file inputs. Set to false to preserve the existing fail-fast behavior. Corresponds to the JSON property truncateInputVideo

Returns:

  • (Boolean)


131
132
133
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 131

def truncate_input_video
  @truncate_input_video
end

#video_transform_mask_gcs_uriString

GCS URI of the grayscale video mask for Differential Diffusion. Maps to sdedit_video_tmax_scale_map Corresponds to the JSON property videoTransformMaskGcsUri

Returns:

  • (String)


138
139
140
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 138

def video_transform_mask_gcs_uri
  @video_transform_mask_gcs_uri
end

#video_transform_strengthFloat

SDEdit: Scalar noise level (0.0 to 1.0) Maps to sdedit_tmax Corresponds to the JSON property videoTransformStrength

Returns:

  • (Float)


143
144
145
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 143

def video_transform_strength
  @video_transform_strength
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 150

def update!(**args)
  @anchor_last_frame = args[:anchor_last_frame] if args.key?(:anchor_last_frame)
  @cfg_scale = args[:cfg_scale] if args.key?(:cfg_scale)
  @codec = args[:codec] if args.key?(:codec)
  @color_alignment = args[:color_alignment] if args.key?(:color_alignment)
  @conditioning_frames = args[:conditioning_frames] if args.key?(:conditioning_frames)
  @custom_parameters = args[:custom_parameters] if args.key?(:custom_parameters)
  @exr_color_space_override = args[:exr_color_space_override] if args.key?(:exr_color_space_override)
  @human_pose = args[:human_pose] if args.key?(:human_pose)
  @model_name = args[:model_name] if args.key?(:model_name)
  @num_diffusion_steps = args[:num_diffusion_steps] if args.key?(:num_diffusion_steps)
  @omni_rewriter = args[:omni_rewriter] if args.key?(:omni_rewriter)
  @original_request_json = args[:original_request_json] if args.key?(:original_request_json)
  @prompt_inputs = args[:prompt_inputs] if args.key?(:prompt_inputs)
  @request_origin_tag = args[:request_origin_tag] if args.key?(:request_origin_tag)
  @scheduling_config = args[:scheduling_config] if args.key?(:scheduling_config)
  @seamless = args[:seamless] if args.key?(:seamless)
  @spatial_alignment = args[:spatial_alignment] if args.key?(:spatial_alignment)
  @truncate_input_video = args[:truncate_input_video] if args.key?(:truncate_input_video)
  @video_transform_mask_gcs_uri = args[:video_transform_mask_gcs_uri] if args.key?(:video_transform_mask_gcs_uri)
  @video_transform_strength = args[:video_transform_strength] if args.key?(:video_transform_strength)
end