Class: Google::Apis::AiplatformV1::CloudAiLargeModelsVisionGenerateVideoExperiments
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::CloudAiLargeModelsVisionGenerateVideoExperiments
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Experimental parameters for video generation.
Instance Attribute Summary collapse
-
#conditioning_frames ⇒ Array<Google::Apis::AiplatformV1::CloudAiLargeModelsVisionGenerateVideoExperimentsConditioningFrame>
Conditioning frames for veo experimental models ONLY, not to be confused with keyframes (ID:31) in GenerateVideoRequest.
-
#human_pose ⇒ Google::Apis::AiplatformV1::CloudAiLargeModelsVisionHumanPose
Human pose parameters for Pose Control Corresponds to the JSON property
humanPose. -
#model_name ⇒ String
Model names, as defined in: xyz Corresponds to the JSON property
modelName. -
#num_diffusion_steps ⇒ Fixnum
Number of diffusion steps Corresponds to the JSON property
numDiffusionSteps. -
#prompt_inputs ⇒ Google::Apis::AiplatformV1::CloudAiLargeModelsVisionPromptInputs
"Direct" prompting for Experimental Video Generation.
-
#request_origin_tag ⇒ String
Optional tag for tracking the source of this request.
-
#video_transform_mask_gcs_uri ⇒ String
GCS URI of the grayscale video mask for Differential Diffusion.
-
#video_transform_strength ⇒ Float
SDEdit: Scalar noise level (0.0 to 1.0) Maps to sdedit_tmax Corresponds to the JSON property
videoTransformStrength.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CloudAiLargeModelsVisionGenerateVideoExperiments
constructor
A new instance of CloudAiLargeModelsVisionGenerateVideoExperiments.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CloudAiLargeModelsVisionGenerateVideoExperiments
Returns a new instance of CloudAiLargeModelsVisionGenerateVideoExperiments.
75 76 77 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 75 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conditioning_frames ⇒ Array<Google::Apis::AiplatformV1::CloudAiLargeModelsVisionGenerateVideoExperimentsConditioningFrame>
Conditioning frames for veo experimental models ONLY, not to be confused with
keyframes (ID:31) in GenerateVideoRequest.
Corresponds to the JSON property conditioningFrames
33 34 35 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33 def conditioning_frames @conditioning_frames end |
#human_pose ⇒ Google::Apis::AiplatformV1::CloudAiLargeModelsVisionHumanPose
Human pose parameters for Pose Control
Corresponds to the JSON property humanPose
38 39 40 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38 def human_pose @human_pose end |
#model_name ⇒ String
Model names, as defined in: xyz
Corresponds to the JSON property modelName
43 44 45 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 43 def model_name @model_name end |
#num_diffusion_steps ⇒ Fixnum
Number of diffusion steps
Corresponds to the JSON property numDiffusionSteps
48 49 50 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48 def num_diffusion_steps @num_diffusion_steps end |
#prompt_inputs ⇒ Google::Apis::AiplatformV1::CloudAiLargeModelsVisionPromptInputs
"Direct" prompting for Experimental Video Generation. These will be sent
directly to the LDM without being rewritten.
Corresponds to the JSON property promptInputs
54 55 56 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 54 def prompt_inputs @prompt_inputs end |
#request_origin_tag ⇒ String
Optional tag for tracking the source of this request. Allowed values: "colab",
"comfyui", "curl", "flowresearch", "vertexstudio". Unrecognized tags are
recorded as "unknown" in metrics. Tags do not affect video generation behavior.
Up to 16 characters, ASCII alphanumeric, hyphens, and underscores only.
Corresponds to the JSON property requestOriginTag
62 63 64 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 62 def request_origin_tag @request_origin_tag end |
#video_transform_mask_gcs_uri ⇒ String
GCS URI of the grayscale video mask for Differential Diffusion. Maps to
sdedit_video_tmax_scale_map
Corresponds to the JSON property videoTransformMaskGcsUri
68 69 70 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 68 def video_transform_mask_gcs_uri @video_transform_mask_gcs_uri end |
#video_transform_strength ⇒ Float
SDEdit: Scalar noise level (0.0 to 1.0) Maps to sdedit_tmax
Corresponds to the JSON property videoTransformStrength
73 74 75 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 73 def video_transform_strength @video_transform_strength end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
80 81 82 83 84 85 86 87 88 89 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 80 def update!(**args) @conditioning_frames = args[:conditioning_frames] if args.key?(:conditioning_frames) @human_pose = args[:human_pose] if args.key?(:human_pose) @model_name = args[:model_name] if args.key?(:model_name) @num_diffusion_steps = args[:num_diffusion_steps] if args.key?(:num_diffusion_steps) @prompt_inputs = args[:prompt_inputs] if args.key?(:prompt_inputs) @request_origin_tag = args[:request_origin_tag] if args.key?(:request_origin_tag) @video_transform_mask_gcs_uri = args[:video_transform_mask_gcs_uri] if args.key?(:video_transform_mask_gcs_uri) @video_transform_strength = args[:video_transform_strength] if args.key?(:video_transform_strength) end |