Class: Google::Apis::AiplatformV1::CloudAiLargeModelsVisionGenerateVideoExperimentsConditioningFrame
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::CloudAiLargeModelsVisionGenerateVideoExperimentsConditioningFrame
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Instance Attribute Summary collapse
-
#frame_num ⇒ Fixnum
The index of the frame, starts with zero and must be a multiple of 8.
-
#image ⇒ Google::Apis::AiplatformV1::CloudAiLargeModelsVisionGenerateVideoRequestImage
The image bytes or Cloud Storage URI to make the prediction on.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CloudAiLargeModelsVisionGenerateVideoExperimentsConditioningFrame
constructor
A new instance of CloudAiLargeModelsVisionGenerateVideoExperimentsConditioningFrame.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CloudAiLargeModelsVisionGenerateVideoExperimentsConditioningFrame
Returns a new instance of CloudAiLargeModelsVisionGenerateVideoExperimentsConditioningFrame.
106 107 108 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 106 def initialize(**args) update!(**args) end |
Instance Attribute Details
#frame_num ⇒ Fixnum
The index of the frame, starts with zero and must be a multiple of 8.
Corresponds to the JSON property frameNum
99 100 101 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 99 def frame_num @frame_num end |
#image ⇒ Google::Apis::AiplatformV1::CloudAiLargeModelsVisionGenerateVideoRequestImage
The image bytes or Cloud Storage URI to make the prediction on.
Corresponds to the JSON property image
104 105 106 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 104 def image @image end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
111 112 113 114 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 111 def update!(**args) @frame_num = args[:frame_num] if args.key?(:frame_num) @image = args[:image] if args.key?(:image) end |