Class: Google::Apis::AiplatformV1::CloudAiLargeModelsVisionHumanPose
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::CloudAiLargeModelsVisionHumanPose
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Instance Attribute Summary collapse
-
#body_landmarks_gcs_uri ⇒ String
GCS URI of the human pose video to condition video generation.
-
#face_landmarks_gcs_uri ⇒ String
GCS URI of the face landmarks video to condition video generation.
-
#perf_mesh_gcs_uri ⇒ String
GCS URI of the performance mesh to condition video generation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CloudAiLargeModelsVisionHumanPose
constructor
A new instance of CloudAiLargeModelsVisionHumanPose.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CloudAiLargeModelsVisionHumanPose
Returns a new instance of CloudAiLargeModelsVisionHumanPose.
326 327 328 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 326 def initialize(**args) update!(**args) end |
Instance Attribute Details
#body_landmarks_gcs_uri ⇒ String
GCS URI of the human pose video to condition video generation.
Corresponds to the JSON property bodyLandmarksGcsUri
314 315 316 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 314 def body_landmarks_gcs_uri @body_landmarks_gcs_uri end |
#face_landmarks_gcs_uri ⇒ String
GCS URI of the face landmarks video to condition video generation.
Corresponds to the JSON property faceLandmarksGcsUri
319 320 321 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 319 def face_landmarks_gcs_uri @face_landmarks_gcs_uri end |
#perf_mesh_gcs_uri ⇒ String
GCS URI of the performance mesh to condition video generation.
Corresponds to the JSON property perfMeshGcsUri
324 325 326 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 324 def perf_mesh_gcs_uri @perf_mesh_gcs_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
331 332 333 334 335 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 331 def update!(**args) @body_landmarks_gcs_uri = args[:body_landmarks_gcs_uri] if args.key?(:body_landmarks_gcs_uri) @face_landmarks_gcs_uri = args[:face_landmarks_gcs_uri] if args.key?(:face_landmarks_gcs_uri) @perf_mesh_gcs_uri = args[:perf_mesh_gcs_uri] if args.key?(:perf_mesh_gcs_uri) end |