Class: Google::Apis::AiplatformV1::CloudAiLargeModelsVisionHumanPose
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::CloudAiLargeModelsVisionHumanPose
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Instance Attribute Summary collapse
-
#body_landmarks_gcs_uri ⇒ String
GCS URI of the human pose video to condition video generation.
-
#face_landmarks_gcs_uri ⇒ String
GCS URI of the face landmarks video to condition video generation.
-
#perf_mesh_gcs_uri ⇒ String
GCS URI of the performance mesh to condition video generation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CloudAiLargeModelsVisionHumanPose
constructor
A new instance of CloudAiLargeModelsVisionHumanPose.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CloudAiLargeModelsVisionHumanPose
Returns a new instance of CloudAiLargeModelsVisionHumanPose.
257 258 259 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 257 def initialize(**args) update!(**args) end |
Instance Attribute Details
#body_landmarks_gcs_uri ⇒ String
GCS URI of the human pose video to condition video generation.
Corresponds to the JSON property bodyLandmarksGcsUri
245 246 247 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 245 def body_landmarks_gcs_uri @body_landmarks_gcs_uri end |
#face_landmarks_gcs_uri ⇒ String
GCS URI of the face landmarks video to condition video generation.
Corresponds to the JSON property faceLandmarksGcsUri
250 251 252 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 250 def face_landmarks_gcs_uri @face_landmarks_gcs_uri end |
#perf_mesh_gcs_uri ⇒ String
GCS URI of the performance mesh to condition video generation.
Corresponds to the JSON property perfMeshGcsUri
255 256 257 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 255 def perf_mesh_gcs_uri @perf_mesh_gcs_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
262 263 264 265 266 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 262 def update!(**args) @body_landmarks_gcs_uri = args[:body_landmarks_gcs_uri] if args.key?(:body_landmarks_gcs_uri) @face_landmarks_gcs_uri = args[:face_landmarks_gcs_uri] if args.key?(:face_landmarks_gcs_uri) @perf_mesh_gcs_uri = args[:perf_mesh_gcs_uri] if args.key?(:perf_mesh_gcs_uri) end |