Class: Google::Apis::AiplatformV1::CloudAiLargeModelsVisionHumanPose
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::CloudAiLargeModelsVisionHumanPose
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Instance Attribute Summary collapse
-
#body_landmarks_gcs_uri ⇒ String
GCS URI of the human pose video to condition video generation.
-
#face_landmarks_gcs_uri ⇒ String
GCS URI of the face landmarks video to condition video generation.
-
#perf_mesh_gcs_uri ⇒ String
GCS URI of the performance mesh to condition video generation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CloudAiLargeModelsVisionHumanPose
constructor
A new instance of CloudAiLargeModelsVisionHumanPose.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CloudAiLargeModelsVisionHumanPose
Returns a new instance of CloudAiLargeModelsVisionHumanPose.
248 249 250 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 248 def initialize(**args) update!(**args) end |
Instance Attribute Details
#body_landmarks_gcs_uri ⇒ String
GCS URI of the human pose video to condition video generation.
Corresponds to the JSON property bodyLandmarksGcsUri
236 237 238 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 236 def body_landmarks_gcs_uri @body_landmarks_gcs_uri end |
#face_landmarks_gcs_uri ⇒ String
GCS URI of the face landmarks video to condition video generation.
Corresponds to the JSON property faceLandmarksGcsUri
241 242 243 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 241 def face_landmarks_gcs_uri @face_landmarks_gcs_uri end |
#perf_mesh_gcs_uri ⇒ String
GCS URI of the performance mesh to condition video generation.
Corresponds to the JSON property perfMeshGcsUri
246 247 248 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 246 def perf_mesh_gcs_uri @perf_mesh_gcs_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
253 254 255 256 257 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 253 def update!(**args) @body_landmarks_gcs_uri = args[:body_landmarks_gcs_uri] if args.key?(:body_landmarks_gcs_uri) @face_landmarks_gcs_uri = args[:face_landmarks_gcs_uri] if args.key?(:face_landmarks_gcs_uri) @perf_mesh_gcs_uri = args[:perf_mesh_gcs_uri] if args.key?(:perf_mesh_gcs_uri) end |