Class: Google::Apis::AiplatformV1::CloudAiLargeModelsVisionRaiInfoDetectedLabelsEntity
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::CloudAiLargeModelsVisionRaiInfoDetectedLabelsEntity
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The properties for a detected entity from the rai signal.
Instance Attribute Summary collapse
-
#bounding_box ⇒ Google::Apis::AiplatformV1::CloudAiLargeModelsVisionRaiInfoDetectedLabelsBoundingBox
An integer bounding box of original pixels of the image for the detected labels.
-
#description ⇒ String
Description of the label Corresponds to the JSON property
description. -
#iou_score ⇒ Float
The intersection ratio between the detection bounding box and the mask.
-
#mid ⇒ String
MID of the label Corresponds to the JSON property
mid. -
#score ⇒ Float
Confidence score of the label Corresponds to the JSON property
score.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CloudAiLargeModelsVisionRaiInfoDetectedLabelsEntity
constructor
A new instance of CloudAiLargeModelsVisionRaiInfoDetectedLabelsEntity.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CloudAiLargeModelsVisionRaiInfoDetectedLabelsEntity
Returns a new instance of CloudAiLargeModelsVisionRaiInfoDetectedLabelsEntity.
432 433 434 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 432 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bounding_box ⇒ Google::Apis::AiplatformV1::CloudAiLargeModelsVisionRaiInfoDetectedLabelsBoundingBox
An integer bounding box of original pixels of the image for the detected
labels.
Corresponds to the JSON property boundingBox
410 411 412 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 410 def bounding_box @bounding_box end |
#description ⇒ String
Description of the label
Corresponds to the JSON property description
415 416 417 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 415 def description @description end |
#iou_score ⇒ Float
The intersection ratio between the detection bounding box and the mask.
Corresponds to the JSON property iouScore
420 421 422 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 420 def iou_score @iou_score end |
#mid ⇒ String
MID of the label
Corresponds to the JSON property mid
425 426 427 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 425 def mid @mid end |
#score ⇒ Float
Confidence score of the label
Corresponds to the JSON property score
430 431 432 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 430 def score @score end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
437 438 439 440 441 442 443 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 437 def update!(**args) @bounding_box = args[:bounding_box] if args.key?(:bounding_box) @description = args[:description] if args.key?(:description) @iou_score = args[:iou_score] if args.key?(:iou_score) @mid = args[:mid] if args.key?(:mid) @score = args[:score] if args.key?(:score) end |