Class: Google::Apis::AiplatformV1::CloudAiLargeModelsVisionSeamless
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::CloudAiLargeModelsVisionSeamless
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Instance Attribute Summary collapse
-
#loop ⇒ Boolean
(also: #loop?)
If true, the generated video will be loopable (seamless time looping).
-
#tessellate_horizontal ⇒ Boolean
(also: #tessellate_horizontal?)
If true, the generated video will be tessellatable as a horizontal tessellation.
-
#tessellate_vertical ⇒ Boolean
(also: #tessellate_vertical?)
If true, the generated video will be tessellatable as a vertical tessellation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CloudAiLargeModelsVisionSeamless
constructor
A new instance of CloudAiLargeModelsVisionSeamless.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CloudAiLargeModelsVisionSeamless
Returns a new instance of CloudAiLargeModelsVisionSeamless.
752 753 754 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 752 def initialize(**args) update!(**args) end |
Instance Attribute Details
#loop ⇒ Boolean Also known as: loop?
If true, the generated video will be loopable (seamless time looping).
Corresponds to the JSON property loop
736 737 738 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 736 def loop @loop end |
#tessellate_horizontal ⇒ Boolean Also known as: tessellate_horizontal?
If true, the generated video will be tessellatable as a horizontal
tessellation.
Corresponds to the JSON property tessellateHorizontal
743 744 745 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 743 def tessellate_horizontal @tessellate_horizontal end |
#tessellate_vertical ⇒ Boolean Also known as: tessellate_vertical?
If true, the generated video will be tessellatable as a vertical tessellation.
Corresponds to the JSON property tessellateVertical
749 750 751 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 749 def tessellate_vertical @tessellate_vertical end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
757 758 759 760 761 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 757 def update!(**args) @loop = args[:loop] if args.key?(:loop) @tessellate_horizontal = args[:tessellate_horizontal] if args.key?(:tessellate_horizontal) @tessellate_vertical = args[:tessellate_vertical] if args.key?(:tessellate_vertical) end |