Class: Google::Apis::AiplatformV1::CloudAiNlLlmProtoServiceCandidate

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CloudAiNlLlmProtoServiceCandidate

Returns a new instance of CloudAiNlLlmProtoServiceCandidate.



494
495
496
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 494

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#citation_metadataGoogle::Apis::AiplatformV1::CloudAiNlLlmProtoServiceCitationMetadata

A collection of source attributions for a piece of content. Corresponds to the JSON property citationMetadata



460
461
462
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 460

def 
  @citation_metadata
end

#contentGoogle::Apis::AiplatformV1::CloudAiNlLlmProtoServiceContent

The content of a single message from a participant. Corresponds to the JSON property content



465
466
467
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 465

def content
  @content
end

#finish_messageString

A string that describes the filtering behavior in more detail. Only filled when reason is set. Corresponds to the JSON property finishMessage

Returns:

  • (String)


471
472
473
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 471

def finish_message
  @finish_message
end

#finish_reasonString

The reason why the model stopped generating tokens. Corresponds to the JSON property finishReason

Returns:

  • (String)


476
477
478
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 476

def finish_reason
  @finish_reason
end

#grounding_metadataGoogle::Apis::AiplatformV1::LearningGenaiRootGroundingMetadata

Grounding metadata. Combine with the facts list from response to generate grounding citations for this choice. Corresponds to the JSON property groundingMetadata



482
483
484
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 482

def 
  @grounding_metadata
end

#indexFixnum

Index of the candidate. Corresponds to the JSON property index

Returns:

  • (Fixnum)


487
488
489
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 487

def index
  @index
end

#safety_ratingsArray<Google::Apis::AiplatformV1::CloudAiNlLlmProtoServiceSafetyRating>

Safety ratings of the generated content. Corresponds to the JSON property safetyRatings



492
493
494
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 492

def safety_ratings
  @safety_ratings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



499
500
501
502
503
504
505
506
507
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 499

def update!(**args)
  @citation_metadata = args[:citation_metadata] if args.key?(:citation_metadata)
  @content = args[:content] if args.key?(:content)
  @finish_message = args[:finish_message] if args.key?(:finish_message)
  @finish_reason = args[:finish_reason] if args.key?(:finish_reason)
  @grounding_metadata = args[:grounding_metadata] if args.key?(:grounding_metadata)
  @index = args[:index] if args.key?(:index)
  @safety_ratings = args[:safety_ratings] if args.key?(:safety_ratings)
end