Class: Google::Apis::AiplatformV1::CloudAiNlLlmProtoServiceRaiSignalInfluentialTerm

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The influential term that could potentially block the response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CloudAiNlLlmProtoServiceRaiSignalInfluentialTerm

Returns a new instance of CloudAiNlLlmProtoServiceRaiSignalInfluentialTerm.



1160
1161
1162
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1160

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#begin_offsetFixnum

The beginning offset of the influential term. Corresponds to the JSON property beginOffset

Returns:

  • (Fixnum)


1143
1144
1145
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1143

def begin_offset
  @begin_offset
end

#confidenceFloat

The confidence score of the influential term. Corresponds to the JSON property confidence

Returns:

  • (Float)


1148
1149
1150
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1148

def confidence
  @confidence
end

#sourceString

The source of the influential term, prompt or response. Corresponds to the JSON property source

Returns:

  • (String)


1153
1154
1155
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1153

def source
  @source
end

#termString

The influential term. Corresponds to the JSON property term

Returns:

  • (String)


1158
1159
1160
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1158

def term
  @term
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1165
1166
1167
1168
1169
1170
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1165

def update!(**args)
  @begin_offset = args[:begin_offset] if args.key?(:begin_offset)
  @confidence = args[:confidence] if args.key?(:confidence)
  @source = args[:source] if args.key?(:source)
  @term = args[:term] if args.key?(:term)
end