Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Agent
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Agent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A Vertex agent contains instructions and configurations for the LLM to execute a certain task.
Instance Attribute Summary collapse
-
#base_agent ⇒ String
Required.
-
#base_environment ⇒ Object
Optional.
-
#created ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#id ⇒ String
Immutable.
-
#metadata ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#object ⇒ String
Output only.
-
#system_instruction ⇒ String
Optional.
-
#tools ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AgentTool>
Optional.
-
#updated ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Agent
constructor
A new instance of GoogleCloudAiplatformV1Agent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Agent
Returns a new instance of GoogleCloudAiplatformV1Agent.
1493 1494 1495 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1493 def initialize(**args) update!(**args) end |
Instance Attribute Details
#base_agent ⇒ String
Required. Immutable. The base agent for the agent. Supported values: *
antigravity-preview-05-2026 Immutable: UpdateAgent rejects a change,
including clearing it. The kind of agent this is gets derived from this field
when the agent is created and is recorded then; nothing recomputes it
afterwards, so a later change would leave the agent described as one kind and
behaving as another. Create a new agent instead.
Corresponds to the JSON property base_agent
1434 1435 1436 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1434 def base_agent @base_agent end |
#base_environment ⇒ Object
Optional. The base environment configuration for the agent. Valid types: * A
string value for the environment ID, or remote for the default. * A struct
value for the environment_config.
Corresponds to the JSON property base_environment
1441 1442 1443 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1441 def base_environment @base_environment end |
#created ⇒ String
Output only. The time the agent was created.
Corresponds to the JSON property created
1446 1447 1448 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1446 def created @created end |
#description ⇒ String
Optional. The description of the agent.
Corresponds to the JSON property description
1451 1452 1453 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1451 def description @description end |
#id ⇒ String
Immutable. The user-specified ID for the agent. This ID becomes the final
component of the agent resource name. If not provided, Vertex AI will generate
a value for this ID. The ID can be up to 63 characters and must match the
regular expression [a-z]([a-z0-9-]0,61[a-z0-9])?.
Corresponds to the JSON property id
1459 1460 1461 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1459 def id @id end |
#metadata ⇒ Hash<String,String>
Optional. The metadata for the agent.
Corresponds to the JSON property metadata
1464 1465 1466 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1464 def @metadata end |
#name ⇒ String
Identifier. The resource name of the agent. Format: projects/project/
locations/location/agents/agent`.
Corresponds to the JSON propertyname`
1470 1471 1472 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1470 def name @name end |
#object ⇒ String
Output only. The object type of the resource. For agents, the value is agent.
Corresponds to the JSON property object
1475 1476 1477 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1475 def object @object end |
#system_instruction ⇒ String
Optional. The instructions for the agent to follow. These instructions are
passed to the LLM as a system instruction.
Corresponds to the JSON property system_instruction
1481 1482 1483 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1481 def system_instruction @system_instruction end |
#tools ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AgentTool>
Optional. The tools available to the agent.
Corresponds to the JSON property tools
1486 1487 1488 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1486 def tools @tools end |
#updated ⇒ String
Output only. The time the agent was last updated.
Corresponds to the JSON property updated
1491 1492 1493 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1491 def updated @updated end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1498 def update!(**args) @base_agent = args[:base_agent] if args.key?(:base_agent) @base_environment = args[:base_environment] if args.key?(:base_environment) @created = args[:created] if args.key?(:created) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @metadata = args[:metadata] if args.key?(:metadata) @name = args[:name] if args.key?(:name) @object = args[:object] if args.key?(:object) @system_instruction = args[:system_instruction] if args.key?(:system_instruction) @tools = args[:tools] if args.key?(:tools) @updated = args[:updated] if args.key?(:updated) end |