Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Agent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A Vertex agent contains instructions and configurations for the LLM to execute a certain task.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Agent

Returns a new instance of GoogleCloudAiplatformV1Agent.



1489
1490
1491
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1489

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_agentString

Required. The base agent for the agent. Supported values: * antigravity- preview-05-2026 Corresponds to the JSON property base_agent

Returns:

  • (String)


1430
1431
1432
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1430

def base_agent
  @base_agent
end

#base_environmentObject

Optional. The base environment configuration for the agent. Valid types: * A string value for the environment ID, or remote for the default. * A struct value for the environment_config. Corresponds to the JSON property base_environment

Returns:

  • (Object)


1437
1438
1439
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1437

def base_environment
  @base_environment
end

#createdString

Output only. The time the agent was created. Corresponds to the JSON property created

Returns:

  • (String)


1442
1443
1444
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1442

def created
  @created
end

#descriptionString

Optional. The description of the agent. Corresponds to the JSON property description

Returns:

  • (String)


1447
1448
1449
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1447

def description
  @description
end

#idString

Immutable. The user-specified ID for the agent. This ID becomes the final component of the agent resource name. If not provided, Vertex AI will generate a value for this ID. The ID can be up to 63 characters and must match the regular expression [a-z]([a-z0-9-]0,61[a-z0-9])?. Corresponds to the JSON property id

Returns:

  • (String)


1455
1456
1457
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1455

def id
  @id
end

#metadataHash<String,String>

Optional. The metadata for the agent. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,String>)


1460
1461
1462
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1460

def 
  @metadata
end

#nameString

Identifier. The resource name of the agent. Format: projects/project/ locations/location/agents/agent`. Corresponds to the JSON propertyname`

Returns:

  • (String)


1466
1467
1468
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1466

def name
  @name
end

#objectString

Output only. The object type of the resource. For agents, the value is agent. Corresponds to the JSON property object

Returns:

  • (String)


1471
1472
1473
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1471

def object
  @object
end

#system_instructionString

Optional. The instructions for the agent to follow. These instructions are passed to the LLM as a system instruction. Corresponds to the JSON property system_instruction

Returns:

  • (String)


1477
1478
1479
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1477

def system_instruction
  @system_instruction
end

#toolsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AgentTool>

Optional. The tools available to the agent. Corresponds to the JSON property tools



1482
1483
1484
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1482

def tools
  @tools
end

#updatedString

Output only. The time the agent was last updated. Corresponds to the JSON property updated

Returns:

  • (String)


1487
1488
1489
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1487

def updated
  @updated
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
1506
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1494

def update!(**args)
  @base_agent = args[:base_agent] if args.key?(:base_agent)
  @base_environment = args[:base_environment] if args.key?(:base_environment)
  @created = args[:created] if args.key?(:created)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @object = args[:object] if args.key?(:object)
  @system_instruction = args[:system_instruction] if args.key?(:system_instruction)
  @tools = args[:tools] if args.key?(:tools)
  @updated = args[:updated] if args.key?(:updated)
end