Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AgentTool

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A tool provides a list of actions available to the Agent during the process of executing a task.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1AgentTool

Returns a new instance of GoogleCloudAiplatformV1AgentTool.



1286
1287
1288
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1286

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#headersHash<String,String>

Optional. The headers for the MCP server, such as for authentication. Only applicable when type is mcp_server. Corresponds to the JSON property headers

Returns:

  • (Hash<String,String>)


1266
1267
1268
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1266

def headers
  @headers
end

#nameString

Optional. The name of the MCP server. Only applicable when type is mcp_server. Corresponds to the JSON property name

Returns:

  • (String)


1272
1273
1274
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1272

def name
  @name
end

#typeString

Required. The type of the tool. Supported types: * code_execution * filesystem * google_search * mcp_server * url_context Corresponds to the JSON property type

Returns:

  • (String)


1278
1279
1280
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1278

def type
  @type
end

#urlString

Optional. The URL for the MCP server endpoint. Only applicable when type is mcp_server. Corresponds to the JSON property url

Returns:

  • (String)


1284
1285
1286
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1284

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1291
1292
1293
1294
1295
1296
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1291

def update!(**args)
  @headers = args[:headers] if args.key?(:headers)
  @name = args[:name] if args.key?(:name)
  @type = args[:type] if args.key?(:type)
  @url = args[:url] if args.key?(:url)
end