Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Annotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Used to assign specific AnnotationSpec to a particular area of a DataItem or the whole part of the DataItem.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Annotation

Returns a new instance of GoogleCloudAiplatformV1Annotation.



1442
1443
1444
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1442

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotation_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1UserActionReference

References an API call. It contains more information about long running operation and Jobs that are triggered by the API call. Corresponds to the JSON property annotationSource



1388
1389
1390
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1388

def annotation_source
  @annotation_source
end

#create_timeString

Output only. Timestamp when this Annotation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1393
1394
1395
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1393

def create_time
  @create_time
end

#etagString

Optional. Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


1399
1400
1401
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1399

def etag
  @etag
end

#labelsHash<String,String>

Optional. The labels with user-defined metadata to organize your Annotations. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. No more than 64 user labels can be associated with one Annotation(System labels are excluded). See https://goo. gl/xmQnxf for more information and examples of labels. System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable. Following system labels exist for each Annotation: * "aiplatform.googleapis. com/annotation_set_name": optional, name of the UI's annotation set this Annotation belongs to. If not set, the Annotation is not visible in the UI. * " aiplatform.googleapis.com/payload_schema": output only, its value is the payload_schema's title. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1415
1416
1417
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1415

def labels
  @labels
end

#nameString

Output only. Resource name of the Annotation. Corresponds to the JSON property name

Returns:

  • (String)


1420
1421
1422
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1420

def name
  @name
end

#payloadObject

Required. The schema of the payload can be found in payload_schema. Corresponds to the JSON property payload

Returns:

  • (Object)


1425
1426
1427
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1425

def payload
  @payload
end

#payload_schema_uriString

Required. Google Cloud Storage URI points to a YAML file describing payload. The schema is defined as an OpenAPI 3.0.2 Schema Object. The schema files that can be used here are found in gs://google-cloud-aiplatform/ schema/dataset/annotation/, note that the chosen schema must be consistent with the parent Dataset's metadata. Corresponds to the JSON property payloadSchemaUri

Returns:

  • (String)


1435
1436
1437
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1435

def payload_schema_uri
  @payload_schema_uri
end

#update_timeString

Output only. Timestamp when this Annotation was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


1440
1441
1442
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1440

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1447

def update!(**args)
  @annotation_source = args[:annotation_source] if args.key?(:annotation_source)
  @create_time = args[:create_time] if args.key?(:create_time)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @payload = args[:payload] if args.key?(:payload)
  @payload_schema_uri = args[:payload_schema_uri] if args.key?(:payload_schema_uri)
  @update_time = args[:update_time] if args.key?(:update_time)
end