Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Artifact

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Instance of a general artifact.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Artifact

Returns a new instance of GoogleCloudAiplatformV1Artifact.



1332
1333
1334
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1332

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this Artifact was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1258
1259
1260
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1258

def create_time
  @create_time
end

#descriptionString

Description of the Artifact Corresponds to the JSON property description

Returns:

  • (String)


1263
1264
1265
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1263

def description
  @description
end

#display_nameString

User provided display name of the Artifact. May be up to 128 Unicode characters. Corresponds to the JSON property displayName

Returns:

  • (String)


1269
1270
1271
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1269

def display_name
  @display_name
end

#etagString

An eTag used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


1275
1276
1277
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1275

def etag
  @etag
end

#labelsHash<String,String>

The labels with user-defined metadata to organize your Artifacts. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. No more than 64 user labels can be associated with one Artifact (System labels are excluded). Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1284
1285
1286
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1284

def labels
  @labels
end

#metadataHash<String,Object>

Properties of the Artifact. Top level metadata keys' heading and trailing spaces will be trimmed. The size of this field should not exceed 200KB. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,Object>)


1290
1291
1292
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1290

def 
  @metadata
end

#nameString

Output only. The resource name of the Artifact. Corresponds to the JSON property name

Returns:

  • (String)


1295
1296
1297
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1295

def name
  @name
end

#schema_titleString

The title of the schema describing the metadata. Schema title and version is expected to be registered in earlier Create Schema calls. And both are used together as unique identifiers to identify schemas within the local metadata store. Corresponds to the JSON property schemaTitle

Returns:

  • (String)


1303
1304
1305
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1303

def schema_title
  @schema_title
end

#schema_versionString

The version of the schema in schema_name to use. Schema title and version is expected to be registered in earlier Create Schema calls. And both are used together as unique identifiers to identify schemas within the local metadata store. Corresponds to the JSON property schemaVersion

Returns:

  • (String)


1311
1312
1313
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1311

def schema_version
  @schema_version
end

#stateString

The state of this Artifact. This is a property of the Artifact, and does not imply or capture any ongoing process. This property is managed by clients ( such as Vertex AI Pipelines), and the system does not prescribe or check the validity of state transitions. Corresponds to the JSON property state

Returns:

  • (String)


1319
1320
1321
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1319

def state
  @state
end

#update_timeString

Output only. Timestamp when this Artifact was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


1324
1325
1326
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1324

def update_time
  @update_time
end

#uriString

The uniform resource identifier of the artifact file. May be empty if there is no actual artifact file. Corresponds to the JSON property uri

Returns:

  • (String)


1330
1331
1332
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1330

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1337
1338
1339
1340
1341
1342
1343
1344
1345
1346
1347
1348
1349
1350
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1337

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @schema_title = args[:schema_title] if args.key?(:schema_title)
  @schema_version = args[:schema_version] if args.key?(:schema_version)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
  @uri = args[:uri] if args.key?(:uri)
end