Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AsyncQueryReasoningEngineRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for ReasoningEngineExecutionService.AsyncQueryReasoningEngine.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1AsyncQueryReasoningEngineRequest

Returns a new instance of GoogleCloudAiplatformV1AsyncQueryReasoningEngineRequest.



1577
1578
1579
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1577

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#input_gcs_uriString

Optional. Input Cloud Storage URI for the Async query. If you are not bringing your own container (BYOC), the content of the file should be a JSON object with an input field matching the input field of QueryReasoningEngineRequest (e.g. "input": ` "user_id": "hello", "message": "$QUERY"`). For BYOC, the content of the file depends on the the agent application. Corresponds to the JSON property inputGcsUri

Returns:

  • (String)


1569
1570
1571
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1569

def input_gcs_uri
  @input_gcs_uri
end

#output_gcs_uriString

Optional. Output Cloud Storage URI for the Async query. This contains the final response of the query. Corresponds to the JSON property outputGcsUri

Returns:

  • (String)


1575
1576
1577
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1575

def output_gcs_uri
  @output_gcs_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1582
1583
1584
1585
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1582

def update!(**args)
  @input_gcs_uri = args[:input_gcs_uri] if args.key?(:input_gcs_uri)
  @output_gcs_uri = args[:output_gcs_uri] if args.key?(:output_gcs_uri)
end