Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AsyncQueryReasoningEngineRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AsyncQueryReasoningEngineRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Request message for ReasoningEngineExecutionService.AsyncQueryReasoningEngine.
Instance Attribute Summary collapse
-
#input_gcs_uri ⇒ String
Optional.
-
#output_gcs_uri ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1AsyncQueryReasoningEngineRequest
constructor
A new instance of GoogleCloudAiplatformV1AsyncQueryReasoningEngineRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1AsyncQueryReasoningEngineRequest
Returns a new instance of GoogleCloudAiplatformV1AsyncQueryReasoningEngineRequest.
1485 1486 1487 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1485 def initialize(**args) update!(**args) end |
Instance Attribute Details
#input_gcs_uri ⇒ String
Optional. Input Cloud Storage URI for the Async query. If you are not bringing
your own container (BYOC), the content of the file should be a JSON object
with an input field matching the input field of
QueryReasoningEngineRequest (e.g. "input": ` "user_id": "hello", "message":
"$QUERY"`). For BYOC, the content of the file depends on the the agent
application.
Corresponds to the JSON property inputGcsUri
1477 1478 1479 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1477 def input_gcs_uri @input_gcs_uri end |
#output_gcs_uri ⇒ String
Optional. Output Cloud Storage URI for the Async query. This contains the
final response of the query.
Corresponds to the JSON property outputGcsUri
1483 1484 1485 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1483 def output_gcs_uri @output_gcs_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1490 1491 1492 1493 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1490 def update!(**args) @input_gcs_uri = args[:input_gcs_uri] if args.key?(:input_gcs_uri) @output_gcs_uri = args[:output_gcs_uri] if args.key?(:output_gcs_uri) end |