Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AudioTranscription

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The transcription of an audio part. For multi-speaker audio, each speaker segment is a separate Part with its own AudioTranscription carrying the speaker_label.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1AudioTranscription

Returns a new instance of GoogleCloudAiplatformV1AudioTranscription.



2157
2158
2159
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2157

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#speaker_labelString

Optional. A label identifying the speaker of this audio segment (e.g. "spk_1", "spk_2"). Present when diarization is set. Corresponds to the JSON property speakerLabel

Returns:

  • (String)


2144
2145
2146
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2144

def speaker_label
  @speaker_label
end

#textString

Required. The transcription text of this audio segment. Corresponds to the JSON property text

Returns:

  • (String)


2149
2150
2151
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2149

def text
  @text
end

#wordsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AudioTranscriptionWordInfo>

Optional. Detailed word-level transcriptions and timing details. Present when word_timestamp is set. Corresponds to the JSON property words



2155
2156
2157
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2155

def words
  @words
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2162
2163
2164
2165
2166
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2162

def update!(**args)
  @speaker_label = args[:speaker_label] if args.key?(:speaker_label)
  @text = args[:text] if args.key?(:text)
  @words = args[:words] if args.key?(:words)
end