Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AudioTranscriptionConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AudioTranscriptionConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Configuration for speech recognition (transcription).
Instance Attribute Summary collapse
-
#adaptation_phrases ⇒ Array<String>
Optional.
-
#custom_vocabulary ⇒ Array<String>
Optional.
-
#diarization ⇒ Boolean
(also: #diarization?)
Optional.
-
#language_auto ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AudioTranscriptionConfigLanguageAuto
Deprecated: Use top-level
language_codesinstead. -
#language_codes ⇒ Array<String>
Optional.
-
#language_hints ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AudioTranscriptionConfigLanguageHints
Deprecated: Use top-level
language_codesinstead. -
#mode ⇒ String
Optional.
-
#word_timestamp ⇒ Boolean
(also: #word_timestamp?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1AudioTranscriptionConfig
constructor
A new instance of GoogleCloudAiplatformV1AudioTranscriptionConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1AudioTranscriptionConfig
Returns a new instance of GoogleCloudAiplatformV1AudioTranscriptionConfig.
2444 2445 2446 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2444 def initialize(**args) update!(**args) end |
Instance Attribute Details
#adaptation_phrases ⇒ Array<String>
Optional. Deprecated: Use custom_vocabulary instead. A list of phrases to
bias the speech recognition model towards.
Corresponds to the JSON property adaptationPhrases
2396 2397 2398 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2396 def adaptation_phrases @adaptation_phrases end |
#custom_vocabulary ⇒ Array<String>
Optional. A list of custom vocabulary phrases to bias the speech recognition
model toward recognizing specific terms.
Corresponds to the JSON property customVocabulary
2402 2403 2404 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2402 def custom_vocabulary @custom_vocabulary end |
#diarization ⇒ Boolean Also known as: diarization?
Optional. Configures speaker diarization.
Corresponds to the JSON property diarization
2407 2408 2409 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2407 def diarization @diarization end |
#language_auto ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AudioTranscriptionConfigLanguageAuto
Deprecated: Use top-level language_codes instead. Indicates the language of
the audio should be automatically detected.
Corresponds to the JSON property languageAuto
2414 2415 2416 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2414 def language_auto @language_auto end |
#language_codes ⇒ Array<String>
Optional. BCP-47 language codes providing hints about the languages present in
the audio. If omitted or empty, defaults to automatic language detection.
Corresponds to the JSON property languageCodes
2420 2421 2422 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2420 def language_codes @language_codes end |
#language_hints ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AudioTranscriptionConfigLanguageHints
Deprecated: Use top-level language_codes instead. Provides hints to the
model about possible languages present in the audio.
Corresponds to the JSON property languageHints
2426 2427 2428 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2426 def language_hints @language_hints end |
#mode ⇒ String
Optional. Configures transcription mode. Supported values: VERBATIM, SMART.
If unspecified, defaults to VERBATIM transcription. In SMART mode, the
model performs disfluency removal (eliminating filler words, repetitions, and
false starts), light grammatical cleanup, automatic formatting (paragraphs,
bullet points, numbered lists), and minor user edits (inline self-corrections).
Timestamps and diarization are incompatible with mode SMART.
Corresponds to the JSON property mode
2436 2437 2438 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2436 def mode @mode end |
#word_timestamp ⇒ Boolean Also known as: word_timestamp?
Optional. Configures word-level timestamp generation.
Corresponds to the JSON property wordTimestamp
2441 2442 2443 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2441 def @word_timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2449 2450 2451 2452 2453 2454 2455 2456 2457 2458 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2449 def update!(**args) @adaptation_phrases = args[:adaptation_phrases] if args.key?(:adaptation_phrases) @custom_vocabulary = args[:custom_vocabulary] if args.key?(:custom_vocabulary) @diarization = args[:diarization] if args.key?(:diarization) @language_auto = args[:language_auto] if args.key?(:language_auto) @language_codes = args[:language_codes] if args.key?(:language_codes) @language_hints = args[:language_hints] if args.key?(:language_hints) @mode = args[:mode] if args.key?(:mode) @word_timestamp = args[:word_timestamp] if args.key?(:word_timestamp) end |