Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AudioTranscriptionConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AudioTranscriptionConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Configuration for speech recognition (transcription).
Instance Attribute Summary collapse
-
#adaptation_phrases ⇒ Array<String>
Optional.
-
#custom_vocabulary ⇒ Array<String>
Optional.
-
#diarization ⇒ Boolean
(also: #diarization?)
Optional.
-
#language_auto ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AudioTranscriptionConfigLanguageAuto
Deprecated: Use top-level
language_codesinstead. -
#language_codes ⇒ Array<String>
Optional.
-
#language_hints ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AudioTranscriptionConfigLanguageHints
Deprecated: Use top-level
language_codesinstead. -
#word_timestamp ⇒ Boolean
(also: #word_timestamp?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1AudioTranscriptionConfig
constructor
A new instance of GoogleCloudAiplatformV1AudioTranscriptionConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1AudioTranscriptionConfig
Returns a new instance of GoogleCloudAiplatformV1AudioTranscriptionConfig.
2430 2431 2432 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2430 def initialize(**args) update!(**args) end |
Instance Attribute Details
#adaptation_phrases ⇒ Array<String>
Optional. Deprecated: Use custom_vocabulary instead. A list of phrases to
bias the speech recognition model towards.
Corresponds to the JSON property adaptationPhrases
2392 2393 2394 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2392 def adaptation_phrases @adaptation_phrases end |
#custom_vocabulary ⇒ Array<String>
Optional. A list of custom vocabulary phrases to bias the speech recognition
model toward recognizing specific terms.
Corresponds to the JSON property customVocabulary
2398 2399 2400 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2398 def custom_vocabulary @custom_vocabulary end |
#diarization ⇒ Boolean Also known as: diarization?
Optional. Configures speaker diarization.
Corresponds to the JSON property diarization
2403 2404 2405 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2403 def diarization @diarization end |
#language_auto ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AudioTranscriptionConfigLanguageAuto
Deprecated: Use top-level language_codes instead. Indicates the language of
the audio should be automatically detected.
Corresponds to the JSON property languageAuto
2410 2411 2412 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2410 def language_auto @language_auto end |
#language_codes ⇒ Array<String>
Optional. BCP-47 language codes providing hints about the languages present in
the audio. If omitted or empty, defaults to automatic language detection.
Corresponds to the JSON property languageCodes
2416 2417 2418 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2416 def language_codes @language_codes end |
#language_hints ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AudioTranscriptionConfigLanguageHints
Deprecated: Use top-level language_codes instead. Provides hints to the
model about possible languages present in the audio.
Corresponds to the JSON property languageHints
2422 2423 2424 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2422 def language_hints @language_hints end |
#word_timestamp ⇒ Boolean Also known as: word_timestamp?
Optional. Configures word-level timestamp generation.
Corresponds to the JSON property wordTimestamp
2427 2428 2429 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2427 def @word_timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2435 2436 2437 2438 2439 2440 2441 2442 2443 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2435 def update!(**args) @adaptation_phrases = args[:adaptation_phrases] if args.key?(:adaptation_phrases) @custom_vocabulary = args[:custom_vocabulary] if args.key?(:custom_vocabulary) @diarization = args[:diarization] if args.key?(:diarization) @language_auto = args[:language_auto] if args.key?(:language_auto) @language_codes = args[:language_codes] if args.key?(:language_codes) @language_hints = args[:language_hints] if args.key?(:language_hints) @word_timestamp = args[:word_timestamp] if args.key?(:word_timestamp) end |