Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AudioTranscriptionConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AudioTranscriptionConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Configuration for speech recognition (transcription).
Instance Attribute Summary collapse
-
#adaptation_phrases ⇒ Array<String>
Optional.
-
#custom_vocabulary ⇒ Array<String>
Optional.
-
#diarization ⇒ Boolean
(also: #diarization?)
Optional.
-
#language_auto ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AudioTranscriptionConfigLanguageAuto
Indicates the language of the audio should be automatically detected.
-
#language_hints ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AudioTranscriptionConfigLanguageHints
Provides hints to the model about possible languages present in the audio.
-
#word_timestamp ⇒ Boolean
(also: #word_timestamp?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1AudioTranscriptionConfig
constructor
A new instance of GoogleCloudAiplatformV1AudioTranscriptionConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1AudioTranscriptionConfig
Returns a new instance of GoogleCloudAiplatformV1AudioTranscriptionConfig.
2206 2207 2208 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2206 def initialize(**args) update!(**args) end |
Instance Attribute Details
#adaptation_phrases ⇒ Array<String>
Optional. A list of phrases to bias the ASR model towards.
Corresponds to the JSON property adaptationPhrases
2176 2177 2178 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2176 def adaptation_phrases @adaptation_phrases end |
#custom_vocabulary ⇒ Array<String>
Optional. A list of custom vocabulary phrases to bias the speech recognition
model toward recognizing specific terms.
Corresponds to the JSON property customVocabulary
2182 2183 2184 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2182 def custom_vocabulary @custom_vocabulary end |
#diarization ⇒ Boolean Also known as: diarization?
Optional. Configures speaker diarization.
Corresponds to the JSON property diarization
2187 2188 2189 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2187 def diarization @diarization end |
#language_auto ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AudioTranscriptionConfigLanguageAuto
Indicates the language of the audio should be automatically detected.
Corresponds to the JSON property languageAuto
2193 2194 2195 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2193 def language_auto @language_auto end |
#language_hints ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AudioTranscriptionConfigLanguageHints
Provides hints to the model about possible languages present in the audio.
Corresponds to the JSON property languageHints
2198 2199 2200 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2198 def language_hints @language_hints end |
#word_timestamp ⇒ Boolean Also known as: word_timestamp?
Optional. Configures word-level timestamp generation.
Corresponds to the JSON property wordTimestamp
2203 2204 2205 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2203 def @word_timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2211 2212 2213 2214 2215 2216 2217 2218 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2211 def update!(**args) @adaptation_phrases = args[:adaptation_phrases] if args.key?(:adaptation_phrases) @custom_vocabulary = args[:custom_vocabulary] if args.key?(:custom_vocabulary) @diarization = args[:diarization] if args.key?(:diarization) @language_auto = args[:language_auto] if args.key?(:language_auto) @language_hints = args[:language_hints] if args.key?(:language_hints) @word_timestamp = args[:word_timestamp] if args.key?(:word_timestamp) end |