Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AugmentPromptResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AugmentPromptResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Response message for AugmentPrompt.
Instance Attribute Summary collapse
-
#augmented_prompt ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content>
Augmented prompt, only text format is supported for now.
-
#facts ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Fact>
Retrieved facts from RAG data sources.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1AugmentPromptResponse
constructor
A new instance of GoogleCloudAiplatformV1AugmentPromptResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1AugmentPromptResponse
Returns a new instance of GoogleCloudAiplatformV1AugmentPromptResponse.
2034 2035 2036 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2034 def initialize(**args) update!(**args) end |
Instance Attribute Details
#augmented_prompt ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content>
Augmented prompt, only text format is supported for now.
Corresponds to the JSON property augmentedPrompt
2027 2028 2029 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2027 def augmented_prompt @augmented_prompt end |
#facts ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Fact>
Retrieved facts from RAG data sources.
Corresponds to the JSON property facts
2032 2033 2034 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2032 def facts @facts end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2039 2040 2041 2042 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2039 def update!(**args) @augmented_prompt = args[:augmented_prompt] if args.key?(:augmented_prompt) @facts = args[:facts] if args.key?(:facts) end |