Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AutomaticResources
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AutomaticResources
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A description of resources that to large degree are decided by Agent Platform, and require only a modest additional configuration. Each Model supporting these resources documents its specific guidelines.
Instance Attribute Summary collapse
-
#max_replica_count ⇒ Fixnum
Immutable.
-
#min_replica_count ⇒ Fixnum
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1AutomaticResources
constructor
A new instance of GoogleCloudAiplatformV1AutomaticResources.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1AutomaticResources
Returns a new instance of GoogleCloudAiplatformV1AutomaticResources.
2353 2354 2355 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2353 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_replica_count ⇒ Fixnum
Immutable. The maximum number of replicas that may be deployed on when the
traffic against it increases. If the requested value is too large, the
deployment will error, but if deployment succeeds then the ability to scale to
that many replicas is guaranteed (barring service outages). If traffic
increases beyond what its replicas at maximum may handle, a portion of the
traffic will be dropped. If this value is not provided, a no upper bound for
scaling under heavy traffic will be assume, though Agent Platform may be
unable to scale beyond certain replica number.
Corresponds to the JSON property maxReplicaCount
2342 2343 2344 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2342 def max_replica_count @max_replica_count end |
#min_replica_count ⇒ Fixnum
Immutable. The minimum number of replicas that will be always deployed on. If
traffic against it increases, it may dynamically be deployed onto more
replicas up to max_replica_count, and as traffic decreases, some of these
extra replicas may be freed. If the requested value is too large, the
deployment will error.
Corresponds to the JSON property minReplicaCount
2351 2352 2353 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2351 def min_replica_count @min_replica_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2358 2359 2360 2361 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2358 def update!(**args) @max_replica_count = args[:max_replica_count] if args.key?(:max_replica_count) @min_replica_count = args[:min_replica_count] if args.key?(:min_replica_count) end |