Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AutomaticResources

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A description of resources that to large degree are decided by Vertex AI, and require only a modest additional configuration. Each Model supporting these resources documents its specific guidelines.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1AutomaticResources

Returns a new instance of GoogleCloudAiplatformV1AutomaticResources.



1501
1502
1503
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1501

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_replica_countFixnum

Immutable. The maximum number of replicas that may be deployed on when the traffic against it increases. If the requested value is too large, the deployment will error, but if deployment succeeds then the ability to scale to that many replicas is guaranteed (barring service outages). If traffic increases beyond what its replicas at maximum may handle, a portion of the traffic will be dropped. If this value is not provided, a no upper bound for scaling under heavy traffic will be assume, though Vertex AI may be unable to scale beyond certain replica number. Corresponds to the JSON property maxReplicaCount

Returns:

  • (Fixnum)


1490
1491
1492
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1490

def max_replica_count
  @max_replica_count
end

#min_replica_countFixnum

Immutable. The minimum number of replicas that will be always deployed on. If traffic against it increases, it may dynamically be deployed onto more replicas up to max_replica_count, and as traffic decreases, some of these extra replicas may be freed. If the requested value is too large, the deployment will error. Corresponds to the JSON property minReplicaCount

Returns:

  • (Fixnum)


1499
1500
1501
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1499

def min_replica_count
  @min_replica_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1506
1507
1508
1509
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1506

def update!(**args)
  @max_replica_count = args[:max_replica_count] if args.key?(:max_replica_count)
  @min_replica_count = args[:min_replica_count] if args.key?(:min_replica_count)
end