Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AutoraterConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AutoraterConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The configs for autorater. This is applicable to both EvaluateInstances and EvaluateDataset.
Instance Attribute Summary collapse
-
#autorater_model ⇒ String
Optional.
-
#flip_enabled ⇒ Boolean
(also: #flip_enabled?)
Optional.
-
#generation_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfig
Configuration for content generation.
-
#sampling_count ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1AutoraterConfig
constructor
A new instance of GoogleCloudAiplatformV1AutoraterConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1AutoraterConfig
Returns a new instance of GoogleCloudAiplatformV1AutoraterConfig.
2407 2408 2409 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2407 def initialize(**args) update!(**args) end |
Instance Attribute Details
#autorater_model ⇒ String
Optional. The fully qualified name of the publisher model or tuned autorater
endpoint to use. Publisher model format: projects/project/locations/
location/publishers/*/models/* Tuned model endpoint format: projects/
project/locations/location/endpoints/endpoint`
Corresponds to the JSON propertyautoraterModel`
2381 2382 2383 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2381 def autorater_model @autorater_model end |
#flip_enabled ⇒ Boolean Also known as: flip_enabled?
Optional. Default is true. Whether to flip the candidate and baseline
responses. This is only applicable to the pairwise metric. If enabled, also
provide PairwiseMetricSpec.candidate_response_field_name and
PairwiseMetricSpec.baseline_response_field_name. When rendering
PairwiseMetricSpec.metric_prompt_template, the candidate and baseline fields
will be flipped for half of the samples to reduce bias.
Corresponds to the JSON property flipEnabled
2391 2392 2393 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2391 def flip_enabled @flip_enabled end |
#generation_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfig
Configuration for content generation. This message contains all the parameters
that control how the model generates content. It allows you to influence the
randomness, length, and structure of the output.
Corresponds to the JSON property generationConfig
2399 2400 2401 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2399 def generation_config @generation_config end |
#sampling_count ⇒ Fixnum
Optional. Number of samples for each instance in the dataset. If not specified,
the default is 4. Minimum value is 1, maximum value is 32.
Corresponds to the JSON property samplingCount
2405 2406 2407 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2405 def sampling_count @sampling_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2412 2413 2414 2415 2416 2417 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2412 def update!(**args) @autorater_model = args[:autorater_model] if args.key?(:autorater_model) @flip_enabled = args[:flip_enabled] if args.key?(:flip_enabled) @generation_config = args[:generation_config] if args.key?(:generation_config) @sampling_count = args[:sampling_count] if args.key?(:sampling_count) end |