Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AutoraterConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AutoraterConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The configs for autorater. This is applicable to both EvaluateInstances and EvaluateDataset.
Instance Attribute Summary collapse
-
#autorater_model ⇒ String
Optional.
-
#flip_enabled ⇒ Boolean
(also: #flip_enabled?)
Optional.
-
#sampling_count ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1AutoraterConfig
constructor
A new instance of GoogleCloudAiplatformV1AutoraterConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1AutoraterConfig
Returns a new instance of GoogleCloudAiplatformV1AutoraterConfig.
1331 1332 1333 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1331 def initialize(**args) update!(**args) end |
Instance Attribute Details
#autorater_model ⇒ String
Optional. The fully qualified name of the publisher model or tuned autorater
endpoint to use. Publisher model format: projects/project/locations/
location/publishers/*/models/* Tuned model endpoint format: projects/
project/locations/location/endpoints/endpoint`
Corresponds to the JSON propertyautoraterModel`
1312 1313 1314 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1312 def autorater_model @autorater_model end |
#flip_enabled ⇒ Boolean Also known as: flip_enabled?
Optional. Default is true. Whether to flip the candidate and baseline
responses. This is only applicable to the pairwise metric. If enabled, also
provide PairwiseMetricSpec.candidate_response_field_name and
PairwiseMetricSpec.baseline_response_field_name. When rendering
PairwiseMetricSpec.metric_prompt_template, the candidate and baseline fields
will be flipped for half of the samples to reduce bias.
Corresponds to the JSON property flipEnabled
1322 1323 1324 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1322 def flip_enabled @flip_enabled end |
#sampling_count ⇒ Fixnum
Optional. Number of samples for each instance in the dataset. If not specified,
the default is 4. Minimum value is 1, maximum value is 32.
Corresponds to the JSON property samplingCount
1329 1330 1331 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1329 def sampling_count @sampling_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1336 1337 1338 1339 1340 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1336 def update!(**args) @autorater_model = args[:autorater_model] if args.key?(:autorater_model) @flip_enabled = args[:flip_enabled] if args.key?(:flip_enabled) @sampling_count = args[:sampling_count] if args.key?(:sampling_count) end |