Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AutoscalingMetricSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The metric specification that defines the target resource utilization (CPU utilization, accelerator's duty cycle, and so on) for calculating the desired replica count.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1AutoscalingMetricSpec

Returns a new instance of GoogleCloudAiplatformV1AutoscalingMetricSpec.



2440
2441
2442
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2440

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#metric_nameString

Required. The resource metric name. Supported metrics: * For Online Prediction:

  • aiplatform.googleapis.com/prediction/online/accelerator/duty_cycle * aiplatform.googleapis.com/prediction/online/cpu/utilization * aiplatform. googleapis.com/prediction/online/request_count * pubsub.googleapis.com/ subscription/num_undelivered_messages * prometheus.googleapis.com/ vertex_dcgm_fi_dev_gpu_util * prometheus.googleapis.com/ vertex_vllm_gpu_cache_usage_perc * prometheus.googleapis.com/ vertex_vllm_num_requests_waiting Corresponds to the JSON property metricName

Returns:

  • (String)


2430
2431
2432
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2430

def metric_name
  @metric_name
end

#targetFixnum

The target resource utilization in percentage (1% - 100%) for the given metric; once the real usage deviates from the target by a certain percentage, the machine replicas change. The default value is 60 (representing 60%) if not provided. Corresponds to the JSON property target

Returns:

  • (Fixnum)


2438
2439
2440
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2438

def target
  @target
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2445
2446
2447
2448
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2445

def update!(**args)
  @metric_name = args[:metric_name] if args.key?(:metric_name)
  @target = args[:target] if args.key?(:target)
end