Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchCreateFeaturesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for FeaturestoreService.BatchCreateFeatures.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1BatchCreateFeaturesRequest

Returns a new instance of GoogleCloudAiplatformV1BatchCreateFeaturesRequest.



2026
2027
2028
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2026

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#requestsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CreateFeatureRequest>

Required. The request message specifying the Features to create. All Features must be created under the same parent EntityType. The parent field in each child request message can be omitted. If parent is set in a child request, then the value must match the parent value in this request message. Corresponds to the JSON property requests



2024
2025
2026
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2024

def requests
  @requests
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2031
2032
2033
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2031

def update!(**args)
  @requests = args[:requests] if args.key?(:requests)
end