Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchMigrateResourcesOperationMetadataPartialResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents a partial result in batch migration operation for one MigrateResourceRequest.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1BatchMigrateResourcesOperationMetadataPartialResult

Returns a new instance of GoogleCloudAiplatformV1BatchMigrateResourcesOperationMetadataPartialResult.



1954
1955
1956
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1954

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#datasetString

Migrated dataset resource name. Corresponds to the JSON property dataset

Returns:

  • (String)


1931
1932
1933
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1931

def dataset
  @dataset
end

#errorGoogle::Apis::AiplatformV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



1941
1942
1943
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1941

def error
  @error
end

#modelString

Migrated model resource name. Corresponds to the JSON property model

Returns:

  • (String)


1946
1947
1948
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1946

def model
  @model
end

#requestGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1MigrateResourceRequest

Config of migrating one resource from automl.googleapis.com, datalabeling. googleapis.com and ml.googleapis.com to Vertex AI. Corresponds to the JSON property request



1952
1953
1954
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1952

def request
  @request
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1959
1960
1961
1962
1963
1964
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1959

def update!(**args)
  @dataset = args[:dataset] if args.key?(:dataset)
  @error = args[:error] if args.key?(:error)
  @model = args[:model] if args.key?(:model)
  @request = args[:request] if args.key?(:request)
end