Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchMigrateResourcesOperationMetadataPartialResult
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchMigrateResourcesOperationMetadataPartialResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Represents a partial result in batch migration operation for one MigrateResourceRequest.
Instance Attribute Summary collapse
-
#dataset ⇒ String
Migrated dataset resource name.
-
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#model ⇒ String
Migrated model resource name.
-
#request ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MigrateResourceRequest
Config of migrating one resource from automl.googleapis.com, datalabeling.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1BatchMigrateResourcesOperationMetadataPartialResult
constructor
A new instance of GoogleCloudAiplatformV1BatchMigrateResourcesOperationMetadataPartialResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1BatchMigrateResourcesOperationMetadataPartialResult
Returns a new instance of GoogleCloudAiplatformV1BatchMigrateResourcesOperationMetadataPartialResult.
1743 1744 1745 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1743 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dataset ⇒ String
Migrated dataset resource name.
Corresponds to the JSON property dataset
1720 1721 1722 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1720 def dataset @dataset end |
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
1730 1731 1732 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1730 def error @error end |
#model ⇒ String
Migrated model resource name.
Corresponds to the JSON property model
1735 1736 1737 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1735 def model @model end |
#request ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MigrateResourceRequest
Config of migrating one resource from automl.googleapis.com, datalabeling.
googleapis.com and ml.googleapis.com to Vertex AI.
Corresponds to the JSON property request
1741 1742 1743 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1741 def request @request end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1748 1749 1750 1751 1752 1753 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1748 def update!(**args) @dataset = args[:dataset] if args.key?(:dataset) @error = args[:error] if args.key?(:error) @model = args[:model] if args.key?(:model) @request = args[:request] if args.key?(:request) end |