Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchPredictionJob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A job that uses a Model to produce predictions on multiple input instances. If predictions for significant portion of the instances fail, the job may finish without attempting predictions for all remaining instances.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1BatchPredictionJob

Returns a new instance of GoogleCloudAiplatformV1BatchPredictionJob.



3082
3083
3084
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3082

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#completion_statsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1CompletionStats

Success and error statistics of processing multiple entities (for example, DataItems or structured data rows) in batch. Corresponds to the JSON property completionStats



2888
2889
2890
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2888

def completion_stats
  @completion_stats
end

#create_timeString

Output only. Time when the BatchPredictionJob was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2893
2894
2895
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2893

def create_time
  @create_time
end

#dedicated_resourcesGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchDedicatedResources

A description of resources that are used for performing batch operations, are dedicated to a Model, and need manual configuration. Corresponds to the JSON property dedicatedResources



2899
2900
2901
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2899

def dedicated_resources
  @dedicated_resources
end

#disable_container_loggingBoolean Also known as: disable_container_logging?

For custom-trained Models and AutoML Tabular Models, the container of the DeployedModel instances will send stderr and stdout streams to Cloud Logging by default. Please note that the logs incur cost, which are subject to Cloud Logging pricing. User can disable container logging by setting this flag to true. Corresponds to the JSON property disableContainerLogging

Returns:

  • (Boolean)


2908
2909
2910
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2908

def disable_container_logging
  @disable_container_logging
end

#display_nameString

Required. The user-defined name of this BatchPredictionJob. Corresponds to the JSON property displayName

Returns:

  • (String)


2914
2915
2916
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2914

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



2920
2921
2922
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2920

def encryption_spec
  @encryption_spec
end

#end_timeString

Output only. Time when the BatchPredictionJob entered any of the following states: JOB_STATE_SUCCEEDED, JOB_STATE_FAILED, JOB_STATE_CANCELLED. Corresponds to the JSON property endTime

Returns:

  • (String)


2926
2927
2928
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2926

def end_time
  @end_time
end

#errorGoogle::Apis::AiplatformV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



2936
2937
2938
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2936

def error
  @error
end

#explanation_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationSpec

Specification of Model explanation. Corresponds to the JSON property explanationSpec



2941
2942
2943
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2941

def explanation_spec
  @explanation_spec
end

#generate_explanationBoolean Also known as: generate_explanation?

Generate explanation with the batch prediction results. When set to true, the batch prediction output changes based on the predictions_format field of the BatchPredictionJob.output_config object: * bigquery: output includes a column named explanation. The value is a struct that conforms to the Explanation object. * jsonl: The JSON objects on each line include an additional entry keyed explanation. The value of the entry is a JSON object that conforms to the Explanation object. * csv: Generating explanations for CSV format is not supported. If this field is set to true, either the Model. explanation_spec or explanation_spec must be populated. Corresponds to the JSON property generateExplanation

Returns:

  • (Boolean)


2954
2955
2956
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2954

def generate_explanation
  @generate_explanation
end

#input_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchPredictionJobInputConfig

Configures the input to BatchPredictionJob. See Model. supported_input_storage_formats for Model's supported input formats, and how instances should be expressed via any of them. Corresponds to the JSON property inputConfig



2962
2963
2964
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2962

def input_config
  @input_config
end

#instance_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchPredictionJobInstanceConfig

Configuration defining how to transform batch prediction input instances to the instances that the Model accepts. Corresponds to the JSON property instanceConfig



2968
2969
2970
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2968

def instance_config
  @instance_config
end

#labelsHash<String,String>

The labels with user-defined metadata to organize BatchPredictionJobs. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2977
2978
2979
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2977

def labels
  @labels
end

#manual_batch_tuning_parametersGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ManualBatchTuningParameters

Manual batch tuning parameters. Corresponds to the JSON property manualBatchTuningParameters



2982
2983
2984
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2982

def manual_batch_tuning_parameters
  @manual_batch_tuning_parameters
end

#modelString

The name of the Model resource that produces the predictions via this job, must share the same ancestor Location. Starting this job has no impact on any existing deployments of the Model and their resources. Exactly one of model, unmanaged_container_model, or endpoint must be set. The model resource name may contain version id or version alias to specify the version. Example: projects/project/locations/location/models/model@2 or projects/ project/locations/location/models/model@golden if no version is specified, the default version will be deployed. The model resource could also be a publisher model. Example: publishers/publisher/models/modelor ` projects/`project`/locations/`location`/publishers/`publisher`/models/`model Corresponds to the JSON property model

Returns:

  • (String)


2996
2997
2998
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2996

def model
  @model
end

#model_parametersObject

The parameters that govern the predictions. The schema of the parameters may be specified via the Model's PredictSchemata's parameters_schema_uri. Corresponds to the JSON property modelParameters

Returns:

  • (Object)


3002
3003
3004
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3002

def model_parameters
  @model_parameters
end

#model_version_idString

Output only. The version ID of the Model that produces the predictions via this job. Corresponds to the JSON property modelVersionId

Returns:

  • (String)


3008
3009
3010
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3008

def model_version_id
  @model_version_id
end

#nameString

Output only. Resource name of the BatchPredictionJob. Corresponds to the JSON property name

Returns:

  • (String)


3013
3014
3015
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3013

def name
  @name
end

#output_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchPredictionJobOutputConfig

Configures the output of BatchPredictionJob. See Model. supported_output_storage_formats for supported output formats, and how predictions are expressed via any of them. Corresponds to the JSON property outputConfig



3020
3021
3022
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3020

def output_config
  @output_config
end

#output_infoGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchPredictionJobOutputInfo

Further describes this job's output. Supplements output_config. Corresponds to the JSON property outputInfo



3025
3026
3027
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3025

def output_info
  @output_info
end

#partial_failuresArray<Google::Apis::AiplatformV1::GoogleRpcStatus>

Output only. Partial failures encountered. For example, single files that can' t be read. This field never exceeds 20 entries. Status details fields contain standard Google Cloud error details. Corresponds to the JSON property partialFailures



3032
3033
3034
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3032

def partial_failures
  @partial_failures
end

#resources_consumedGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ResourcesConsumed

Statistics information about resource consumption. Corresponds to the JSON property resourcesConsumed



3037
3038
3039
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3037

def resources_consumed
  @resources_consumed
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


3042
3043
3044
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3042

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


3048
3049
3050
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3048

def satisfies_pzs
  @satisfies_pzs
end

#service_accountString

The service account that the DeployedModel's container runs as. If not specified, a system generated one will be used, which has minimal permissions and the custom container, if used, may not have enough permission to access other Google Cloud resources. Users deploying the Model must have the iam. serviceAccounts.actAs permission on this service account. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


3058
3059
3060
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3058

def 
  @service_account
end

#start_timeString

Output only. Time when the BatchPredictionJob for the first time entered the JOB_STATE_RUNNING state. Corresponds to the JSON property startTime

Returns:

  • (String)


3064
3065
3066
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3064

def start_time
  @start_time
end

#stateString

Output only. The detailed state of the job. Corresponds to the JSON property state

Returns:

  • (String)


3069
3070
3071
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3069

def state
  @state
end

#unmanaged_container_modelGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1UnmanagedContainerModel

Contains model information necessary to perform batch prediction without requiring a full model import. Corresponds to the JSON property unmanagedContainerModel



3075
3076
3077
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3075

def unmanaged_container_model
  @unmanaged_container_model
end

#update_timeString

Output only. Time when the BatchPredictionJob was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


3080
3081
3082
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3080

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3087
3088
3089
3090
3091
3092
3093
3094
3095
3096
3097
3098
3099
3100
3101
3102
3103
3104
3105
3106
3107
3108
3109
3110
3111
3112
3113
3114
3115
3116
3117
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3087

def update!(**args)
  @completion_stats = args[:completion_stats] if args.key?(:completion_stats)
  @create_time = args[:create_time] if args.key?(:create_time)
  @dedicated_resources = args[:dedicated_resources] if args.key?(:dedicated_resources)
  @disable_container_logging = args[:disable_container_logging] if args.key?(:disable_container_logging)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @end_time = args[:end_time] if args.key?(:end_time)
  @error = args[:error] if args.key?(:error)
  @explanation_spec = args[:explanation_spec] if args.key?(:explanation_spec)
  @generate_explanation = args[:generate_explanation] if args.key?(:generate_explanation)
  @input_config = args[:input_config] if args.key?(:input_config)
  @instance_config = args[:instance_config] if args.key?(:instance_config)
  @labels = args[:labels] if args.key?(:labels)
  @manual_batch_tuning_parameters = args[:manual_batch_tuning_parameters] if args.key?(:manual_batch_tuning_parameters)
  @model = args[:model] if args.key?(:model)
  @model_parameters = args[:model_parameters] if args.key?(:model_parameters)
  @model_version_id = args[:model_version_id] if args.key?(:model_version_id)
  @name = args[:name] if args.key?(:name)
  @output_config = args[:output_config] if args.key?(:output_config)
  @output_info = args[:output_info] if args.key?(:output_info)
  @partial_failures = args[:partial_failures] if args.key?(:partial_failures)
  @resources_consumed = args[:resources_consumed] if args.key?(:resources_consumed)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @service_account = args[:service_account] if args.key?(:service_account)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @unmanaged_container_model = args[:unmanaged_container_model] if args.key?(:unmanaged_container_model)
  @update_time = args[:update_time] if args.key?(:update_time)
end