Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchPredictionJob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A job that uses a Model to produce predictions on multiple input instances. If predictions for significant portion of the instances fail, the job may finish without attempting predictions for all remaining instances.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1BatchPredictionJob

Returns a new instance of GoogleCloudAiplatformV1BatchPredictionJob.



2638
2639
2640
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2638

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#completion_statsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1CompletionStats

Success and error statistics of processing multiple entities (for example, DataItems or structured data rows) in batch. Corresponds to the JSON property completionStats



2444
2445
2446
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2444

def completion_stats
  @completion_stats
end

#create_timeString

Output only. Time when the BatchPredictionJob was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2449
2450
2451
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2449

def create_time
  @create_time
end

#dedicated_resourcesGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchDedicatedResources

A description of resources that are used for performing batch operations, are dedicated to a Model, and need manual configuration. Corresponds to the JSON property dedicatedResources



2455
2456
2457
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2455

def dedicated_resources
  @dedicated_resources
end

#disable_container_loggingBoolean Also known as: disable_container_logging?

For custom-trained Models and AutoML Tabular Models, the container of the DeployedModel instances will send stderr and stdout streams to Cloud Logging by default. Please note that the logs incur cost, which are subject to Cloud Logging pricing. User can disable container logging by setting this flag to true. Corresponds to the JSON property disableContainerLogging

Returns:

  • (Boolean)


2464
2465
2466
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2464

def disable_container_logging
  @disable_container_logging
end

#display_nameString

Required. The user-defined name of this BatchPredictionJob. Corresponds to the JSON property displayName

Returns:

  • (String)


2470
2471
2472
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2470

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



2476
2477
2478
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2476

def encryption_spec
  @encryption_spec
end

#end_timeString

Output only. Time when the BatchPredictionJob entered any of the following states: JOB_STATE_SUCCEEDED, JOB_STATE_FAILED, JOB_STATE_CANCELLED. Corresponds to the JSON property endTime

Returns:

  • (String)


2482
2483
2484
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2482

def end_time
  @end_time
end

#errorGoogle::Apis::AiplatformV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



2492
2493
2494
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2492

def error
  @error
end

#explanation_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationSpec

Specification of Model explanation. Corresponds to the JSON property explanationSpec



2497
2498
2499
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2497

def explanation_spec
  @explanation_spec
end

#generate_explanationBoolean Also known as: generate_explanation?

Generate explanation with the batch prediction results. When set to true, the batch prediction output changes based on the predictions_format field of the BatchPredictionJob.output_config object: * bigquery: output includes a column named explanation. The value is a struct that conforms to the Explanation object. * jsonl: The JSON objects on each line include an additional entry keyed explanation. The value of the entry is a JSON object that conforms to the Explanation object. * csv: Generating explanations for CSV format is not supported. If this field is set to true, either the Model. explanation_spec or explanation_spec must be populated. Corresponds to the JSON property generateExplanation

Returns:

  • (Boolean)


2510
2511
2512
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2510

def generate_explanation
  @generate_explanation
end

#input_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchPredictionJobInputConfig

Configures the input to BatchPredictionJob. See Model. supported_input_storage_formats for Model's supported input formats, and how instances should be expressed via any of them. Corresponds to the JSON property inputConfig



2518
2519
2520
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2518

def input_config
  @input_config
end

#instance_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchPredictionJobInstanceConfig

Configuration defining how to transform batch prediction input instances to the instances that the Model accepts. Corresponds to the JSON property instanceConfig



2524
2525
2526
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2524

def instance_config
  @instance_config
end

#labelsHash<String,String>

The labels with user-defined metadata to organize BatchPredictionJobs. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2533
2534
2535
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2533

def labels
  @labels
end

#manual_batch_tuning_parametersGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ManualBatchTuningParameters

Manual batch tuning parameters. Corresponds to the JSON property manualBatchTuningParameters



2538
2539
2540
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2538

def manual_batch_tuning_parameters
  @manual_batch_tuning_parameters
end

#modelString

The name of the Model resource that produces the predictions via this job, must share the same ancestor Location. Starting this job has no impact on any existing deployments of the Model and their resources. Exactly one of model, unmanaged_container_model, or endpoint must be set. The model resource name may contain version id or version alias to specify the version. Example: projects/project/locations/location/models/model@2 or projects/ project/locations/location/models/model@golden if no version is specified, the default version will be deployed. The model resource could also be a publisher model. Example: publishers/publisher/models/modelor ` projects/`project`/locations/`location`/publishers/`publisher`/models/`model Corresponds to the JSON property model

Returns:

  • (String)


2552
2553
2554
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2552

def model
  @model
end

#model_parametersObject

The parameters that govern the predictions. The schema of the parameters may be specified via the Model's PredictSchemata's parameters_schema_uri. Corresponds to the JSON property modelParameters

Returns:

  • (Object)


2558
2559
2560
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2558

def model_parameters
  @model_parameters
end

#model_version_idString

Output only. The version ID of the Model that produces the predictions via this job. Corresponds to the JSON property modelVersionId

Returns:

  • (String)


2564
2565
2566
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2564

def model_version_id
  @model_version_id
end

#nameString

Output only. Resource name of the BatchPredictionJob. Corresponds to the JSON property name

Returns:

  • (String)


2569
2570
2571
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2569

def name
  @name
end

#output_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchPredictionJobOutputConfig

Configures the output of BatchPredictionJob. See Model. supported_output_storage_formats for supported output formats, and how predictions are expressed via any of them. Corresponds to the JSON property outputConfig



2576
2577
2578
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2576

def output_config
  @output_config
end

#output_infoGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchPredictionJobOutputInfo

Further describes this job's output. Supplements output_config. Corresponds to the JSON property outputInfo



2581
2582
2583
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2581

def output_info
  @output_info
end

#partial_failuresArray<Google::Apis::AiplatformV1::GoogleRpcStatus>

Output only. Partial failures encountered. For example, single files that can' t be read. This field never exceeds 20 entries. Status details fields contain standard Google Cloud error details. Corresponds to the JSON property partialFailures



2588
2589
2590
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2588

def partial_failures
  @partial_failures
end

#resources_consumedGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ResourcesConsumed

Statistics information about resource consumption. Corresponds to the JSON property resourcesConsumed



2593
2594
2595
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2593

def resources_consumed
  @resources_consumed
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


2598
2599
2600
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2598

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


2604
2605
2606
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2604

def satisfies_pzs
  @satisfies_pzs
end

#service_accountString

The service account that the DeployedModel's container runs as. If not specified, a system generated one will be used, which has minimal permissions and the custom container, if used, may not have enough permission to access other Google Cloud resources. Users deploying the Model must have the iam. serviceAccounts.actAs permission on this service account. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


2614
2615
2616
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2614

def 
  @service_account
end

#start_timeString

Output only. Time when the BatchPredictionJob for the first time entered the JOB_STATE_RUNNING state. Corresponds to the JSON property startTime

Returns:

  • (String)


2620
2621
2622
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2620

def start_time
  @start_time
end

#stateString

Output only. The detailed state of the job. Corresponds to the JSON property state

Returns:

  • (String)


2625
2626
2627
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2625

def state
  @state
end

#unmanaged_container_modelGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1UnmanagedContainerModel

Contains model information necessary to perform batch prediction without requiring a full model import. Corresponds to the JSON property unmanagedContainerModel



2631
2632
2633
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2631

def unmanaged_container_model
  @unmanaged_container_model
end

#update_timeString

Output only. Time when the BatchPredictionJob was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


2636
2637
2638
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2636

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2643
2644
2645
2646
2647
2648
2649
2650
2651
2652
2653
2654
2655
2656
2657
2658
2659
2660
2661
2662
2663
2664
2665
2666
2667
2668
2669
2670
2671
2672
2673
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2643

def update!(**args)
  @completion_stats = args[:completion_stats] if args.key?(:completion_stats)
  @create_time = args[:create_time] if args.key?(:create_time)
  @dedicated_resources = args[:dedicated_resources] if args.key?(:dedicated_resources)
  @disable_container_logging = args[:disable_container_logging] if args.key?(:disable_container_logging)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @end_time = args[:end_time] if args.key?(:end_time)
  @error = args[:error] if args.key?(:error)
  @explanation_spec = args[:explanation_spec] if args.key?(:explanation_spec)
  @generate_explanation = args[:generate_explanation] if args.key?(:generate_explanation)
  @input_config = args[:input_config] if args.key?(:input_config)
  @instance_config = args[:instance_config] if args.key?(:instance_config)
  @labels = args[:labels] if args.key?(:labels)
  @manual_batch_tuning_parameters = args[:manual_batch_tuning_parameters] if args.key?(:manual_batch_tuning_parameters)
  @model = args[:model] if args.key?(:model)
  @model_parameters = args[:model_parameters] if args.key?(:model_parameters)
  @model_version_id = args[:model_version_id] if args.key?(:model_version_id)
  @name = args[:name] if args.key?(:name)
  @output_config = args[:output_config] if args.key?(:output_config)
  @output_info = args[:output_info] if args.key?(:output_info)
  @partial_failures = args[:partial_failures] if args.key?(:partial_failures)
  @resources_consumed = args[:resources_consumed] if args.key?(:resources_consumed)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @service_account = args[:service_account] if args.key?(:service_account)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @unmanaged_container_model = args[:unmanaged_container_model] if args.key?(:unmanaged_container_model)
  @update_time = args[:update_time] if args.key?(:update_time)
end