Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchPredictionJob
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchPredictionJob
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A job that uses a Model to produce predictions on multiple input instances. If predictions for significant portion of the instances fail, the job may finish without attempting predictions for all remaining instances.
Instance Attribute Summary collapse
-
#completion_stats ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CompletionStats
Success and error statistics of processing multiple entities (for example, DataItems or structured data rows) in batch.
-
#create_time ⇒ String
Output only.
-
#dedicated_resources ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchDedicatedResources
A description of resources that are used for performing batch operations, are dedicated to a Model, and need manual configuration.
-
#disable_container_logging ⇒ Boolean
(also: #disable_container_logging?)
For custom-trained Models and AutoML Tabular Models, the container of the DeployedModel instances will send
stderrandstdoutstreams to Cloud Logging by default. -
#display_name ⇒ String
Required.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top- level resource.
-
#end_time ⇒ String
Output only.
-
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#explanation_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationSpec
Specification of Model explanation.
-
#generate_explanation ⇒ Boolean
(also: #generate_explanation?)
Generate explanation with the batch prediction results.
-
#input_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchPredictionJobInputConfig
Configures the input to BatchPredictionJob.
-
#instance_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchPredictionJobInstanceConfig
Configuration defining how to transform batch prediction input instances to the instances that the Model accepts.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize BatchPredictionJobs.
-
#manual_batch_tuning_parameters ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ManualBatchTuningParameters
Manual batch tuning parameters.
-
#model ⇒ String
The name of the Model resource that produces the predictions via this job, must share the same ancestor Location.
-
#model_parameters ⇒ Object
The parameters that govern the predictions.
-
#model_version_id ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#output_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchPredictionJobOutputConfig
Configures the output of BatchPredictionJob.
-
#output_info ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchPredictionJobOutputInfo
Further describes this job's output.
-
#partial_failures ⇒ Array<Google::Apis::AiplatformV1::GoogleRpcStatus>
Output only.
-
#resources_consumed ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ResourcesConsumed
Statistics information about resource consumption.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#service_account ⇒ String
The service account that the DeployedModel's container runs as.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#unmanaged_container_model ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1UnmanagedContainerModel
Contains model information necessary to perform batch prediction without requiring a full model import.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1BatchPredictionJob
constructor
A new instance of GoogleCloudAiplatformV1BatchPredictionJob.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1BatchPredictionJob
Returns a new instance of GoogleCloudAiplatformV1BatchPredictionJob.
2000 2001 2002 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2000 def initialize(**args) update!(**args) end |
Instance Attribute Details
#completion_stats ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CompletionStats
Success and error statistics of processing multiple entities (for example,
DataItems or structured data rows) in batch.
Corresponds to the JSON property completionStats
1806 1807 1808 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1806 def completion_stats @completion_stats end |
#create_time ⇒ String
Output only. Time when the BatchPredictionJob was created.
Corresponds to the JSON property createTime
1811 1812 1813 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1811 def create_time @create_time end |
#dedicated_resources ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchDedicatedResources
A description of resources that are used for performing batch operations, are
dedicated to a Model, and need manual configuration.
Corresponds to the JSON property dedicatedResources
1817 1818 1819 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1817 def dedicated_resources @dedicated_resources end |
#disable_container_logging ⇒ Boolean Also known as: disable_container_logging?
For custom-trained Models and AutoML Tabular Models, the container of the
DeployedModel instances will send stderr and stdout streams to Cloud
Logging by default. Please note that the logs incur cost, which are subject to
Cloud Logging pricing. User can
disable container logging by setting this flag to true.
Corresponds to the JSON property disableContainerLogging
1826 1827 1828 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1826 def disable_container_logging @disable_container_logging end |
#display_name ⇒ String
Required. The user-defined name of this BatchPredictionJob.
Corresponds to the JSON property displayName
1832 1833 1834 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1832 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top-
level resource.
Corresponds to the JSON property encryptionSpec
1838 1839 1840 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1838 def encryption_spec @encryption_spec end |
#end_time ⇒ String
Output only. Time when the BatchPredictionJob entered any of the following
states: JOB_STATE_SUCCEEDED, JOB_STATE_FAILED, JOB_STATE_CANCELLED.
Corresponds to the JSON property endTime
1844 1845 1846 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1844 def end_time @end_time end |
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
1854 1855 1856 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1854 def error @error end |
#explanation_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationSpec
Specification of Model explanation.
Corresponds to the JSON property explanationSpec
1859 1860 1861 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1859 def explanation_spec @explanation_spec end |
#generate_explanation ⇒ Boolean Also known as: generate_explanation?
Generate explanation with the batch prediction results. When set to true,
the batch prediction output changes based on the predictions_format field of
the BatchPredictionJob.output_config object: * bigquery: output includes a
column named explanation. The value is a struct that conforms to the
Explanation object. * jsonl: The JSON objects on each line include an
additional entry keyed explanation. The value of the entry is a JSON object
that conforms to the Explanation object. * csv: Generating explanations for
CSV format is not supported. If this field is set to true, either the Model.
explanation_spec or explanation_spec must be populated.
Corresponds to the JSON property generateExplanation
1872 1873 1874 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1872 def generate_explanation @generate_explanation end |
#input_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchPredictionJobInputConfig
Configures the input to BatchPredictionJob. See Model.
supported_input_storage_formats for Model's supported input formats, and how
instances should be expressed via any of them.
Corresponds to the JSON property inputConfig
1880 1881 1882 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1880 def input_config @input_config end |
#instance_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchPredictionJobInstanceConfig
Configuration defining how to transform batch prediction input instances to
the instances that the Model accepts.
Corresponds to the JSON property instanceConfig
1886 1887 1888 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1886 def instance_config @instance_config end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize BatchPredictionJobs. Label
keys and values can be no longer than 64 characters (Unicode codepoints), can
only contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. See https://goo.gl/xmQnxf for more
information and examples of labels.
Corresponds to the JSON property labels
1895 1896 1897 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1895 def labels @labels end |
#manual_batch_tuning_parameters ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ManualBatchTuningParameters
Manual batch tuning parameters.
Corresponds to the JSON property manualBatchTuningParameters
1900 1901 1902 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1900 def manual_batch_tuning_parameters @manual_batch_tuning_parameters end |
#model ⇒ String
The name of the Model resource that produces the predictions via this job,
must share the same ancestor Location. Starting this job has no impact on any
existing deployments of the Model and their resources. Exactly one of model
and unmanaged_container_model must be set. The model resource name may contain
version id or version alias to specify the version. Example: projects/
project/locations/location/models/model@2 or projects/project/
locations/location/models/model@golden if no version is specified, the
default version will be deployed. The model resource could also be a publisher
model. Example: publishers/publisher/models/modelor `projects/`project`/
locations/`location`/publishers/`publisher`/models/`model
Corresponds to the JSON property model
1914 1915 1916 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1914 def model @model end |
#model_parameters ⇒ Object
The parameters that govern the predictions. The schema of the parameters may
be specified via the Model's PredictSchemata's parameters_schema_uri.
Corresponds to the JSON property modelParameters
1920 1921 1922 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1920 def model_parameters @model_parameters end |
#model_version_id ⇒ String
Output only. The version ID of the Model that produces the predictions via
this job.
Corresponds to the JSON property modelVersionId
1926 1927 1928 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1926 def model_version_id @model_version_id end |
#name ⇒ String
Output only. Resource name of the BatchPredictionJob.
Corresponds to the JSON property name
1931 1932 1933 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1931 def name @name end |
#output_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchPredictionJobOutputConfig
Configures the output of BatchPredictionJob. See Model.
supported_output_storage_formats for supported output formats, and how
predictions are expressed via any of them.
Corresponds to the JSON property outputConfig
1938 1939 1940 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1938 def output_config @output_config end |
#output_info ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchPredictionJobOutputInfo
Further describes this job's output. Supplements output_config.
Corresponds to the JSON property outputInfo
1943 1944 1945 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1943 def output_info @output_info end |
#partial_failures ⇒ Array<Google::Apis::AiplatformV1::GoogleRpcStatus>
Output only. Partial failures encountered. For example, single files that can'
t be read. This field never exceeds 20 entries. Status details fields contain
standard Google Cloud error details.
Corresponds to the JSON property partialFailures
1950 1951 1952 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1950 def partial_failures @partial_failures end |
#resources_consumed ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ResourcesConsumed
Statistics information about resource consumption.
Corresponds to the JSON property resourcesConsumed
1955 1956 1957 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1955 def resources_consumed @resources_consumed end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
1960 1961 1962 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1960 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
1966 1967 1968 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1966 def satisfies_pzs @satisfies_pzs end |
#service_account ⇒ String
The service account that the DeployedModel's container runs as. If not
specified, a system generated one will be used, which has minimal permissions
and the custom container, if used, may not have enough permission to access
other Google Cloud resources. Users deploying the Model must have the iam.
serviceAccounts.actAs permission on this service account.
Corresponds to the JSON property serviceAccount
1976 1977 1978 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1976 def service_account @service_account end |
#start_time ⇒ String
Output only. Time when the BatchPredictionJob for the first time entered the
JOB_STATE_RUNNING state.
Corresponds to the JSON property startTime
1982 1983 1984 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1982 def start_time @start_time end |
#state ⇒ String
Output only. The detailed state of the job.
Corresponds to the JSON property state
1987 1988 1989 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1987 def state @state end |
#unmanaged_container_model ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1UnmanagedContainerModel
Contains model information necessary to perform batch prediction without
requiring a full model import.
Corresponds to the JSON property unmanagedContainerModel
1993 1994 1995 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1993 def unmanaged_container_model @unmanaged_container_model end |
#update_time ⇒ String
Output only. Time when the BatchPredictionJob was most recently updated.
Corresponds to the JSON property updateTime
1998 1999 2000 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1998 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2005 2006 2007 2008 2009 2010 2011 2012 2013 2014 2015 2016 2017 2018 2019 2020 2021 2022 2023 2024 2025 2026 2027 2028 2029 2030 2031 2032 2033 2034 2035 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2005 def update!(**args) @completion_stats = args[:completion_stats] if args.key?(:completion_stats) @create_time = args[:create_time] if args.key?(:create_time) @dedicated_resources = args[:dedicated_resources] if args.key?(:dedicated_resources) @disable_container_logging = args[:disable_container_logging] if args.key?(:disable_container_logging) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @end_time = args[:end_time] if args.key?(:end_time) @error = args[:error] if args.key?(:error) @explanation_spec = args[:explanation_spec] if args.key?(:explanation_spec) @generate_explanation = args[:generate_explanation] if args.key?(:generate_explanation) @input_config = args[:input_config] if args.key?(:input_config) @instance_config = args[:instance_config] if args.key?(:instance_config) @labels = args[:labels] if args.key?(:labels) @manual_batch_tuning_parameters = args[:manual_batch_tuning_parameters] if args.key?(:manual_batch_tuning_parameters) @model = args[:model] if args.key?(:model) @model_parameters = args[:model_parameters] if args.key?(:model_parameters) @model_version_id = args[:model_version_id] if args.key?(:model_version_id) @name = args[:name] if args.key?(:name) @output_config = args[:output_config] if args.key?(:output_config) @output_info = args[:output_info] if args.key?(:output_info) @partial_failures = args[:partial_failures] if args.key?(:partial_failures) @resources_consumed = args[:resources_consumed] if args.key?(:resources_consumed) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @service_account = args[:service_account] if args.key?(:service_account) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @unmanaged_container_model = args[:unmanaged_container_model] if args.key?(:unmanaged_container_model) @update_time = args[:update_time] if args.key?(:update_time) end |