Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchPredictionJob
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchPredictionJob
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A job that uses a Model to produce predictions on multiple input instances. If predictions for significant portion of the instances fail, the job may finish without attempting predictions for all remaining instances.
Instance Attribute Summary collapse
-
#completion_stats ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CompletionStats
Success and error statistics of processing multiple entities (for example, DataItems or structured data rows) in batch.
-
#create_time ⇒ String
Output only.
-
#dedicated_resources ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchDedicatedResources
A description of resources that are used for performing batch operations, are dedicated to a Model, and need manual configuration.
-
#disable_container_logging ⇒ Boolean
(also: #disable_container_logging?)
For custom-trained Models and AutoML Tabular Models, the container of the DeployedModel instances will send
stderrandstdoutstreams to Cloud Logging by default. -
#display_name ⇒ String
Required.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top- level resource.
-
#end_time ⇒ String
Output only.
-
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#explanation_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationSpec
Specification of Model explanation.
-
#generate_explanation ⇒ Boolean
(also: #generate_explanation?)
Generate explanation with the batch prediction results.
-
#input_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchPredictionJobInputConfig
Configures the input to BatchPredictionJob.
-
#instance_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchPredictionJobInstanceConfig
Configuration defining how to transform batch prediction input instances to the instances that the Model accepts.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize BatchPredictionJobs.
-
#manual_batch_tuning_parameters ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ManualBatchTuningParameters
Manual batch tuning parameters.
-
#model ⇒ String
The name of the Model resource that produces the predictions via this job, must share the same ancestor Location.
-
#model_parameters ⇒ Object
The parameters that govern the predictions.
-
#model_version_id ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#output_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchPredictionJobOutputConfig
Configures the output of BatchPredictionJob.
-
#output_info ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchPredictionJobOutputInfo
Further describes this job's output.
-
#partial_failures ⇒ Array<Google::Apis::AiplatformV1::GoogleRpcStatus>
Output only.
-
#resources_consumed ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ResourcesConsumed
Statistics information about resource consumption.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#service_account ⇒ String
The service account that the DeployedModel's container runs as.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#unmanaged_container_model ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1UnmanagedContainerModel
Contains model information necessary to perform batch prediction without requiring a full model import.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1BatchPredictionJob
constructor
A new instance of GoogleCloudAiplatformV1BatchPredictionJob.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1BatchPredictionJob
Returns a new instance of GoogleCloudAiplatformV1BatchPredictionJob.
1779 1780 1781 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1779 def initialize(**args) update!(**args) end |
Instance Attribute Details
#completion_stats ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CompletionStats
Success and error statistics of processing multiple entities (for example,
DataItems or structured data rows) in batch.
Corresponds to the JSON property completionStats
1585 1586 1587 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1585 def completion_stats @completion_stats end |
#create_time ⇒ String
Output only. Time when the BatchPredictionJob was created.
Corresponds to the JSON property createTime
1590 1591 1592 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1590 def create_time @create_time end |
#dedicated_resources ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchDedicatedResources
A description of resources that are used for performing batch operations, are
dedicated to a Model, and need manual configuration.
Corresponds to the JSON property dedicatedResources
1596 1597 1598 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1596 def dedicated_resources @dedicated_resources end |
#disable_container_logging ⇒ Boolean Also known as: disable_container_logging?
For custom-trained Models and AutoML Tabular Models, the container of the
DeployedModel instances will send stderr and stdout streams to Cloud
Logging by default. Please note that the logs incur cost, which are subject to
Cloud Logging pricing. User can
disable container logging by setting this flag to true.
Corresponds to the JSON property disableContainerLogging
1605 1606 1607 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1605 def disable_container_logging @disable_container_logging end |
#display_name ⇒ String
Required. The user-defined name of this BatchPredictionJob.
Corresponds to the JSON property displayName
1611 1612 1613 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1611 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top-
level resource.
Corresponds to the JSON property encryptionSpec
1617 1618 1619 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1617 def encryption_spec @encryption_spec end |
#end_time ⇒ String
Output only. Time when the BatchPredictionJob entered any of the following
states: JOB_STATE_SUCCEEDED, JOB_STATE_FAILED, JOB_STATE_CANCELLED.
Corresponds to the JSON property endTime
1623 1624 1625 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1623 def end_time @end_time end |
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
1633 1634 1635 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1633 def error @error end |
#explanation_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationSpec
Specification of Model explanation.
Corresponds to the JSON property explanationSpec
1638 1639 1640 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1638 def explanation_spec @explanation_spec end |
#generate_explanation ⇒ Boolean Also known as: generate_explanation?
Generate explanation with the batch prediction results. When set to true,
the batch prediction output changes based on the predictions_format field of
the BatchPredictionJob.output_config object: * bigquery: output includes a
column named explanation. The value is a struct that conforms to the
Explanation object. * jsonl: The JSON objects on each line include an
additional entry keyed explanation. The value of the entry is a JSON object
that conforms to the Explanation object. * csv: Generating explanations for
CSV format is not supported. If this field is set to true, either the Model.
explanation_spec or explanation_spec must be populated.
Corresponds to the JSON property generateExplanation
1651 1652 1653 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1651 def generate_explanation @generate_explanation end |
#input_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchPredictionJobInputConfig
Configures the input to BatchPredictionJob. See Model.
supported_input_storage_formats for Model's supported input formats, and how
instances should be expressed via any of them.
Corresponds to the JSON property inputConfig
1659 1660 1661 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1659 def input_config @input_config end |
#instance_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchPredictionJobInstanceConfig
Configuration defining how to transform batch prediction input instances to
the instances that the Model accepts.
Corresponds to the JSON property instanceConfig
1665 1666 1667 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1665 def instance_config @instance_config end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize BatchPredictionJobs. Label
keys and values can be no longer than 64 characters (Unicode codepoints), can
only contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. See https://goo.gl/xmQnxf for more
information and examples of labels.
Corresponds to the JSON property labels
1674 1675 1676 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1674 def labels @labels end |
#manual_batch_tuning_parameters ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ManualBatchTuningParameters
Manual batch tuning parameters.
Corresponds to the JSON property manualBatchTuningParameters
1679 1680 1681 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1679 def manual_batch_tuning_parameters @manual_batch_tuning_parameters end |
#model ⇒ String
The name of the Model resource that produces the predictions via this job,
must share the same ancestor Location. Starting this job has no impact on any
existing deployments of the Model and their resources. Exactly one of model
and unmanaged_container_model must be set. The model resource name may contain
version id or version alias to specify the version. Example: projects/
project/locations/location/models/model@2 or projects/project/
locations/location/models/model@golden if no version is specified, the
default version will be deployed. The model resource could also be a publisher
model. Example: publishers/publisher/models/modelor `projects/`project`/
locations/`location`/publishers/`publisher`/models/`model
Corresponds to the JSON property model
1693 1694 1695 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1693 def model @model end |
#model_parameters ⇒ Object
The parameters that govern the predictions. The schema of the parameters may
be specified via the Model's PredictSchemata's parameters_schema_uri.
Corresponds to the JSON property modelParameters
1699 1700 1701 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1699 def model_parameters @model_parameters end |
#model_version_id ⇒ String
Output only. The version ID of the Model that produces the predictions via
this job.
Corresponds to the JSON property modelVersionId
1705 1706 1707 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1705 def model_version_id @model_version_id end |
#name ⇒ String
Output only. Resource name of the BatchPredictionJob.
Corresponds to the JSON property name
1710 1711 1712 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1710 def name @name end |
#output_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchPredictionJobOutputConfig
Configures the output of BatchPredictionJob. See Model.
supported_output_storage_formats for supported output formats, and how
predictions are expressed via any of them.
Corresponds to the JSON property outputConfig
1717 1718 1719 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1717 def output_config @output_config end |
#output_info ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchPredictionJobOutputInfo
Further describes this job's output. Supplements output_config.
Corresponds to the JSON property outputInfo
1722 1723 1724 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1722 def output_info @output_info end |
#partial_failures ⇒ Array<Google::Apis::AiplatformV1::GoogleRpcStatus>
Output only. Partial failures encountered. For example, single files that can'
t be read. This field never exceeds 20 entries. Status details fields contain
standard Google Cloud error details.
Corresponds to the JSON property partialFailures
1729 1730 1731 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1729 def partial_failures @partial_failures end |
#resources_consumed ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ResourcesConsumed
Statistics information about resource consumption.
Corresponds to the JSON property resourcesConsumed
1734 1735 1736 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1734 def resources_consumed @resources_consumed end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
1739 1740 1741 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1739 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
1745 1746 1747 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1745 def satisfies_pzs @satisfies_pzs end |
#service_account ⇒ String
The service account that the DeployedModel's container runs as. If not
specified, a system generated one will be used, which has minimal permissions
and the custom container, if used, may not have enough permission to access
other Google Cloud resources. Users deploying the Model must have the iam.
serviceAccounts.actAs permission on this service account.
Corresponds to the JSON property serviceAccount
1755 1756 1757 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1755 def service_account @service_account end |
#start_time ⇒ String
Output only. Time when the BatchPredictionJob for the first time entered the
JOB_STATE_RUNNING state.
Corresponds to the JSON property startTime
1761 1762 1763 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1761 def start_time @start_time end |
#state ⇒ String
Output only. The detailed state of the job.
Corresponds to the JSON property state
1766 1767 1768 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1766 def state @state end |
#unmanaged_container_model ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1UnmanagedContainerModel
Contains model information necessary to perform batch prediction without
requiring a full model import.
Corresponds to the JSON property unmanagedContainerModel
1772 1773 1774 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1772 def unmanaged_container_model @unmanaged_container_model end |
#update_time ⇒ String
Output only. Time when the BatchPredictionJob was most recently updated.
Corresponds to the JSON property updateTime
1777 1778 1779 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1777 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 1814 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 1784 def update!(**args) @completion_stats = args[:completion_stats] if args.key?(:completion_stats) @create_time = args[:create_time] if args.key?(:create_time) @dedicated_resources = args[:dedicated_resources] if args.key?(:dedicated_resources) @disable_container_logging = args[:disable_container_logging] if args.key?(:disable_container_logging) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @end_time = args[:end_time] if args.key?(:end_time) @error = args[:error] if args.key?(:error) @explanation_spec = args[:explanation_spec] if args.key?(:explanation_spec) @generate_explanation = args[:generate_explanation] if args.key?(:generate_explanation) @input_config = args[:input_config] if args.key?(:input_config) @instance_config = args[:instance_config] if args.key?(:instance_config) @labels = args[:labels] if args.key?(:labels) @manual_batch_tuning_parameters = args[:manual_batch_tuning_parameters] if args.key?(:manual_batch_tuning_parameters) @model = args[:model] if args.key?(:model) @model_parameters = args[:model_parameters] if args.key?(:model_parameters) @model_version_id = args[:model_version_id] if args.key?(:model_version_id) @name = args[:name] if args.key?(:name) @output_config = args[:output_config] if args.key?(:output_config) @output_info = args[:output_info] if args.key?(:output_info) @partial_failures = args[:partial_failures] if args.key?(:partial_failures) @resources_consumed = args[:resources_consumed] if args.key?(:resources_consumed) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @service_account = args[:service_account] if args.key?(:service_account) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @unmanaged_container_model = args[:unmanaged_container_model] if args.key?(:unmanaged_container_model) @update_time = args[:update_time] if args.key?(:update_time) end |