Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchPredictionJobInputConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Configures the input to BatchPredictionJob. See Model. supported_input_storage_formats for Model's supported input formats, and how instances should be expressed via any of them.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1BatchPredictionJobInputConfig

Returns a new instance of GoogleCloudAiplatformV1BatchPredictionJobInputConfig.



3614
3615
3616
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3614

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bigquery_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQuerySource

The BigQuery location for the input content. Corresponds to the JSON property bigquerySource



3596
3597
3598
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3596

def bigquery_source
  @bigquery_source
end

#gcs_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsSource

The Google Cloud Storage location for the input content. Corresponds to the JSON property gcsSource



3601
3602
3603
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3601

def gcs_source
  @gcs_source
end

#instances_formatString

Required. The format in which instances are given, must be one of the Model's supported_input_storage_formats. Corresponds to the JSON property instancesFormat

Returns:

  • (String)


3607
3608
3609
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3607

def instances_format
  @instances_format
end

#vertex_multimodal_dataset_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexMultimodalDatasetSource

The Vertex Multimodal Dataset for the input content. Corresponds to the JSON property vertexMultimodalDatasetSource



3612
3613
3614
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3612

def vertex_multimodal_dataset_source
  @vertex_multimodal_dataset_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3619
3620
3621
3622
3623
3624
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3619

def update!(**args)
  @bigquery_source = args[:bigquery_source] if args.key?(:bigquery_source)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @instances_format = args[:instances_format] if args.key?(:instances_format)
  @vertex_multimodal_dataset_source = args[:vertex_multimodal_dataset_source] if args.key?(:vertex_multimodal_dataset_source)
end