Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchPredictionJobInputConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchPredictionJobInputConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Configures the input to BatchPredictionJob. See Model. supported_input_storage_formats for Model's supported input formats, and how instances should be expressed via any of them.
Instance Attribute Summary collapse
-
#bigquery_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQuerySource
The BigQuery location for the input content.
-
#gcs_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsSource
The Google Cloud Storage location for the input content.
-
#instances_format ⇒ String
Required.
-
#vertex_multimodal_dataset_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexMultimodalDatasetSource
The Vertex Multimodal Dataset for the input content.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1BatchPredictionJobInputConfig
constructor
A new instance of GoogleCloudAiplatformV1BatchPredictionJobInputConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1BatchPredictionJobInputConfig
Returns a new instance of GoogleCloudAiplatformV1BatchPredictionJobInputConfig.
3386 3387 3388 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3386 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bigquery_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQuerySource
The BigQuery location for the input content.
Corresponds to the JSON property bigquerySource
3368 3369 3370 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3368 def bigquery_source @bigquery_source end |
#gcs_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsSource
The Google Cloud Storage location for the input content.
Corresponds to the JSON property gcsSource
3373 3374 3375 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3373 def gcs_source @gcs_source end |
#instances_format ⇒ String
Required. The format in which instances are given, must be one of the Model's
supported_input_storage_formats.
Corresponds to the JSON property instancesFormat
3379 3380 3381 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3379 def instances_format @instances_format end |
#vertex_multimodal_dataset_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexMultimodalDatasetSource
The Vertex Multimodal Dataset for the input content.
Corresponds to the JSON property vertexMultimodalDatasetSource
3384 3385 3386 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3384 def vertex_multimodal_dataset_source @vertex_multimodal_dataset_source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3391 3392 3393 3394 3395 3396 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3391 def update!(**args) @bigquery_source = args[:bigquery_source] if args.key?(:bigquery_source) @gcs_source = args[:gcs_source] if args.key?(:gcs_source) @instances_format = args[:instances_format] if args.key?(:instances_format) @vertex_multimodal_dataset_source = args[:vertex_multimodal_dataset_source] if args.key?(:vertex_multimodal_dataset_source) end |