Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchPredictionJobInputConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchPredictionJobInputConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Configures the input to BatchPredictionJob. See Model. supported_input_storage_formats for Model's supported input formats, and how instances should be expressed via any of them.
Instance Attribute Summary collapse
-
#bigquery_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQuerySource
The BigQuery location for the input content.
-
#gcs_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsSource
The Google Cloud Storage location for the input content.
-
#instances_format ⇒ String
Required.
-
#vertex_multimodal_dataset_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexMultimodalDatasetSource
The Vertex Multimodal Dataset for the input content.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1BatchPredictionJobInputConfig
constructor
A new instance of GoogleCloudAiplatformV1BatchPredictionJobInputConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1BatchPredictionJobInputConfig
Returns a new instance of GoogleCloudAiplatformV1BatchPredictionJobInputConfig.
3065 3066 3067 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3065 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bigquery_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQuerySource
The BigQuery location for the input content.
Corresponds to the JSON property bigquerySource
3047 3048 3049 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3047 def bigquery_source @bigquery_source end |
#gcs_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsSource
The Google Cloud Storage location for the input content.
Corresponds to the JSON property gcsSource
3052 3053 3054 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3052 def gcs_source @gcs_source end |
#instances_format ⇒ String
Required. The format in which instances are given, must be one of the Model's
supported_input_storage_formats.
Corresponds to the JSON property instancesFormat
3058 3059 3060 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3058 def instances_format @instances_format end |
#vertex_multimodal_dataset_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexMultimodalDatasetSource
The Vertex Multimodal Dataset for the input content.
Corresponds to the JSON property vertexMultimodalDatasetSource
3063 3064 3065 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3063 def vertex_multimodal_dataset_source @vertex_multimodal_dataset_source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3070 3071 3072 3073 3074 3075 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3070 def update!(**args) @bigquery_source = args[:bigquery_source] if args.key?(:bigquery_source) @gcs_source = args[:gcs_source] if args.key?(:gcs_source) @instances_format = args[:instances_format] if args.key?(:instances_format) @vertex_multimodal_dataset_source = args[:vertex_multimodal_dataset_source] if args.key?(:vertex_multimodal_dataset_source) end |