Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchPredictionJobInputConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Configures the input to BatchPredictionJob. See Model. supported_input_storage_formats for Model's supported input formats, and how instances should be expressed via any of them.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1BatchPredictionJobInputConfig

Returns a new instance of GoogleCloudAiplatformV1BatchPredictionJobInputConfig.



2669
2670
2671
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2669

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bigquery_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQuerySource

The BigQuery location for the input content. Corresponds to the JSON property bigquerySource



2651
2652
2653
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2651

def bigquery_source
  @bigquery_source
end

#gcs_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsSource

The Google Cloud Storage location for the input content. Corresponds to the JSON property gcsSource



2656
2657
2658
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2656

def gcs_source
  @gcs_source
end

#instances_formatString

Required. The format in which instances are given, must be one of the Model's supported_input_storage_formats. Corresponds to the JSON property instancesFormat

Returns:

  • (String)


2662
2663
2664
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2662

def instances_format
  @instances_format
end

#vertex_multimodal_dataset_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexMultimodalDatasetSource

The Vertex Multimodal Dataset for the input content. Corresponds to the JSON property vertexMultimodalDatasetSource



2667
2668
2669
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2667

def vertex_multimodal_dataset_source
  @vertex_multimodal_dataset_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2674
2675
2676
2677
2678
2679
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2674

def update!(**args)
  @bigquery_source = args[:bigquery_source] if args.key?(:bigquery_source)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @instances_format = args[:instances_format] if args.key?(:instances_format)
  @vertex_multimodal_dataset_source = args[:vertex_multimodal_dataset_source] if args.key?(:vertex_multimodal_dataset_source)
end