Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchPredictionJobInputConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Configures the input to BatchPredictionJob. See Model. supported_input_storage_formats for Model's supported input formats, and how instances should be expressed via any of them.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1BatchPredictionJobInputConfig

Returns a new instance of GoogleCloudAiplatformV1BatchPredictionJobInputConfig.



2630
2631
2632
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2630

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bigquery_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQuerySource

The BigQuery location for the input content. Corresponds to the JSON property bigquerySource



2617
2618
2619
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2617

def bigquery_source
  @bigquery_source
end

#gcs_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsSource

The Google Cloud Storage location for the input content. Corresponds to the JSON property gcsSource



2622
2623
2624
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2622

def gcs_source
  @gcs_source
end

#instances_formatString

Required. The format in which instances are given, must be one of the Model's supported_input_storage_formats. Corresponds to the JSON property instancesFormat

Returns:

  • (String)


2628
2629
2630
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2628

def instances_format
  @instances_format
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2635
2636
2637
2638
2639
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2635

def update!(**args)
  @bigquery_source = args[:bigquery_source] if args.key?(:bigquery_source)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @instances_format = args[:instances_format] if args.key?(:instances_format)
end