Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchPredictionJobOutputConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Configures the output of BatchPredictionJob. See Model. supported_output_storage_formats for supported output formats, and how predictions are expressed via any of them.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1BatchPredictionJobOutputConfig

Returns a new instance of GoogleCloudAiplatformV1BatchPredictionJobOutputConfig.



3179
3180
3181
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3179

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bigquery_destinationGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQueryDestination

The BigQuery location for the output content. Corresponds to the JSON property bigqueryDestination



3161
3162
3163
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3161

def bigquery_destination
  @bigquery_destination
end

#gcs_destinationGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsDestination

The Google Cloud Storage location where the output is to be written to. Corresponds to the JSON property gcsDestination



3166
3167
3168
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3166

def gcs_destination
  @gcs_destination
end

#predictions_formatString

Required. The format in which Vertex AI gives the predictions, must be one of the Model's supported_output_storage_formats. Corresponds to the JSON property predictionsFormat

Returns:

  • (String)


3172
3173
3174
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3172

def predictions_format
  @predictions_format
end

#vertex_multimodal_dataset_destinationGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexMultimodalDatasetDestination

The details for a Vertex Multimodal Dataset output. Corresponds to the JSON property vertexMultimodalDatasetDestination



3177
3178
3179
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3177

def vertex_multimodal_dataset_destination
  @vertex_multimodal_dataset_destination
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3184
3185
3186
3187
3188
3189
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3184

def update!(**args)
  @bigquery_destination = args[:bigquery_destination] if args.key?(:bigquery_destination)
  @gcs_destination = args[:gcs_destination] if args.key?(:gcs_destination)
  @predictions_format = args[:predictions_format] if args.key?(:predictions_format)
  @vertex_multimodal_dataset_destination = args[:vertex_multimodal_dataset_destination] if args.key?(:vertex_multimodal_dataset_destination)
end