Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchPredictionJobOutputConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchPredictionJobOutputConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Configures the output of BatchPredictionJob. See Model. supported_output_storage_formats for supported output formats, and how predictions are expressed via any of them.
Instance Attribute Summary collapse
-
#bigquery_destination ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQueryDestination
The BigQuery location for the output content.
-
#gcs_destination ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsDestination
The Google Cloud Storage location where the output is to be written to.
-
#predictions_format ⇒ String
Required.
-
#vertex_multimodal_dataset_destination ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexMultimodalDatasetDestination
The details for a Vertex Multimodal Dataset output.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1BatchPredictionJobOutputConfig
constructor
A new instance of GoogleCloudAiplatformV1BatchPredictionJobOutputConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1BatchPredictionJobOutputConfig
Returns a new instance of GoogleCloudAiplatformV1BatchPredictionJobOutputConfig.
2829 2830 2831 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2829 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bigquery_destination ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQueryDestination
The BigQuery location for the output content.
Corresponds to the JSON property bigqueryDestination
2811 2812 2813 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2811 def bigquery_destination @bigquery_destination end |
#gcs_destination ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsDestination
The Google Cloud Storage location where the output is to be written to.
Corresponds to the JSON property gcsDestination
2816 2817 2818 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2816 def gcs_destination @gcs_destination end |
#predictions_format ⇒ String
Required. The format in which Vertex AI gives the predictions, must be one of
the Model's supported_output_storage_formats.
Corresponds to the JSON property predictionsFormat
2822 2823 2824 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2822 def predictions_format @predictions_format end |
#vertex_multimodal_dataset_destination ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexMultimodalDatasetDestination
The details for a Vertex Multimodal Dataset output.
Corresponds to the JSON property vertexMultimodalDatasetDestination
2827 2828 2829 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2827 def vertex_multimodal_dataset_destination @vertex_multimodal_dataset_destination end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2834 2835 2836 2837 2838 2839 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2834 def update!(**args) @bigquery_destination = args[:bigquery_destination] if args.key?(:bigquery_destination) @gcs_destination = args[:gcs_destination] if args.key?(:gcs_destination) @predictions_format = args[:predictions_format] if args.key?(:predictions_format) @vertex_multimodal_dataset_destination = args[:vertex_multimodal_dataset_destination] if args.key?(:vertex_multimodal_dataset_destination) end |