Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchPredictionJobOutputConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Configures the output of BatchPredictionJob. See Model. supported_output_storage_formats for supported output formats, and how predictions are expressed via any of them.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1BatchPredictionJobOutputConfig

Returns a new instance of GoogleCloudAiplatformV1BatchPredictionJobOutputConfig.



2817
2818
2819
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2817

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bigquery_destinationGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQueryDestination

The BigQuery location for the output content. Corresponds to the JSON property bigqueryDestination



2799
2800
2801
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2799

def bigquery_destination
  @bigquery_destination
end

#gcs_destinationGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsDestination

The Google Cloud Storage location where the output is to be written to. Corresponds to the JSON property gcsDestination



2804
2805
2806
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2804

def gcs_destination
  @gcs_destination
end

#predictions_formatString

Required. The format in which Vertex AI gives the predictions, must be one of the Model's supported_output_storage_formats. Corresponds to the JSON property predictionsFormat

Returns:

  • (String)


2810
2811
2812
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2810

def predictions_format
  @predictions_format
end

#vertex_multimodal_dataset_destinationGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexMultimodalDatasetDestination

The details for a Vertex Multimodal Dataset output. Corresponds to the JSON property vertexMultimodalDatasetDestination



2815
2816
2817
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2815

def vertex_multimodal_dataset_destination
  @vertex_multimodal_dataset_destination
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2822
2823
2824
2825
2826
2827
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2822

def update!(**args)
  @bigquery_destination = args[:bigquery_destination] if args.key?(:bigquery_destination)
  @gcs_destination = args[:gcs_destination] if args.key?(:gcs_destination)
  @predictions_format = args[:predictions_format] if args.key?(:predictions_format)
  @vertex_multimodal_dataset_destination = args[:vertex_multimodal_dataset_destination] if args.key?(:vertex_multimodal_dataset_destination)
end