Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchPredictionJobOutputConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Configures the output of BatchPredictionJob. See Model. supported_output_storage_formats for supported output formats, and how predictions are expressed via any of them.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1BatchPredictionJobOutputConfig

Returns a new instance of GoogleCloudAiplatformV1BatchPredictionJobOutputConfig.



2496
2497
2498
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2496

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bigquery_destinationGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQueryDestination

The BigQuery location for the output content. Corresponds to the JSON property bigqueryDestination



2478
2479
2480
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2478

def bigquery_destination
  @bigquery_destination
end

#gcs_destinationGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsDestination

The Google Cloud Storage location where the output is to be written to. Corresponds to the JSON property gcsDestination



2483
2484
2485
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2483

def gcs_destination
  @gcs_destination
end

#predictions_formatString

Required. The format in which Vertex AI gives the predictions, must be one of the Model's supported_output_storage_formats. Corresponds to the JSON property predictionsFormat

Returns:

  • (String)


2489
2490
2491
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2489

def predictions_format
  @predictions_format
end

#vertex_multimodal_dataset_destinationGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexMultimodalDatasetDestination

The details for a Vertex Multimodal Dataset output. Corresponds to the JSON property vertexMultimodalDatasetDestination



2494
2495
2496
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2494

def vertex_multimodal_dataset_destination
  @vertex_multimodal_dataset_destination
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2501
2502
2503
2504
2505
2506
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2501

def update!(**args)
  @bigquery_destination = args[:bigquery_destination] if args.key?(:bigquery_destination)
  @gcs_destination = args[:gcs_destination] if args.key?(:gcs_destination)
  @predictions_format = args[:predictions_format] if args.key?(:predictions_format)
  @vertex_multimodal_dataset_destination = args[:vertex_multimodal_dataset_destination] if args.key?(:vertex_multimodal_dataset_destination)
end