Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchPredictionJobOutputInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Further describes this job's output. Supplements output_config.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1BatchPredictionJobOutputInfo

Returns a new instance of GoogleCloudAiplatformV1BatchPredictionJobOutputInfo.



3298
3299
3300
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3298

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bigquery_output_datasetString

Output only. The path of the BigQuery dataset created, in bq://projectId. bqDatasetId format, into which the prediction output is written. Corresponds to the JSON property bigqueryOutputDataset

Returns:

  • (String)


3276
3277
3278
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3276

def bigquery_output_dataset
  @bigquery_output_dataset
end

#bigquery_output_tableString

Output only. The name of the BigQuery table created, in predictions_ format, into which the prediction output is written. Can be used by UI to generate the BigQuery output path, for example. Corresponds to the JSON property bigqueryOutputTable

Returns:

  • (String)


3283
3284
3285
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3283

def bigquery_output_table
  @bigquery_output_table
end

#gcs_output_directoryString

Output only. The full path of the Cloud Storage directory created, into which the prediction output is written. Corresponds to the JSON property gcsOutputDirectory

Returns:

  • (String)


3289
3290
3291
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3289

def gcs_output_directory
  @gcs_output_directory
end

#vertex_multimodal_dataset_nameString

Output only. The resource name of the Vertex Managed Dataset created, into which the prediction output is written. Format: projects/project/locations/ location/datasets/dataset` Corresponds to the JSON propertyvertexMultimodalDatasetName`

Returns:

  • (String)


3296
3297
3298
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3296

def vertex_multimodal_dataset_name
  @vertex_multimodal_dataset_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3303
3304
3305
3306
3307
3308
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3303

def update!(**args)
  @bigquery_output_dataset = args[:bigquery_output_dataset] if args.key?(:bigquery_output_dataset)
  @bigquery_output_table = args[:bigquery_output_table] if args.key?(:bigquery_output_table)
  @gcs_output_directory = args[:gcs_output_directory] if args.key?(:gcs_output_directory)
  @vertex_multimodal_dataset_name = args[:vertex_multimodal_dataset_name] if args.key?(:vertex_multimodal_dataset_name)
end