Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchReadFeatureValuesRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchReadFeatureValuesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Request message for FeaturestoreService.BatchReadFeatureValues.
Instance Attribute Summary collapse
-
#bigquery_read_instances ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQuerySource
The BigQuery location for the input content.
-
#csv_read_instances ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CsvSource
The storage details for CSV input content.
-
#destination ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureValueDestination
A destination location for Feature values and format.
-
#entity_type_specs ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchReadFeatureValuesRequestEntityTypeSpec>
Required.
-
#pass_through_fields ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchReadFeatureValuesRequestPassThroughField>
When not empty, the specified fields in the *_read_instances source will be joined as-is in the output, in addition to those fields from the Featurestore Entity.
-
#start_time ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1BatchReadFeatureValuesRequest
constructor
A new instance of GoogleCloudAiplatformV1BatchReadFeatureValuesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1BatchReadFeatureValuesRequest
Returns a new instance of GoogleCloudAiplatformV1BatchReadFeatureValuesRequest.
2945 2946 2947 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2945 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bigquery_read_instances ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQuerySource
The BigQuery location for the input content.
Corresponds to the JSON property bigqueryReadInstances
2911 2912 2913 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2911 def bigquery_read_instances @bigquery_read_instances end |
#csv_read_instances ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CsvSource
The storage details for CSV input content.
Corresponds to the JSON property csvReadInstances
2916 2917 2918 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2916 def csv_read_instances @csv_read_instances end |
#destination ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureValueDestination
A destination location for Feature values and format.
Corresponds to the JSON property destination
2921 2922 2923 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2921 def destination @destination end |
#entity_type_specs ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchReadFeatureValuesRequestEntityTypeSpec>
Required. Specifies EntityType grouping Features to read values of and
settings.
Corresponds to the JSON property entityTypeSpecs
2927 2928 2929 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2927 def entity_type_specs @entity_type_specs end |
#pass_through_fields ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchReadFeatureValuesRequestPassThroughField>
When not empty, the specified fields in the *_read_instances source will be
joined as-is in the output, in addition to those fields from the Featurestore
Entity. For BigQuery source, the type of the pass-through values will be
automatically inferred. For CSV source, the pass-through values will be passed
as opaque bytes.
Corresponds to the JSON property passThroughFields
2936 2937 2938 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2936 def pass_through_fields @pass_through_fields end |
#start_time ⇒ String
Optional. Excludes Feature values with feature generation timestamp before
this timestamp. If not set, retrieve oldest values kept in Feature Store.
Timestamp, if present, must not have higher than millisecond precision.
Corresponds to the JSON property startTime
2943 2944 2945 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2943 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2950 2951 2952 2953 2954 2955 2956 2957 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2950 def update!(**args) @bigquery_read_instances = args[:bigquery_read_instances] if args.key?(:bigquery_read_instances) @csv_read_instances = args[:csv_read_instances] if args.key?(:csv_read_instances) @destination = args[:destination] if args.key?(:destination) @entity_type_specs = args[:entity_type_specs] if args.key?(:entity_type_specs) @pass_through_fields = args[:pass_through_fields] if args.key?(:pass_through_fields) @start_time = args[:start_time] if args.key?(:start_time) end |