Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchReadFeatureValuesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for FeaturestoreService.BatchReadFeatureValues.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1BatchReadFeatureValuesRequest

Returns a new instance of GoogleCloudAiplatformV1BatchReadFeatureValuesRequest.



2273
2274
2275
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2273

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bigquery_read_instancesGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQuerySource

The BigQuery location for the input content. Corresponds to the JSON property bigqueryReadInstances



2239
2240
2241
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2239

def bigquery_read_instances
  @bigquery_read_instances
end

#csv_read_instancesGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1CsvSource

The storage details for CSV input content. Corresponds to the JSON property csvReadInstances



2244
2245
2246
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2244

def csv_read_instances
  @csv_read_instances
end

#destinationGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureValueDestination

A destination location for Feature values and format. Corresponds to the JSON property destination



2249
2250
2251
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2249

def destination
  @destination
end

#entity_type_specsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchReadFeatureValuesRequestEntityTypeSpec>

Required. Specifies EntityType grouping Features to read values of and settings. Corresponds to the JSON property entityTypeSpecs



2255
2256
2257
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2255

def entity_type_specs
  @entity_type_specs
end

#pass_through_fieldsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BatchReadFeatureValuesRequestPassThroughField>

When not empty, the specified fields in the *_read_instances source will be joined as-is in the output, in addition to those fields from the Featurestore Entity. For BigQuery source, the type of the pass-through values will be automatically inferred. For CSV source, the pass-through values will be passed as opaque bytes. Corresponds to the JSON property passThroughFields



2264
2265
2266
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2264

def pass_through_fields
  @pass_through_fields
end

#start_timeString

Optional. Excludes Feature values with feature generation timestamp before this timestamp. If not set, retrieve oldest values kept in Feature Store. Timestamp, if present, must not have higher than millisecond precision. Corresponds to the JSON property startTime

Returns:

  • (String)


2271
2272
2273
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2271

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2278
2279
2280
2281
2282
2283
2284
2285
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2278

def update!(**args)
  @bigquery_read_instances = args[:bigquery_read_instances] if args.key?(:bigquery_read_instances)
  @csv_read_instances = args[:csv_read_instances] if args.key?(:csv_read_instances)
  @destination = args[:destination] if args.key?(:destination)
  @entity_type_specs = args[:entity_type_specs] if args.key?(:entity_type_specs)
  @pass_through_fields = args[:pass_through_fields] if args.key?(:pass_through_fields)
  @start_time = args[:start_time] if args.key?(:start_time)
end