Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQueryDestination
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQueryDestination
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The BigQuery location for the output content.
Instance Attribute Summary collapse
-
#output_uri ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1BigQueryDestination
constructor
A new instance of GoogleCloudAiplatformV1BigQueryDestination.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1BigQueryDestination
Returns a new instance of GoogleCloudAiplatformV1BigQueryDestination.
3046 3047 3048 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3046 def initialize(**args) update!(**args) end |
Instance Attribute Details
#output_uri ⇒ String
Required. BigQuery URI to a project or table, up to 2000 characters long. When
only the project is specified, the Dataset and Table is created. When the full
table reference is specified, the Dataset must exist and table must not exist.
Accepted forms: * BigQuery path. For example: bq://projectId or bq://
projectId.bqDatasetId or bq://projectId.bqDatasetId.bqTableId.
Corresponds to the JSON property outputUri
3044 3045 3046 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3044 def output_uri @output_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3051 3052 3053 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3051 def update!(**args) @output_uri = args[:output_uri] if args.key?(:output_uri) end |