Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQueryRequestSet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The request set for the evaluation run.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1BigQueryRequestSet

Returns a new instance of GoogleCloudAiplatformV1BigQueryRequestSet.



3055
3056
3057
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3055

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#candidate_response_columnsHash<String,String>

Optional. Map of candidate name to candidate response column name. The column will be in evaluation_item.CandidateResponse format. Corresponds to the JSON property candidateResponseColumns

Returns:

  • (Hash<String,String>)


3030
3031
3032
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3030

def candidate_response_columns
  @candidate_response_columns
end

#prompt_columnString

Optional. The name of the column that contains the requests to evaluate. This will be in evaluation_item.EvalPrompt format. Corresponds to the JSON property promptColumn

Returns:

  • (String)


3036
3037
3038
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3036

def prompt_column
  @prompt_column
end

#rubrics_columnString

Optional. The name of the column that contains the rubrics. This is in evaluation_rubric.RubricGroup format. Corresponds to the JSON property rubricsColumn

Returns:

  • (String)


3042
3043
3044
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3042

def rubrics_column
  @rubrics_column
end

#sampling_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQueryRequestSetSamplingConfig

The sampling config. Corresponds to the JSON property samplingConfig



3047
3048
3049
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3047

def sampling_config
  @sampling_config
end

#uriString

Required. The URI of a BigQuery table. e.g. bq://projectId.bqDatasetId. bqTableId Corresponds to the JSON property uri

Returns:

  • (String)


3053
3054
3055
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3053

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3060
3061
3062
3063
3064
3065
3066
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3060

def update!(**args)
  @candidate_response_columns = args[:candidate_response_columns] if args.key?(:candidate_response_columns)
  @prompt_column = args[:prompt_column] if args.key?(:prompt_column)
  @rubrics_column = args[:rubrics_column] if args.key?(:rubrics_column)
  @sampling_config = args[:sampling_config] if args.key?(:sampling_config)
  @uri = args[:uri] if args.key?(:uri)
end