Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQueryRequestSet
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQueryRequestSet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The request set for the evaluation run.
Instance Attribute Summary collapse
-
#candidate_response_columns ⇒ Hash<String,String>
Optional.
-
#prompt_column ⇒ String
Optional.
-
#rubrics_column ⇒ String
Optional.
-
#sampling_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQueryRequestSetSamplingConfig
The sampling config.
-
#uri ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1BigQueryRequestSet
constructor
A new instance of GoogleCloudAiplatformV1BigQueryRequestSet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1BigQueryRequestSet
Returns a new instance of GoogleCloudAiplatformV1BigQueryRequestSet.
2768 2769 2770 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2768 def initialize(**args) update!(**args) end |
Instance Attribute Details
#candidate_response_columns ⇒ Hash<String,String>
Optional. Map of candidate name to candidate response column name. The column
will be in evaluation_item.CandidateResponse format.
Corresponds to the JSON property candidateResponseColumns
2743 2744 2745 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2743 def candidate_response_columns @candidate_response_columns end |
#prompt_column ⇒ String
Optional. The name of the column that contains the requests to evaluate. This
will be in evaluation_item.EvalPrompt format.
Corresponds to the JSON property promptColumn
2749 2750 2751 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2749 def prompt_column @prompt_column end |
#rubrics_column ⇒ String
Optional. The name of the column that contains the rubrics. This is in
evaluation_rubric.RubricGroup format.
Corresponds to the JSON property rubricsColumn
2755 2756 2757 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2755 def rubrics_column @rubrics_column end |
#sampling_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQueryRequestSetSamplingConfig
The sampling config.
Corresponds to the JSON property samplingConfig
2760 2761 2762 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2760 def sampling_config @sampling_config end |
#uri ⇒ String
Required. The URI of a BigQuery table. e.g. bq://projectId.bqDatasetId.
bqTableId
Corresponds to the JSON property uri
2766 2767 2768 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2766 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2773 2774 2775 2776 2777 2778 2779 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2773 def update!(**args) @candidate_response_columns = args[:candidate_response_columns] if args.key?(:candidate_response_columns) @prompt_column = args[:prompt_column] if args.key?(:prompt_column) @rubrics_column = args[:rubrics_column] if args.key?(:rubrics_column) @sampling_config = args[:sampling_config] if args.key?(:sampling_config) @uri = args[:uri] if args.key?(:uri) end |