Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Blob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A content blob. A Blob contains data of a specific media type. It is used to represent images, audio, and video.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Blob

Returns a new instance of GoogleCloudAiplatformV1Blob.



3256
3257
3258
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3256

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dataString

Required. The raw bytes of the data. Corresponds to the JSON property data NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


3241
3242
3243
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3241

def data
  @data
end

#display_nameString

Optional. The display name of the blob. Used to provide a label or filename to distinguish blobs. This field is only returned in PromptMessage for prompt management. It is used in the Gemini calls only when server-side tools ( code_execution, google_search, and url_context) are enabled. Corresponds to the JSON property displayName

Returns:

  • (String)


3249
3250
3251
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3249

def display_name
  @display_name
end

#mime_typeString

Required. The IANA standard MIME type of the source data. Corresponds to the JSON property mimeType

Returns:

  • (String)


3254
3255
3256
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3254

def mime_type
  @mime_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3261
3262
3263
3264
3265
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3261

def update!(**args)
  @data = args[:data] if args.key?(:data)
  @display_name = args[:display_name] if args.key?(:display_name)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
end