Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Blob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Content blob.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Blob

Returns a new instance of GoogleCloudAiplatformV1Blob.



2761
2762
2763
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2761

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dataString

Required. Raw bytes. Corresponds to the JSON property data NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


2747
2748
2749
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2747

def data
  @data
end

#display_nameString

Optional. Display name of the blob. Used to provide a label or filename to distinguish blobs. This field is only returned in PromptMessage for prompt management. It is not currently used in the Gemini GenerateContent calls. Corresponds to the JSON property displayName

Returns:

  • (String)


2754
2755
2756
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2754

def display_name
  @display_name
end

#mime_typeString

Required. The IANA standard MIME type of the source data. Corresponds to the JSON property mimeType

Returns:

  • (String)


2759
2760
2761
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2759

def mime_type
  @mime_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2766
2767
2768
2769
2770
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2766

def update!(**args)
  @data = args[:data] if args.key?(:data)
  @display_name = args[:display_name] if args.key?(:display_name)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
end