Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BlurBaselineConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BlurBaselineConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Config for blur baseline. When enabled, a linear path from the maximally blurred image to the input image is created. Using a blurred baseline instead of zero (black image) is motivated by the BlurIG approach explained here: https://arxiv.org/abs/2004.03383
Instance Attribute Summary collapse
-
#max_blur_sigma ⇒ Float
The standard deviation of the blur kernel for the blurred baseline.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1BlurBaselineConfig
constructor
A new instance of GoogleCloudAiplatformV1BlurBaselineConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1BlurBaselineConfig
Returns a new instance of GoogleCloudAiplatformV1BlurBaselineConfig.
2280 2281 2282 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2280 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_blur_sigma ⇒ Float
The standard deviation of the blur kernel for the blurred baseline. The same
blurring parameter is used for both the height and the width dimension. If not
set, the method defaults to the zero (i.e. black for images) baseline.
Corresponds to the JSON property maxBlurSigma
2278 2279 2280 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2278 def max_blur_sigma @max_blur_sigma end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2285 2286 2287 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2285 def update!(**args) @max_blur_sigma = args[:max_blur_sigma] if args.key?(:max_blur_sigma) end |