Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CachedContent
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CachedContent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A resource used in LLM queries for users to explicitly specify what to cache and how to cache.
Instance Attribute Summary collapse
-
#contents ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content>
Optional.
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Optional.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top- level resource.
-
#expire_time ⇒ String
Timestamp of when this resource is considered expired.
-
#model ⇒ String
Immutable.
-
#name ⇒ String
Immutable.
-
#system_instruction ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content
The base structured datatype containing multi-part content of a message.
-
#tool_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolConfig
Tool config.
-
#tools ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tool>
Optional.
-
#ttl ⇒ String
Input only.
-
#update_time ⇒ String
Output only.
-
#usage_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CachedContentUsageMetadata
Metadata on the usage of the cached content.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1CachedContent
constructor
A new instance of GoogleCloudAiplatformV1CachedContent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1CachedContent
Returns a new instance of GoogleCloudAiplatformV1CachedContent.
2927 2928 2929 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2927 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contents ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content>
Optional. Input only. Immutable. The content to cache
Corresponds to the JSON property contents
2853 2854 2855 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2853 def contents @contents end |
#create_time ⇒ String
Output only. Creation time of the cache entry.
Corresponds to the JSON property createTime
2858 2859 2860 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2858 def create_time @create_time end |
#display_name ⇒ String
Optional. Immutable. The user-generated meaningful display name of the cached
content.
Corresponds to the JSON property displayName
2864 2865 2866 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2864 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top-
level resource.
Corresponds to the JSON property encryptionSpec
2870 2871 2872 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2870 def encryption_spec @encryption_spec end |
#expire_time ⇒ String
Timestamp of when this resource is considered expired. This is always
provided on output, regardless of what was sent on input.
Corresponds to the JSON property expireTime
2876 2877 2878 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2876 def expire_time @expire_time end |
#model ⇒ String
Immutable. The name of the Model to use for cached content. Currently, only
the published Gemini base models are supported, in form of projects/PROJECT/
locations/LOCATION/publishers/google/models/MODEL
Corresponds to the JSON property model
2883 2884 2885 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2883 def model @model end |
#name ⇒ String
Immutable. Identifier. The server-generated resource name of the cached
content Format: projects/project/locations/location/cachedContents/
cached_content
Corresponds to the JSON property name
2890 2891 2892 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2890 def name @name end |
#system_instruction ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content
The base structured datatype containing multi-part content of a message. A
Content includes a role field designating the producer of the Content and
a parts field containing multi-part data that contains the content of the
message turn.
Corresponds to the JSON property systemInstruction
2898 2899 2900 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2898 def system_instruction @system_instruction end |
#tool_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolConfig
Tool config. This config is shared for all tools provided in the request.
Corresponds to the JSON property toolConfig
2903 2904 2905 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2903 def tool_config @tool_config end |
#tools ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tool>
Optional. Input only. Immutable. A list of Tools the model may use to
generate the next response
Corresponds to the JSON property tools
2909 2910 2911 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2909 def tools @tools end |
#ttl ⇒ String
Input only. The TTL for this resource. The expiration time is computed: now +
TTL.
Corresponds to the JSON property ttl
2915 2916 2917 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2915 def ttl @ttl end |
#update_time ⇒ String
Output only. When the cache entry was last updated in UTC time.
Corresponds to the JSON property updateTime
2920 2921 2922 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2920 def update_time @update_time end |
#usage_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CachedContentUsageMetadata
Metadata on the usage of the cached content.
Corresponds to the JSON property usageMetadata
2925 2926 2927 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2925 def @usage_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2932 2933 2934 2935 2936 2937 2938 2939 2940 2941 2942 2943 2944 2945 2946 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2932 def update!(**args) @contents = args[:contents] if args.key?(:contents) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @expire_time = args[:expire_time] if args.key?(:expire_time) @model = args[:model] if args.key?(:model) @name = args[:name] if args.key?(:name) @system_instruction = args[:system_instruction] if args.key?(:system_instruction) @tool_config = args[:tool_config] if args.key?(:tool_config) @tools = args[:tools] if args.key?(:tools) @ttl = args[:ttl] if args.key?(:ttl) @update_time = args[:update_time] if args.key?(:update_time) @usage_metadata = args[:usage_metadata] if args.key?(:usage_metadata) end |