Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CachedContent
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CachedContent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A resource used in LLM queries for users to explicitly specify what to cache and how to cache.
Instance Attribute Summary collapse
-
#contents ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content>
Optional.
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Optional.
-
#expire_time ⇒ String
Timestamp of when this resource is considered expired.
-
#model ⇒ String
Immutable.
-
#name ⇒ String
Immutable.
-
#system_instruction ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content
The base structured datatype containing multi-part content of a message.
-
#tool_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolConfig
Tool config.
-
#tools ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tool>
Optional.
-
#ttl ⇒ String
Input only.
-
#update_time ⇒ String
Output only.
-
#usage_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CachedContentUsageMetadata
Metadata on the usage of the cached content.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1CachedContent
constructor
A new instance of GoogleCloudAiplatformV1CachedContent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1CachedContent
Returns a new instance of GoogleCloudAiplatformV1CachedContent.
2706 2707 2708 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2706 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contents ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content>
Optional. Input only. Immutable. The content to cache
Corresponds to the JSON property contents
2638 2639 2640 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2638 def contents @contents end |
#create_time ⇒ String
Output only. Creation time of the cache entry.
Corresponds to the JSON property createTime
2643 2644 2645 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2643 def create_time @create_time end |
#display_name ⇒ String
Optional. Immutable. The user-generated meaningful display name of the cached
content.
Corresponds to the JSON property displayName
2649 2650 2651 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2649 def display_name @display_name end |
#expire_time ⇒ String
Timestamp of when this resource is considered expired. This is always
provided on output, regardless of what was sent on input.
Corresponds to the JSON property expireTime
2655 2656 2657 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2655 def expire_time @expire_time end |
#model ⇒ String
Immutable. The name of the Model to use for cached content. Currently, only
the published Gemini base models are supported, in form of projects/PROJECT/
locations/LOCATION/publishers/google/models/MODEL
Corresponds to the JSON property model
2662 2663 2664 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2662 def model @model end |
#name ⇒ String
Immutable. Identifier. The server-generated resource name of the cached
content Format: projects/project/locations/location/cachedContents/
cached_content
Corresponds to the JSON property name
2669 2670 2671 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2669 def name @name end |
#system_instruction ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content
The base structured datatype containing multi-part content of a message. A
Content includes a role field designating the producer of the Content and
a parts field containing multi-part data that contains the content of the
message turn.
Corresponds to the JSON property systemInstruction
2677 2678 2679 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2677 def system_instruction @system_instruction end |
#tool_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolConfig
Tool config. This config is shared for all tools provided in the request.
Corresponds to the JSON property toolConfig
2682 2683 2684 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2682 def tool_config @tool_config end |
#tools ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tool>
Optional. Input only. Immutable. A list of Tools the model may use to
generate the next response
Corresponds to the JSON property tools
2688 2689 2690 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2688 def tools @tools end |
#ttl ⇒ String
Input only. The TTL for this resource. The expiration time is computed: now +
TTL.
Corresponds to the JSON property ttl
2694 2695 2696 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2694 def ttl @ttl end |
#update_time ⇒ String
Output only. When the cache entry was last updated in UTC time.
Corresponds to the JSON property updateTime
2699 2700 2701 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2699 def update_time @update_time end |
#usage_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CachedContentUsageMetadata
Metadata on the usage of the cached content.
Corresponds to the JSON property usageMetadata
2704 2705 2706 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2704 def @usage_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2711 2712 2713 2714 2715 2716 2717 2718 2719 2720 2721 2722 2723 2724 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2711 def update!(**args) @contents = args[:contents] if args.key?(:contents) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @expire_time = args[:expire_time] if args.key?(:expire_time) @model = args[:model] if args.key?(:model) @name = args[:name] if args.key?(:name) @system_instruction = args[:system_instruction] if args.key?(:system_instruction) @tool_config = args[:tool_config] if args.key?(:tool_config) @tools = args[:tools] if args.key?(:tools) @ttl = args[:ttl] if args.key?(:ttl) @update_time = args[:update_time] if args.key?(:update_time) @usage_metadata = args[:usage_metadata] if args.key?(:usage_metadata) end |