Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CachedContentUsageMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CachedContentUsageMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Metadata on the usage of the cached content.
Instance Attribute Summary collapse
-
#audio_duration_seconds ⇒ Fixnum
Duration of audio in seconds.
-
#image_count ⇒ Fixnum
Number of images.
-
#text_count ⇒ Fixnum
Number of text characters.
-
#total_token_count ⇒ Fixnum
Total number of tokens that the cached content consumes.
-
#video_duration_seconds ⇒ Fixnum
Duration of video in seconds.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1CachedContentUsageMetadata
constructor
A new instance of GoogleCloudAiplatformV1CachedContentUsageMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1CachedContentUsageMetadata
Returns a new instance of GoogleCloudAiplatformV1CachedContentUsageMetadata.
3608 3609 3610 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3608 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audio_duration_seconds ⇒ Fixnum
Duration of audio in seconds.
Corresponds to the JSON property audioDurationSeconds
3586 3587 3588 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3586 def audio_duration_seconds @audio_duration_seconds end |
#image_count ⇒ Fixnum
Number of images.
Corresponds to the JSON property imageCount
3591 3592 3593 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3591 def image_count @image_count end |
#text_count ⇒ Fixnum
Number of text characters.
Corresponds to the JSON property textCount
3596 3597 3598 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3596 def text_count @text_count end |
#total_token_count ⇒ Fixnum
Total number of tokens that the cached content consumes.
Corresponds to the JSON property totalTokenCount
3601 3602 3603 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3601 def total_token_count @total_token_count end |
#video_duration_seconds ⇒ Fixnum
Duration of video in seconds.
Corresponds to the JSON property videoDurationSeconds
3606 3607 3608 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3606 def video_duration_seconds @video_duration_seconds end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3613 3614 3615 3616 3617 3618 3619 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3613 def update!(**args) @audio_duration_seconds = args[:audio_duration_seconds] if args.key?(:audio_duration_seconds) @image_count = args[:image_count] if args.key?(:image_count) @text_count = args[:text_count] if args.key?(:text_count) @total_token_count = args[:total_token_count] if args.key?(:total_token_count) @video_duration_seconds = args[:video_duration_seconds] if args.key?(:video_duration_seconds) end |