Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CachedContentUsageMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CachedContentUsageMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Metadata on the usage of the cached content.
Instance Attribute Summary collapse
-
#audio_duration_seconds ⇒ Fixnum
Duration of audio in seconds.
-
#image_count ⇒ Fixnum
Number of images.
-
#text_count ⇒ Fixnum
Number of text characters.
-
#total_token_count ⇒ Fixnum
Total number of tokens that the cached content consumes.
-
#video_duration_seconds ⇒ Fixnum
Duration of video in seconds.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1CachedContentUsageMetadata
constructor
A new instance of GoogleCloudAiplatformV1CachedContentUsageMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1CachedContentUsageMetadata
Returns a new instance of GoogleCloudAiplatformV1CachedContentUsageMetadata.
3183 3184 3185 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3183 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audio_duration_seconds ⇒ Fixnum
Duration of audio in seconds.
Corresponds to the JSON property audioDurationSeconds
3161 3162 3163 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3161 def audio_duration_seconds @audio_duration_seconds end |
#image_count ⇒ Fixnum
Number of images.
Corresponds to the JSON property imageCount
3166 3167 3168 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3166 def image_count @image_count end |
#text_count ⇒ Fixnum
Number of text characters.
Corresponds to the JSON property textCount
3171 3172 3173 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3171 def text_count @text_count end |
#total_token_count ⇒ Fixnum
Total number of tokens that the cached content consumes.
Corresponds to the JSON property totalTokenCount
3176 3177 3178 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3176 def total_token_count @total_token_count end |
#video_duration_seconds ⇒ Fixnum
Duration of video in seconds.
Corresponds to the JSON property videoDurationSeconds
3181 3182 3183 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3181 def video_duration_seconds @video_duration_seconds end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3188 3189 3190 3191 3192 3193 3194 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3188 def update!(**args) @audio_duration_seconds = args[:audio_duration_seconds] if args.key?(:audio_duration_seconds) @image_count = args[:image_count] if args.key?(:image_count) @text_count = args[:text_count] if args.key?(:text_count) @total_token_count = args[:total_token_count] if args.key?(:total_token_count) @video_duration_seconds = args[:video_duration_seconds] if args.key?(:video_duration_seconds) end |