Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Candidate

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A response candidate generated from the model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Candidate

Returns a new instance of GoogleCloudAiplatformV1Candidate.



3386
3387
3388
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3386

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#avg_logprobsFloat

Output only. The average log probability of the tokens in this candidate. This is a length-normalized score that can be used to compare the quality of candidates of different lengths. A higher average log probability suggests a more confident and coherent response. Corresponds to the JSON property avgLogprobs

Returns:

  • (Float)


3324
3325
3326
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3324

def avg_logprobs
  @avg_logprobs
end

#citation_metadataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1CitationMetadata

A collection of citations that apply to a piece of generated content. Corresponds to the JSON property citationMetadata



3329
3330
3331
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3329

def 
  @citation_metadata
end

#contentGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Content

The structured data content of a message. A Content message contains a role field, which indicates the producer of the content, and a parts field, which contains the multi-part data of the message. Corresponds to the JSON property content



3336
3337
3338
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3336

def content
  @content
end

#finish_messageString

Output only. Describes the reason the model stopped generating tokens in more detail. This field is returned only when finish_reason is set. Corresponds to the JSON property finishMessage

Returns:

  • (String)


3342
3343
3344
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3342

def finish_message
  @finish_message
end

#finish_reasonString

Output only. The reason why the model stopped generating tokens. If empty, the model has not stopped generating. Corresponds to the JSON property finishReason

Returns:

  • (String)


3348
3349
3350
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3348

def finish_reason
  @finish_reason
end

#grounding_metadataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingMetadata

Information about the sources that support the content of a response. When grounding is enabled, the model returns citations for claims in the response. This object contains the retrieved sources. Corresponds to the JSON property groundingMetadata



3355
3356
3357
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3355

def 
  @grounding_metadata
end

#indexFixnum

Output only. The 0-based index of this candidate in the list of generated responses. This is useful for distinguishing between multiple candidates when candidate_count > 1. Corresponds to the JSON property index

Returns:

  • (Fixnum)


3362
3363
3364
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3362

def index
  @index
end

#logprobs_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1LogprobsResult

The log probabilities of the tokens generated by the model. This is useful for understanding the model's confidence in its predictions and for debugging. For example, you can use log probabilities to identify when the model is making a less confident prediction or to explore alternative responses that the model considered. A low log probability can also indicate that the model is " hallucinating" or generating factually incorrect information. Corresponds to the JSON property logprobsResult



3372
3373
3374
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3372

def logprobs_result
  @logprobs_result
end

#safety_ratingsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetyRating>

Output only. A list of ratings for the safety of a response candidate. There is at most one rating per category. Corresponds to the JSON property safetyRatings



3378
3379
3380
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3378

def safety_ratings
  @safety_ratings
end

#url_context_metadataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1UrlContextMetadata

Metadata returned when the model uses the url_context tool to get information from a user-provided URL. Corresponds to the JSON property urlContextMetadata



3384
3385
3386
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3384

def 
  @url_context_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3391
3392
3393
3394
3395
3396
3397
3398
3399
3400
3401
3402
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3391

def update!(**args)
  @avg_logprobs = args[:avg_logprobs] if args.key?(:avg_logprobs)
  @citation_metadata = args[:citation_metadata] if args.key?(:citation_metadata)
  @content = args[:content] if args.key?(:content)
  @finish_message = args[:finish_message] if args.key?(:finish_message)
  @finish_reason = args[:finish_reason] if args.key?(:finish_reason)
  @grounding_metadata = args[:grounding_metadata] if args.key?(:grounding_metadata)
  @index = args[:index] if args.key?(:index)
  @logprobs_result = args[:logprobs_result] if args.key?(:logprobs_result)
  @safety_ratings = args[:safety_ratings] if args.key?(:safety_ratings)
  @url_context_metadata = args[:url_context_metadata] if args.key?(:url_context_metadata)
end