Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Candidate
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Candidate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A response candidate generated from the model.
Instance Attribute Summary collapse
-
#avg_logprobs ⇒ Float
Output only.
-
#citation_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CitationMetadata
A collection of source attributions for a piece of content.
-
#content ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content
The base structured datatype containing multi-part content of a message.
-
#finish_message ⇒ String
Output only.
-
#finish_reason ⇒ String
Output only.
-
#grounding_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingMetadata
Metadata returned to client when grounding is enabled.
-
#index ⇒ Fixnum
Output only.
-
#logprobs_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1LogprobsResult
Logprobs Result Corresponds to the JSON property
logprobsResult. -
#safety_ratings ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetyRating>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Candidate
constructor
A new instance of GoogleCloudAiplatformV1Candidate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Candidate
Returns a new instance of GoogleCloudAiplatformV1Candidate.
2929 2930 2931 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2929 def initialize(**args) update!(**args) end |
Instance Attribute Details
#avg_logprobs ⇒ Float
Output only. Average log probability score of the candidate.
Corresponds to the JSON property avgLogprobs
2881 2882 2883 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2881 def avg_logprobs @avg_logprobs end |
#citation_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CitationMetadata
A collection of source attributions for a piece of content.
Corresponds to the JSON property citationMetadata
2886 2887 2888 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2886 def @citation_metadata end |
#content ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content
The base structured datatype containing multi-part content of a message. A
Content includes a role field designating the producer of the Content and
a parts field containing multi-part data that contains the content of the
message turn.
Corresponds to the JSON property content
2894 2895 2896 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2894 def content @content end |
#finish_message ⇒ String
Output only. Describes the reason the mode stopped generating tokens in more
detail. This is only filled when finish_reason is set.
Corresponds to the JSON property finishMessage
2900 2901 2902 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2900 def @finish_message end |
#finish_reason ⇒ String
Output only. The reason why the model stopped generating tokens. If empty, the
model has not stopped generating the tokens.
Corresponds to the JSON property finishReason
2906 2907 2908 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2906 def finish_reason @finish_reason end |
#grounding_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingMetadata
Metadata returned to client when grounding is enabled.
Corresponds to the JSON property groundingMetadata
2911 2912 2913 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2911 def @grounding_metadata end |
#index ⇒ Fixnum
Output only. Index of the candidate.
Corresponds to the JSON property index
2916 2917 2918 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2916 def index @index end |
#logprobs_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1LogprobsResult
Logprobs Result
Corresponds to the JSON property logprobsResult
2921 2922 2923 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2921 def logprobs_result @logprobs_result end |
#safety_ratings ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetyRating>
Output only. List of ratings for the safety of a response candidate. There is
at most one rating per category.
Corresponds to the JSON property safetyRatings
2927 2928 2929 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2927 def @safety_ratings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2934 2935 2936 2937 2938 2939 2940 2941 2942 2943 2944 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2934 def update!(**args) @avg_logprobs = args[:avg_logprobs] if args.key?(:avg_logprobs) @citation_metadata = args[:citation_metadata] if args.key?(:citation_metadata) @content = args[:content] if args.key?(:content) @finish_message = args[:finish_message] if args.key?(:finish_message) @finish_reason = args[:finish_reason] if args.key?(:finish_reason) @grounding_metadata = args[:grounding_metadata] if args.key?(:grounding_metadata) @index = args[:index] if args.key?(:index) @logprobs_result = args[:logprobs_result] if args.key?(:logprobs_result) @safety_ratings = args[:safety_ratings] if args.key?(:safety_ratings) end |