Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Candidate
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Candidate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A response candidate generated from the model.
Instance Attribute Summary collapse
-
#citation_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CitationMetadata
A collection of source attributions for a piece of content.
-
#content ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content
The base structured datatype containing multi-part content of a message.
-
#finish_message ⇒ String
Output only.
-
#finish_reason ⇒ String
Output only.
-
#grounding_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingMetadata
Metadata returned to client when grounding is enabled.
-
#index ⇒ Fixnum
Output only.
-
#safety_ratings ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetyRating>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Candidate
constructor
A new instance of GoogleCloudAiplatformV1Candidate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Candidate
Returns a new instance of GoogleCloudAiplatformV1Candidate.
2457 2458 2459 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2457 def initialize(**args) update!(**args) end |
Instance Attribute Details
#citation_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CitationMetadata
A collection of source attributions for a piece of content.
Corresponds to the JSON property citationMetadata
2419 2420 2421 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2419 def @citation_metadata end |
#content ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content
The base structured datatype containing multi-part content of a message. A
Content includes a role field designating the producer of the Content and
a parts field containing multi-part data that contains the content of the
message turn.
Corresponds to the JSON property content
2427 2428 2429 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2427 def content @content end |
#finish_message ⇒ String
Output only. Describes the reason the mode stopped generating tokens in more
detail. This is only filled when finish_reason is set.
Corresponds to the JSON property finishMessage
2433 2434 2435 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2433 def @finish_message end |
#finish_reason ⇒ String
Output only. The reason why the model stopped generating tokens. If empty, the
model has not stopped generating the tokens.
Corresponds to the JSON property finishReason
2439 2440 2441 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2439 def finish_reason @finish_reason end |
#grounding_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingMetadata
Metadata returned to client when grounding is enabled.
Corresponds to the JSON property groundingMetadata
2444 2445 2446 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2444 def @grounding_metadata end |
#index ⇒ Fixnum
Output only. Index of the candidate.
Corresponds to the JSON property index
2449 2450 2451 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2449 def index @index end |
#safety_ratings ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetyRating>
Output only. List of ratings for the safety of a response candidate. There is
at most one rating per category.
Corresponds to the JSON property safetyRatings
2455 2456 2457 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2455 def @safety_ratings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2462 2463 2464 2465 2466 2467 2468 2469 2470 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2462 def update!(**args) @citation_metadata = args[:citation_metadata] if args.key?(:citation_metadata) @content = args[:content] if args.key?(:content) @finish_message = args[:finish_message] if args.key?(:finish_message) @finish_reason = args[:finish_reason] if args.key?(:finish_reason) @grounding_metadata = args[:grounding_metadata] if args.key?(:grounding_metadata) @index = args[:index] if args.key?(:index) @safety_ratings = args[:safety_ratings] if args.key?(:safety_ratings) end |