Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CandidateResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CandidateResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Responses from model or agent.
Instance Attribute Summary collapse
-
#agent_data ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AgentData
Represents data specific to multi-turn agent evaluations.
-
#candidate ⇒ String
Required.
-
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#text ⇒ String
Text response.
-
#value ⇒ Object
Fields and values that can be used to populate the response template.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1CandidateResponse
constructor
A new instance of GoogleCloudAiplatformV1CandidateResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1CandidateResponse
Returns a new instance of GoogleCloudAiplatformV1CandidateResponse.
4234 4235 4236 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4234 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_data ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AgentData
Represents data specific to multi-turn agent evaluations.
Corresponds to the JSON property agentData
4207 4208 4209 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4207 def agent_data @agent_data end |
#candidate ⇒ String
Required. The name of the candidate that produced the response.
Corresponds to the JSON property candidate
4212 4213 4214 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4212 def candidate @candidate end |
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
4222 4223 4224 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4222 def error @error end |
#text ⇒ String
Text response.
Corresponds to the JSON property text
4227 4228 4229 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4227 def text @text end |
#value ⇒ Object
Fields and values that can be used to populate the response template.
Corresponds to the JSON property value
4232 4233 4234 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4232 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4239 4240 4241 4242 4243 4244 4245 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4239 def update!(**args) @agent_data = args[:agent_data] if args.key?(:agent_data) @candidate = args[:candidate] if args.key?(:candidate) @error = args[:error] if args.key?(:error) @text = args[:text] if args.key?(:text) @value = args[:value] if args.key?(:value) end |