Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CandidateResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CandidateResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Responses from model or agent.
Instance Attribute Summary collapse
-
#candidate ⇒ String
Required.
-
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#text ⇒ String
Text response.
-
#value ⇒ Object
Fields and values that can be used to populate the response template.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1CandidateResponse
constructor
A new instance of GoogleCloudAiplatformV1CandidateResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1CandidateResponse
Returns a new instance of GoogleCloudAiplatformV1CandidateResponse.
3895 3896 3897 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3895 def initialize(**args) update!(**args) end |
Instance Attribute Details
#candidate ⇒ String
Required. The name of the candidate that produced the response.
Corresponds to the JSON property candidate
3873 3874 3875 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3873 def candidate @candidate end |
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
3883 3884 3885 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3883 def error @error end |
#text ⇒ String
Text response.
Corresponds to the JSON property text
3888 3889 3890 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3888 def text @text end |
#value ⇒ Object
Fields and values that can be used to populate the response template.
Corresponds to the JSON property value
3893 3894 3895 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3893 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3900 3901 3902 3903 3904 3905 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3900 def update!(**args) @candidate = args[:candidate] if args.key?(:candidate) @error = args[:error] if args.key?(:error) @text = args[:text] if args.key?(:text) @value = args[:value] if args.key?(:value) end |