Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CandidateResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Responses from model or agent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1CandidateResponse

Returns a new instance of GoogleCloudAiplatformV1CandidateResponse.



3803
3804
3805
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3803

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#candidateString

Required. The name of the candidate that produced the response. Corresponds to the JSON property candidate

Returns:

  • (String)


3781
3782
3783
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3781

def candidate
  @candidate
end

#errorGoogle::Apis::AiplatformV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



3791
3792
3793
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3791

def error
  @error
end

#textString

Text response. Corresponds to the JSON property text

Returns:

  • (String)


3796
3797
3798
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3796

def text
  @text
end

#valueObject

Fields and values that can be used to populate the response template. Corresponds to the JSON property value

Returns:

  • (Object)


3801
3802
3803
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3801

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3808
3809
3810
3811
3812
3813
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3808

def update!(**args)
  @candidate = args[:candidate] if args.key?(:candidate)
  @error = args[:error] if args.key?(:error)
  @text = args[:text] if args.key?(:text)
  @value = args[:value] if args.key?(:value)
end