Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CandidateResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CandidateResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Responses from model or agent.
Instance Attribute Summary collapse
-
#candidate ⇒ String
Required.
-
#text ⇒ String
Text response.
-
#value ⇒ Object
Fields and values that can be used to populate the response template.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1CandidateResponse
constructor
A new instance of GoogleCloudAiplatformV1CandidateResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1CandidateResponse
Returns a new instance of GoogleCloudAiplatformV1CandidateResponse.
3424 3425 3426 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3424 def initialize(**args) update!(**args) end |
Instance Attribute Details
#candidate ⇒ String
Required. The name of the candidate that produced the response.
Corresponds to the JSON property candidate
3412 3413 3414 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3412 def candidate @candidate end |
#text ⇒ String
Text response.
Corresponds to the JSON property text
3417 3418 3419 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3417 def text @text end |
#value ⇒ Object
Fields and values that can be used to populate the response template.
Corresponds to the JSON property value
3422 3423 3424 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3422 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3429 3430 3431 3432 3433 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3429 def update!(**args) @candidate = args[:candidate] if args.key?(:candidate) @text = args[:text] if args.key?(:text) @value = args[:value] if args.key?(:value) end |