Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CandidateResult
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CandidateResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Result for a single candidate.
Instance Attribute Summary collapse
-
#additional_results ⇒ Object
Optional.
-
#candidate ⇒ String
Required.
-
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#explanation ⇒ String
Optional.
-
#metric ⇒ String
Required.
-
#rubric_verdicts ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricVerdict>
Optional.
-
#score ⇒ Float
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1CandidateResult
constructor
A new instance of GoogleCloudAiplatformV1CandidateResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1CandidateResult
Returns a new instance of GoogleCloudAiplatformV1CandidateResult.
4538 4539 4540 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4538 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_results ⇒ Object
Optional. Additional results for the metric.
Corresponds to the JSON property additionalResults
4500 4501 4502 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4500 def additional_results @additional_results end |
#candidate ⇒ String
Required. The candidate that is being evaluated. The value is the same as the
candidate name in the EvaluationRequest.
Corresponds to the JSON property candidate
4506 4507 4508 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4506 def candidate @candidate end |
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
4516 4517 4518 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4516 def error @error end |
#explanation ⇒ String
Optional. The explanation for the metric.
Corresponds to the JSON property explanation
4521 4522 4523 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4521 def explanation @explanation end |
#metric ⇒ String
Required. The metric that was evaluated.
Corresponds to the JSON property metric
4526 4527 4528 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4526 def metric @metric end |
#rubric_verdicts ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricVerdict>
Optional. The rubric verdicts for the metric.
Corresponds to the JSON property rubricVerdicts
4531 4532 4533 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4531 def rubric_verdicts @rubric_verdicts end |
#score ⇒ Float
Optional. The score for the metric.
Corresponds to the JSON property score
4536 4537 4538 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4536 def score @score end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4543 4544 4545 4546 4547 4548 4549 4550 4551 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4543 def update!(**args) @additional_results = args[:additional_results] if args.key?(:additional_results) @candidate = args[:candidate] if args.key?(:candidate) @error = args[:error] if args.key?(:error) @explanation = args[:explanation] if args.key?(:explanation) @metric = args[:metric] if args.key?(:metric) @rubric_verdicts = args[:rubric_verdicts] if args.key?(:rubric_verdicts) @score = args[:score] if args.key?(:score) end |