Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CandidateResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Result for a single candidate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1CandidateResult

Returns a new instance of GoogleCloudAiplatformV1CandidateResult.



4293
4294
4295
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4293

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_resultsObject

Optional. Additional results for the metric. Corresponds to the JSON property additionalResults

Returns:

  • (Object)


4255
4256
4257
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4255

def additional_results
  @additional_results
end

#candidateString

Required. The candidate that is being evaluated. The value is the same as the candidate name in the EvaluationRequest. Corresponds to the JSON property candidate

Returns:

  • (String)


4261
4262
4263
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4261

def candidate
  @candidate
end

#errorGoogle::Apis::AiplatformV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



4271
4272
4273
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4271

def error
  @error
end

#explanationString

Optional. The explanation for the metric. Corresponds to the JSON property explanation

Returns:

  • (String)


4276
4277
4278
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4276

def explanation
  @explanation
end

#metricString

Required. The metric that was evaluated. Corresponds to the JSON property metric

Returns:

  • (String)


4281
4282
4283
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4281

def metric
  @metric
end

#rubric_verdictsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricVerdict>

Optional. The rubric verdicts for the metric. Corresponds to the JSON property rubricVerdicts



4286
4287
4288
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4286

def rubric_verdicts
  @rubric_verdicts
end

#scoreFloat

Optional. The score for the metric. Corresponds to the JSON property score

Returns:

  • (Float)


4291
4292
4293
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4291

def score
  @score
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4298
4299
4300
4301
4302
4303
4304
4305
4306
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4298

def update!(**args)
  @additional_results = args[:additional_results] if args.key?(:additional_results)
  @candidate = args[:candidate] if args.key?(:candidate)
  @error = args[:error] if args.key?(:error)
  @explanation = args[:explanation] if args.key?(:explanation)
  @metric = args[:metric] if args.key?(:metric)
  @rubric_verdicts = args[:rubric_verdicts] if args.key?(:rubric_verdicts)
  @score = args[:score] if args.key?(:score)
end