Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Citation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A citation for a piece of generatedcontent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Citation

Returns a new instance of GoogleCloudAiplatformV1Citation.



3955
3956
3957
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3955

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_indexFixnum

Output only. The end index of the citation in the content. Corresponds to the JSON property endIndex

Returns:

  • (Fixnum)


3921
3922
3923
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3921

def end_index
  @end_index
end

#licenseString

Output only. The license of the source of the citation. Corresponds to the JSON property license

Returns:

  • (String)


3926
3927
3928
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3926

def license
  @license
end

#publication_dateGoogle::Apis::AiplatformV1::GoogleTypeDate

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property publicationDate



3938
3939
3940
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3938

def publication_date
  @publication_date
end

#start_indexFixnum

Output only. The start index of the citation in the content. Corresponds to the JSON property startIndex

Returns:

  • (Fixnum)


3943
3944
3945
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3943

def start_index
  @start_index
end

#titleString

Output only. The title of the source of the citation. Corresponds to the JSON property title

Returns:

  • (String)


3948
3949
3950
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3948

def title
  @title
end

#uriString

Output only. The URI of the source of the citation. Corresponds to the JSON property uri

Returns:

  • (String)


3953
3954
3955
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3953

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3960
3961
3962
3963
3964
3965
3966
3967
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3960

def update!(**args)
  @end_index = args[:end_index] if args.key?(:end_index)
  @license = args[:license] if args.key?(:license)
  @publication_date = args[:publication_date] if args.key?(:publication_date)
  @start_index = args[:start_index] if args.key?(:start_index)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end