Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Citation
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Citation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A citation for a piece of generatedcontent.
Instance Attribute Summary collapse
-
#end_index ⇒ Fixnum
Output only.
-
#license ⇒ String
Output only.
-
#publication_date ⇒ Google::Apis::AiplatformV1::GoogleTypeDate
Represents a whole or partial calendar date, such as a birthday.
-
#start_index ⇒ Fixnum
Output only.
-
#title ⇒ String
Output only.
-
#uri ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Citation
constructor
A new instance of GoogleCloudAiplatformV1Citation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Citation
Returns a new instance of GoogleCloudAiplatformV1Citation.
3657 3658 3659 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3657 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_index ⇒ Fixnum
Output only. The end index of the citation in the content.
Corresponds to the JSON property endIndex
3623 3624 3625 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3623 def end_index @end_index end |
#license ⇒ String
Output only. The license of the source of the citation.
Corresponds to the JSON property license
3628 3629 3630 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3628 def license @license end |
#publication_date ⇒ Google::Apis::AiplatformV1::GoogleTypeDate
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property publicationDate
3640 3641 3642 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3640 def publication_date @publication_date end |
#start_index ⇒ Fixnum
Output only. The start index of the citation in the content.
Corresponds to the JSON property startIndex
3645 3646 3647 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3645 def start_index @start_index end |
#title ⇒ String
Output only. The title of the source of the citation.
Corresponds to the JSON property title
3650 3651 3652 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3650 def title @title end |
#uri ⇒ String
Output only. The URI of the source of the citation.
Corresponds to the JSON property uri
3655 3656 3657 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3655 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3662 3663 3664 3665 3666 3667 3668 3669 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3662 def update!(**args) @end_index = args[:end_index] if args.key?(:end_index) @license = args[:license] if args.key?(:license) @publication_date = args[:publication_date] if args.key?(:publication_date) @start_index = args[:start_index] if args.key?(:start_index) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) end |