Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Citation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Source attributions for content.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Citation

Returns a new instance of GoogleCloudAiplatformV1Citation.



2579
2580
2581
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2579

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_indexFixnum

Output only. End index into the content. Corresponds to the JSON property endIndex

Returns:

  • (Fixnum)


2545
2546
2547
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2545

def end_index
  @end_index
end

#licenseString

Output only. License of the attribution. Corresponds to the JSON property license

Returns:

  • (String)


2550
2551
2552
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2550

def license
  @license
end

#publication_dateGoogle::Apis::AiplatformV1::GoogleTypeDate

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property publicationDate



2562
2563
2564
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2562

def publication_date
  @publication_date
end

#start_indexFixnum

Output only. Start index into the content. Corresponds to the JSON property startIndex

Returns:

  • (Fixnum)


2567
2568
2569
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2567

def start_index
  @start_index
end

#titleString

Output only. Title of the attribution. Corresponds to the JSON property title

Returns:

  • (String)


2572
2573
2574
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2572

def title
  @title
end

#uriString

Output only. Url reference of the attribution. Corresponds to the JSON property uri

Returns:

  • (String)


2577
2578
2579
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2577

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2584
2585
2586
2587
2588
2589
2590
2591
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2584

def update!(**args)
  @end_index = args[:end_index] if args.key?(:end_index)
  @license = args[:license] if args.key?(:license)
  @publication_date = args[:publication_date] if args.key?(:publication_date)
  @start_index = args[:start_index] if args.key?(:start_index)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end