Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Citation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Source attributions for content.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Citation

Returns a new instance of GoogleCloudAiplatformV1Citation.



3081
3082
3083
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3081

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_indexFixnum

Output only. End index into the content. Corresponds to the JSON property endIndex

Returns:

  • (Fixnum)


3047
3048
3049
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3047

def end_index
  @end_index
end

#licenseString

Output only. License of the attribution. Corresponds to the JSON property license

Returns:

  • (String)


3052
3053
3054
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3052

def license
  @license
end

#publication_dateGoogle::Apis::AiplatformV1::GoogleTypeDate

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property publicationDate



3064
3065
3066
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3064

def publication_date
  @publication_date
end

#start_indexFixnum

Output only. Start index into the content. Corresponds to the JSON property startIndex

Returns:

  • (Fixnum)


3069
3070
3071
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3069

def start_index
  @start_index
end

#titleString

Output only. Title of the attribution. Corresponds to the JSON property title

Returns:

  • (String)


3074
3075
3076
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3074

def title
  @title
end

#uriString

Output only. Url reference of the attribution. Corresponds to the JSON property uri

Returns:

  • (String)


3079
3080
3081
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3079

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3086
3087
3088
3089
3090
3091
3092
3093
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3086

def update!(**args)
  @end_index = args[:end_index] if args.key?(:end_index)
  @license = args[:license] if args.key?(:license)
  @publication_date = args[:publication_date] if args.key?(:publication_date)
  @start_index = args[:start_index] if args.key?(:start_index)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end