Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Claim

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Claim that is extracted from the input text and facts that support it.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Claim

Returns a new instance of GoogleCloudAiplatformV1Claim.



4095
4096
4097
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4095

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_indexFixnum

Index in the input text where the claim ends (exclusive). Corresponds to the JSON property endIndex

Returns:

  • (Fixnum)


4078
4079
4080
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4078

def end_index
  @end_index
end

#fact_indexesArray<Fixnum>

Indexes of the facts supporting this claim. Corresponds to the JSON property factIndexes

Returns:

  • (Array<Fixnum>)


4083
4084
4085
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4083

def fact_indexes
  @fact_indexes
end

#scoreFloat

Confidence score of this corroboration. Corresponds to the JSON property score

Returns:

  • (Float)


4088
4089
4090
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4088

def score
  @score
end

#start_indexFixnum

Index in the input text where the claim starts (inclusive). Corresponds to the JSON property startIndex

Returns:

  • (Fixnum)


4093
4094
4095
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4093

def start_index
  @start_index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4100
4101
4102
4103
4104
4105
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4100

def update!(**args)
  @end_index = args[:end_index] if args.key?(:end_index)
  @fact_indexes = args[:fact_indexes] if args.key?(:fact_indexes)
  @score = args[:score] if args.key?(:score)
  @start_index = args[:start_index] if args.key?(:start_index)
end