Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Claim

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Claim that is extracted from the input text and facts that support it.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Claim

Returns a new instance of GoogleCloudAiplatformV1Claim.



3715
3716
3717
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3715

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_indexFixnum

Index in the input text where the claim ends (exclusive). Corresponds to the JSON property endIndex

Returns:

  • (Fixnum)


3698
3699
3700
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3698

def end_index
  @end_index
end

#fact_indexesArray<Fixnum>

Indexes of the facts supporting this claim. Corresponds to the JSON property factIndexes

Returns:

  • (Array<Fixnum>)


3703
3704
3705
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3703

def fact_indexes
  @fact_indexes
end

#scoreFloat

Confidence score of this corroboration. Corresponds to the JSON property score

Returns:

  • (Float)


3708
3709
3710
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3708

def score
  @score
end

#start_indexFixnum

Index in the input text where the claim starts (inclusive). Corresponds to the JSON property startIndex

Returns:

  • (Fixnum)


3713
3714
3715
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3713

def start_index
  @start_index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3720
3721
3722
3723
3724
3725
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3720

def update!(**args)
  @end_index = args[:end_index] if args.key?(:end_index)
  @fact_indexes = args[:fact_indexes] if args.key?(:fact_indexes)
  @score = args[:score] if args.key?(:score)
  @start_index = args[:start_index] if args.key?(:start_index)
end