Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Claim

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Claim that is extracted from the input text and facts that support it.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Claim

Returns a new instance of GoogleCloudAiplatformV1Claim.



3370
3371
3372
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3370

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_indexFixnum

Index in the input text where the claim ends (exclusive). Corresponds to the JSON property endIndex

Returns:

  • (Fixnum)


3353
3354
3355
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3353

def end_index
  @end_index
end

#fact_indexesArray<Fixnum>

Indexes of the facts supporting this claim. Corresponds to the JSON property factIndexes

Returns:

  • (Array<Fixnum>)


3358
3359
3360
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3358

def fact_indexes
  @fact_indexes
end

#scoreFloat

Confidence score of this corroboration. Corresponds to the JSON property score

Returns:

  • (Float)


3363
3364
3365
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3363

def score
  @score
end

#start_indexFixnum

Index in the input text where the claim starts (inclusive). Corresponds to the JSON property startIndex

Returns:

  • (Fixnum)


3368
3369
3370
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3368

def start_index
  @start_index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3375
3376
3377
3378
3379
3380
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3375

def update!(**args)
  @end_index = args[:end_index] if args.key?(:end_index)
  @fact_indexes = args[:fact_indexes] if args.key?(:fact_indexes)
  @score = args[:score] if args.key?(:score)
  @start_index = args[:start_index] if args.key?(:start_index)
end