Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Claim
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Claim
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Claim that is extracted from the input text and facts that support it.
Instance Attribute Summary collapse
-
#end_index ⇒ Fixnum
Index in the input text where the claim ends (exclusive).
-
#fact_indexes ⇒ Array<Fixnum>
Indexes of the facts supporting this claim.
-
#score ⇒ Float
Confidence score of this corroboration.
-
#start_index ⇒ Fixnum
Index in the input text where the claim starts (inclusive).
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Claim
constructor
A new instance of GoogleCloudAiplatformV1Claim.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Claim
Returns a new instance of GoogleCloudAiplatformV1Claim.
3111 3112 3113 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3111 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_index ⇒ Fixnum
Index in the input text where the claim ends (exclusive).
Corresponds to the JSON property endIndex
3094 3095 3096 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3094 def end_index @end_index end |
#fact_indexes ⇒ Array<Fixnum>
Indexes of the facts supporting this claim.
Corresponds to the JSON property factIndexes
3099 3100 3101 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3099 def fact_indexes @fact_indexes end |
#score ⇒ Float
Confidence score of this corroboration.
Corresponds to the JSON property score
3104 3105 3106 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3104 def score @score end |
#start_index ⇒ Fixnum
Index in the input text where the claim starts (inclusive).
Corresponds to the JSON property startIndex
3109 3110 3111 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3109 def start_index @start_index end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3116 3117 3118 3119 3120 3121 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3116 def update!(**args) @end_index = args[:end_index] if args.key?(:end_index) @fact_indexes = args[:fact_indexes] if args.key?(:fact_indexes) @score = args[:score] if args.key?(:score) @start_index = args[:start_index] if args.key?(:start_index) end |