Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CompletionStats

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Success and error statistics of processing multiple entities (for example, DataItems or structured data rows) in batch.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1CompletionStats

Returns a new instance of GoogleCloudAiplatformV1CompletionStats.



5223
5224
5225
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5223

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#failed_countFixnum

Output only. The number of entities for which any error was encountered. Corresponds to the JSON property failedCount

Returns:

  • (Fixnum)


5200
5201
5202
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5200

def failed_count
  @failed_count
end

#incomplete_countFixnum

Output only. In cases when enough errors are encountered a job, pipeline, or operation may be failed as a whole. Below is the number of entities for which the processing had not been finished (either in successful or failed state). Set to -1 if the number is unknown (for example, the operation failed before the total entity number could be collected). Corresponds to the JSON property incompleteCount

Returns:

  • (Fixnum)


5209
5210
5211
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5209

def incomplete_count
  @incomplete_count
end

#successful_countFixnum

Output only. The number of entities that had been processed successfully. Corresponds to the JSON property successfulCount

Returns:

  • (Fixnum)


5214
5215
5216
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5214

def successful_count
  @successful_count
end

#successful_forecast_point_countFixnum

Output only. The number of the successful forecast points that are generated by the forecasting model. This is ONLY used by the forecasting batch prediction. Corresponds to the JSON property successfulForecastPointCount

Returns:

  • (Fixnum)


5221
5222
5223
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5221

def successful_forecast_point_count
  @successful_forecast_point_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5228
5229
5230
5231
5232
5233
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5228

def update!(**args)
  @failed_count = args[:failed_count] if args.key?(:failed_count)
  @incomplete_count = args[:incomplete_count] if args.key?(:incomplete_count)
  @successful_count = args[:successful_count] if args.key?(:successful_count)
  @successful_forecast_point_count = args[:successful_forecast_point_count] if args.key?(:successful_forecast_point_count)
end