Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CompletionStats

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Success and error statistics of processing multiple entities (for example, DataItems or structured data rows) in batch.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1CompletionStats

Returns a new instance of GoogleCloudAiplatformV1CompletionStats.



4404
4405
4406
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4404

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#failed_countFixnum

Output only. The number of entities for which any error was encountered. Corresponds to the JSON property failedCount

Returns:

  • (Fixnum)


4381
4382
4383
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4381

def failed_count
  @failed_count
end

#incomplete_countFixnum

Output only. In cases when enough errors are encountered a job, pipeline, or operation may be failed as a whole. Below is the number of entities for which the processing had not been finished (either in successful or failed state). Set to -1 if the number is unknown (for example, the operation failed before the total entity number could be collected). Corresponds to the JSON property incompleteCount

Returns:

  • (Fixnum)


4390
4391
4392
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4390

def incomplete_count
  @incomplete_count
end

#successful_countFixnum

Output only. The number of entities that had been processed successfully. Corresponds to the JSON property successfulCount

Returns:

  • (Fixnum)


4395
4396
4397
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4395

def successful_count
  @successful_count
end

#successful_forecast_point_countFixnum

Output only. The number of the successful forecast points that are generated by the forecasting model. This is ONLY used by the forecasting batch prediction. Corresponds to the JSON property successfulForecastPointCount

Returns:

  • (Fixnum)


4402
4403
4404
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4402

def successful_forecast_point_count
  @successful_forecast_point_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4409
4410
4411
4412
4413
4414
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4409

def update!(**args)
  @failed_count = args[:failed_count] if args.key?(:failed_count)
  @incomplete_count = args[:incomplete_count] if args.key?(:incomplete_count)
  @successful_count = args[:successful_count] if args.key?(:successful_count)
  @successful_forecast_point_count = args[:successful_forecast_point_count] if args.key?(:successful_forecast_point_count)
end