Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CompletionStats
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CompletionStats
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Success and error statistics of processing multiple entities (for example, DataItems or structured data rows) in batch.
Instance Attribute Summary collapse
-
#failed_count ⇒ Fixnum
Output only.
-
#incomplete_count ⇒ Fixnum
Output only.
-
#successful_count ⇒ Fixnum
Output only.
-
#successful_forecast_point_count ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1CompletionStats
constructor
A new instance of GoogleCloudAiplatformV1CompletionStats.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1CompletionStats
Returns a new instance of GoogleCloudAiplatformV1CompletionStats.
4370 4371 4372 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4370 def initialize(**args) update!(**args) end |
Instance Attribute Details
#failed_count ⇒ Fixnum
Output only. The number of entities for which any error was encountered.
Corresponds to the JSON property failedCount
4347 4348 4349 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4347 def failed_count @failed_count end |
#incomplete_count ⇒ Fixnum
Output only. In cases when enough errors are encountered a job, pipeline, or
operation may be failed as a whole. Below is the number of entities for which
the processing had not been finished (either in successful or failed state).
Set to -1 if the number is unknown (for example, the operation failed before
the total entity number could be collected).
Corresponds to the JSON property incompleteCount
4356 4357 4358 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4356 def incomplete_count @incomplete_count end |
#successful_count ⇒ Fixnum
Output only. The number of entities that had been processed successfully.
Corresponds to the JSON property successfulCount
4361 4362 4363 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4361 def successful_count @successful_count end |
#successful_forecast_point_count ⇒ Fixnum
Output only. The number of the successful forecast points that are generated
by the forecasting model. This is ONLY used by the forecasting batch
prediction.
Corresponds to the JSON property successfulForecastPointCount
4368 4369 4370 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4368 def successful_forecast_point_count @successful_forecast_point_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4375 4376 4377 4378 4379 4380 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4375 def update!(**args) @failed_count = args[:failed_count] if args.key?(:failed_count) @incomplete_count = args[:incomplete_count] if args.key?(:incomplete_count) @successful_count = args[:successful_count] if args.key?(:successful_count) @successful_forecast_point_count = args[:successful_forecast_point_count] if args.key?(:successful_forecast_point_count) end |