Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CompletionStats

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Success and error statistics of processing multiple entities (for example, DataItems or structured data rows) in batch.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1CompletionStats

Returns a new instance of GoogleCloudAiplatformV1CompletionStats.



3726
3727
3728
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3726

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#failed_countFixnum

Output only. The number of entities for which any error was encountered. Corresponds to the JSON property failedCount

Returns:

  • (Fixnum)


3703
3704
3705
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3703

def failed_count
  @failed_count
end

#incomplete_countFixnum

Output only. In cases when enough errors are encountered a job, pipeline, or operation may be failed as a whole. Below is the number of entities for which the processing had not been finished (either in successful or failed state). Set to -1 if the number is unknown (for example, the operation failed before the total entity number could be collected). Corresponds to the JSON property incompleteCount

Returns:

  • (Fixnum)


3712
3713
3714
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3712

def incomplete_count
  @incomplete_count
end

#successful_countFixnum

Output only. The number of entities that had been processed successfully. Corresponds to the JSON property successfulCount

Returns:

  • (Fixnum)


3717
3718
3719
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3717

def successful_count
  @successful_count
end

#successful_forecast_point_countFixnum

Output only. The number of the successful forecast points that are generated by the forecasting model. This is ONLY used by the forecasting batch prediction. Corresponds to the JSON property successfulForecastPointCount

Returns:

  • (Fixnum)


3724
3725
3726
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3724

def successful_forecast_point_count
  @successful_forecast_point_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3731
3732
3733
3734
3735
3736
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3731

def update!(**args)
  @failed_count = args[:failed_count] if args.key?(:failed_count)
  @incomplete_count = args[:incomplete_count] if args.key?(:incomplete_count)
  @successful_count = args[:successful_count] if args.key?(:successful_count)
  @successful_forecast_point_count = args[:successful_forecast_point_count] if args.key?(:successful_forecast_point_count)
end