Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CompletionStats
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CompletionStats
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Success and error statistics of processing multiple entities (for example, DataItems or structured data rows) in batch.
Instance Attribute Summary collapse
-
#failed_count ⇒ Fixnum
Output only.
-
#incomplete_count ⇒ Fixnum
Output only.
-
#successful_count ⇒ Fixnum
Output only.
-
#successful_forecast_point_count ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1CompletionStats
constructor
A new instance of GoogleCloudAiplatformV1CompletionStats.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1CompletionStats
Returns a new instance of GoogleCloudAiplatformV1CompletionStats.
2773 2774 2775 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2773 def initialize(**args) update!(**args) end |
Instance Attribute Details
#failed_count ⇒ Fixnum
Output only. The number of entities for which any error was encountered.
Corresponds to the JSON property failedCount
2750 2751 2752 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2750 def failed_count @failed_count end |
#incomplete_count ⇒ Fixnum
Output only. In cases when enough errors are encountered a job, pipeline, or
operation may be failed as a whole. Below is the number of entities for which
the processing had not been finished (either in successful or failed state).
Set to -1 if the number is unknown (for example, the operation failed before
the total entity number could be collected).
Corresponds to the JSON property incompleteCount
2759 2760 2761 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2759 def incomplete_count @incomplete_count end |
#successful_count ⇒ Fixnum
Output only. The number of entities that had been processed successfully.
Corresponds to the JSON property successfulCount
2764 2765 2766 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2764 def successful_count @successful_count end |
#successful_forecast_point_count ⇒ Fixnum
Output only. The number of the successful forecast points that are generated
by the forecasting model. This is ONLY used by the forecasting batch
prediction.
Corresponds to the JSON property successfulForecastPointCount
2771 2772 2773 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2771 def successful_forecast_point_count @successful_forecast_point_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2778 2779 2780 2781 2782 2783 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2778 def update!(**args) @failed_count = args[:failed_count] if args.key?(:failed_count) @incomplete_count = args[:incomplete_count] if args.key?(:incomplete_count) @successful_count = args[:successful_count] if args.key?(:successful_count) @successful_forecast_point_count = args[:successful_forecast_point_count] if args.key?(:successful_forecast_point_count) end |