Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ComputeTokensRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ComputeTokensRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Request message for ComputeTokens RPC call.
Instance Attribute Summary collapse
-
#contents ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content>
Optional.
-
#instances ⇒ Array<Object>
Optional.
-
#model ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ComputeTokensRequest
constructor
A new instance of GoogleCloudAiplatformV1ComputeTokensRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ComputeTokensRequest
Returns a new instance of GoogleCloudAiplatformV1ComputeTokensRequest.
4604 4605 4606 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4604 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contents ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content>
Optional. Input content.
Corresponds to the JSON property contents
4589 4590 4591 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4589 def contents @contents end |
#instances ⇒ Array<Object>
Optional. The instances that are the input to token computing API call. Schema
is identical to the prediction schema of the text model, even for the non-text
models, like chat models, or Codey models.
Corresponds to the JSON property instances
4596 4597 4598 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4596 def instances @instances end |
#model ⇒ String
Optional. The name of the publisher model requested to serve the prediction.
Format: projects/project/locations/location/publishers//models/
Corresponds to the JSON property model
4602 4603 4604 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4602 def model @model end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4609 4610 4611 4612 4613 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4609 def update!(**args) @contents = args[:contents] if args.key?(:contents) @instances = args[:instances] if args.key?(:instances) @model = args[:model] if args.key?(:model) end |