Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ComputeTokensRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for ComputeTokens RPC call.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ComputeTokensRequest

Returns a new instance of GoogleCloudAiplatformV1ComputeTokensRequest.



4430
4431
4432
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4430

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content>

Optional. Input content. Corresponds to the JSON property contents



4415
4416
4417
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4415

def contents
  @contents
end

#instancesArray<Object>

Optional. The instances that are the input to token computing API call. Schema is identical to the prediction schema of the text model, even for the non-text models, like chat models, or Codey models. Corresponds to the JSON property instances

Returns:

  • (Array<Object>)


4422
4423
4424
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4422

def instances
  @instances
end

#modelString

Optional. The name of the publisher model requested to serve the prediction. Format: projects/project/locations/location/publishers//models/ Corresponds to the JSON property model

Returns:

  • (String)


4428
4429
4430
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4428

def model
  @model
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4435
4436
4437
4438
4439
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4435

def update!(**args)
  @contents = args[:contents] if args.key?(:contents)
  @instances = args[:instances] if args.key?(:instances)
  @model = args[:model] if args.key?(:model)
end