Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ComputeTokensRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ComputeTokensRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Request message for ComputeTokens RPC call.
Instance Attribute Summary collapse
-
#contents ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content>
Optional.
-
#instances ⇒ Array<Object>
Optional.
-
#model ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ComputeTokensRequest
constructor
A new instance of GoogleCloudAiplatformV1ComputeTokensRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ComputeTokensRequest
Returns a new instance of GoogleCloudAiplatformV1ComputeTokensRequest.
3761 3762 3763 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3761 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contents ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content>
Optional. Input content.
Corresponds to the JSON property contents
3746 3747 3748 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3746 def contents @contents end |
#instances ⇒ Array<Object>
Optional. The instances that are the input to token computing API call. Schema
is identical to the prediction schema of the text model, even for the non-text
models, like chat models, or Codey models.
Corresponds to the JSON property instances
3753 3754 3755 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3753 def instances @instances end |
#model ⇒ String
Optional. The name of the publisher model requested to serve the prediction.
Format: projects/project/locations/location/publishers//models/
Corresponds to the JSON property model
3759 3760 3761 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3759 def model @model end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3766 3767 3768 3769 3770 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3766 def update!(**args) @contents = args[:contents] if args.key?(:contents) @instances = args[:instances] if args.key?(:instances) @model = args[:model] if args.key?(:model) end |