Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ComputeTokensRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for ComputeTokens RPC call.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ComputeTokensRequest

Returns a new instance of GoogleCloudAiplatformV1ComputeTokensRequest.



2815
2816
2817
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2815

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content>

Optional. Input content. Corresponds to the JSON property contents



2800
2801
2802
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2800

def contents
  @contents
end

#instancesArray<Object>

Optional. The instances that are the input to token computing API call. Schema is identical to the prediction schema of the text model, even for the non-text models, like chat models, or Codey models. Corresponds to the JSON property instances

Returns:

  • (Array<Object>)


2807
2808
2809
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2807

def instances
  @instances
end

#modelString

Optional. The name of the publisher model requested to serve the prediction. Format: projects/project/locations/location/publishers//models/ Corresponds to the JSON property model

Returns:

  • (String)


2813
2814
2815
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2813

def model
  @model
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2820
2821
2822
2823
2824
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2820

def update!(**args)
  @contents = args[:contents] if args.key?(:contents)
  @instances = args[:instances] if args.key?(:instances)
  @model = args[:model] if args.key?(:model)
end