Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ContainerSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ContainerSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The spec of a Container.
Instance Attribute Summary collapse
-
#args ⇒ Array<String>
The arguments to be passed when starting the container.
-
#command ⇒ Array<String>
The command to be invoked when the container is started.
-
#env ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EnvVar>
Environment variables to be passed to the container.
-
#image_uri ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ContainerSpec
constructor
A new instance of GoogleCloudAiplatformV1ContainerSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ContainerSpec
Returns a new instance of GoogleCloudAiplatformV1ContainerSpec.
4687 4688 4689 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4687 def initialize(**args) update!(**args) end |
Instance Attribute Details
#args ⇒ Array<String>
The arguments to be passed when starting the container.
Corresponds to the JSON property args
4668 4669 4670 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4668 def args @args end |
#command ⇒ Array<String>
The command to be invoked when the container is started. It overrides the
entrypoint instruction in Dockerfile when provided.
Corresponds to the JSON property command
4674 4675 4676 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4674 def command @command end |
#env ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EnvVar>
Environment variables to be passed to the container. Maximum limit is 100.
Corresponds to the JSON property env
4679 4680 4681 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4679 def env @env end |
#image_uri ⇒ String
Required. The URI of a container image in the Container Registry that is to be
run on each worker replica.
Corresponds to the JSON property imageUri
4685 4686 4687 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4685 def image_uri @image_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4692 4693 4694 4695 4696 4697 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4692 def update!(**args) @args = args[:args] if args.key?(:args) @command = args[:command] if args.key?(:command) @env = args[:env] if args.key?(:env) @image_uri = args[:image_uri] if args.key?(:image_uri) end |