Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ContainerSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The spec of a Container.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ContainerSpec

Returns a new instance of GoogleCloudAiplatformV1ContainerSpec.



3809
3810
3811
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3809

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#argsArray<String>

The arguments to be passed when starting the container. Corresponds to the JSON property args

Returns:

  • (Array<String>)


3790
3791
3792
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3790

def args
  @args
end

#commandArray<String>

The command to be invoked when the container is started. It overrides the entrypoint instruction in Dockerfile when provided. Corresponds to the JSON property command

Returns:

  • (Array<String>)


3796
3797
3798
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3796

def command
  @command
end

#envArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EnvVar>

Environment variables to be passed to the container. Maximum limit is 100. Corresponds to the JSON property env



3801
3802
3803
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3801

def env
  @env
end

#image_uriString

Required. The URI of a container image in the Container Registry that is to be run on each worker replica. Corresponds to the JSON property imageUri

Returns:

  • (String)


3807
3808
3809
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3807

def image_uri
  @image_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3814
3815
3816
3817
3818
3819
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3814

def update!(**args)
  @args = args[:args] if args.key?(:args)
  @command = args[:command] if args.key?(:command)
  @env = args[:env] if args.key?(:env)
  @image_uri = args[:image_uri] if args.key?(:image_uri)
end