Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ContainerSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The spec of a Container.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ContainerSpec

Returns a new instance of GoogleCloudAiplatformV1ContainerSpec.



3591
3592
3593
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3591

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#argsArray<String>

The arguments to be passed when starting the container. Corresponds to the JSON property args

Returns:

  • (Array<String>)


3572
3573
3574
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3572

def args
  @args
end

#commandArray<String>

The command to be invoked when the container is started. It overrides the entrypoint instruction in Dockerfile when provided. Corresponds to the JSON property command

Returns:

  • (Array<String>)


3578
3579
3580
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3578

def command
  @command
end

#envArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EnvVar>

Environment variables to be passed to the container. Maximum limit is 100. Corresponds to the JSON property env



3583
3584
3585
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3583

def env
  @env
end

#image_uriString

Required. The URI of a container image in the Container Registry that is to be run on each worker replica. Corresponds to the JSON property imageUri

Returns:

  • (String)


3589
3590
3591
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3589

def image_uri
  @image_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3596
3597
3598
3599
3600
3601
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3596

def update!(**args)
  @args = args[:args] if args.key?(:args)
  @command = args[:command] if args.key?(:command)
  @env = args[:env] if args.key?(:env)
  @image_uri = args[:image_uri] if args.key?(:image_uri)
end