Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ContainerSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The spec of a Container.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ContainerSpec

Returns a new instance of GoogleCloudAiplatformV1ContainerSpec.



2577
2578
2579
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2577

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#argsArray<String>

The arguments to be passed when starting the container. Corresponds to the JSON property args

Returns:

  • (Array<String>)


2558
2559
2560
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2558

def args
  @args
end

#commandArray<String>

The command to be invoked when the container is started. It overrides the entrypoint instruction in Dockerfile when provided. Corresponds to the JSON property command

Returns:

  • (Array<String>)


2564
2565
2566
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2564

def command
  @command
end

#envArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EnvVar>

Environment variables to be passed to the container. Maximum limit is 100. Corresponds to the JSON property env



2569
2570
2571
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2569

def env
  @env
end

#image_uriString

Required. The URI of a container image in the Container Registry that is to be run on each worker replica. Corresponds to the JSON property imageUri

Returns:

  • (String)


2575
2576
2577
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2575

def image_uri
  @image_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2582
2583
2584
2585
2586
2587
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2582

def update!(**args)
  @args = args[:args] if args.key?(:args)
  @command = args[:command] if args.key?(:command)
  @env = args[:env] if args.key?(:env)
  @image_uri = args[:image_uri] if args.key?(:image_uri)
end