Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The structured data content of a message. A Content message contains a role field, which indicates the producer of the content, and a parts field, which contains the multi-part data of the message.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Content

Returns a new instance of GoogleCloudAiplatformV1Content.



4223
4224
4225
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4223

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#partsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Part>

Required. A list of Part objects that make up a single message. Parts of a message can have different MIME types. A Content message must have at least one Part. Corresponds to the JSON property parts



4215
4216
4217
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4215

def parts
  @parts
end

#roleString

Optional. The producer of the content. Must be either 'user' or 'model'. If not set, the service will default to 'user'. Corresponds to the JSON property role

Returns:

  • (String)


4221
4222
4223
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4221

def role
  @role
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4228
4229
4230
4231
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4228

def update!(**args)
  @parts = args[:parts] if args.key?(:parts)
  @role = args[:role] if args.key?(:role)
end