Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Context
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Context
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Instance of a general context.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Description of the Context Corresponds to the JSON property
description. -
#display_name ⇒ String
User provided display name of the Context.
-
#etag ⇒ String
An eTag used to perform consistent read-modify-write updates.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your Contexts.
-
#metadata ⇒ Hash<String,Object>
Properties of the Context.
-
#name ⇒ String
Immutable.
-
#parent_contexts ⇒ Array<String>
Output only.
-
#schema_title ⇒ String
The title of the schema describing the metadata.
-
#schema_version ⇒ String
The version of the schema in schema_name to use.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Context
constructor
A new instance of GoogleCloudAiplatformV1Context.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Context
Returns a new instance of GoogleCloudAiplatformV1Context.
4748 4749 4750 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4748 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this Context was created.
Corresponds to the JSON property createTime
4683 4684 4685 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4683 def create_time @create_time end |
#description ⇒ String
Description of the Context
Corresponds to the JSON property description
4688 4689 4690 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4688 def description @description end |
#display_name ⇒ String
User provided display name of the Context. May be up to 128 Unicode characters.
Corresponds to the JSON property displayName
4693 4694 4695 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4693 def display_name @display_name end |
#etag ⇒ String
An eTag used to perform consistent read-modify-write updates. If not set, a
blind "overwrite" update happens.
Corresponds to the JSON property etag
4699 4700 4701 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4699 def etag @etag end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your Contexts. Label keys
and values can be no longer than 64 characters (Unicode codepoints), can only
contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. No more than 64 user labels can be
associated with one Context (System labels are excluded).
Corresponds to the JSON property labels
4708 4709 4710 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4708 def labels @labels end |
#metadata ⇒ Hash<String,Object>
Properties of the Context. Top level metadata keys' heading and trailing
spaces will be trimmed. The size of this field should not exceed 200KB.
Corresponds to the JSON property metadata
4714 4715 4716 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4714 def @metadata end |
#name ⇒ String
Immutable. The resource name of the Context.
Corresponds to the JSON property name
4719 4720 4721 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4719 def name @name end |
#parent_contexts ⇒ Array<String>
Output only. A list of resource names of Contexts that are parents of this
Context. A Context may have at most 10 parent_contexts.
Corresponds to the JSON property parentContexts
4725 4726 4727 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4725 def parent_contexts @parent_contexts end |
#schema_title ⇒ String
The title of the schema describing the metadata. Schema title and version is
expected to be registered in earlier Create Schema calls. And both are used
together as unique identifiers to identify schemas within the local metadata
store.
Corresponds to the JSON property schemaTitle
4733 4734 4735 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4733 def schema_title @schema_title end |
#schema_version ⇒ String
The version of the schema in schema_name to use. Schema title and version is
expected to be registered in earlier Create Schema calls. And both are used
together as unique identifiers to identify schemas within the local metadata
store.
Corresponds to the JSON property schemaVersion
4741 4742 4743 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4741 def schema_version @schema_version end |
#update_time ⇒ String
Output only. Timestamp when this Context was last updated.
Corresponds to the JSON property updateTime
4746 4747 4748 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4746 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4753 4754 4755 4756 4757 4758 4759 4760 4761 4762 4763 4764 4765 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4753 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @metadata = args[:metadata] if args.key?(:metadata) @name = args[:name] if args.key?(:name) @parent_contexts = args[:parent_contexts] if args.key?(:parent_contexts) @schema_title = args[:schema_title] if args.key?(:schema_title) @schema_version = args[:schema_version] if args.key?(:schema_version) @update_time = args[:update_time] if args.key?(:update_time) end |