Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Context

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Instance of a general context.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Context

Returns a new instance of GoogleCloudAiplatformV1Context.



4344
4345
4346
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4344

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this Context was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4279
4280
4281
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4279

def create_time
  @create_time
end

#descriptionString

Description of the Context Corresponds to the JSON property description

Returns:

  • (String)


4284
4285
4286
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4284

def description
  @description
end

#display_nameString

User provided display name of the Context. May be up to 128 Unicode characters. Corresponds to the JSON property displayName

Returns:

  • (String)


4289
4290
4291
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4289

def display_name
  @display_name
end

#etagString

An eTag used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


4295
4296
4297
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4295

def etag
  @etag
end

#labelsHash<String,String>

The labels with user-defined metadata to organize your Contexts. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. No more than 64 user labels can be associated with one Context (System labels are excluded). Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4304
4305
4306
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4304

def labels
  @labels
end

#metadataHash<String,Object>

Properties of the Context. Top level metadata keys' heading and trailing spaces will be trimmed. The size of this field should not exceed 200KB. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,Object>)


4310
4311
4312
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4310

def 
  @metadata
end

#nameString

Immutable. The resource name of the Context. Corresponds to the JSON property name

Returns:

  • (String)


4315
4316
4317
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4315

def name
  @name
end

#parent_contextsArray<String>

Output only. A list of resource names of Contexts that are parents of this Context. A Context may have at most 10 parent_contexts. Corresponds to the JSON property parentContexts

Returns:

  • (Array<String>)


4321
4322
4323
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4321

def parent_contexts
  @parent_contexts
end

#schema_titleString

The title of the schema describing the metadata. Schema title and version is expected to be registered in earlier Create Schema calls. And both are used together as unique identifiers to identify schemas within the local metadata store. Corresponds to the JSON property schemaTitle

Returns:

  • (String)


4329
4330
4331
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4329

def schema_title
  @schema_title
end

#schema_versionString

The version of the schema in schema_name to use. Schema title and version is expected to be registered in earlier Create Schema calls. And both are used together as unique identifiers to identify schemas within the local metadata store. Corresponds to the JSON property schemaVersion

Returns:

  • (String)


4337
4338
4339
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4337

def schema_version
  @schema_version
end

#update_timeString

Output only. Timestamp when this Context was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


4342
4343
4344
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4342

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4349
4350
4351
4352
4353
4354
4355
4356
4357
4358
4359
4360
4361
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4349

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @parent_contexts = args[:parent_contexts] if args.key?(:parent_contexts)
  @schema_title = args[:schema_title] if args.key?(:schema_title)
  @schema_version = args[:schema_version] if args.key?(:schema_version)
  @update_time = args[:update_time] if args.key?(:update_time)
end