Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Context

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Instance of a general context.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Context

Returns a new instance of GoogleCloudAiplatformV1Context.



2693
2694
2695
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2693

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this Context was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2628
2629
2630
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2628

def create_time
  @create_time
end

#descriptionString

Description of the Context Corresponds to the JSON property description

Returns:

  • (String)


2633
2634
2635
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2633

def description
  @description
end

#display_nameString

User provided display name of the Context. May be up to 128 Unicode characters. Corresponds to the JSON property displayName

Returns:

  • (String)


2638
2639
2640
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2638

def display_name
  @display_name
end

#etagString

An eTag used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


2644
2645
2646
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2644

def etag
  @etag
end

#labelsHash<String,String>

The labels with user-defined metadata to organize your Contexts. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. No more than 64 user labels can be associated with one Context (System labels are excluded). Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2653
2654
2655
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2653

def labels
  @labels
end

#metadataHash<String,Object>

Properties of the Context. Top level metadata keys' heading and trailing spaces will be trimmed. The size of this field should not exceed 200KB. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,Object>)


2659
2660
2661
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2659

def 
  @metadata
end

#nameString

Immutable. The resource name of the Context. Corresponds to the JSON property name

Returns:

  • (String)


2664
2665
2666
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2664

def name
  @name
end

#parent_contextsArray<String>

Output only. A list of resource names of Contexts that are parents of this Context. A Context may have at most 10 parent_contexts. Corresponds to the JSON property parentContexts

Returns:

  • (Array<String>)


2670
2671
2672
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2670

def parent_contexts
  @parent_contexts
end

#schema_titleString

The title of the schema describing the metadata. Schema title and version is expected to be registered in earlier Create Schema calls. And both are used together as unique identifiers to identify schemas within the local metadata store. Corresponds to the JSON property schemaTitle

Returns:

  • (String)


2678
2679
2680
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2678

def schema_title
  @schema_title
end

#schema_versionString

The version of the schema in schema_name to use. Schema title and version is expected to be registered in earlier Create Schema calls. And both are used together as unique identifiers to identify schemas within the local metadata store. Corresponds to the JSON property schemaVersion

Returns:

  • (String)


2686
2687
2688
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2686

def schema_version
  @schema_version
end

#update_timeString

Output only. Timestamp when this Context was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


2691
2692
2693
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2691

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2698
2699
2700
2701
2702
2703
2704
2705
2706
2707
2708
2709
2710
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 2698

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @parent_contexts = args[:parent_contexts] if args.key?(:parent_contexts)
  @schema_title = args[:schema_title] if args.key?(:schema_title)
  @schema_version = args[:schema_version] if args.key?(:schema_version)
  @update_time = args[:update_time] if args.key?(:update_time)
end