Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CopyModelRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for ModelService.CopyModel.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1CopyModelRequest

Returns a new instance of GoogleCloudAiplatformV1CopyModelRequest.



4829
4830
4831
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4829

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#custom_service_accountString

Optional. The user-provided custom service account to use to do the copy model. If empty, Vertex AI Service Agent will be used to access resources needed to upload the model. This account must belong to the destination project where the model is copied to, i.e., the project specified in the parent field of this request and have the Vertex AI Service Agent role in the source project. Requires the user copying the Model to have the iam.serviceAccounts.actAs permission on this service account. Corresponds to the JSON property customServiceAccount

Returns:

  • (String)


4801
4802
4803
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4801

def 
  @custom_service_account
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



4807
4808
4809
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4807

def encryption_spec
  @encryption_spec
end

#model_idString

Optional. Copy source_model into a new Model with this ID. The ID will become the final component of the model resource name. This value may be up to 63 characters, and valid characters are [a-z0-9_-]. The first character cannot be a number or hyphen. Corresponds to the JSON property modelId

Returns:

  • (String)


4815
4816
4817
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4815

def model_id
  @model_id
end

#parent_modelString

Optional. Specify this field to copy source_model into this existing Model as a new version. Format: projects/project/locations/location/models/model` Corresponds to the JSON propertyparentModel`

Returns:

  • (String)


4821
4822
4823
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4821

def parent_model
  @parent_model
end

#source_modelString

Required. The resource name of the Model to copy. That Model must be in the same Project. Format: projects/project/locations/location/models/model` Corresponds to the JSON propertysourceModel`

Returns:

  • (String)


4827
4828
4829
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4827

def source_model
  @source_model
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4834
4835
4836
4837
4838
4839
4840
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4834

def update!(**args)
  @custom_service_account = args[:custom_service_account] if args.key?(:custom_service_account)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @model_id = args[:model_id] if args.key?(:model_id)
  @parent_model = args[:parent_model] if args.key?(:parent_model)
  @source_model = args[:source_model] if args.key?(:source_model)
end