Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CopyModelRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CopyModelRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Request message for ModelService.CopyModel.
Instance Attribute Summary collapse
-
#custom_service_account ⇒ String
Optional.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.
-
#model_id ⇒ String
Optional.
-
#parent_model ⇒ String
Optional.
-
#source_model ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1CopyModelRequest
constructor
A new instance of GoogleCloudAiplatformV1CopyModelRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1CopyModelRequest
Returns a new instance of GoogleCloudAiplatformV1CopyModelRequest.
4781 4782 4783 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4781 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_service_account ⇒ String
Optional. The user-provided custom service account to use to do the copy model.
If empty, Vertex AI Service Agent will be used to access resources needed
to upload the model. This account must belong to the destination project where
the model is copied to, i.e., the project specified in the parent field of
this request and have the Vertex AI Service Agent role in the source project.
Requires the user copying the Model to have the iam.serviceAccounts.actAs
permission on this service account.
Corresponds to the JSON property customServiceAccount
4753 4754 4755 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4753 def custom_service_account @custom_service_account end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied
to a Vertex AI resource.
Corresponds to the JSON property encryptionSpec
4759 4760 4761 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4759 def encryption_spec @encryption_spec end |
#model_id ⇒ String
Optional. Copy source_model into a new Model with this ID. The ID will become
the final component of the model resource name. This value may be up to 63
characters, and valid characters are [a-z0-9_-]. The first character cannot
be a number or hyphen.
Corresponds to the JSON property modelId
4767 4768 4769 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4767 def model_id @model_id end |
#parent_model ⇒ String
Optional. Specify this field to copy source_model into this existing Model as
a new version. Format: projects/project/locations/location/models/model`
Corresponds to the JSON propertyparentModel`
4773 4774 4775 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4773 def parent_model @parent_model end |
#source_model ⇒ String
Required. The resource name of the Model to copy. That Model must be in the
same Project. Format: projects/project/locations/location/models/model`
Corresponds to the JSON propertysourceModel`
4779 4780 4781 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4779 def source_model @source_model end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4786 4787 4788 4789 4790 4791 4792 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4786 def update!(**args) @custom_service_account = args[:custom_service_account] if args.key?(:custom_service_account) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @model_id = args[:model_id] if args.key?(:model_id) @parent_model = args[:parent_model] if args.key?(:parent_model) @source_model = args[:source_model] if args.key?(:source_model) end |