Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CountTokensRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for PredictionService.CountTokens.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1CountTokensRequest

Returns a new instance of GoogleCloudAiplatformV1CountTokensRequest.



5820
5821
5822
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5820

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content>

Optional. Input content. Corresponds to the JSON property contents



5784
5785
5786
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5784

def contents
  @contents
end

#generation_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfig

Configuration for content generation. This message contains all the parameters that control how the model generates content. It allows you to influence the randomness, length, and structure of the output. Corresponds to the JSON property generationConfig



5791
5792
5793
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5791

def generation_config
  @generation_config
end

#instancesArray<Object>

Optional. The instances that are the input to token counting call. Schema is identical to the prediction schema of the underlying model. Corresponds to the JSON property instances

Returns:

  • (Array<Object>)


5797
5798
5799
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5797

def instances
  @instances
end

#modelString

Optional. The name of the publisher model requested to serve the prediction. Format: projects/project/locations/location/publishers/*/models/* Corresponds to the JSON property model

Returns:

  • (String)


5803
5804
5805
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5803

def model
  @model
end

#system_instructionGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Content

The structured data content of a message. A Content message contains a role field, which indicates the producer of the content, and a parts field, which contains the multi-part data of the message. Corresponds to the JSON property systemInstruction



5810
5811
5812
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5810

def system_instruction
  @system_instruction
end

#toolsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tool>

Optional. A list of Tools the model may use to generate the next response. A Tool is a piece of code that enables the system to interact with external systems to perform an action, or set of actions, outside of knowledge and scope of the model. Corresponds to the JSON property tools



5818
5819
5820
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5818

def tools
  @tools
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5825
5826
5827
5828
5829
5830
5831
5832
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5825

def update!(**args)
  @contents = args[:contents] if args.key?(:contents)
  @generation_config = args[:generation_config] if args.key?(:generation_config)
  @instances = args[:instances] if args.key?(:instances)
  @model = args[:model] if args.key?(:model)
  @system_instruction = args[:system_instruction] if args.key?(:system_instruction)
  @tools = args[:tools] if args.key?(:tools)
end