Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CountTokensRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for PredictionService.CountTokens.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1CountTokensRequest

Returns a new instance of GoogleCloudAiplatformV1CountTokensRequest.



4600
4601
4602
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4600

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content>

Optional. Input content. Corresponds to the JSON property contents



4564
4565
4566
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4564

def contents
  @contents
end

#generation_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfig

Configuration for content generation. This message contains all the parameters that control how the model generates content. It allows you to influence the randomness, length, and structure of the output. Corresponds to the JSON property generationConfig



4571
4572
4573
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4571

def generation_config
  @generation_config
end

#instancesArray<Object>

Optional. The instances that are the input to token counting call. Schema is identical to the prediction schema of the underlying model. Corresponds to the JSON property instances

Returns:

  • (Array<Object>)


4577
4578
4579
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4577

def instances
  @instances
end

#modelString

Optional. The name of the publisher model requested to serve the prediction. Format: projects/project/locations/location/publishers/*/models/* Corresponds to the JSON property model

Returns:

  • (String)


4583
4584
4585
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4583

def model
  @model
end

#system_instructionGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Content

The structured data content of a message. A Content message contains a role field, which indicates the producer of the content, and a parts field, which contains the multi-part data of the message. Corresponds to the JSON property systemInstruction



4590
4591
4592
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4590

def system_instruction
  @system_instruction
end

#toolsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tool>

Optional. A list of Tools the model may use to generate the next response. A Tool is a piece of code that enables the system to interact with external systems to perform an action, or set of actions, outside of knowledge and scope of the model. Corresponds to the JSON property tools



4598
4599
4600
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4598

def tools
  @tools
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4605
4606
4607
4608
4609
4610
4611
4612
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4605

def update!(**args)
  @contents = args[:contents] if args.key?(:contents)
  @generation_config = args[:generation_config] if args.key?(:generation_config)
  @instances = args[:instances] if args.key?(:instances)
  @model = args[:model] if args.key?(:model)
  @system_instruction = args[:system_instruction] if args.key?(:system_instruction)
  @tools = args[:tools] if args.key?(:tools)
end