Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CountTokensRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CountTokensRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Request message for PredictionService.CountTokens.
Instance Attribute Summary collapse
-
#contents ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content>
Required.
-
#instances ⇒ Array<Object>
Required.
-
#model ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1CountTokensRequest
constructor
A new instance of GoogleCloudAiplatformV1CountTokensRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1CountTokensRequest
Returns a new instance of GoogleCloudAiplatformV1CountTokensRequest.
3123 3124 3125 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3123 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contents ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content>
Required. Input content.
Corresponds to the JSON property contents
3109 3110 3111 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3109 def contents @contents end |
#instances ⇒ Array<Object>
Required. The instances that are the input to token counting call. Schema is
identical to the prediction schema of the underlying model.
Corresponds to the JSON property instances
3115 3116 3117 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3115 def instances @instances end |
#model ⇒ String
Required. The name of the publisher model requested to serve the prediction.
Format: projects/project/locations/location/publishers/*/models/*
Corresponds to the JSON property model
3121 3122 3123 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3121 def model @model end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3128 3129 3130 3131 3132 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3128 def update!(**args) @contents = args[:contents] if args.key?(:contents) @instances = args[:instances] if args.key?(:instances) @model = args[:model] if args.key?(:model) end |