Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CountTokensRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CountTokensRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Request message for PredictionService.CountTokens.
Instance Attribute Summary collapse
-
#contents ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content>
Required.
-
#instances ⇒ Array<Object>
Required.
-
#model ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1CountTokensRequest
constructor
A new instance of GoogleCloudAiplatformV1CountTokensRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1CountTokensRequest
Returns a new instance of GoogleCloudAiplatformV1CountTokensRequest.
3778 3779 3780 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3778 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contents ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content>
Required. Input content.
Corresponds to the JSON property contents
3764 3765 3766 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3764 def contents @contents end |
#instances ⇒ Array<Object>
Required. The instances that are the input to token counting call. Schema is
identical to the prediction schema of the underlying model.
Corresponds to the JSON property instances
3770 3771 3772 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3770 def instances @instances end |
#model ⇒ String
Required. The name of the publisher model requested to serve the prediction.
Format: projects/project/locations/location/publishers/*/models/*
Corresponds to the JSON property model
3776 3777 3778 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3776 def model @model end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3783 3784 3785 3786 3787 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3783 def update!(**args) @contents = args[:contents] if args.key?(:contents) @instances = args[:instances] if args.key?(:instances) @model = args[:model] if args.key?(:model) end |