Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CountTokensResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CountTokensResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Response message for PredictionService.CountTokens.
Instance Attribute Summary collapse
-
#total_billable_characters ⇒ Fixnum
The total number of billable characters counted across all instances from the request.
-
#total_tokens ⇒ Fixnum
The total number of tokens counted across all instances from the request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1CountTokensResponse
constructor
A new instance of GoogleCloudAiplatformV1CountTokensResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1CountTokensResponse
Returns a new instance of GoogleCloudAiplatformV1CountTokensResponse.
3267 3268 3269 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3267 def initialize(**args) update!(**args) end |
Instance Attribute Details
#total_billable_characters ⇒ Fixnum
The total number of billable characters counted across all instances from the
request.
Corresponds to the JSON property totalBillableCharacters
3260 3261 3262 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3260 def total_billable_characters @total_billable_characters end |
#total_tokens ⇒ Fixnum
The total number of tokens counted across all instances from the request.
Corresponds to the JSON property totalTokens
3265 3266 3267 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3265 def total_tokens @total_tokens end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3272 3273 3274 3275 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3272 def update!(**args) @total_billable_characters = args[:total_billable_characters] if args.key?(:total_billable_characters) @total_tokens = args[:total_tokens] if args.key?(:total_tokens) end |