Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CountTokensResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Response message for PredictionService.CountTokens.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1CountTokensResponse

Returns a new instance of GoogleCloudAiplatformV1CountTokensResponse.



3558
3559
3560
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3558

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#total_billable_charactersFixnum

The total number of billable characters counted across all instances from the request. Corresponds to the JSON property totalBillableCharacters

Returns:

  • (Fixnum)


3551
3552
3553
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3551

def total_billable_characters
  @total_billable_characters
end

#total_tokensFixnum

The total number of tokens counted across all instances from the request. Corresponds to the JSON property totalTokens

Returns:

  • (Fixnum)


3556
3557
3558
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3556

def total_tokens
  @total_tokens
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3563
3564
3565
3566
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3563

def update!(**args)
  @total_billable_characters = args[:total_billable_characters] if args.key?(:total_billable_characters)
  @total_tokens = args[:total_tokens] if args.key?(:total_tokens)
end