Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CreateDeploymentResourcePoolRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for CreateDeploymentResourcePool method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1CreateDeploymentResourcePoolRequest

Returns a new instance of GoogleCloudAiplatformV1CreateDeploymentResourcePoolRequest.



3236
3237
3238
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3236

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deployment_resource_poolGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1DeploymentResourcePool

A description of resources that can be shared by multiple DeployedModels, whose underlying specification consists of a DedicatedResources. Corresponds to the JSON property deploymentResourcePool



3226
3227
3228
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3226

def deployment_resource_pool
  @deployment_resource_pool
end

#deployment_resource_pool_idString

Required. The ID to use for the DeploymentResourcePool, which will become the final component of the DeploymentResourcePool's resource name. The maximum length is 63 characters, and valid characters are /^[a-z]([a-z0-9-]0,61[a- z0-9])?$/. Corresponds to the JSON property deploymentResourcePoolId

Returns:

  • (String)


3234
3235
3236
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3234

def deployment_resource_pool_id
  @deployment_resource_pool_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3241
3242
3243
3244
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3241

def update!(**args)
  @deployment_resource_pool = args[:deployment_resource_pool] if args.key?(:deployment_resource_pool)
  @deployment_resource_pool_id = args[:deployment_resource_pool_id] if args.key?(:deployment_resource_pool_id)
end