Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CreateFeatureRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for FeaturestoreService.CreateFeature. Request message for FeatureRegistryService.CreateFeature.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1CreateFeatureRequest

Returns a new instance of GoogleCloudAiplatformV1CreateFeatureRequest.



6413
6414
6415
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6413

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#featureGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Feature

Feature Metadata information. For example, color is a feature that describes an apple. Corresponds to the JSON property feature



6394
6395
6396
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6394

def feature
  @feature
end

#feature_idString

Required. The ID to use for the Feature, which will become the final component of the Feature's resource name. This value may be up to 128 characters, and valid characters are [a-z0-9_]. The first character cannot be a number. The value must be unique within an EntityType/FeatureGroup. Corresponds to the JSON property featureId

Returns:

  • (String)


6402
6403
6404
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6402

def feature_id
  @feature_id
end

#parentString

Required. The resource name of the EntityType or FeatureGroup to create a Feature. Format for entity_type as parent: projects/project/locations/ location/featurestores/featurestore/entityTypes/entity_typeFormat for feature_group as parent: `projects/`project`/locations/`location`/ featureGroups/`feature_group Corresponds to the JSON property parent

Returns:

  • (String)


6411
6412
6413
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6411

def parent
  @parent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6418
6419
6420
6421
6422
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6418

def update!(**args)
  @feature = args[:feature] if args.key?(:feature)
  @feature_id = args[:feature_id] if args.key?(:feature_id)
  @parent = args[:parent] if args.key?(:parent)
end