Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CreateFeatureRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for FeaturestoreService.CreateFeature. Request message for FeatureRegistryService.CreateFeature.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1CreateFeatureRequest

Returns a new instance of GoogleCloudAiplatformV1CreateFeatureRequest.



4019
4020
4021
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4019

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#featureGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Feature

Feature Metadata information. For example, color is a feature that describes an apple. Corresponds to the JSON property feature



4000
4001
4002
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4000

def feature
  @feature
end

#feature_idString

Required. The ID to use for the Feature, which will become the final component of the Feature's resource name. This value may be up to 128 characters, and valid characters are [a-z0-9_]. The first character cannot be a number. The value must be unique within an EntityType/FeatureGroup. Corresponds to the JSON property featureId

Returns:

  • (String)


4008
4009
4010
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4008

def feature_id
  @feature_id
end

#parentString

Required. The resource name of the EntityType or FeatureGroup to create a Feature. Format for entity_type as parent: projects/project/locations/ location/featurestores/featurestore/entityTypes/entity_typeFormat for feature_group as parent: `projects/`project`/locations/`location`/ featureGroups/`feature_group Corresponds to the JSON property parent

Returns:

  • (String)


4017
4018
4019
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4017

def parent
  @parent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4024
4025
4026
4027
4028
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4024

def update!(**args)
  @feature = args[:feature] if args.key?(:feature)
  @feature_id = args[:feature_id] if args.key?(:feature_id)
  @parent = args[:parent] if args.key?(:parent)
end