Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CreatePipelineJobRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CreatePipelineJobRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Request message for PipelineService.CreatePipelineJob.
Instance Attribute Summary collapse
-
#parent ⇒ String
Required.
-
#pipeline_job ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineJob
An instance of a machine learning PipelineJob.
-
#pipeline_job_id ⇒ String
The ID to use for the PipelineJob, which will become the final component of the PipelineJob name.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1CreatePipelineJobRequest
constructor
A new instance of GoogleCloudAiplatformV1CreatePipelineJobRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1CreatePipelineJobRequest
Returns a new instance of GoogleCloudAiplatformV1CreatePipelineJobRequest.
6340 6341 6342 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6340 def initialize(**args) update!(**args) end |
Instance Attribute Details
#parent ⇒ String
Required. The resource name of the Location to create the PipelineJob in.
Format: projects/project/locations/location`
Corresponds to the JSON propertyparent`
6325 6326 6327 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6325 def parent @parent end |
#pipeline_job ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineJob
An instance of a machine learning PipelineJob.
Corresponds to the JSON property pipelineJob
6330 6331 6332 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6330 def pipeline_job @pipeline_job end |
#pipeline_job_id ⇒ String
The ID to use for the PipelineJob, which will become the final component of
the PipelineJob name. If not provided, an ID will be automatically generated.
This value should be less than 128 characters, and valid characters are /a-z-/
.
Corresponds to the JSON property pipelineJobId
6338 6339 6340 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6338 def pipeline_job_id @pipeline_job_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6345 6346 6347 6348 6349 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6345 def update!(**args) @parent = args[:parent] if args.key?(:parent) @pipeline_job = args[:pipeline_job] if args.key?(:pipeline_job) @pipeline_job_id = args[:pipeline_job_id] if args.key?(:pipeline_job_id) end |