Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CreatePipelineJobRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for PipelineService.CreatePipelineJob.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1CreatePipelineJobRequest

Returns a new instance of GoogleCloudAiplatformV1CreatePipelineJobRequest.



5610
5611
5612
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5610

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#parentString

Required. The resource name of the Location to create the PipelineJob in. Format: projects/project/locations/location` Corresponds to the JSON propertyparent`

Returns:

  • (String)


5595
5596
5597
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5595

def parent
  @parent
end

#pipeline_jobGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineJob

An instance of a machine learning PipelineJob. Corresponds to the JSON property pipelineJob



5600
5601
5602
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5600

def pipeline_job
  @pipeline_job
end

#pipeline_job_idString

The ID to use for the PipelineJob, which will become the final component of the PipelineJob name. If not provided, an ID will be automatically generated. This value should be less than 128 characters, and valid characters are /a-z-/ . Corresponds to the JSON property pipelineJobId

Returns:

  • (String)


5608
5609
5610
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5608

def pipeline_job_id
  @pipeline_job_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5615
5616
5617
5618
5619
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5615

def update!(**args)
  @parent = args[:parent] if args.key?(:parent)
  @pipeline_job = args[:pipeline_job] if args.key?(:pipeline_job)
  @pipeline_job_id = args[:pipeline_job_id] if args.key?(:pipeline_job_id)
end