Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CreatePipelineJobRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CreatePipelineJobRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Request message for PipelineService.CreatePipelineJob.
Instance Attribute Summary collapse
-
#parent ⇒ String
Required.
-
#pipeline_job ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineJob
An instance of a machine learning PipelineJob.
-
#pipeline_job_id ⇒ String
The ID to use for the PipelineJob, which will become the final component of the PipelineJob name.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1CreatePipelineJobRequest
constructor
A new instance of GoogleCloudAiplatformV1CreatePipelineJobRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1CreatePipelineJobRequest
Returns a new instance of GoogleCloudAiplatformV1CreatePipelineJobRequest.
5470 5471 5472 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5470 def initialize(**args) update!(**args) end |
Instance Attribute Details
#parent ⇒ String
Required. The resource name of the Location to create the PipelineJob in.
Format: projects/project/locations/location`
Corresponds to the JSON propertyparent`
5455 5456 5457 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5455 def parent @parent end |
#pipeline_job ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineJob
An instance of a machine learning PipelineJob.
Corresponds to the JSON property pipelineJob
5460 5461 5462 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5460 def pipeline_job @pipeline_job end |
#pipeline_job_id ⇒ String
The ID to use for the PipelineJob, which will become the final component of
the PipelineJob name. If not provided, an ID will be automatically generated.
This value should be less than 128 characters, and valid characters are /a-z-/
.
Corresponds to the JSON property pipelineJobId
5468 5469 5470 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5468 def pipeline_job_id @pipeline_job_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5475 5476 5477 5478 5479 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5475 def update!(**args) @parent = args[:parent] if args.key?(:parent) @pipeline_job = args[:pipeline_job] if args.key?(:pipeline_job) @pipeline_job_id = args[:pipeline_job_id] if args.key?(:pipeline_job_id) end |