Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CreatePipelineJobRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CreatePipelineJobRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Request message for PipelineService.CreatePipelineJob.
Instance Attribute Summary collapse
-
#parent ⇒ String
Required.
-
#pipeline_job ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineJob
An instance of a machine learning PipelineJob.
-
#pipeline_job_id ⇒ String
The ID to use for the PipelineJob, which will become the final component of the PipelineJob name.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1CreatePipelineJobRequest
constructor
A new instance of GoogleCloudAiplatformV1CreatePipelineJobRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1CreatePipelineJobRequest
Returns a new instance of GoogleCloudAiplatformV1CreatePipelineJobRequest.
4756 4757 4758 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4756 def initialize(**args) update!(**args) end |
Instance Attribute Details
#parent ⇒ String
Required. The resource name of the Location to create the PipelineJob in.
Format: projects/project/locations/location`
Corresponds to the JSON propertyparent`
4741 4742 4743 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4741 def parent @parent end |
#pipeline_job ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineJob
An instance of a machine learning PipelineJob.
Corresponds to the JSON property pipelineJob
4746 4747 4748 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4746 def pipeline_job @pipeline_job end |
#pipeline_job_id ⇒ String
The ID to use for the PipelineJob, which will become the final component of
the PipelineJob name. If not provided, an ID will be automatically generated.
This value should be less than 128 characters, and valid characters are /a-z-/
.
Corresponds to the JSON property pipelineJobId
4754 4755 4756 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4754 def pipeline_job_id @pipeline_job_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4761 4762 4763 4764 4765 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4761 def update!(**args) @parent = args[:parent] if args.key?(:parent) @pipeline_job = args[:pipeline_job] if args.key?(:pipeline_job) @pipeline_job_id = args[:pipeline_job_id] if args.key?(:pipeline_job_id) end |