Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CreatePipelineJobRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for PipelineService.CreatePipelineJob.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1CreatePipelineJobRequest

Returns a new instance of GoogleCloudAiplatformV1CreatePipelineJobRequest.



4502
4503
4504
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4502

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#parentString

Required. The resource name of the Location to create the PipelineJob in. Format: projects/project/locations/location` Corresponds to the JSON propertyparent`

Returns:

  • (String)


4487
4488
4489
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4487

def parent
  @parent
end

#pipeline_jobGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineJob

An instance of a machine learning PipelineJob. Corresponds to the JSON property pipelineJob



4492
4493
4494
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4492

def pipeline_job
  @pipeline_job
end

#pipeline_job_idString

The ID to use for the PipelineJob, which will become the final component of the PipelineJob name. If not provided, an ID will be automatically generated. This value should be less than 128 characters, and valid characters are /a-z-/ . Corresponds to the JSON property pipelineJobId

Returns:

  • (String)


4500
4501
4502
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4500

def pipeline_job_id
  @pipeline_job_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4507
4508
4509
4510
4511
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4507

def update!(**args)
  @parent = args[:parent] if args.key?(:parent)
  @pipeline_job = args[:pipeline_job] if args.key?(:pipeline_job)
  @pipeline_job_id = args[:pipeline_job_id] if args.key?(:pipeline_job_id)
end