Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CreatePipelineJobRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for PipelineService.CreatePipelineJob.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1CreatePipelineJobRequest

Returns a new instance of GoogleCloudAiplatformV1CreatePipelineJobRequest.



3940
3941
3942
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3940

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#parentString

Required. The resource name of the Location to create the PipelineJob in. Format: projects/project/locations/location` Corresponds to the JSON propertyparent`

Returns:

  • (String)


3918
3919
3920
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3918

def parent
  @parent
end

#pipeline_jobGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineJob

An instance of a machine learning PipelineJob. Corresponds to the JSON property pipelineJob



3923
3924
3925
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3923

def pipeline_job
  @pipeline_job
end

#pipeline_job_idString

The ID to use for the PipelineJob, which will become the final component of the PipelineJob name. If not provided, an ID will be automatically generated. This value should be less than 128 characters, and valid characters are /a-z-/ . Corresponds to the JSON property pipelineJobId

Returns:

  • (String)


3931
3932
3933
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3931

def pipeline_job_id
  @pipeline_job_id
end

#preflight_validationsBoolean Also known as: preflight_validations?

Optional. Whether to do component level validations before job creation. Currently we only support Google First Party Component/Pipelines. Corresponds to the JSON property preflightValidations

Returns:

  • (Boolean)


3937
3938
3939
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3937

def preflight_validations
  @preflight_validations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3945
3946
3947
3948
3949
3950
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 3945

def update!(**args)
  @parent = args[:parent] if args.key?(:parent)
  @pipeline_job = args[:pipeline_job] if args.key?(:pipeline_job)
  @pipeline_job_id = args[:pipeline_job_id] if args.key?(:pipeline_job_id)
  @preflight_validations = args[:preflight_validations] if args.key?(:preflight_validations)
end