Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CreateTensorboardRunRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CreateTensorboardRunRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Request message for TensorboardService.CreateTensorboardRun.
Instance Attribute Summary collapse
-
#parent ⇒ String
Required.
-
#tensorboard_run ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardRun
TensorboardRun maps to a specific execution of a training job with a given set of hyperparameter values, model definition, dataset, etc Corresponds to the JSON property
tensorboardRun. -
#tensorboard_run_id ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1CreateTensorboardRunRequest
constructor
A new instance of GoogleCloudAiplatformV1CreateTensorboardRunRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1CreateTensorboardRunRequest
Returns a new instance of GoogleCloudAiplatformV1CreateTensorboardRunRequest.
4216 4217 4218 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4216 def initialize(**args) update!(**args) end |
Instance Attribute Details
#parent ⇒ String
Required. The resource name of the TensorboardExperiment to create the
TensorboardRun in. Format: projects/project/locations/location/
tensorboards/tensorboard/experiments/experiment`
Corresponds to the JSON propertyparent`
4201 4202 4203 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4201 def parent @parent end |
#tensorboard_run ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardRun
TensorboardRun maps to a specific execution of a training job with a given set
of hyperparameter values, model definition, dataset, etc
Corresponds to the JSON property tensorboardRun
4207 4208 4209 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4207 def tensorboard_run @tensorboard_run end |
#tensorboard_run_id ⇒ String
Required. The ID to use for the Tensorboard run, which becomes the final
component of the Tensorboard run's resource name. This value should be 1-128
characters, and valid characters are /a-z-/.
Corresponds to the JSON property tensorboardRunId
4214 4215 4216 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4214 def tensorboard_run_id @tensorboard_run_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4221 4222 4223 4224 4225 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4221 def update!(**args) @parent = args[:parent] if args.key?(:parent) @tensorboard_run = args[:tensorboard_run] if args.key?(:tensorboard_run) @tensorboard_run_id = args[:tensorboard_run_id] if args.key?(:tensorboard_run_id) end |