Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CustomJob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents a job that runs custom workloads such as a Docker container or a Python package. A CustomJob can have multiple worker pools and each worker pool can have its own machine and input spec. A CustomJob will be cleaned up once the job enters terminal state (failed or succeeded).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1CustomJob

Returns a new instance of GoogleCloudAiplatformV1CustomJob.



5749
5750
5751
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5749

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Time when the CustomJob was created. Corresponds to the JSON property createTime

Returns:

  • (String)


5661
5662
5663
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5661

def create_time
  @create_time
end

#display_nameString

Required. The display name of the CustomJob. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


5667
5668
5669
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5667

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



5673
5674
5675
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5673

def encryption_spec
  @encryption_spec
end

#end_timeString

Output only. Time when the CustomJob entered any of the following states: JOB_STATE_SUCCEEDED, JOB_STATE_FAILED, JOB_STATE_CANCELLED. Corresponds to the JSON property endTime

Returns:

  • (String)


5679
5680
5681
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5679

def end_time
  @end_time
end

#errorGoogle::Apis::AiplatformV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



5689
5690
5691
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5689

def error
  @error
end

#job_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1CustomJobSpec

Represents the spec of a CustomJob. Corresponds to the JSON property jobSpec



5694
5695
5696
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5694

def job_spec
  @job_spec
end

#labelsHash<String,String>

The labels with user-defined metadata to organize CustomJobs. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


5703
5704
5705
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5703

def labels
  @labels
end

#nameString

Output only. Resource name of a CustomJob. Corresponds to the JSON property name

Returns:

  • (String)


5708
5709
5710
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5708

def name
  @name
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


5713
5714
5715
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5713

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


5719
5720
5721
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5719

def satisfies_pzs
  @satisfies_pzs
end

#start_timeString

Output only. Time when the CustomJob for the first time entered the JOB_STATE_RUNNING state. Corresponds to the JSON property startTime

Returns:

  • (String)


5726
5727
5728
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5726

def start_time
  @start_time
end

#stateString

Output only. The detailed state of the job. Corresponds to the JSON property state

Returns:

  • (String)


5731
5732
5733
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5731

def state
  @state
end

#update_timeString

Output only. Time when the CustomJob was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


5736
5737
5738
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5736

def update_time
  @update_time
end

#web_access_urisHash<String,String>

Output only. URIs for accessing interactive shells (one URI for each training node). Only available if job_spec.enable_web_access is true. The keys are names of each node in the training job; for example, workerpool0-0 for the primary node, workerpool1-0 for the first node in the second worker pool, and workerpool1-1 for the second node in the second worker pool. The values are the URIs for each node's interactive shell. Corresponds to the JSON property webAccessUris

Returns:

  • (Hash<String,String>)


5747
5748
5749
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5747

def web_access_uris
  @web_access_uris
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5754
5755
5756
5757
5758
5759
5760
5761
5762
5763
5764
5765
5766
5767
5768
5769
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5754

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @end_time = args[:end_time] if args.key?(:end_time)
  @error = args[:error] if args.key?(:error)
  @job_spec = args[:job_spec] if args.key?(:job_spec)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
  @web_access_uris = args[:web_access_uris] if args.key?(:web_access_uris)
end