Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CustomJob
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CustomJob
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Represents a job that runs custom workloads such as a Docker container or a Python package. A CustomJob can have multiple worker pools and each worker pool can have its own machine and input spec. A CustomJob will be cleaned up once the job enters terminal state (failed or succeeded).
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Required.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top- level resource.
-
#end_time ⇒ String
Output only.
-
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#job_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CustomJobSpec
Represents the spec of a CustomJob.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize CustomJobs.
-
#name ⇒ String
Output only.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
-
#web_access_uris ⇒ Hash<String,String>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1CustomJob
constructor
A new instance of GoogleCloudAiplatformV1CustomJob.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1CustomJob
Returns a new instance of GoogleCloudAiplatformV1CustomJob.
5024 5025 5026 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5024 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Time when the CustomJob was created.
Corresponds to the JSON property createTime
4936 4937 4938 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4936 def create_time @create_time end |
#display_name ⇒ String
Required. The display name of the CustomJob. The name can be up to 128
characters long and can consist of any UTF-8 characters.
Corresponds to the JSON property displayName
4942 4943 4944 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4942 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top-
level resource.
Corresponds to the JSON property encryptionSpec
4948 4949 4950 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4948 def encryption_spec @encryption_spec end |
#end_time ⇒ String
Output only. Time when the CustomJob entered any of the following states:
JOB_STATE_SUCCEEDED, JOB_STATE_FAILED, JOB_STATE_CANCELLED.
Corresponds to the JSON property endTime
4954 4955 4956 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4954 def end_time @end_time end |
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
4964 4965 4966 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4964 def error @error end |
#job_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CustomJobSpec
Represents the spec of a CustomJob.
Corresponds to the JSON property jobSpec
4969 4970 4971 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4969 def job_spec @job_spec end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize CustomJobs. Label keys and
values can be no longer than 64 characters (Unicode codepoints), can only
contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. See https://goo.gl/xmQnxf for more
information and examples of labels.
Corresponds to the JSON property labels
4978 4979 4980 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4978 def labels @labels end |
#name ⇒ String
Output only. Resource name of a CustomJob.
Corresponds to the JSON property name
4983 4984 4985 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4983 def name @name end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
4988 4989 4990 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4988 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
4994 4995 4996 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4994 def satisfies_pzs @satisfies_pzs end |
#start_time ⇒ String
Output only. Time when the CustomJob for the first time entered the
JOB_STATE_RUNNING state.
Corresponds to the JSON property startTime
5001 5002 5003 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5001 def start_time @start_time end |
#state ⇒ String
Output only. The detailed state of the job.
Corresponds to the JSON property state
5006 5007 5008 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5006 def state @state end |
#update_time ⇒ String
Output only. Time when the CustomJob was most recently updated.
Corresponds to the JSON property updateTime
5011 5012 5013 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5011 def update_time @update_time end |
#web_access_uris ⇒ Hash<String,String>
Output only. URIs for accessing interactive shells (one URI for each
training node). Only available if job_spec.enable_web_access is true. The
keys are names of each node in the training job; for example, workerpool0-0
for the primary node, workerpool1-0 for the first node in the second worker
pool, and workerpool1-1 for the second node in the second worker pool. The
values are the URIs for each node's interactive shell.
Corresponds to the JSON property webAccessUris
5022 5023 5024 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5022 def web_access_uris @web_access_uris end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5029 5030 5031 5032 5033 5034 5035 5036 5037 5038 5039 5040 5041 5042 5043 5044 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5029 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @end_time = args[:end_time] if args.key?(:end_time) @error = args[:error] if args.key?(:error) @job_spec = args[:job_spec] if args.key?(:job_spec) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) @web_access_uris = args[:web_access_uris] if args.key?(:web_access_uris) end |