Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CustomJob
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CustomJob
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Represents a job that runs custom workloads such as a Docker container or a Python package. A CustomJob can have multiple worker pools and each worker pool can have its own machine and input spec. A CustomJob will be cleaned up once the job enters terminal state (failed or succeeded).
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Required.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top- level resource.
-
#end_time ⇒ String
Output only.
-
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#job_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CustomJobSpec
Represents the spec of a CustomJob.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize CustomJobs.
-
#name ⇒ String
Output only.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
-
#web_access_uris ⇒ Hash<String,String>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1CustomJob
constructor
A new instance of GoogleCloudAiplatformV1CustomJob.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1CustomJob
Returns a new instance of GoogleCloudAiplatformV1CustomJob.
4205 4206 4207 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4205 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Time when the CustomJob was created.
Corresponds to the JSON property createTime
4129 4130 4131 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4129 def create_time @create_time end |
#display_name ⇒ String
Required. The display name of the CustomJob. The name can be up to 128
characters long and can consist of any UTF-8 characters.
Corresponds to the JSON property displayName
4135 4136 4137 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4135 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top-
level resource.
Corresponds to the JSON property encryptionSpec
4141 4142 4143 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4141 def encryption_spec @encryption_spec end |
#end_time ⇒ String
Output only. Time when the CustomJob entered any of the following states:
JOB_STATE_SUCCEEDED, JOB_STATE_FAILED, JOB_STATE_CANCELLED.
Corresponds to the JSON property endTime
4147 4148 4149 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4147 def end_time @end_time end |
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
4157 4158 4159 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4157 def error @error end |
#job_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CustomJobSpec
Represents the spec of a CustomJob.
Corresponds to the JSON property jobSpec
4162 4163 4164 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4162 def job_spec @job_spec end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize CustomJobs. Label keys and
values can be no longer than 64 characters (Unicode codepoints), can only
contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. See https://goo.gl/xmQnxf for more
information and examples of labels.
Corresponds to the JSON property labels
4171 4172 4173 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4171 def labels @labels end |
#name ⇒ String
Output only. Resource name of a CustomJob.
Corresponds to the JSON property name
4176 4177 4178 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4176 def name @name end |
#start_time ⇒ String
Output only. Time when the CustomJob for the first time entered the
JOB_STATE_RUNNING state.
Corresponds to the JSON property startTime
4182 4183 4184 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4182 def start_time @start_time end |
#state ⇒ String
Output only. The detailed state of the job.
Corresponds to the JSON property state
4187 4188 4189 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4187 def state @state end |
#update_time ⇒ String
Output only. Time when the CustomJob was most recently updated.
Corresponds to the JSON property updateTime
4192 4193 4194 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4192 def update_time @update_time end |
#web_access_uris ⇒ Hash<String,String>
Output only. URIs for accessing interactive shells (one URI for each
training node). Only available if job_spec.enable_web_access is true. The
keys are names of each node in the training job; for example, workerpool0-0
for the primary node, workerpool1-0 for the first node in the second worker
pool, and workerpool1-1 for the second node in the second worker pool. The
values are the URIs for each node's interactive shell.
Corresponds to the JSON property webAccessUris
4203 4204 4205 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4203 def web_access_uris @web_access_uris end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4210 4211 4212 4213 4214 4215 4216 4217 4218 4219 4220 4221 4222 4223 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4210 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @end_time = args[:end_time] if args.key?(:end_time) @error = args[:error] if args.key?(:error) @job_spec = args[:job_spec] if args.key?(:job_spec) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) @web_access_uris = args[:web_access_uris] if args.key?(:web_access_uris) end |