Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DataItem

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A piece of data in a Dataset. Could be an image, a video, a document or plain text.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1DataItem

Returns a new instance of GoogleCloudAiplatformV1DataItem.



7281
7282
7283
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7281

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this DataItem was created. Corresponds to the JSON property createTime

Returns:

  • (String)


7233
7234
7235
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7233

def create_time
  @create_time
end

#etagString

Optional. Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


7239
7240
7241
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7239

def etag
  @etag
end

#labelsHash<String,String>

Optional. The labels with user-defined metadata to organize your DataItems. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. No more than 64 user labels can be associated with one DataItem(System labels are excluded). See https://goo. gl/xmQnxf for more information and examples of labels. System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


7250
7251
7252
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7250

def labels
  @labels
end

#nameString

Output only. The resource name of the DataItem. Corresponds to the JSON property name

Returns:

  • (String)


7255
7256
7257
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7255

def name
  @name
end

#payloadObject

Required. The data that the DataItem represents (for example, an image or a text snippet). The schema of the payload is stored in the parent Dataset's metadata schema's dataItemSchemaUri field. Corresponds to the JSON property payload

Returns:

  • (Object)


7262
7263
7264
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7262

def payload
  @payload
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


7267
7268
7269
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7267

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


7273
7274
7275
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7273

def satisfies_pzs
  @satisfies_pzs
end

#update_timeString

Output only. Timestamp when this DataItem was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


7279
7280
7281
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7279

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7286
7287
7288
7289
7290
7291
7292
7293
7294
7295
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7286

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @payload = args[:payload] if args.key?(:payload)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @update_time = args[:update_time] if args.key?(:update_time)
end