Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DataItem

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A piece of data in a Dataset. Could be an image, a video, a document or plain text.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1DataItem

Returns a new instance of GoogleCloudAiplatformV1DataItem.



6110
6111
6112
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6110

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this DataItem was created. Corresponds to the JSON property createTime

Returns:

  • (String)


6062
6063
6064
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6062

def create_time
  @create_time
end

#etagString

Optional. Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


6068
6069
6070
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6068

def etag
  @etag
end

#labelsHash<String,String>

Optional. The labels with user-defined metadata to organize your DataItems. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. No more than 64 user labels can be associated with one DataItem(System labels are excluded). See https://goo. gl/xmQnxf for more information and examples of labels. System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


6079
6080
6081
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6079

def labels
  @labels
end

#nameString

Output only. The resource name of the DataItem. Corresponds to the JSON property name

Returns:

  • (String)


6084
6085
6086
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6084

def name
  @name
end

#payloadObject

Required. The data that the DataItem represents (for example, an image or a text snippet). The schema of the payload is stored in the parent Dataset's metadata schema's dataItemSchemaUri field. Corresponds to the JSON property payload

Returns:

  • (Object)


6091
6092
6093
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6091

def payload
  @payload
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


6096
6097
6098
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6096

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


6102
6103
6104
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6102

def satisfies_pzs
  @satisfies_pzs
end

#update_timeString

Output only. Timestamp when this DataItem was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


6108
6109
6110
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6108

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6115
6116
6117
6118
6119
6120
6121
6122
6123
6124
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6115

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @payload = args[:payload] if args.key?(:payload)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @update_time = args[:update_time] if args.key?(:update_time)
end