Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DataItem
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DataItem
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A piece of data in a Dataset. Could be an image, a video, a document or plain text.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#etag ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Output only.
-
#payload ⇒ Object
Required.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1DataItem
constructor
A new instance of GoogleCloudAiplatformV1DataItem.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1DataItem
Returns a new instance of GoogleCloudAiplatformV1DataItem.
4921 4922 4923 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4921 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this DataItem was created.
Corresponds to the JSON property createTime
4873 4874 4875 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4873 def create_time @create_time end |
#etag ⇒ String
Optional. Used to perform consistent read-modify-write updates. If not set, a
blind "overwrite" update happens.
Corresponds to the JSON property etag
4879 4880 4881 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4879 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. The labels with user-defined metadata to organize your DataItems.
Label keys and values can be no longer than 64 characters (Unicode codepoints),
can only contain lowercase letters, numeric characters, underscores and
dashes. International characters are allowed. No more than 64 user labels can
be associated with one DataItem(System labels are excluded). See https://goo.
gl/xmQnxf for more information and examples of labels. System reserved label
keys are prefixed with "aiplatform.googleapis.com/" and are immutable.
Corresponds to the JSON property labels
4890 4891 4892 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4890 def labels @labels end |
#name ⇒ String
Output only. The resource name of the DataItem.
Corresponds to the JSON property name
4895 4896 4897 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4895 def name @name end |
#payload ⇒ Object
Required. The data that the DataItem represents (for example, an image or a
text snippet). The schema of the payload is stored in the parent Dataset's
metadata schema's dataItemSchemaUri field.
Corresponds to the JSON property payload
4902 4903 4904 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4902 def payload @payload end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
4907 4908 4909 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4907 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
4913 4914 4915 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4913 def satisfies_pzs @satisfies_pzs end |
#update_time ⇒ String
Output only. Timestamp when this DataItem was last updated.
Corresponds to the JSON property updateTime
4919 4920 4921 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4919 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4926 4927 4928 4929 4930 4931 4932 4933 4934 4935 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4926 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @payload = args[:payload] if args.key?(:payload) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @update_time = args[:update_time] if args.key?(:update_time) end |