Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DataItemView
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DataItemView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A container for a single DataItem and Annotations on it.
Instance Attribute Summary collapse
-
#annotations ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Annotation>
The Annotations on the DataItem.
-
#data_item ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DataItem
A piece of data in a Dataset.
-
#has_truncated_annotations ⇒ Boolean
(also: #has_truncated_annotations?)
True if and only if the Annotations field has been truncated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1DataItemView
constructor
A new instance of GoogleCloudAiplatformV1DataItemView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1DataItemView
Returns a new instance of GoogleCloudAiplatformV1DataItemView.
5075 5076 5077 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5075 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Annotation>
The Annotations on the DataItem. If too many Annotations should be returned
for the DataItem, this field will be truncated per annotations_limit in
request. If it was, then the has_truncated_annotations will be set to true.
Corresponds to the JSON property annotations
5057 5058 5059 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5057 def annotations @annotations end |
#data_item ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DataItem
A piece of data in a Dataset. Could be an image, a video, a document or plain
text.
Corresponds to the JSON property dataItem
5063 5064 5065 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5063 def data_item @data_item end |
#has_truncated_annotations ⇒ Boolean Also known as: has_truncated_annotations?
True if and only if the Annotations field has been truncated. It happens if
more Annotations for this DataItem met the request's annotation_filter than
are allowed to be returned by annotations_limit. Note that if Annotations
field is not being returned due to field mask, then this field will not be set
to true no matter how many Annotations are there.
Corresponds to the JSON property hasTruncatedAnnotations
5072 5073 5074 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5072 def has_truncated_annotations @has_truncated_annotations end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5080 5081 5082 5083 5084 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5080 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @data_item = args[:data_item] if args.key?(:data_item) @has_truncated_annotations = args[:has_truncated_annotations] if args.key?(:has_truncated_annotations) end |