Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DataLabelingJob
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DataLabelingJob
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
DataLabelingJob is used to trigger a human labeling job on unlabeled data from the following Dataset:
Instance Attribute Summary collapse
-
#active_learning_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ActiveLearningConfig
Parameters that configure the active learning pipeline.
-
#annotation_labels ⇒ Hash<String,String>
Labels to assign to annotations generated by this DataLabelingJob.
-
#create_time ⇒ String
Output only.
-
#current_spend ⇒ Google::Apis::AiplatformV1::GoogleTypeMoney
Represents an amount of money with its currency type.
-
#datasets ⇒ Array<String>
Required.
-
#display_name ⇒ String
Required.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.
-
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#inputs ⇒ Object
Required.
-
#inputs_schema_uri ⇒ String
Required.
-
#instruction_uri ⇒ String
Required.
-
#labeler_count ⇒ Fixnum
Required.
-
#labeling_progress ⇒ Fixnum
Output only.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your DataLabelingJobs.
-
#name ⇒ String
Output only.
-
#specialist_pools ⇒ Array<String>
The SpecialistPools' resource names associated with this job.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1DataLabelingJob
constructor
A new instance of GoogleCloudAiplatformV1DataLabelingJob.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1DataLabelingJob
Returns a new instance of GoogleCloudAiplatformV1DataLabelingJob.
6886 6887 6888 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6886 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active_learning_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ActiveLearningConfig
Parameters that configure the active learning pipeline. Active learning will
label the data incrementally by several iterations. For every iteration, it
will select a batch of data based on the sampling strategy.
Corresponds to the JSON property activeLearningConfig
6771 6772 6773 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6771 def active_learning_config @active_learning_config end |
#annotation_labels ⇒ Hash<String,String>
Labels to assign to annotations generated by this DataLabelingJob. Label keys
and values can be no longer than 64 characters (Unicode codepoints), can only
contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. See https://goo.gl/xmQnxf for more
information and examples of labels. System reserved label keys are prefixed
with "aiplatform.googleapis.com/" and are immutable.
Corresponds to the JSON property annotationLabels
6781 6782 6783 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6781 def annotation_labels @annotation_labels end |
#create_time ⇒ String
Output only. Timestamp when this DataLabelingJob was created.
Corresponds to the JSON property createTime
6786 6787 6788 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6786 def create_time @create_time end |
#current_spend ⇒ Google::Apis::AiplatformV1::GoogleTypeMoney
Represents an amount of money with its currency type.
Corresponds to the JSON property currentSpend
6791 6792 6793 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6791 def current_spend @current_spend end |
#datasets ⇒ Array<String>
Required. Dataset resource names. Right now we only support labeling from a
single Dataset. Format: projects/project/locations/location/datasets/
dataset`
Corresponds to the JSON propertydatasets`
6798 6799 6800 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6798 def datasets @datasets end |
#display_name ⇒ String
Required. The user-defined name of the DataLabelingJob. The name can be up to
128 characters long and can consist of any UTF-8 characters. Display name of a
DataLabelingJob.
Corresponds to the JSON property displayName
6805 6806 6807 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6805 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied
to a Vertex AI resource.
Corresponds to the JSON property encryptionSpec
6811 6812 6813 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6811 def encryption_spec @encryption_spec end |
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
6821 6822 6823 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6821 def error @error end |
#inputs ⇒ Object
Required. Input config parameters for the DataLabelingJob.
Corresponds to the JSON property inputs
6826 6827 6828 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6826 def inputs @inputs end |
#inputs_schema_uri ⇒ String
Required. Points to a YAML file stored on Google Cloud Storage describing the
config for a specific type of DataLabelingJob. The schema files that can be
used here are found in the https://storage.googleapis.com/google-cloud-
aiplatform bucket in the /schema/datalabelingjob/inputs/ folder.
Corresponds to the JSON property inputsSchemaUri
6834 6835 6836 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6834 def inputs_schema_uri @inputs_schema_uri end |
#instruction_uri ⇒ String
Required. The Google Cloud Storage location of the instruction pdf. This pdf
is shared with labelers, and provides detailed description on how to label
DataItems in Datasets.
Corresponds to the JSON property instructionUri
6841 6842 6843 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6841 def instruction_uri @instruction_uri end |
#labeler_count ⇒ Fixnum
Required. Number of labelers to work on each DataItem.
Corresponds to the JSON property labelerCount
6846 6847 6848 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6846 def labeler_count @labeler_count end |
#labeling_progress ⇒ Fixnum
Output only. Current labeling job progress percentage scaled in interval [0,
100], indicating the percentage of DataItems that has been finished.
Corresponds to the JSON property labelingProgress
6852 6853 6854 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6852 def labeling_progress @labeling_progress end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your DataLabelingJobs. Label
keys and values can be no longer than 64 characters (Unicode codepoints), can
only contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. See https://goo.gl/xmQnxf for more
information and examples of labels. System reserved label keys are prefixed
with "aiplatform.googleapis.com/" and are immutable. Following system labels
exist for each DataLabelingJob: * "aiplatform.googleapis.com/schema": output
only, its value is the inputs_schema's title.
Corresponds to the JSON property labels
6864 6865 6866 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6864 def labels @labels end |
#name ⇒ String
Output only. Resource name of the DataLabelingJob.
Corresponds to the JSON property name
6869 6870 6871 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6869 def name @name end |
#specialist_pools ⇒ Array<String>
The SpecialistPools' resource names associated with this job.
Corresponds to the JSON property specialistPools
6874 6875 6876 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6874 def specialist_pools @specialist_pools end |
#state ⇒ String
Output only. The detailed state of the job.
Corresponds to the JSON property state
6879 6880 6881 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6879 def state @state end |
#update_time ⇒ String
Output only. Timestamp when this DataLabelingJob was updated most recently.
Corresponds to the JSON property updateTime
6884 6885 6886 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6884 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6891 6892 6893 6894 6895 6896 6897 6898 6899 6900 6901 6902 6903 6904 6905 6906 6907 6908 6909 6910 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6891 def update!(**args) @active_learning_config = args[:active_learning_config] if args.key?(:active_learning_config) @annotation_labels = args[:annotation_labels] if args.key?(:annotation_labels) @create_time = args[:create_time] if args.key?(:create_time) @current_spend = args[:current_spend] if args.key?(:current_spend) @datasets = args[:datasets] if args.key?(:datasets) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @error = args[:error] if args.key?(:error) @inputs = args[:inputs] if args.key?(:inputs) @inputs_schema_uri = args[:inputs_schema_uri] if args.key?(:inputs_schema_uri) @instruction_uri = args[:instruction_uri] if args.key?(:instruction_uri) @labeler_count = args[:labeler_count] if args.key?(:labeler_count) @labeling_progress = args[:labeling_progress] if args.key?(:labeling_progress) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @specialist_pools = args[:specialist_pools] if args.key?(:specialist_pools) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |