Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DataLabelingJob
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DataLabelingJob
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
DataLabelingJob is used to trigger a human labeling job on unlabeled data from the following Dataset:
Instance Attribute Summary collapse
-
#active_learning_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ActiveLearningConfig
Parameters that configure the active learning pipeline.
-
#annotation_labels ⇒ Hash<String,String>
Labels to assign to annotations generated by this DataLabelingJob.
-
#create_time ⇒ String
Output only.
-
#current_spend ⇒ Google::Apis::AiplatformV1::GoogleTypeMoney
Represents an amount of money with its currency type.
-
#datasets ⇒ Array<String>
Required.
-
#display_name ⇒ String
Required.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top- level resource.
-
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#inputs ⇒ Object
Required.
-
#inputs_schema_uri ⇒ String
Required.
-
#instruction_uri ⇒ String
Required.
-
#labeler_count ⇒ Fixnum
Required.
-
#labeling_progress ⇒ Fixnum
Output only.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your DataLabelingJobs.
-
#name ⇒ String
Output only.
-
#specialist_pools ⇒ Array<String>
The SpecialistPools' resource names associated with this job.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1DataLabelingJob
constructor
A new instance of GoogleCloudAiplatformV1DataLabelingJob.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1DataLabelingJob
Returns a new instance of GoogleCloudAiplatformV1DataLabelingJob.
5479 5480 5481 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5479 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active_learning_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ActiveLearningConfig
Parameters that configure the active learning pipeline. Active learning will
label the data incrementally by several iterations. For every iteration, it
will select a batch of data based on the sampling strategy.
Corresponds to the JSON property activeLearningConfig
5364 5365 5366 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5364 def active_learning_config @active_learning_config end |
#annotation_labels ⇒ Hash<String,String>
Labels to assign to annotations generated by this DataLabelingJob. Label keys
and values can be no longer than 64 characters (Unicode codepoints), can only
contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. See https://goo.gl/xmQnxf for more
information and examples of labels. System reserved label keys are prefixed
with "aiplatform.googleapis.com/" and are immutable.
Corresponds to the JSON property annotationLabels
5374 5375 5376 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5374 def annotation_labels @annotation_labels end |
#create_time ⇒ String
Output only. Timestamp when this DataLabelingJob was created.
Corresponds to the JSON property createTime
5379 5380 5381 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5379 def create_time @create_time end |
#current_spend ⇒ Google::Apis::AiplatformV1::GoogleTypeMoney
Represents an amount of money with its currency type.
Corresponds to the JSON property currentSpend
5384 5385 5386 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5384 def current_spend @current_spend end |
#datasets ⇒ Array<String>
Required. Dataset resource names. Right now we only support labeling from a
single Dataset. Format: projects/project/locations/location/datasets/
dataset`
Corresponds to the JSON propertydatasets`
5391 5392 5393 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5391 def datasets @datasets end |
#display_name ⇒ String
Required. The user-defined name of the DataLabelingJob. The name can be up to
128 characters long and can consist of any UTF-8 characters. Display name of a
DataLabelingJob.
Corresponds to the JSON property displayName
5398 5399 5400 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5398 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top-
level resource.
Corresponds to the JSON property encryptionSpec
5404 5405 5406 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5404 def encryption_spec @encryption_spec end |
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
5414 5415 5416 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5414 def error @error end |
#inputs ⇒ Object
Required. Input config parameters for the DataLabelingJob.
Corresponds to the JSON property inputs
5419 5420 5421 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5419 def inputs @inputs end |
#inputs_schema_uri ⇒ String
Required. Points to a YAML file stored on Google Cloud Storage describing the
config for a specific type of DataLabelingJob. The schema files that can be
used here are found in the https://storage.googleapis.com/google-cloud-
aiplatform bucket in the /schema/datalabelingjob/inputs/ folder.
Corresponds to the JSON property inputsSchemaUri
5427 5428 5429 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5427 def inputs_schema_uri @inputs_schema_uri end |
#instruction_uri ⇒ String
Required. The Google Cloud Storage location of the instruction pdf. This pdf
is shared with labelers, and provides detailed description on how to label
DataItems in Datasets.
Corresponds to the JSON property instructionUri
5434 5435 5436 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5434 def instruction_uri @instruction_uri end |
#labeler_count ⇒ Fixnum
Required. Number of labelers to work on each DataItem.
Corresponds to the JSON property labelerCount
5439 5440 5441 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5439 def labeler_count @labeler_count end |
#labeling_progress ⇒ Fixnum
Output only. Current labeling job progress percentage scaled in interval [0,
100], indicating the percentage of DataItems that has been finished.
Corresponds to the JSON property labelingProgress
5445 5446 5447 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5445 def labeling_progress @labeling_progress end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your DataLabelingJobs. Label
keys and values can be no longer than 64 characters (Unicode codepoints), can
only contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. See https://goo.gl/xmQnxf for more
information and examples of labels. System reserved label keys are prefixed
with "aiplatform.googleapis.com/" and are immutable. Following system labels
exist for each DataLabelingJob: * "aiplatform.googleapis.com/schema": output
only, its value is the inputs_schema's title.
Corresponds to the JSON property labels
5457 5458 5459 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5457 def labels @labels end |
#name ⇒ String
Output only. Resource name of the DataLabelingJob.
Corresponds to the JSON property name
5462 5463 5464 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5462 def name @name end |
#specialist_pools ⇒ Array<String>
The SpecialistPools' resource names associated with this job.
Corresponds to the JSON property specialistPools
5467 5468 5469 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5467 def specialist_pools @specialist_pools end |
#state ⇒ String
Output only. The detailed state of the job.
Corresponds to the JSON property state
5472 5473 5474 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5472 def state @state end |
#update_time ⇒ String
Output only. Timestamp when this DataLabelingJob was updated most recently.
Corresponds to the JSON property updateTime
5477 5478 5479 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5477 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5484 5485 5486 5487 5488 5489 5490 5491 5492 5493 5494 5495 5496 5497 5498 5499 5500 5501 5502 5503 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5484 def update!(**args) @active_learning_config = args[:active_learning_config] if args.key?(:active_learning_config) @annotation_labels = args[:annotation_labels] if args.key?(:annotation_labels) @create_time = args[:create_time] if args.key?(:create_time) @current_spend = args[:current_spend] if args.key?(:current_spend) @datasets = args[:datasets] if args.key?(:datasets) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @error = args[:error] if args.key?(:error) @inputs = args[:inputs] if args.key?(:inputs) @inputs_schema_uri = args[:inputs_schema_uri] if args.key?(:inputs_schema_uri) @instruction_uri = args[:instruction_uri] if args.key?(:instruction_uri) @labeler_count = args[:labeler_count] if args.key?(:labeler_count) @labeling_progress = args[:labeling_progress] if args.key?(:labeling_progress) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @specialist_pools = args[:specialist_pools] if args.key?(:specialist_pools) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |