Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DataLabelingJob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

DataLabelingJob is used to trigger a human labeling job on unlabeled data from the following Dataset:

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1DataLabelingJob

Returns a new instance of GoogleCloudAiplatformV1DataLabelingJob.



5219
5220
5221
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5219

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#active_learning_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ActiveLearningConfig

Parameters that configure the active learning pipeline. Active learning will label the data incrementally by several iterations. For every iteration, it will select a batch of data based on the sampling strategy. Corresponds to the JSON property activeLearningConfig



5104
5105
5106
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5104

def active_learning_config
  @active_learning_config
end

#annotation_labelsHash<String,String>

Labels to assign to annotations generated by this DataLabelingJob. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable. Corresponds to the JSON property annotationLabels

Returns:

  • (Hash<String,String>)


5114
5115
5116
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5114

def annotation_labels
  @annotation_labels
end

#create_timeString

Output only. Timestamp when this DataLabelingJob was created. Corresponds to the JSON property createTime

Returns:

  • (String)


5119
5120
5121
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5119

def create_time
  @create_time
end

#current_spendGoogle::Apis::AiplatformV1::GoogleTypeMoney

Represents an amount of money with its currency type. Corresponds to the JSON property currentSpend



5124
5125
5126
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5124

def current_spend
  @current_spend
end

#datasetsArray<String>

Required. Dataset resource names. Right now we only support labeling from a single Dataset. Format: projects/project/locations/location/datasets/ dataset` Corresponds to the JSON propertydatasets`

Returns:

  • (Array<String>)


5131
5132
5133
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5131

def datasets
  @datasets
end

#display_nameString

Required. The user-defined name of the DataLabelingJob. The name can be up to 128 characters long and can consist of any UTF-8 characters. Display name of a DataLabelingJob. Corresponds to the JSON property displayName

Returns:

  • (String)


5138
5139
5140
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5138

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key spec that can be applied to a top- level resource. Corresponds to the JSON property encryptionSpec



5144
5145
5146
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5144

def encryption_spec
  @encryption_spec
end

#errorGoogle::Apis::AiplatformV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



5154
5155
5156
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5154

def error
  @error
end

#inputsObject

Required. Input config parameters for the DataLabelingJob. Corresponds to the JSON property inputs

Returns:

  • (Object)


5159
5160
5161
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5159

def inputs
  @inputs
end

#inputs_schema_uriString

Required. Points to a YAML file stored on Google Cloud Storage describing the config for a specific type of DataLabelingJob. The schema files that can be used here are found in the https://storage.googleapis.com/google-cloud- aiplatform bucket in the /schema/datalabelingjob/inputs/ folder. Corresponds to the JSON property inputsSchemaUri

Returns:

  • (String)


5167
5168
5169
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5167

def inputs_schema_uri
  @inputs_schema_uri
end

#instruction_uriString

Required. The Google Cloud Storage location of the instruction pdf. This pdf is shared with labelers, and provides detailed description on how to label DataItems in Datasets. Corresponds to the JSON property instructionUri

Returns:

  • (String)


5174
5175
5176
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5174

def instruction_uri
  @instruction_uri
end

#labeler_countFixnum

Required. Number of labelers to work on each DataItem. Corresponds to the JSON property labelerCount

Returns:

  • (Fixnum)


5179
5180
5181
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5179

def labeler_count
  @labeler_count
end

#labeling_progressFixnum

Output only. Current labeling job progress percentage scaled in interval [0, 100], indicating the percentage of DataItems that has been finished. Corresponds to the JSON property labelingProgress

Returns:

  • (Fixnum)


5185
5186
5187
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5185

def labeling_progress
  @labeling_progress
end

#labelsHash<String,String>

The labels with user-defined metadata to organize your DataLabelingJobs. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable. Following system labels exist for each DataLabelingJob: * "aiplatform.googleapis.com/schema": output only, its value is the inputs_schema's title. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


5197
5198
5199
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5197

def labels
  @labels
end

#nameString

Output only. Resource name of the DataLabelingJob. Corresponds to the JSON property name

Returns:

  • (String)


5202
5203
5204
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5202

def name
  @name
end

#specialist_poolsArray<String>

The SpecialistPools' resource names associated with this job. Corresponds to the JSON property specialistPools

Returns:

  • (Array<String>)


5207
5208
5209
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5207

def specialist_pools
  @specialist_pools
end

#stateString

Output only. The detailed state of the job. Corresponds to the JSON property state

Returns:

  • (String)


5212
5213
5214
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5212

def state
  @state
end

#update_timeString

Output only. Timestamp when this DataLabelingJob was updated most recently. Corresponds to the JSON property updateTime

Returns:

  • (String)


5217
5218
5219
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5217

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5224
5225
5226
5227
5228
5229
5230
5231
5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
5242
5243
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5224

def update!(**args)
  @active_learning_config = args[:active_learning_config] if args.key?(:active_learning_config)
  @annotation_labels = args[:annotation_labels] if args.key?(:annotation_labels)
  @create_time = args[:create_time] if args.key?(:create_time)
  @current_spend = args[:current_spend] if args.key?(:current_spend)
  @datasets = args[:datasets] if args.key?(:datasets)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @error = args[:error] if args.key?(:error)
  @inputs = args[:inputs] if args.key?(:inputs)
  @inputs_schema_uri = args[:inputs_schema_uri] if args.key?(:inputs_schema_uri)
  @instruction_uri = args[:instruction_uri] if args.key?(:instruction_uri)
  @labeler_count = args[:labeler_count] if args.key?(:labeler_count)
  @labeling_progress = args[:labeling_progress] if args.key?(:labeling_progress)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @specialist_pools = args[:specialist_pools] if args.key?(:specialist_pools)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end