Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DataLabelingJob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

DataLabelingJob is used to trigger a human labeling job on unlabeled data from the following Dataset:

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1DataLabelingJob

Returns a new instance of GoogleCloudAiplatformV1DataLabelingJob.



5059
5060
5061
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5059

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#active_learning_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ActiveLearningConfig

Parameters that configure the active learning pipeline. Active learning will label the data incrementally by several iterations. For every iteration, it will select a batch of data based on the sampling strategy. Corresponds to the JSON property activeLearningConfig



4944
4945
4946
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4944

def active_learning_config
  @active_learning_config
end

#annotation_labelsHash<String,String>

Labels to assign to annotations generated by this DataLabelingJob. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable. Corresponds to the JSON property annotationLabels

Returns:

  • (Hash<String,String>)


4954
4955
4956
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4954

def annotation_labels
  @annotation_labels
end

#create_timeString

Output only. Timestamp when this DataLabelingJob was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4959
4960
4961
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4959

def create_time
  @create_time
end

#current_spendGoogle::Apis::AiplatformV1::GoogleTypeMoney

Represents an amount of money with its currency type. Corresponds to the JSON property currentSpend



4964
4965
4966
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4964

def current_spend
  @current_spend
end

#datasetsArray<String>

Required. Dataset resource names. Right now we only support labeling from a single Dataset. Format: projects/project/locations/location/datasets/ dataset` Corresponds to the JSON propertydatasets`

Returns:

  • (Array<String>)


4971
4972
4973
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4971

def datasets
  @datasets
end

#display_nameString

Required. The user-defined name of the DataLabelingJob. The name can be up to 128 characters long and can consist of any UTF-8 characters. Display name of a DataLabelingJob. Corresponds to the JSON property displayName

Returns:

  • (String)


4978
4979
4980
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4978

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key spec that can be applied to a top- level resource. Corresponds to the JSON property encryptionSpec



4984
4985
4986
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4984

def encryption_spec
  @encryption_spec
end

#errorGoogle::Apis::AiplatformV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



4994
4995
4996
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4994

def error
  @error
end

#inputsObject

Required. Input config parameters for the DataLabelingJob. Corresponds to the JSON property inputs

Returns:

  • (Object)


4999
5000
5001
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4999

def inputs
  @inputs
end

#inputs_schema_uriString

Required. Points to a YAML file stored on Google Cloud Storage describing the config for a specific type of DataLabelingJob. The schema files that can be used here are found in the https://storage.googleapis.com/google-cloud- aiplatform bucket in the /schema/datalabelingjob/inputs/ folder. Corresponds to the JSON property inputsSchemaUri

Returns:

  • (String)


5007
5008
5009
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5007

def inputs_schema_uri
  @inputs_schema_uri
end

#instruction_uriString

Required. The Google Cloud Storage location of the instruction pdf. This pdf is shared with labelers, and provides detailed description on how to label DataItems in Datasets. Corresponds to the JSON property instructionUri

Returns:

  • (String)


5014
5015
5016
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5014

def instruction_uri
  @instruction_uri
end

#labeler_countFixnum

Required. Number of labelers to work on each DataItem. Corresponds to the JSON property labelerCount

Returns:

  • (Fixnum)


5019
5020
5021
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5019

def labeler_count
  @labeler_count
end

#labeling_progressFixnum

Output only. Current labeling job progress percentage scaled in interval [0, 100], indicating the percentage of DataItems that has been finished. Corresponds to the JSON property labelingProgress

Returns:

  • (Fixnum)


5025
5026
5027
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5025

def labeling_progress
  @labeling_progress
end

#labelsHash<String,String>

The labels with user-defined metadata to organize your DataLabelingJobs. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable. Following system labels exist for each DataLabelingJob: * "aiplatform.googleapis.com/schema": output only, its value is the inputs_schema's title. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


5037
5038
5039
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5037

def labels
  @labels
end

#nameString

Output only. Resource name of the DataLabelingJob. Corresponds to the JSON property name

Returns:

  • (String)


5042
5043
5044
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5042

def name
  @name
end

#specialist_poolsArray<String>

The SpecialistPools' resource names associated with this job. Corresponds to the JSON property specialistPools

Returns:

  • (Array<String>)


5047
5048
5049
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5047

def specialist_pools
  @specialist_pools
end

#stateString

Output only. The detailed state of the job. Corresponds to the JSON property state

Returns:

  • (String)


5052
5053
5054
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5052

def state
  @state
end

#update_timeString

Output only. Timestamp when this DataLabelingJob was updated most recently. Corresponds to the JSON property updateTime

Returns:

  • (String)


5057
5058
5059
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5057

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5064
5065
5066
5067
5068
5069
5070
5071
5072
5073
5074
5075
5076
5077
5078
5079
5080
5081
5082
5083
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5064

def update!(**args)
  @active_learning_config = args[:active_learning_config] if args.key?(:active_learning_config)
  @annotation_labels = args[:annotation_labels] if args.key?(:annotation_labels)
  @create_time = args[:create_time] if args.key?(:create_time)
  @current_spend = args[:current_spend] if args.key?(:current_spend)
  @datasets = args[:datasets] if args.key?(:datasets)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @error = args[:error] if args.key?(:error)
  @inputs = args[:inputs] if args.key?(:inputs)
  @inputs_schema_uri = args[:inputs_schema_uri] if args.key?(:inputs_schema_uri)
  @instruction_uri = args[:instruction_uri] if args.key?(:instruction_uri)
  @labeler_count = args[:labeler_count] if args.key?(:labeler_count)
  @labeling_progress = args[:labeling_progress] if args.key?(:labeling_progress)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @specialist_pools = args[:specialist_pools] if args.key?(:specialist_pools)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end