Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DataLabelingJob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

DataLabelingJob is used to trigger a human labeling job on unlabeled data from the following Dataset:

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1DataLabelingJob

Returns a new instance of GoogleCloudAiplatformV1DataLabelingJob.



4200
4201
4202
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4200

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#active_learning_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ActiveLearningConfig

Parameters that configure the active learning pipeline. Active learning will label the data incrementally by several iterations. For every iteration, it will select a batch of data based on the sampling strategy. Corresponds to the JSON property activeLearningConfig



4085
4086
4087
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4085

def active_learning_config
  @active_learning_config
end

#annotation_labelsHash<String,String>

Labels to assign to annotations generated by this DataLabelingJob. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable. Corresponds to the JSON property annotationLabels

Returns:

  • (Hash<String,String>)


4095
4096
4097
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4095

def annotation_labels
  @annotation_labels
end

#create_timeString

Output only. Timestamp when this DataLabelingJob was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4100
4101
4102
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4100

def create_time
  @create_time
end

#current_spendGoogle::Apis::AiplatformV1::GoogleTypeMoney

Represents an amount of money with its currency type. Corresponds to the JSON property currentSpend



4105
4106
4107
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4105

def current_spend
  @current_spend
end

#datasetsArray<String>

Required. Dataset resource names. Right now we only support labeling from a single Dataset. Format: projects/project/locations/location/datasets/ dataset` Corresponds to the JSON propertydatasets`

Returns:

  • (Array<String>)


4112
4113
4114
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4112

def datasets
  @datasets
end

#display_nameString

Required. The user-defined name of the DataLabelingJob. The name can be up to 128 characters long and can consist of any UTF-8 characters. Display name of a DataLabelingJob. Corresponds to the JSON property displayName

Returns:

  • (String)


4119
4120
4121
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4119

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key spec that can be applied to a top- level resource. Corresponds to the JSON property encryptionSpec



4125
4126
4127
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4125

def encryption_spec
  @encryption_spec
end

#errorGoogle::Apis::AiplatformV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



4135
4136
4137
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4135

def error
  @error
end

#inputsObject

Required. Input config parameters for the DataLabelingJob. Corresponds to the JSON property inputs

Returns:

  • (Object)


4140
4141
4142
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4140

def inputs
  @inputs
end

#inputs_schema_uriString

Required. Points to a YAML file stored on Google Cloud Storage describing the config for a specific type of DataLabelingJob. The schema files that can be used here are found in the https://storage.googleapis.com/google-cloud- aiplatform bucket in the /schema/datalabelingjob/inputs/ folder. Corresponds to the JSON property inputsSchemaUri

Returns:

  • (String)


4148
4149
4150
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4148

def inputs_schema_uri
  @inputs_schema_uri
end

#instruction_uriString

Required. The Google Cloud Storage location of the instruction pdf. This pdf is shared with labelers, and provides detailed description on how to label DataItems in Datasets. Corresponds to the JSON property instructionUri

Returns:

  • (String)


4155
4156
4157
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4155

def instruction_uri
  @instruction_uri
end

#labeler_countFixnum

Required. Number of labelers to work on each DataItem. Corresponds to the JSON property labelerCount

Returns:

  • (Fixnum)


4160
4161
4162
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4160

def labeler_count
  @labeler_count
end

#labeling_progressFixnum

Output only. Current labeling job progress percentage scaled in interval [0, 100], indicating the percentage of DataItems that has been finished. Corresponds to the JSON property labelingProgress

Returns:

  • (Fixnum)


4166
4167
4168
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4166

def labeling_progress
  @labeling_progress
end

#labelsHash<String,String>

The labels with user-defined metadata to organize your DataLabelingJobs. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable. Following system labels exist for each DataLabelingJob: * "aiplatform.googleapis.com/schema": output only, its value is the inputs_schema's title. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4178
4179
4180
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4178

def labels
  @labels
end

#nameString

Output only. Resource name of the DataLabelingJob. Corresponds to the JSON property name

Returns:

  • (String)


4183
4184
4185
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4183

def name
  @name
end

#specialist_poolsArray<String>

The SpecialistPools' resource names associated with this job. Corresponds to the JSON property specialistPools

Returns:

  • (Array<String>)


4188
4189
4190
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4188

def specialist_pools
  @specialist_pools
end

#stateString

Output only. The detailed state of the job. Corresponds to the JSON property state

Returns:

  • (String)


4193
4194
4195
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4193

def state
  @state
end

#update_timeString

Output only. Timestamp when this DataLabelingJob was updated most recently. Corresponds to the JSON property updateTime

Returns:

  • (String)


4198
4199
4200
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4198

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4205
4206
4207
4208
4209
4210
4211
4212
4213
4214
4215
4216
4217
4218
4219
4220
4221
4222
4223
4224
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4205

def update!(**args)
  @active_learning_config = args[:active_learning_config] if args.key?(:active_learning_config)
  @annotation_labels = args[:annotation_labels] if args.key?(:annotation_labels)
  @create_time = args[:create_time] if args.key?(:create_time)
  @current_spend = args[:current_spend] if args.key?(:current_spend)
  @datasets = args[:datasets] if args.key?(:datasets)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @error = args[:error] if args.key?(:error)
  @inputs = args[:inputs] if args.key?(:inputs)
  @inputs_schema_uri = args[:inputs_schema_uri] if args.key?(:inputs_schema_uri)
  @instruction_uri = args[:instruction_uri] if args.key?(:instruction_uri)
  @labeler_count = args[:labeler_count] if args.key?(:labeler_count)
  @labeling_progress = args[:labeling_progress] if args.key?(:labeling_progress)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @specialist_pools = args[:specialist_pools] if args.key?(:specialist_pools)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end