Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DataLabelingJob
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DataLabelingJob
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
DataLabelingJob is used to trigger a human labeling job on unlabeled data from the following Dataset:
Instance Attribute Summary collapse
-
#active_learning_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ActiveLearningConfig
Parameters that configure the active learning pipeline.
-
#annotation_labels ⇒ Hash<String,String>
Labels to assign to annotations generated by this DataLabelingJob.
-
#create_time ⇒ String
Output only.
-
#current_spend ⇒ Google::Apis::AiplatformV1::GoogleTypeMoney
Represents an amount of money with its currency type.
-
#datasets ⇒ Array<String>
Required.
-
#display_name ⇒ String
Required.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top- level resource.
-
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#inputs ⇒ Object
Required.
-
#inputs_schema_uri ⇒ String
Required.
-
#instruction_uri ⇒ String
Required.
-
#labeler_count ⇒ Fixnum
Required.
-
#labeling_progress ⇒ Fixnum
Output only.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your DataLabelingJobs.
-
#name ⇒ String
Output only.
-
#specialist_pools ⇒ Array<String>
The SpecialistPools' resource names associated with this job.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1DataLabelingJob
constructor
A new instance of GoogleCloudAiplatformV1DataLabelingJob.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1DataLabelingJob
Returns a new instance of GoogleCloudAiplatformV1DataLabelingJob.
4235 4236 4237 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4235 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active_learning_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ActiveLearningConfig
Parameters that configure the active learning pipeline. Active learning will
label the data incrementally by several iterations. For every iteration, it
will select a batch of data based on the sampling strategy.
Corresponds to the JSON property activeLearningConfig
4120 4121 4122 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4120 def active_learning_config @active_learning_config end |
#annotation_labels ⇒ Hash<String,String>
Labels to assign to annotations generated by this DataLabelingJob. Label keys
and values can be no longer than 64 characters (Unicode codepoints), can only
contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. See https://goo.gl/xmQnxf for more
information and examples of labels. System reserved label keys are prefixed
with "aiplatform.googleapis.com/" and are immutable.
Corresponds to the JSON property annotationLabels
4130 4131 4132 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4130 def annotation_labels @annotation_labels end |
#create_time ⇒ String
Output only. Timestamp when this DataLabelingJob was created.
Corresponds to the JSON property createTime
4135 4136 4137 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4135 def create_time @create_time end |
#current_spend ⇒ Google::Apis::AiplatformV1::GoogleTypeMoney
Represents an amount of money with its currency type.
Corresponds to the JSON property currentSpend
4140 4141 4142 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4140 def current_spend @current_spend end |
#datasets ⇒ Array<String>
Required. Dataset resource names. Right now we only support labeling from a
single Dataset. Format: projects/project/locations/location/datasets/
dataset`
Corresponds to the JSON propertydatasets`
4147 4148 4149 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4147 def datasets @datasets end |
#display_name ⇒ String
Required. The user-defined name of the DataLabelingJob. The name can be up to
128 characters long and can consist of any UTF-8 characters. Display name of a
DataLabelingJob.
Corresponds to the JSON property displayName
4154 4155 4156 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4154 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top-
level resource.
Corresponds to the JSON property encryptionSpec
4160 4161 4162 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4160 def encryption_spec @encryption_spec end |
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
4170 4171 4172 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4170 def error @error end |
#inputs ⇒ Object
Required. Input config parameters for the DataLabelingJob.
Corresponds to the JSON property inputs
4175 4176 4177 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4175 def inputs @inputs end |
#inputs_schema_uri ⇒ String
Required. Points to a YAML file stored on Google Cloud Storage describing the
config for a specific type of DataLabelingJob. The schema files that can be
used here are found in the https://storage.googleapis.com/google-cloud-
aiplatform bucket in the /schema/datalabelingjob/inputs/ folder.
Corresponds to the JSON property inputsSchemaUri
4183 4184 4185 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4183 def inputs_schema_uri @inputs_schema_uri end |
#instruction_uri ⇒ String
Required. The Google Cloud Storage location of the instruction pdf. This pdf
is shared with labelers, and provides detailed description on how to label
DataItems in Datasets.
Corresponds to the JSON property instructionUri
4190 4191 4192 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4190 def instruction_uri @instruction_uri end |
#labeler_count ⇒ Fixnum
Required. Number of labelers to work on each DataItem.
Corresponds to the JSON property labelerCount
4195 4196 4197 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4195 def labeler_count @labeler_count end |
#labeling_progress ⇒ Fixnum
Output only. Current labeling job progress percentage scaled in interval [0,
100], indicating the percentage of DataItems that has been finished.
Corresponds to the JSON property labelingProgress
4201 4202 4203 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4201 def labeling_progress @labeling_progress end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your DataLabelingJobs. Label
keys and values can be no longer than 64 characters (Unicode codepoints), can
only contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. See https://goo.gl/xmQnxf for more
information and examples of labels. System reserved label keys are prefixed
with "aiplatform.googleapis.com/" and are immutable. Following system labels
exist for each DataLabelingJob: * "aiplatform.googleapis.com/schema": output
only, its value is the inputs_schema's title.
Corresponds to the JSON property labels
4213 4214 4215 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4213 def labels @labels end |
#name ⇒ String
Output only. Resource name of the DataLabelingJob.
Corresponds to the JSON property name
4218 4219 4220 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4218 def name @name end |
#specialist_pools ⇒ Array<String>
The SpecialistPools' resource names associated with this job.
Corresponds to the JSON property specialistPools
4223 4224 4225 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4223 def specialist_pools @specialist_pools end |
#state ⇒ String
Output only. The detailed state of the job.
Corresponds to the JSON property state
4228 4229 4230 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4228 def state @state end |
#update_time ⇒ String
Output only. Timestamp when this DataLabelingJob was updated most recently.
Corresponds to the JSON property updateTime
4233 4234 4235 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4233 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4240 4241 4242 4243 4244 4245 4246 4247 4248 4249 4250 4251 4252 4253 4254 4255 4256 4257 4258 4259 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4240 def update!(**args) @active_learning_config = args[:active_learning_config] if args.key?(:active_learning_config) @annotation_labels = args[:annotation_labels] if args.key?(:annotation_labels) @create_time = args[:create_time] if args.key?(:create_time) @current_spend = args[:current_spend] if args.key?(:current_spend) @datasets = args[:datasets] if args.key?(:datasets) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @error = args[:error] if args.key?(:error) @inputs = args[:inputs] if args.key?(:inputs) @inputs_schema_uri = args[:inputs_schema_uri] if args.key?(:inputs_schema_uri) @instruction_uri = args[:instruction_uri] if args.key?(:instruction_uri) @labeler_count = args[:labeler_count] if args.key?(:labeler_count) @labeling_progress = args[:labeling_progress] if args.key?(:labeling_progress) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @specialist_pools = args[:specialist_pools] if args.key?(:specialist_pools) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |