Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Dataset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A collection of DataItems and Annotations on them.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Dataset

Returns a new instance of GoogleCloudAiplatformV1Dataset.



5198
5199
5200
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5198

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this Dataset was created. Corresponds to the JSON property createTime

Returns:

  • (String)


5093
5094
5095
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5093

def create_time
  @create_time
end

#data_item_countFixnum

Output only. The number of DataItems in this Dataset. Only apply for non- structured Dataset. Corresponds to the JSON property dataItemCount

Returns:

  • (Fixnum)


5099
5100
5101
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5099

def data_item_count
  @data_item_count
end

#descriptionString

The description of the Dataset. Corresponds to the JSON property description

Returns:

  • (String)


5104
5105
5106
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5104

def description
  @description
end

#display_nameString

Required. The user-defined name of the Dataset. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


5110
5111
5112
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5110

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key spec that can be applied to a top- level resource. Corresponds to the JSON property encryptionSpec



5116
5117
5118
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5116

def encryption_spec
  @encryption_spec
end

#etagString

Used to perform consistent read-modify-write updates. If not set, a blind " overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


5122
5123
5124
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5122

def etag
  @etag
end

#labelsHash<String,String>

The labels with user-defined metadata to organize your Datasets. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. No more than 64 user labels can be associated with one Dataset (System labels are excluded). See https://goo.gl/ xmQnxf for more information and examples of labels. System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable. Following system labels exist for each Dataset: * "aiplatform.googleapis.com/ dataset_metadata_schema": output only, its value is the metadata_schema's title. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


5136
5137
5138
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5136

def labels
  @labels
end

#metadataObject

Required. Additional information about the Dataset. Corresponds to the JSON property metadata

Returns:

  • (Object)


5141
5142
5143
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5141

def 
  @metadata
end

#metadata_artifactString

Output only. The resource name of the Artifact that was created in MetadataStore when creating the Dataset. The Artifact resource name pattern is projects/project/locations/location/metadataStores/metadata_store/ artifacts/artifact`. Corresponds to the JSON propertymetadataArtifact`

Returns:

  • (String)


5149
5150
5151
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5149

def 
  @metadata_artifact
end

#metadata_schema_uriString

Required. Points to a YAML file stored on Google Cloud Storage describing additional information about the Dataset. The schema is defined as an OpenAPI 3.0.2 Schema Object. The schema files that can be used here are found in gs:// google-cloud-aiplatform/schema/dataset/metadata/. Corresponds to the JSON property metadataSchemaUri

Returns:

  • (String)


5157
5158
5159
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5157

def 
  @metadata_schema_uri
end

#model_referenceString

Optional. Reference to the public base model last used by the dataset. Only set for prompt datasets. Corresponds to the JSON property modelReference

Returns:

  • (String)


5163
5164
5165
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5163

def model_reference
  @model_reference
end

#nameString

Output only. Identifier. The resource name of the Dataset. Format: projects/ project/locations/location/datasets/dataset` Corresponds to the JSON propertyname`

Returns:

  • (String)


5169
5170
5171
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5169

def name
  @name
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


5174
5175
5176
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5174

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


5180
5181
5182
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5180

def satisfies_pzs
  @satisfies_pzs
end

#saved_queriesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SavedQuery>

All SavedQueries belong to the Dataset will be returned in List/Get Dataset response. The annotation_specs field will not be populated except for UI cases which will only use annotation_spec_count. In CreateDataset request, a SavedQuery is created together if this field is set, up to one SavedQuery can be set in CreateDatasetRequest. The SavedQuery should not contain any AnnotationSpec. Corresponds to the JSON property savedQueries



5191
5192
5193
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5191

def saved_queries
  @saved_queries
end

#update_timeString

Output only. Timestamp when this Dataset was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


5196
5197
5198
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5196

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5203
5204
5205
5206
5207
5208
5209
5210
5211
5212
5213
5214
5215
5216
5217
5218
5219
5220
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5203

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_item_count = args[:data_item_count] if args.key?(:data_item_count)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @metadata = args[:metadata] if args.key?(:metadata)
  @metadata_artifact = args[:metadata_artifact] if args.key?(:metadata_artifact)
  @metadata_schema_uri = args[:metadata_schema_uri] if args.key?(:metadata_schema_uri)
  @model_reference = args[:model_reference] if args.key?(:model_reference)
  @name = args[:name] if args.key?(:name)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @saved_queries = args[:saved_queries] if args.key?(:saved_queries)
  @update_time = args[:update_time] if args.key?(:update_time)
end