Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DedicatedResources

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A description of resources that are dedicated to a DeployedModel or DeployedIndex, and that need a higher degree of manual configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1DedicatedResources

Returns a new instance of GoogleCloudAiplatformV1DedicatedResources.



5780
5781
5782
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5780

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#autoscaling_metric_specsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AutoscalingMetricSpec>

Immutable. The metric specifications that overrides a resource utilization metric (CPU utilization, accelerator's duty cycle, and so on) target value ( default to 60 if not set). At most one entry is allowed per metric. If machine_spec.accelerator_count is above 0, the autoscaling will be based on both CPU utilization and accelerator's duty cycle metrics and scale up when either metrics exceeds its target value while scale down if both metrics are under their target value. The default target value is 60 for both metrics. If machine_spec.accelerator_count is 0, the autoscaling will be based on CPU utilization metric only with default target value 60 if not explicitly set. For example, in the case of Online Prediction, if you want to override target CPU utilization to 80, you should set autoscaling_metric_specs.metric_name to aiplatform.googleapis.com/prediction/online/cpu/utilization and autoscaling_metric_specs.target to 80. Corresponds to the JSON property autoscalingMetricSpecs



5735
5736
5737
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5735

def autoscaling_metric_specs
  @autoscaling_metric_specs
end

#machine_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1MachineSpec

Specification of a single machine. Corresponds to the JSON property machineSpec



5740
5741
5742
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5740

def machine_spec
  @machine_spec
end

#max_replica_countFixnum

Immutable. The maximum number of replicas that may be deployed on when the traffic against it increases. If the requested value is too large, the deployment will error, but if deployment succeeds then the ability to scale to that many replicas is guaranteed (barring service outages). If traffic increases beyond what its replicas at maximum may handle, a portion of the traffic will be dropped. If this value is not provided, will use min_replica_count as the default value. The value of this field impacts the charge against Vertex CPU and GPU quotas. Specifically, you will be charged for (max_replica_count * number of cores in the selected machine type) and ( max_replica_count * number of GPUs per replica in the selected machine type). Corresponds to the JSON property maxReplicaCount

Returns:

  • (Fixnum)


5754
5755
5756
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5754

def max_replica_count
  @max_replica_count
end

#min_replica_countFixnum

Required. Immutable. The minimum number of machine replicas that will be always deployed on. This value must be greater than or equal to 1. If traffic increases, it may dynamically be deployed onto more replicas, and as traffic decreases, some of these extra replicas may be freed. Corresponds to the JSON property minReplicaCount

Returns:

  • (Fixnum)


5762
5763
5764
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5762

def min_replica_count
  @min_replica_count
end

#required_replica_countFixnum

Optional. Number of required available replicas for the deployment to succeed. This field is only needed when partial deployment/mutation is desired. If set, the deploy/mutate operation will succeed once available_replica_count reaches required_replica_count, and the rest of the replicas will be retried. If not set, the default required_replica_count will be min_replica_count. Corresponds to the JSON property requiredReplicaCount

Returns:

  • (Fixnum)


5771
5772
5773
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5771

def required_replica_count
  @required_replica_count
end

#spotBoolean Also known as: spot?

Optional. If true, schedule the deployment workload on spot VMs. Corresponds to the JSON property spot

Returns:

  • (Boolean)


5777
5778
5779
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5777

def spot
  @spot
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5785
5786
5787
5788
5789
5790
5791
5792
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5785

def update!(**args)
  @autoscaling_metric_specs = args[:autoscaling_metric_specs] if args.key?(:autoscaling_metric_specs)
  @machine_spec = args[:machine_spec] if args.key?(:machine_spec)
  @max_replica_count = args[:max_replica_count] if args.key?(:max_replica_count)
  @min_replica_count = args[:min_replica_count] if args.key?(:min_replica_count)
  @required_replica_count = args[:required_replica_count] if args.key?(:required_replica_count)
  @spot = args[:spot] if args.key?(:spot)
end