Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DedicatedResources
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DedicatedResources
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A description of resources that are dedicated to a DeployedModel or DeployedIndex, and that need a higher degree of manual configuration.
Instance Attribute Summary collapse
-
#autoscaling_metric_specs ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AutoscalingMetricSpec>
Immutable.
-
#machine_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MachineSpec
Specification of a single machine.
-
#max_replica_count ⇒ Fixnum
Immutable.
-
#min_replica_count ⇒ Fixnum
Required.
-
#required_replica_count ⇒ Fixnum
Optional.
-
#spot ⇒ Boolean
(also: #spot?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1DedicatedResources
constructor
A new instance of GoogleCloudAiplatformV1DedicatedResources.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1DedicatedResources
Returns a new instance of GoogleCloudAiplatformV1DedicatedResources.
5411 5412 5413 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5411 def initialize(**args) update!(**args) end |
Instance Attribute Details
#autoscaling_metric_specs ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AutoscalingMetricSpec>
Immutable. The metric specifications that overrides a resource utilization
metric (CPU utilization, accelerator's duty cycle, and so on) target value (
default to 60 if not set). At most one entry is allowed per metric. If
machine_spec.accelerator_count is above 0, the autoscaling will be based on
both CPU utilization and accelerator's duty cycle metrics and scale up when
either metrics exceeds its target value while scale down if both metrics are
under their target value. The default target value is 60 for both metrics. If
machine_spec.accelerator_count is 0, the autoscaling will be based on CPU
utilization metric only with default target value 60 if not explicitly set.
For example, in the case of Online Prediction, if you want to override target
CPU utilization to 80, you should set autoscaling_metric_specs.metric_name to
aiplatform.googleapis.com/prediction/online/cpu/utilization and
autoscaling_metric_specs.target to 80.
Corresponds to the JSON property autoscalingMetricSpecs
5366 5367 5368 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5366 def autoscaling_metric_specs @autoscaling_metric_specs end |
#machine_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MachineSpec
Specification of a single machine.
Corresponds to the JSON property machineSpec
5371 5372 5373 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5371 def machine_spec @machine_spec end |
#max_replica_count ⇒ Fixnum
Immutable. The maximum number of replicas that may be deployed on when the
traffic against it increases. If the requested value is too large, the
deployment will error, but if deployment succeeds then the ability to scale to
that many replicas is guaranteed (barring service outages). If traffic
increases beyond what its replicas at maximum may handle, a portion of the
traffic will be dropped. If this value is not provided, will use
min_replica_count as the default value. The value of this field impacts the
charge against Vertex CPU and GPU quotas. Specifically, you will be charged
for (max_replica_count * number of cores in the selected machine type) and (
max_replica_count * number of GPUs per replica in the selected machine type).
Corresponds to the JSON property maxReplicaCount
5385 5386 5387 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5385 def max_replica_count @max_replica_count end |
#min_replica_count ⇒ Fixnum
Required. Immutable. The minimum number of machine replicas that will be
always deployed on. This value must be greater than or equal to 1. If traffic
increases, it may dynamically be deployed onto more replicas, and as traffic
decreases, some of these extra replicas may be freed.
Corresponds to the JSON property minReplicaCount
5393 5394 5395 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5393 def min_replica_count @min_replica_count end |
#required_replica_count ⇒ Fixnum
Optional. Number of required available replicas for the deployment to succeed.
This field is only needed when partial deployment/mutation is desired. If set,
the deploy/mutate operation will succeed once available_replica_count reaches
required_replica_count, and the rest of the replicas will be retried. If not
set, the default required_replica_count will be min_replica_count.
Corresponds to the JSON property requiredReplicaCount
5402 5403 5404 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5402 def required_replica_count @required_replica_count end |
#spot ⇒ Boolean Also known as: spot?
Optional. If true, schedule the deployment workload on spot VMs.
Corresponds to the JSON property spot
5408 5409 5410 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5408 def spot @spot end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5416 5417 5418 5419 5420 5421 5422 5423 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5416 def update!(**args) @autoscaling_metric_specs = args[:autoscaling_metric_specs] if args.key?(:autoscaling_metric_specs) @machine_spec = args[:machine_spec] if args.key?(:machine_spec) @max_replica_count = args[:max_replica_count] if args.key?(:max_replica_count) @min_replica_count = args[:min_replica_count] if args.key?(:min_replica_count) @required_replica_count = args[:required_replica_count] if args.key?(:required_replica_count) @spot = args[:spot] if args.key?(:spot) end |