Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeleteFeatureValuesRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeleteFeatureValuesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Request message for FeaturestoreService.DeleteFeatureValues.
Instance Attribute Summary collapse
-
#select_entity ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeleteFeatureValuesRequestSelectEntity
Message to select entity.
-
#select_time_range_and_feature ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeleteFeatureValuesRequestSelectTimeRangeAndFeature
Message to select time range and feature.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1DeleteFeatureValuesRequest
constructor
A new instance of GoogleCloudAiplatformV1DeleteFeatureValuesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1DeleteFeatureValuesRequest
Returns a new instance of GoogleCloudAiplatformV1DeleteFeatureValuesRequest.
7629 7630 7631 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7629 def initialize(**args) update!(**args) end |
Instance Attribute Details
#select_entity ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeleteFeatureValuesRequestSelectEntity
Message to select entity. If an entity id is selected, all the feature values
corresponding to the entity id will be deleted, including the entityId.
Corresponds to the JSON property selectEntity
7617 7618 7619 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7617 def select_entity @select_entity end |
#select_time_range_and_feature ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeleteFeatureValuesRequestSelectTimeRangeAndFeature
Message to select time range and feature. Values of the selected feature
generated within an inclusive time range will be deleted. Using this option
permanently deletes the feature values from the specified feature IDs within
the specified time range. This might include data from the online storage. If
you want to retain any deleted historical data in the online storage, you must
re-ingest it.
Corresponds to the JSON property selectTimeRangeAndFeature
7627 7628 7629 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7627 def select_time_range_and_feature @select_time_range_and_feature end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7634 7635 7636 7637 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7634 def update!(**args) @select_entity = args[:select_entity] if args.key?(:select_entity) @select_time_range_and_feature = args[:select_time_range_and_feature] if args.key?(:select_time_range_and_feature) end |