Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeleteFeatureValuesRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeleteFeatureValuesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Request message for FeaturestoreService.DeleteFeatureValues.
Instance Attribute Summary collapse
-
#select_entity ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeleteFeatureValuesRequestSelectEntity
Message to select entity.
-
#select_time_range_and_feature ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeleteFeatureValuesRequestSelectTimeRangeAndFeature
Message to select time range and feature.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1DeleteFeatureValuesRequest
constructor
A new instance of GoogleCloudAiplatformV1DeleteFeatureValuesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1DeleteFeatureValuesRequest
Returns a new instance of GoogleCloudAiplatformV1DeleteFeatureValuesRequest.
5835 5836 5837 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5835 def initialize(**args) update!(**args) end |
Instance Attribute Details
#select_entity ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeleteFeatureValuesRequestSelectEntity
Message to select entity. If an entity id is selected, all the feature values
corresponding to the entity id will be deleted, including the entityId.
Corresponds to the JSON property selectEntity
5823 5824 5825 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5823 def select_entity @select_entity end |
#select_time_range_and_feature ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeleteFeatureValuesRequestSelectTimeRangeAndFeature
Message to select time range and feature. Values of the selected feature
generated within an inclusive time range will be deleted. Using this option
permanently deletes the feature values from the specified feature IDs within
the specified time range. This might include data from the online storage. If
you want to retain any deleted historical data in the online storage, you must
re-ingest it.
Corresponds to the JSON property selectTimeRangeAndFeature
5833 5834 5835 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5833 def select_time_range_and_feature @select_time_range_and_feature end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5840 5841 5842 5843 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5840 def update!(**args) @select_entity = args[:select_entity] if args.key?(:select_entity) @select_time_range_and_feature = args[:select_time_range_and_feature] if args.key?(:select_time_range_and_feature) end |