Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeleteFeatureValuesRequestSelectEntity

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Message to select entity. If an entity id is selected, all the feature values corresponding to the entity id will be deleted, including the entityId.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1DeleteFeatureValuesRequestSelectEntity

Returns a new instance of GoogleCloudAiplatformV1DeleteFeatureValuesRequestSelectEntity.



5443
5444
5445
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5443

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#entity_id_selectorGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EntityIdSelector

Selector for entityId. Getting ids from the given source. Corresponds to the JSON property entityIdSelector



5441
5442
5443
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5441

def entity_id_selector
  @entity_id_selector
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5448
5449
5450
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5448

def update!(**args)
  @entity_id_selector = args[:entity_id_selector] if args.key?(:entity_id_selector)
end