Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeleteFeatureValuesRequestSelectTimeRangeAndFeature
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeleteFeatureValuesRequestSelectTimeRangeAndFeature
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Message to select time range and feature. Values of the selected feature generated within an inclusive time range will be deleted. Using this option permanently deletes the feature values from the specified feature IDs within the specified time range. This might include data from the online storage. If you want to retain any deleted historical data in the online storage, you must re-ingest it.
Instance Attribute Summary collapse
-
#feature_selector ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureSelector
Selector for Features of an EntityType.
-
#skip_online_storage_delete ⇒ Boolean
(also: #skip_online_storage_delete?)
If set, data will not be deleted from online storage.
-
#time_range ⇒ Google::Apis::AiplatformV1::GoogleTypeInterval
Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive).
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1DeleteFeatureValuesRequestSelectTimeRangeAndFeature
constructor
A new instance of GoogleCloudAiplatformV1DeleteFeatureValuesRequestSelectTimeRangeAndFeature.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1DeleteFeatureValuesRequestSelectTimeRangeAndFeature
Returns a new instance of GoogleCloudAiplatformV1DeleteFeatureValuesRequestSelectTimeRangeAndFeature.
5009 5010 5011 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5009 def initialize(**args) update!(**args) end |
Instance Attribute Details
#feature_selector ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureSelector
Selector for Features of an EntityType.
Corresponds to the JSON property featureSelector
4991 4992 4993 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4991 def feature_selector @feature_selector end |
#skip_online_storage_delete ⇒ Boolean Also known as: skip_online_storage_delete?
If set, data will not be deleted from online storage. When time range is older
than the data in online storage, setting this to be true will make the
deletion have no impact on online serving.
Corresponds to the JSON property skipOnlineStorageDelete
4998 4999 5000 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 4998 def skip_online_storage_delete @skip_online_storage_delete end |
#time_range ⇒ Google::Apis::AiplatformV1::GoogleTypeInterval
Represents a time interval, encoded as a Timestamp start (inclusive) and a
Timestamp end (exclusive). The start must be less than or equal to the end.
When the start equals the end, the interval is empty (matches no time). When
both start and end are unspecified, the interval matches any time.
Corresponds to the JSON property timeRange
5007 5008 5009 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5007 def time_range @time_range end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5014 5015 5016 5017 5018 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5014 def update!(**args) @feature_selector = args[:feature_selector] if args.key?(:feature_selector) @skip_online_storage_delete = args[:skip_online_storage_delete] if args.key?(:skip_online_storage_delete) @time_range = args[:time_range] if args.key?(:time_range) end |