Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeleteFeatureValuesResponseSelectEntity

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Response message if the request uses the SelectEntity option.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1DeleteFeatureValuesResponseSelectEntity

Returns a new instance of GoogleCloudAiplatformV1DeleteFeatureValuesResponseSelectEntity.



5272
5273
5274
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5272

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#offline_storage_deleted_entity_row_countFixnum

The count of deleted entity rows in the offline storage. Each row corresponds to the combination of an entity ID and a timestamp. One entity ID can have multiple rows in the offline storage. Corresponds to the JSON property offlineStorageDeletedEntityRowCount

Returns:

  • (Fixnum)


5264
5265
5266
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5264

def offline_storage_deleted_entity_row_count
  @offline_storage_deleted_entity_row_count
end

#online_storage_deleted_entity_countFixnum

The count of deleted entities in the online storage. Each entity ID corresponds to one entity. Corresponds to the JSON property onlineStorageDeletedEntityCount

Returns:

  • (Fixnum)


5270
5271
5272
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5270

def online_storage_deleted_entity_count
  @online_storage_deleted_entity_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5277
5278
5279
5280
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5277

def update!(**args)
  @offline_storage_deleted_entity_row_count = args[:offline_storage_deleted_entity_row_count] if args.key?(:offline_storage_deleted_entity_row_count)
  @online_storage_deleted_entity_count = args[:online_storage_deleted_entity_count] if args.key?(:online_storage_deleted_entity_count)
end