Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeleteFeatureValuesResponseSelectTimeRangeAndFeature
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeleteFeatureValuesResponseSelectTimeRangeAndFeature
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Response message if the request uses the SelectTimeRangeAndFeature option.
Instance Attribute Summary collapse
-
#impacted_feature_count ⇒ Fixnum
The count of the features or columns impacted.
-
#offline_storage_modified_entity_row_count ⇒ Fixnum
The count of modified entity rows in the offline storage.
-
#online_storage_modified_entity_count ⇒ Fixnum
The count of modified entities in the online storage.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1DeleteFeatureValuesResponseSelectTimeRangeAndFeature
constructor
A new instance of GoogleCloudAiplatformV1DeleteFeatureValuesResponseSelectTimeRangeAndFeature.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1DeleteFeatureValuesResponseSelectTimeRangeAndFeature
Returns a new instance of GoogleCloudAiplatformV1DeleteFeatureValuesResponseSelectTimeRangeAndFeature.
5726 5727 5728 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5726 def initialize(**args) update!(**args) end |
Instance Attribute Details
#impacted_feature_count ⇒ Fixnum
The count of the features or columns impacted. This is the same as the feature
count in the request.
Corresponds to the JSON property impactedFeatureCount
5709 5710 5711 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5709 def impacted_feature_count @impacted_feature_count end |
#offline_storage_modified_entity_row_count ⇒ Fixnum
The count of modified entity rows in the offline storage. Each row corresponds
to the combination of an entity ID and a timestamp. One entity ID can have
multiple rows in the offline storage. Within each row, only the features
specified in the request are deleted.
Corresponds to the JSON property offlineStorageModifiedEntityRowCount
5717 5718 5719 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5717 def offline_storage_modified_entity_row_count @offline_storage_modified_entity_row_count end |
#online_storage_modified_entity_count ⇒ Fixnum
The count of modified entities in the online storage. Each entity ID
corresponds to one entity. Within each entity, only the features specified in
the request are deleted.
Corresponds to the JSON property onlineStorageModifiedEntityCount
5724 5725 5726 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5724 def online_storage_modified_entity_count @online_storage_modified_entity_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5731 5732 5733 5734 5735 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5731 def update!(**args) @impacted_feature_count = args[:impacted_feature_count] if args.key?(:impacted_feature_count) @offline_storage_modified_entity_row_count = args[:offline_storage_modified_entity_row_count] if args.key?(:offline_storage_modified_entity_row_count) @online_storage_modified_entity_count = args[:online_storage_modified_entity_count] if args.key?(:online_storage_modified_entity_count) end |