Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeleteFeatureValuesResponseSelectTimeRangeAndFeature

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Response message if the request uses the SelectTimeRangeAndFeature option.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1DeleteFeatureValuesResponseSelectTimeRangeAndFeature

Returns a new instance of GoogleCloudAiplatformV1DeleteFeatureValuesResponseSelectTimeRangeAndFeature.



5693
5694
5695
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5693

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#impacted_feature_countFixnum

The count of the features or columns impacted. This is the same as the feature count in the request. Corresponds to the JSON property impactedFeatureCount

Returns:

  • (Fixnum)


5676
5677
5678
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5676

def impacted_feature_count
  @impacted_feature_count
end

#offline_storage_modified_entity_row_countFixnum

The count of modified entity rows in the offline storage. Each row corresponds to the combination of an entity ID and a timestamp. One entity ID can have multiple rows in the offline storage. Within each row, only the features specified in the request are deleted. Corresponds to the JSON property offlineStorageModifiedEntityRowCount

Returns:

  • (Fixnum)


5684
5685
5686
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5684

def offline_storage_modified_entity_row_count
  @offline_storage_modified_entity_row_count
end

#online_storage_modified_entity_countFixnum

The count of modified entities in the online storage. Each entity ID corresponds to one entity. Within each entity, only the features specified in the request are deleted. Corresponds to the JSON property onlineStorageModifiedEntityCount

Returns:

  • (Fixnum)


5691
5692
5693
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5691

def online_storage_modified_entity_count
  @online_storage_modified_entity_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5698
5699
5700
5701
5702
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5698

def update!(**args)
  @impacted_feature_count = args[:impacted_feature_count] if args.key?(:impacted_feature_count)
  @offline_storage_modified_entity_row_count = args[:offline_storage_modified_entity_row_count] if args.key?(:offline_storage_modified_entity_row_count)
  @online_storage_modified_entity_count = args[:online_storage_modified_entity_count] if args.key?(:online_storage_modified_entity_count)
end