Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployModelRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployModelRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Request message for EndpointService.DeployModel.
Instance Attribute Summary collapse
-
#deployed_model ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployedModel
A deployment of a Model.
-
#traffic_split ⇒ Hash<String,Fixnum>
A map from a DeployedModel's ID to the percentage of this Endpoint's traffic that should be forwarded to that DeployedModel.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1DeployModelRequest
constructor
A new instance of GoogleCloudAiplatformV1DeployModelRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1DeployModelRequest
Returns a new instance of GoogleCloudAiplatformV1DeployModelRequest.
7208 7209 7210 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7208 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deployed_model ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployedModel
A deployment of a Model. Endpoints contain one or more DeployedModels.
Corresponds to the JSON property deployedModel
7195 7196 7197 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7195 def deployed_model @deployed_model end |
#traffic_split ⇒ Hash<String,Fixnum>
A map from a DeployedModel's ID to the percentage of this Endpoint's traffic
that should be forwarded to that DeployedModel. If this field is non-empty,
then the Endpoint's traffic_split will be overwritten with it. To refer to the
ID of the just being deployed Model, a "0" should be used, and the actual ID
of the new DeployedModel will be filled in its place by this method. The
traffic percentage values must add up to 100. If this field is empty, then the
Endpoint's traffic_split is not updated.
Corresponds to the JSON property trafficSplit
7206 7207 7208 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7206 def traffic_split @traffic_split end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7213 7214 7215 7216 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7213 def update!(**args) @deployed_model = args[:deployed_model] if args.key?(:deployed_model) @traffic_split = args[:traffic_split] if args.key?(:traffic_split) end |