Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployModelRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for EndpointService.DeployModel.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1DeployModelRequest

Returns a new instance of GoogleCloudAiplatformV1DeployModelRequest.



5460
5461
5462
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5460

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deployed_modelGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployedModel

A deployment of a Model. Endpoints contain one or more DeployedModels. Corresponds to the JSON property deployedModel



5447
5448
5449
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5447

def deployed_model
  @deployed_model
end

#traffic_splitHash<String,Fixnum>

A map from a DeployedModel's ID to the percentage of this Endpoint's traffic that should be forwarded to that DeployedModel. If this field is non-empty, then the Endpoint's traffic_split will be overwritten with it. To refer to the ID of the just being deployed Model, a "0" should be used, and the actual ID of the new DeployedModel will be filled in its place by this method. The traffic percentage values must add up to 100. If this field is empty, then the Endpoint's traffic_split is not updated. Corresponds to the JSON property trafficSplit

Returns:

  • (Hash<String,Fixnum>)


5458
5459
5460
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5458

def traffic_split
  @traffic_split
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5465
5466
5467
5468
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5465

def update!(**args)
  @deployed_model = args[:deployed_model] if args.key?(:deployed_model)
  @traffic_split = args[:traffic_split] if args.key?(:traffic_split)
end