Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployOperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Runtime operation information for ModelGardenService.Deploy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1DeployOperationMetadata

Returns a new instance of GoogleCloudAiplatformV1DeployOperationMetadata.



7268
7269
7270
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7268

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destinationString

Output only. The resource name of the Location to deploy the model in. Format: projects/project/locations/location` Corresponds to the JSON propertydestination`

Returns:

  • (String)


7246
7247
7248
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7246

def destination
  @destination
end

#generic_metadataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GenericOperationMetadata

Generic Metadata shared by all operations. Corresponds to the JSON property genericMetadata



7251
7252
7253
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7251

def 
  @generic_metadata
end

#model_idString

Output only. The model id to be used at query time. Corresponds to the JSON property modelId

Returns:

  • (String)


7256
7257
7258
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7256

def model_id
  @model_id
end

#project_numberFixnum

Output only. The project number where the deploy model request is sent. Corresponds to the JSON property projectNumber

Returns:

  • (Fixnum)


7261
7262
7263
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7261

def project_number
  @project_number
end

#publisher_modelString

Output only. The name of the model resource. Corresponds to the JSON property publisherModel

Returns:

  • (String)


7266
7267
7268
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7266

def publisher_model
  @publisher_model
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7273
7274
7275
7276
7277
7278
7279
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7273

def update!(**args)
  @destination = args[:destination] if args.key?(:destination)
  @generic_metadata = args[:generic_metadata] if args.key?(:generic_metadata)
  @model_id = args[:model_id] if args.key?(:model_id)
  @project_number = args[:project_number] if args.key?(:project_number)
  @publisher_model = args[:publisher_model] if args.key?(:publisher_model)
end