Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployOperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Runtime operation information for ModelGardenService.Deploy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1DeployOperationMetadata

Returns a new instance of GoogleCloudAiplatformV1DeployOperationMetadata.



7108
7109
7110
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7108

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destinationString

Output only. The resource name of the Location to deploy the model in. Format: projects/project/locations/location` Corresponds to the JSON propertydestination`

Returns:

  • (String)


7086
7087
7088
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7086

def destination
  @destination
end

#generic_metadataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GenericOperationMetadata

Generic Metadata shared by all operations. Corresponds to the JSON property genericMetadata



7091
7092
7093
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7091

def 
  @generic_metadata
end

#model_idString

Output only. The model id to be used at query time. Corresponds to the JSON property modelId

Returns:

  • (String)


7096
7097
7098
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7096

def model_id
  @model_id
end

#project_numberFixnum

Output only. The project number where the deploy model request is sent. Corresponds to the JSON property projectNumber

Returns:

  • (Fixnum)


7101
7102
7103
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7101

def project_number
  @project_number
end

#publisher_modelString

Output only. The name of the model resource. Corresponds to the JSON property publisherModel

Returns:

  • (String)


7106
7107
7108
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7106

def publisher_model
  @publisher_model
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7113
7114
7115
7116
7117
7118
7119
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7113

def update!(**args)
  @destination = args[:destination] if args.key?(:destination)
  @generic_metadata = args[:generic_metadata] if args.key?(:generic_metadata)
  @model_id = args[:model_id] if args.key?(:model_id)
  @project_number = args[:project_number] if args.key?(:project_number)
  @publisher_model = args[:publisher_model] if args.key?(:publisher_model)
end