Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployOperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Runtime operation information for ModelGardenService.Deploy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1DeployOperationMetadata

Returns a new instance of GoogleCloudAiplatformV1DeployOperationMetadata.



6724
6725
6726
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6724

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destinationString

Output only. The resource name of the Location to deploy the model in. Format: projects/project/locations/location` Corresponds to the JSON propertydestination`

Returns:

  • (String)


6702
6703
6704
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6702

def destination
  @destination
end

#generic_metadataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GenericOperationMetadata

Generic Metadata shared by all operations. Corresponds to the JSON property genericMetadata



6707
6708
6709
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6707

def 
  @generic_metadata
end

#model_idString

Output only. The model id to be used at query time. Corresponds to the JSON property modelId

Returns:

  • (String)


6712
6713
6714
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6712

def model_id
  @model_id
end

#project_numberFixnum

Output only. The project number where the deploy model request is sent. Corresponds to the JSON property projectNumber

Returns:

  • (Fixnum)


6717
6718
6719
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6717

def project_number
  @project_number
end

#publisher_modelString

Output only. The name of the model resource. Corresponds to the JSON property publisherModel

Returns:

  • (String)


6722
6723
6724
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6722

def publisher_model
  @publisher_model
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6729
6730
6731
6732
6733
6734
6735
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6729

def update!(**args)
  @destination = args[:destination] if args.key?(:destination)
  @generic_metadata = args[:generic_metadata] if args.key?(:generic_metadata)
  @model_id = args[:model_id] if args.key?(:model_id)
  @project_number = args[:project_number] if args.key?(:project_number)
  @publisher_model = args[:publisher_model] if args.key?(:publisher_model)
end