Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployOperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployOperationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Runtime operation information for ModelGardenService.Deploy.
Instance Attribute Summary collapse
-
#destination ⇒ String
Output only.
-
#generic_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenericOperationMetadata
Generic Metadata shared by all operations.
-
#model_id ⇒ String
Output only.
-
#project_number ⇒ Fixnum
Output only.
-
#publisher_model ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1DeployOperationMetadata
constructor
A new instance of GoogleCloudAiplatformV1DeployOperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1DeployOperationMetadata
Returns a new instance of GoogleCloudAiplatformV1DeployOperationMetadata.
6699 6700 6701 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6699 def initialize(**args) update!(**args) end |
Instance Attribute Details
#destination ⇒ String
Output only. The resource name of the Location to deploy the model in. Format:
projects/project/locations/location`
Corresponds to the JSON propertydestination`
6677 6678 6679 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6677 def destination @destination end |
#generic_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenericOperationMetadata
Generic Metadata shared by all operations.
Corresponds to the JSON property genericMetadata
6682 6683 6684 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6682 def @generic_metadata end |
#model_id ⇒ String
Output only. The model id to be used at query time.
Corresponds to the JSON property modelId
6687 6688 6689 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6687 def model_id @model_id end |
#project_number ⇒ Fixnum
Output only. The project number where the deploy model request is sent.
Corresponds to the JSON property projectNumber
6692 6693 6694 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6692 def project_number @project_number end |
#publisher_model ⇒ String
Output only. The name of the model resource.
Corresponds to the JSON property publisherModel
6697 6698 6699 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6697 def publisher_model @publisher_model end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6704 6705 6706 6707 6708 6709 6710 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6704 def update!(**args) @destination = args[:destination] if args.key?(:destination) @generic_metadata = args[:generic_metadata] if args.key?(:generic_metadata) @model_id = args[:model_id] if args.key?(:model_id) @project_number = args[:project_number] if args.key?(:project_number) @publisher_model = args[:publisher_model] if args.key?(:publisher_model) end |