Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployOperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Runtime operation information for ModelGardenService.Deploy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1DeployOperationMetadata

Returns a new instance of GoogleCloudAiplatformV1DeployOperationMetadata.



6211
6212
6213
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6211

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destinationString

Output only. The resource name of the Location to deploy the model in. Format: projects/project/locations/location` Corresponds to the JSON propertydestination`

Returns:

  • (String)


6189
6190
6191
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6189

def destination
  @destination
end

#generic_metadataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GenericOperationMetadata

Generic Metadata shared by all operations. Corresponds to the JSON property genericMetadata



6194
6195
6196
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6194

def 
  @generic_metadata
end

#model_idString

Output only. The model id to be used at query time. Corresponds to the JSON property modelId

Returns:

  • (String)


6199
6200
6201
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6199

def model_id
  @model_id
end

#project_numberFixnum

Output only. The project number where the deploy model request is sent. Corresponds to the JSON property projectNumber

Returns:

  • (Fixnum)


6204
6205
6206
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6204

def project_number
  @project_number
end

#publisher_modelString

Output only. The name of the model resource. Corresponds to the JSON property publisherModel

Returns:

  • (String)


6209
6210
6211
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6209

def publisher_model
  @publisher_model
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6216
6217
6218
6219
6220
6221
6222
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6216

def update!(**args)
  @destination = args[:destination] if args.key?(:destination)
  @generic_metadata = args[:generic_metadata] if args.key?(:generic_metadata)
  @model_id = args[:model_id] if args.key?(:model_id)
  @project_number = args[:project_number] if args.key?(:project_number)
  @publisher_model = args[:publisher_model] if args.key?(:publisher_model)
end