Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployRequestDeployConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployRequestDeployConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The deploy config to use for the deployment.
Instance Attribute Summary collapse
-
#dedicated_resources ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DedicatedResources
A description of resources that are dedicated to a DeployedModel or DeployedIndex, and that need a higher degree of manual configuration.
-
#fast_tryout_enabled ⇒ Boolean
(also: #fast_tryout_enabled?)
Optional.
-
#system_labels ⇒ Hash<String,String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1DeployRequestDeployConfig
constructor
A new instance of GoogleCloudAiplatformV1DeployRequestDeployConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1DeployRequestDeployConfig
Returns a new instance of GoogleCloudAiplatformV1DeployRequestDeployConfig.
6295 6296 6297 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6295 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dedicated_resources ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DedicatedResources
A description of resources that are dedicated to a DeployedModel or
DeployedIndex, and that need a higher degree of manual configuration.
Corresponds to the JSON property dedicatedResources
6280 6281 6282 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6280 def dedicated_resources @dedicated_resources end |
#fast_tryout_enabled ⇒ Boolean Also known as: fast_tryout_enabled?
Optional. If true, enable the QMT fast tryout feature for this model if
possible.
Corresponds to the JSON property fastTryoutEnabled
6286 6287 6288 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6286 def fast_tryout_enabled @fast_tryout_enabled end |
#system_labels ⇒ Hash<String,String>
Optional. System labels for Model Garden deployments. These labels are managed
by Google and for tracking purposes only.
Corresponds to the JSON property systemLabels
6293 6294 6295 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6293 def system_labels @system_labels end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6300 6301 6302 6303 6304 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6300 def update!(**args) @dedicated_resources = args[:dedicated_resources] if args.key?(:dedicated_resources) @fast_tryout_enabled = args[:fast_tryout_enabled] if args.key?(:fast_tryout_enabled) @system_labels = args[:system_labels] if args.key?(:system_labels) end |