Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployRequestDeployConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The deploy config to use for the deployment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1DeployRequestDeployConfig

Returns a new instance of GoogleCloudAiplatformV1DeployRequestDeployConfig.



6281
6282
6283
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6281

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dedicated_resourcesGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1DedicatedResources

A description of resources that are dedicated to a DeployedModel or DeployedIndex, and that need a higher degree of manual configuration. Corresponds to the JSON property dedicatedResources



6266
6267
6268
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6266

def dedicated_resources
  @dedicated_resources
end

#fast_tryout_enabledBoolean Also known as: fast_tryout_enabled?

Optional. If true, enable the QMT fast tryout feature for this model if possible. Corresponds to the JSON property fastTryoutEnabled

Returns:

  • (Boolean)


6272
6273
6274
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6272

def fast_tryout_enabled
  @fast_tryout_enabled
end

#system_labelsHash<String,String>

Optional. System labels for Model Garden deployments. These labels are managed by Google and for tracking purposes only. Corresponds to the JSON property systemLabels

Returns:

  • (Hash<String,String>)


6279
6280
6281
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6279

def system_labels
  @system_labels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6286
6287
6288
6289
6290
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6286

def update!(**args)
  @dedicated_resources = args[:dedicated_resources] if args.key?(:dedicated_resources)
  @fast_tryout_enabled = args[:fast_tryout_enabled] if args.key?(:fast_tryout_enabled)
  @system_labels = args[:system_labels] if args.key?(:system_labels)
end