Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployRequestEndpointConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The endpoint config to use for the deployment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1DeployRequestEndpointConfig

Returns a new instance of GoogleCloudAiplatformV1DeployRequestEndpointConfig.



7427
7428
7429
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7427

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dedicated_endpoint_disabledBoolean Also known as: dedicated_endpoint_disabled?

Optional. By default, if dedicated endpoint is enabled and private service connect config is not set, the endpoint will be exposed through a dedicated DNS [Endpoint.dedicated_endpoint_dns]. If private service connect config is set, the endpoint will be exposed through private service connect. Your request to the dedicated DNS will be isolated from other users' traffic and will have better performance and reliability. Note: Once you enabled dedicated endpoint, you won't be able to send request to the shared DNS region- aiplatform.googleapis.com. The limitations will be removed soon. If this field is set to true, the dedicated endpoint will be disabled and the deployed model will be exposed through the shared DNS region-aiplatform.googleapis.com. Corresponds to the JSON property dedicatedEndpointDisabled

Returns:

  • (Boolean)


7379
7380
7381
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7379

def dedicated_endpoint_disabled
  @dedicated_endpoint_disabled
end

#dedicated_endpoint_enabledBoolean Also known as: dedicated_endpoint_enabled?

Optional. Deprecated. Use dedicated_endpoint_disabled instead. If true, the endpoint will be exposed through a dedicated DNS [Endpoint. dedicated_endpoint_dns]. Your request to the dedicated DNS will be isolated from other users' traffic and will have better performance and reliability. Note: Once you enabled dedicated endpoint, you won't be able to send request to the shared DNS region-aiplatform.googleapis.com. The limitations will be removed soon. Corresponds to the JSON property dedicatedEndpointEnabled

Returns:

  • (Boolean)


7391
7392
7393
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7391

def dedicated_endpoint_enabled
  @dedicated_endpoint_enabled
end

#endpoint_display_nameString

Optional. The user-specified display name of the endpoint. If not set, a default name will be used. Corresponds to the JSON property endpointDisplayName

Returns:

  • (String)


7398
7399
7400
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7398

def endpoint_display_name
  @endpoint_display_name
end

#endpoint_user_idString

Optional. Immutable. The ID to use for endpoint, which will become the final component of the endpoint resource name. If not provided, Vertex AI will generate a value for this ID. If the first character is a letter, this value may be up to 63 characters, and valid characters are [a-z0-9-]. The last character must be a letter or number. If the first character is a number, this value may be up to 9 characters, and valid characters are [0-9] with no leading zeros. When using HTTP/JSON, this field is populated based on a query string argument, such as ?endpoint_id=12345. This is the fallback for fields that are not included in either the URI or the body. Corresponds to the JSON property endpointUserId

Returns:

  • (String)


7411
7412
7413
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7411

def endpoint_user_id
  @endpoint_user_id
end

#labelsHash<String,String>

Optional. The labels with user-defined metadata to organize your Endpoints. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


7420
7421
7422
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7420

def labels
  @labels
end

#private_service_connect_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PrivateServiceConnectConfig

Represents configuration for private service connect. Corresponds to the JSON property privateServiceConnectConfig



7425
7426
7427
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7425

def private_service_connect_config
  @private_service_connect_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7432
7433
7434
7435
7436
7437
7438
7439
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7432

def update!(**args)
  @dedicated_endpoint_disabled = args[:dedicated_endpoint_disabled] if args.key?(:dedicated_endpoint_disabled)
  @dedicated_endpoint_enabled = args[:dedicated_endpoint_enabled] if args.key?(:dedicated_endpoint_enabled)
  @endpoint_display_name = args[:endpoint_display_name] if args.key?(:endpoint_display_name)
  @endpoint_user_id = args[:endpoint_user_id] if args.key?(:endpoint_user_id)
  @labels = args[:labels] if args.key?(:labels)
  @private_service_connect_config = args[:private_service_connect_config] if args.key?(:private_service_connect_config)
end