Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployRequestEndpointConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The endpoint config to use for the deployment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1DeployRequestEndpointConfig

Returns a new instance of GoogleCloudAiplatformV1DeployRequestEndpointConfig.



6328
6329
6330
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6328

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dedicated_endpoint_enabledBoolean Also known as: dedicated_endpoint_enabled?

Optional. If true, the endpoint will be exposed through a dedicated DNS [ Endpoint.dedicated_endpoint_dns]. Your request to the dedicated DNS will be isolated from other users' traffic and will have better performance and reliability. Note: Once you enabled dedicated endpoint, you won't be able to send request to the shared DNS region-aiplatform.googleapis.com. The limitations will be removed soon. Corresponds to the JSON property dedicatedEndpointEnabled

Returns:

  • (Boolean)


6319
6320
6321
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6319

def dedicated_endpoint_enabled
  @dedicated_endpoint_enabled
end

#endpoint_display_nameString

Optional. The user-specified display name of the endpoint. If not set, a default name will be used. Corresponds to the JSON property endpointDisplayName

Returns:

  • (String)


6326
6327
6328
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6326

def endpoint_display_name
  @endpoint_display_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6333
6334
6335
6336
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6333

def update!(**args)
  @dedicated_endpoint_enabled = args[:dedicated_endpoint_enabled] if args.key?(:dedicated_endpoint_enabled)
  @endpoint_display_name = args[:endpoint_display_name] if args.key?(:endpoint_display_name)
end