Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployRequestModelConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The model config to use for the deployment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1DeployRequestModelConfig

Returns a new instance of GoogleCloudAiplatformV1DeployRequestModelConfig.



7283
7284
7285
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7283

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accept_eulaBoolean Also known as: accept_eula?

Optional. Whether the user accepts the End User License Agreement (EULA) for the model. Corresponds to the JSON property acceptEula

Returns:

  • (Boolean)


7243
7244
7245
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7243

def accept_eula
  @accept_eula
end

#container_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelContainerSpec

Specification of a container for serving predictions. Some fields in this message correspond to fields in the Kubernetes Container v1 core specification. Corresponds to the JSON property containerSpec



7252
7253
7254
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7252

def container_spec
  @container_spec
end

#hugging_face_access_tokenString

Optional. The Hugging Face read access token used to access the model artifacts of gated models. Corresponds to the JSON property huggingFaceAccessToken

Returns:

  • (String)


7258
7259
7260
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7258

def hugging_face_access_token
  @hugging_face_access_token
end

#hugging_face_cache_enabledBoolean Also known as: hugging_face_cache_enabled?

Optional. If true, the model will deploy with a cached version instead of directly downloading the model artifacts from Hugging Face. This is suitable for VPC-SC users with limited internet access. Corresponds to the JSON property huggingFaceCacheEnabled

Returns:

  • (Boolean)


7265
7266
7267
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7265

def hugging_face_cache_enabled
  @hugging_face_cache_enabled
end

#model_display_nameString

Optional. The user-specified display name of the uploaded model. If not set, a default name will be used. Corresponds to the JSON property modelDisplayName

Returns:

  • (String)


7272
7273
7274
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7272

def model_display_name
  @model_display_name
end

#model_user_idString

Optional. The ID to use for the uploaded Model, which will become the final component of the model resource name. When not provided, Vertex AI will generate a value for this ID. When Model Registry model is provided, this field will be ignored. This value may be up to 63 characters, and valid characters are [a-z0-9_-]. The first character cannot be a number or hyphen. Corresponds to the JSON property modelUserId

Returns:

  • (String)


7281
7282
7283
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7281

def model_user_id
  @model_user_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7288
7289
7290
7291
7292
7293
7294
7295
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7288

def update!(**args)
  @accept_eula = args[:accept_eula] if args.key?(:accept_eula)
  @container_spec = args[:container_spec] if args.key?(:container_spec)
  @hugging_face_access_token = args[:hugging_face_access_token] if args.key?(:hugging_face_access_token)
  @hugging_face_cache_enabled = args[:hugging_face_cache_enabled] if args.key?(:hugging_face_cache_enabled)
  @model_display_name = args[:model_display_name] if args.key?(:model_display_name)
  @model_user_id = args[:model_user_id] if args.key?(:model_user_id)
end