Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployRequestModelConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployRequestModelConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The model config to use for the deployment.
Instance Attribute Summary collapse
-
#accept_eula ⇒ Boolean
(also: #accept_eula?)
Optional.
-
#container_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelContainerSpec
Specification of a container for serving predictions.
-
#hugging_face_access_token ⇒ String
Optional.
-
#hugging_face_cache_enabled ⇒ Boolean
(also: #hugging_face_cache_enabled?)
Optional.
-
#model_display_name ⇒ String
Optional.
-
#model_user_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1DeployRequestModelConfig
constructor
A new instance of GoogleCloudAiplatformV1DeployRequestModelConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1DeployRequestModelConfig
Returns a new instance of GoogleCloudAiplatformV1DeployRequestModelConfig.
6387 6388 6389 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6387 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accept_eula ⇒ Boolean Also known as: accept_eula?
Optional. Whether the user accepts the End User License Agreement (EULA) for
the model.
Corresponds to the JSON property acceptEula
6347 6348 6349 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6347 def accept_eula @accept_eula end |
#container_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelContainerSpec
Specification of a container for serving predictions. Some fields in this
message correspond to fields in the Kubernetes Container v1 core
specification.
Corresponds to the JSON property containerSpec
6356 6357 6358 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6356 def container_spec @container_spec end |
#hugging_face_access_token ⇒ String
Optional. The Hugging Face read access token used to access the model
artifacts of gated models.
Corresponds to the JSON property huggingFaceAccessToken
6362 6363 6364 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6362 def hugging_face_access_token @hugging_face_access_token end |
#hugging_face_cache_enabled ⇒ Boolean Also known as: hugging_face_cache_enabled?
Optional. If true, the model will deploy with a cached version instead of
directly downloading the model artifacts from Hugging Face. This is suitable
for VPC-SC users with limited internet access.
Corresponds to the JSON property huggingFaceCacheEnabled
6369 6370 6371 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6369 def hugging_face_cache_enabled @hugging_face_cache_enabled end |
#model_display_name ⇒ String
Optional. The user-specified display name of the uploaded model. If not set, a
default name will be used.
Corresponds to the JSON property modelDisplayName
6376 6377 6378 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6376 def model_display_name @model_display_name end |
#model_user_id ⇒ String
Optional. The ID to use for the uploaded Model, which will become the final
component of the model resource name. When not provided, Vertex AI will
generate a value for this ID. When Model Registry model is provided, this
field will be ignored. This value may be up to 63 characters, and valid
characters are [a-z0-9_-]. The first character cannot be a number or hyphen.
Corresponds to the JSON property modelUserId
6385 6386 6387 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6385 def model_user_id @model_user_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6392 6393 6394 6395 6396 6397 6398 6399 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6392 def update!(**args) @accept_eula = args[:accept_eula] if args.key?(:accept_eula) @container_spec = args[:container_spec] if args.key?(:container_spec) @hugging_face_access_token = args[:hugging_face_access_token] if args.key?(:hugging_face_access_token) @hugging_face_cache_enabled = args[:hugging_face_cache_enabled] if args.key?(:hugging_face_cache_enabled) @model_display_name = args[:model_display_name] if args.key?(:model_display_name) @model_user_id = args[:model_user_id] if args.key?(:model_user_id) end |