Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployRequestModelConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The model config to use for the deployment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1DeployRequestModelConfig

Returns a new instance of GoogleCloudAiplatformV1DeployRequestModelConfig.



6364
6365
6366
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6364

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accept_eulaBoolean Also known as: accept_eula?

Optional. Whether the user accepts the End User License Agreement (EULA) for the model. Corresponds to the JSON property acceptEula

Returns:

  • (Boolean)


6333
6334
6335
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6333

def accept_eula
  @accept_eula
end

#container_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelContainerSpec

Specification of a container for serving predictions. Some fields in this message correspond to fields in the Kubernetes Container v1 core specification. Corresponds to the JSON property containerSpec



6342
6343
6344
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6342

def container_spec
  @container_spec
end

#hugging_face_access_tokenString

Optional. The Hugging Face read access token used to access the model artifacts of gated models. Corresponds to the JSON property huggingFaceAccessToken

Returns:

  • (String)


6348
6349
6350
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6348

def hugging_face_access_token
  @hugging_face_access_token
end

#hugging_face_cache_enabledBoolean Also known as: hugging_face_cache_enabled?

Optional. If true, the model will deploy with a cached version instead of directly downloading the model artifacts from Hugging Face. This is suitable for VPC-SC users with limited internet access. Corresponds to the JSON property huggingFaceCacheEnabled

Returns:

  • (Boolean)


6355
6356
6357
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6355

def hugging_face_cache_enabled
  @hugging_face_cache_enabled
end

#model_display_nameString

Optional. The user-specified display name of the uploaded model. If not set, a default name will be used. Corresponds to the JSON property modelDisplayName

Returns:

  • (String)


6362
6363
6364
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6362

def model_display_name
  @model_display_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6369
6370
6371
6372
6373
6374
6375
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6369

def update!(**args)
  @accept_eula = args[:accept_eula] if args.key?(:accept_eula)
  @container_spec = args[:container_spec] if args.key?(:container_spec)
  @hugging_face_access_token = args[:hugging_face_access_token] if args.key?(:hugging_face_access_token)
  @hugging_face_cache_enabled = args[:hugging_face_cache_enabled] if args.key?(:hugging_face_cache_enabled)
  @model_display_name = args[:model_display_name] if args.key?(:model_display_name)
end