Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployedIndex

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A deployment of an Index. IndexEndpoints contain one or more DeployedIndexes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1DeployedIndex

Returns a new instance of GoogleCloudAiplatformV1DeployedIndex.



6523
6524
6525
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6523

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#automatic_resourcesGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1AutomaticResources

A description of resources that to large degree are decided by Vertex AI, and require only a modest additional configuration. Each Model supporting these resources documents its specific guidelines. Corresponds to the JSON property automaticResources



6422
6423
6424
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6422

def automatic_resources
  @automatic_resources
end

#create_timeString

Output only. Timestamp when the DeployedIndex was created. Corresponds to the JSON property createTime

Returns:

  • (String)


6427
6428
6429
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6427

def create_time
  @create_time
end

#dedicated_resourcesGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1DedicatedResources

A description of resources that are dedicated to a DeployedModel or DeployedIndex, and that need a higher degree of manual configuration. Corresponds to the JSON property dedicatedResources



6433
6434
6435
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6433

def dedicated_resources
  @dedicated_resources
end

#deployed_index_auth_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployedIndexAuthConfig

Used to set up the auth on the DeployedIndex's private endpoint. Corresponds to the JSON property deployedIndexAuthConfig



6438
6439
6440
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6438

def deployed_index_auth_config
  @deployed_index_auth_config
end

#deployment_groupString

Optional. The deployment group can be no longer than 64 characters (eg: 'test', 'prod'). If not set, we will use the 'default' deployment group. Creating deployment_groups with reserved_ip_ranges is a recommended practice when the peered network has multiple peering ranges. This creates your deployments from predictable IP spaces for easier traffic administration. Also, one deployment_group (except 'default') can only be used with the same reserved_ip_ranges which means if the deployment_group has been used with reserved_ip_ranges: [a, b, c], using it with [a, b] or [d, e] is disallowed. Note: we only support up to 5 deployment groups(not including 'default'). Corresponds to the JSON property deploymentGroup

Returns:

  • (String)


6451
6452
6453
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6451

def deployment_group
  @deployment_group
end

#display_nameString

The display name of the DeployedIndex. If not provided upon creation, the Index's display_name is used. Corresponds to the JSON property displayName

Returns:

  • (String)


6457
6458
6459
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6457

def display_name
  @display_name
end

#enable_access_loggingBoolean Also known as: enable_access_logging?

Optional. If true, private endpoint's access logs are sent to Cloud Logging. These logs are like standard server access logs, containing information like timestamp and latency for each MatchRequest. Note that logs may incur a cost, especially if the deployed index receives a high queries per second rate (QPS). Estimate your costs before enabling this option. Corresponds to the JSON property enableAccessLogging

Returns:

  • (Boolean)


6466
6467
6468
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6466

def enable_access_logging
  @enable_access_logging
end

#idString

Required. The user specified ID of the DeployedIndex. The ID can be up to 128 characters long and must start with a letter and only contain letters, numbers, and underscores. The ID must be unique within the project it is created in. Corresponds to the JSON property id

Returns:

  • (String)


6474
6475
6476
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6474

def id
  @id
end

#indexString

Required. The name of the Index this is the deployment of. We may refer to this Index as the DeployedIndex's "original" Index. Corresponds to the JSON property index

Returns:

  • (String)


6480
6481
6482
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6480

def index
  @index
end

#index_sync_timeString

Output only. The DeployedIndex may depend on various data on its original Index. Additionally when certain changes to the original Index are being done ( e.g. when what the Index contains is being changed) the DeployedIndex may be asynchronously updated in the background to reflect these changes. If this timestamp's value is at least the Index.update_time of the original Index, it means that this DeployedIndex and the original Index are in sync. If this timestamp is older, then to see which updates this DeployedIndex already contains (and which it does not), one must list the operations that are running on the original Index. Only the successfully completed Operations with update_time equal or before this sync time are contained in this DeployedIndex. Corresponds to the JSON property indexSyncTime

Returns:

  • (String)


6494
6495
6496
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6494

def index_sync_time
  @index_sync_time
end

#private_endpointsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexPrivateEndpoints

IndexPrivateEndpoints proto is used to provide paths for users to send requests via private endpoints (e.g. private service access, private service connect). To send request via private service access, use match_grpc_address. To send request via private service connect, use service_attachment. Corresponds to the JSON property privateEndpoints



6502
6503
6504
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6502

def private_endpoints
  @private_endpoints
end

#psc_automation_configsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PscAutomationConfig>

Optional. If set for PSC deployed index, PSC connection will be automatically created after deployment is done and the endpoint information is populated in private_endpoints.psc_automated_endpoints. Corresponds to the JSON property pscAutomationConfigs



6509
6510
6511
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6509

def psc_automation_configs
  @psc_automation_configs
end

#reserved_ip_rangesArray<String>

Optional. A list of reserved ip ranges under the VPC network that can be used for this DeployedIndex. If set, we will deploy the index within the provided ip ranges. Otherwise, the index might be deployed to any ip ranges under the provided VPC network. The value should be the name of the address (https:// cloud.google.com/compute/docs/reference/rest/v1/addresses) Example: ['vertex- ai-ip-range']. For more information about subnets and network IP ranges, please see https://cloud.google.com/vpc/docs/subnets# manually_created_subnet_ip_ranges. Corresponds to the JSON property reservedIpRanges

Returns:

  • (Array<String>)


6521
6522
6523
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6521

def reserved_ip_ranges
  @reserved_ip_ranges
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6528
6529
6530
6531
6532
6533
6534
6535
6536
6537
6538
6539
6540
6541
6542
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6528

def update!(**args)
  @automatic_resources = args[:automatic_resources] if args.key?(:automatic_resources)
  @create_time = args[:create_time] if args.key?(:create_time)
  @dedicated_resources = args[:dedicated_resources] if args.key?(:dedicated_resources)
  @deployed_index_auth_config = args[:deployed_index_auth_config] if args.key?(:deployed_index_auth_config)
  @deployment_group = args[:deployment_group] if args.key?(:deployment_group)
  @display_name = args[:display_name] if args.key?(:display_name)
  @enable_access_logging = args[:enable_access_logging] if args.key?(:enable_access_logging)
  @id = args[:id] if args.key?(:id)
  @index = args[:index] if args.key?(:index)
  @index_sync_time = args[:index_sync_time] if args.key?(:index_sync_time)
  @private_endpoints = args[:private_endpoints] if args.key?(:private_endpoints)
  @psc_automation_configs = args[:psc_automation_configs] if args.key?(:psc_automation_configs)
  @reserved_ip_ranges = args[:reserved_ip_ranges] if args.key?(:reserved_ip_ranges)
end