Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployedIndex
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployedIndex
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A deployment of an Index. IndexEndpoints contain one or more DeployedIndexes.
Instance Attribute Summary collapse
-
#automatic_resources ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AutomaticResources
A description of resources that to large degree are decided by Vertex AI, and require only a modest additional configuration.
-
#create_time ⇒ String
Output only.
-
#dedicated_resources ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DedicatedResources
A description of resources that are dedicated to a DeployedModel or DeployedIndex, and that need a higher degree of manual configuration.
-
#deployed_index_auth_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployedIndexAuthConfig
Used to set up the auth on the DeployedIndex's private endpoint.
-
#deployment_group ⇒ String
Optional.
-
#display_name ⇒ String
The display name of the DeployedIndex.
-
#enable_access_logging ⇒ Boolean
(also: #enable_access_logging?)
Optional.
-
#id ⇒ String
Required.
-
#index ⇒ String
Required.
-
#index_sync_time ⇒ String
Output only.
-
#private_endpoints ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexPrivateEndpoints
IndexPrivateEndpoints proto is used to provide paths for users to send requests via private endpoints (e.g. private service access, private service connect).
-
#psc_automation_configs ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PscAutomationConfig>
Optional.
-
#reserved_ip_ranges ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1DeployedIndex
constructor
A new instance of GoogleCloudAiplatformV1DeployedIndex.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1DeployedIndex
Returns a new instance of GoogleCloudAiplatformV1DeployedIndex.
6236 6237 6238 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6236 def initialize(**args) update!(**args) end |
Instance Attribute Details
#automatic_resources ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AutomaticResources
A description of resources that to large degree are decided by Vertex AI, and
require only a modest additional configuration. Each Model supporting these
resources documents its specific guidelines.
Corresponds to the JSON property automaticResources
6135 6136 6137 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6135 def automatic_resources @automatic_resources end |
#create_time ⇒ String
Output only. Timestamp when the DeployedIndex was created.
Corresponds to the JSON property createTime
6140 6141 6142 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6140 def create_time @create_time end |
#dedicated_resources ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DedicatedResources
A description of resources that are dedicated to a DeployedModel or
DeployedIndex, and that need a higher degree of manual configuration.
Corresponds to the JSON property dedicatedResources
6146 6147 6148 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6146 def dedicated_resources @dedicated_resources end |
#deployed_index_auth_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployedIndexAuthConfig
Used to set up the auth on the DeployedIndex's private endpoint.
Corresponds to the JSON property deployedIndexAuthConfig
6151 6152 6153 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6151 def deployed_index_auth_config @deployed_index_auth_config end |
#deployment_group ⇒ String
Optional. The deployment group can be no longer than 64 characters (eg: 'test',
'prod'). If not set, we will use the 'default' deployment group. Creating
deployment_groups with reserved_ip_ranges is a recommended practice when
the peered network has multiple peering ranges. This creates your deployments
from predictable IP spaces for easier traffic administration. Also, one
deployment_group (except 'default') can only be used with the same
reserved_ip_ranges which means if the deployment_group has been used with
reserved_ip_ranges: [a, b, c], using it with [a, b] or [d, e] is disallowed.
Note: we only support up to 5 deployment groups(not including 'default').
Corresponds to the JSON property deploymentGroup
6164 6165 6166 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6164 def deployment_group @deployment_group end |
#display_name ⇒ String
The display name of the DeployedIndex. If not provided upon creation, the
Index's display_name is used.
Corresponds to the JSON property displayName
6170 6171 6172 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6170 def display_name @display_name end |
#enable_access_logging ⇒ Boolean Also known as: enable_access_logging?
Optional. If true, private endpoint's access logs are sent to Cloud Logging.
These logs are like standard server access logs, containing information like
timestamp and latency for each MatchRequest. Note that logs may incur a cost,
especially if the deployed index receives a high queries per second rate (QPS).
Estimate your costs before enabling this option.
Corresponds to the JSON property enableAccessLogging
6179 6180 6181 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6179 def enable_access_logging @enable_access_logging end |
#id ⇒ String
Required. The user specified ID of the DeployedIndex. The ID can be up to 128
characters long and must start with a letter and only contain letters, numbers,
and underscores. The ID must be unique within the project it is created in.
Corresponds to the JSON property id
6187 6188 6189 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6187 def id @id end |
#index ⇒ String
Required. The name of the Index this is the deployment of. We may refer to
this Index as the DeployedIndex's "original" Index.
Corresponds to the JSON property index
6193 6194 6195 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6193 def index @index end |
#index_sync_time ⇒ String
Output only. The DeployedIndex may depend on various data on its original
Index. Additionally when certain changes to the original Index are being done (
e.g. when what the Index contains is being changed) the DeployedIndex may be
asynchronously updated in the background to reflect these changes. If this
timestamp's value is at least the Index.update_time of the original Index, it
means that this DeployedIndex and the original Index are in sync. If this
timestamp is older, then to see which updates this DeployedIndex already
contains (and which it does not), one must list the operations that are
running on the original Index. Only the successfully completed Operations with
update_time equal or before this sync time are contained in this DeployedIndex.
Corresponds to the JSON property indexSyncTime
6207 6208 6209 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6207 def index_sync_time @index_sync_time end |
#private_endpoints ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexPrivateEndpoints
IndexPrivateEndpoints proto is used to provide paths for users to send
requests via private endpoints (e.g. private service access, private service
connect). To send request via private service access, use match_grpc_address.
To send request via private service connect, use service_attachment.
Corresponds to the JSON property privateEndpoints
6215 6216 6217 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6215 def private_endpoints @private_endpoints end |
#psc_automation_configs ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PscAutomationConfig>
Optional. If set for PSC deployed index, PSC connection will be automatically
created after deployment is done and the endpoint information is populated in
private_endpoints.psc_automated_endpoints.
Corresponds to the JSON property pscAutomationConfigs
6222 6223 6224 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6222 def psc_automation_configs @psc_automation_configs end |
#reserved_ip_ranges ⇒ Array<String>
Optional. A list of reserved ip ranges under the VPC network that can be used
for this DeployedIndex. If set, we will deploy the index within the provided
ip ranges. Otherwise, the index might be deployed to any ip ranges under the
provided VPC network. The value should be the name of the address (https://
cloud.google.com/compute/docs/reference/rest/v1/addresses) Example: ['vertex-
ai-ip-range']. For more information about subnets and network IP ranges,
please see https://cloud.google.com/vpc/docs/subnets#
manually_created_subnet_ip_ranges.
Corresponds to the JSON property reservedIpRanges
6234 6235 6236 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6234 def reserved_ip_ranges @reserved_ip_ranges end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6241 6242 6243 6244 6245 6246 6247 6248 6249 6250 6251 6252 6253 6254 6255 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6241 def update!(**args) @automatic_resources = args[:automatic_resources] if args.key?(:automatic_resources) @create_time = args[:create_time] if args.key?(:create_time) @dedicated_resources = args[:dedicated_resources] if args.key?(:dedicated_resources) @deployed_index_auth_config = args[:deployed_index_auth_config] if args.key?(:deployed_index_auth_config) @deployment_group = args[:deployment_group] if args.key?(:deployment_group) @display_name = args[:display_name] if args.key?(:display_name) @enable_access_logging = args[:enable_access_logging] if args.key?(:enable_access_logging) @id = args[:id] if args.key?(:id) @index = args[:index] if args.key?(:index) @index_sync_time = args[:index_sync_time] if args.key?(:index_sync_time) @private_endpoints = args[:private_endpoints] if args.key?(:private_endpoints) @psc_automation_configs = args[:psc_automation_configs] if args.key?(:psc_automation_configs) @reserved_ip_ranges = args[:reserved_ip_ranges] if args.key?(:reserved_ip_ranges) end |