Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployedModel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A deployment of a Model. Endpoints contain one or more DeployedModels.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1DeployedModel

Returns a new instance of GoogleCloudAiplatformV1DeployedModel.



7341
7342
7343
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7341

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#automatic_resourcesGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1AutomaticResources

A description of resources that to large degree are decided by Vertex AI, and require only a modest additional configuration. Each Model supporting these resources documents its specific guidelines. Corresponds to the JSON property automaticResources



7212
7213
7214
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7212

def automatic_resources
  @automatic_resources
end

#checkpoint_idString

The checkpoint id of the model. Corresponds to the JSON property checkpointId

Returns:

  • (String)


7217
7218
7219
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7217

def checkpoint_id
  @checkpoint_id
end

#create_timeString

Output only. Timestamp when the DeployedModel was created. Corresponds to the JSON property createTime

Returns:

  • (String)


7222
7223
7224
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7222

def create_time
  @create_time
end

#dedicated_resourcesGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1DedicatedResources

A description of resources that are dedicated to a DeployedModel or DeployedIndex, and that need a higher degree of manual configuration. Corresponds to the JSON property dedicatedResources



7228
7229
7230
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7228

def dedicated_resources
  @dedicated_resources
end

#disable_container_loggingBoolean Also known as: disable_container_logging?

For custom-trained Models and AutoML Tabular Models, the container of the DeployedModel instances will send stderr and stdout streams to Cloud Logging by default. Please note that the logs incur cost, which are subject to Cloud Logging pricing. User can disable container logging by setting this flag to true. Corresponds to the JSON property disableContainerLogging

Returns:

  • (Boolean)


7237
7238
7239
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7237

def disable_container_logging
  @disable_container_logging
end

#disable_explanationsBoolean Also known as: disable_explanations?

If true, deploy the model without explainable feature, regardless the existence of Model.explanation_spec or explanation_spec. Corresponds to the JSON property disableExplanations

Returns:

  • (Boolean)


7244
7245
7246
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7244

def disable_explanations
  @disable_explanations
end

#display_nameString

The display name of the DeployedModel. If not provided upon creation, the Model's display_name is used. Corresponds to the JSON property displayName

Returns:

  • (String)


7251
7252
7253
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7251

def display_name
  @display_name
end

#enable_access_loggingBoolean Also known as: enable_access_logging?

If true, online prediction access logs are sent to Cloud Logging. These logs are like standard server access logs, containing information like timestamp and latency for each prediction request. Note that logs may incur a cost, especially if your project receives prediction requests at a high queries per second rate (QPS). Estimate your costs before enabling this option. Corresponds to the JSON property enableAccessLogging

Returns:

  • (Boolean)


7260
7261
7262
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7260

def enable_access_logging
  @enable_access_logging
end

#explanation_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationSpec

Specification of Model explanation. Corresponds to the JSON property explanationSpec



7266
7267
7268
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7266

def explanation_spec
  @explanation_spec
end

#faster_deployment_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FasterDeploymentConfig

Configuration for faster model deployment. Corresponds to the JSON property fasterDeploymentConfig



7271
7272
7273
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7271

def faster_deployment_config
  @faster_deployment_config
end

#gdc_connected_modelString

GDC pretrained / Gemini model name. The model name is a plain model name, e.g. gemini-1.5-flash-002. Corresponds to the JSON property gdcConnectedModel

Returns:

  • (String)


7277
7278
7279
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7277

def gdc_connected_model
  @gdc_connected_model
end

#idString

Immutable. The ID of the DeployedModel. If not provided upon deployment, Vertex AI will generate a value for this ID. This value should be 1-10 characters, and valid characters are /[0-9]/. Corresponds to the JSON property id

Returns:

  • (String)


7284
7285
7286
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7284

def id
  @id
end

#modelString

The resource name of the Model that this is the deployment of. Note that the Model may be in a different location than the DeployedModel's Endpoint. The resource name may contain version id or version alias to specify the version. Example: projects/project/locations/location/models/model@2 or projects/project/locations/location/models/model@golden if no version is specified, the default version will be deployed. Corresponds to the JSON property model

Returns:

  • (String)


7294
7295
7296
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7294

def model
  @model
end

#model_version_idString

Output only. The version ID of the model that is deployed. Corresponds to the JSON property modelVersionId

Returns:

  • (String)


7299
7300
7301
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7299

def model_version_id
  @model_version_id
end

#private_endpointsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PrivateEndpoints

PrivateEndpoints proto is used to provide paths for users to send requests privately. To send request via private service access, use predict_http_uri, explain_http_uri or health_http_uri. To send request via private service connect, use service_attachment. Corresponds to the JSON property privateEndpoints



7307
7308
7309
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7307

def private_endpoints
  @private_endpoints
end

#service_accountString

The service account that the DeployedModel's container runs as. Specify the email address of the service account. If this service account is not specified, the container runs as a service account that doesn't have access to the resource project. Users deploying the Model must have the iam.serviceAccounts. actAs permission on this service account. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


7316
7317
7318
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7316

def 
  @service_account
end

#shared_resourcesString

The resource name of the shared DeploymentResourcePool to deploy on. Format: projects/project/locations/location/deploymentResourcePools/ deployment_resource_pool` Corresponds to the JSON propertysharedResources`

Returns:

  • (String)


7323
7324
7325
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7323

def shared_resources
  @shared_resources
end

#speculative_decoding_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SpeculativeDecodingSpec

Configuration for Speculative Decoding. Corresponds to the JSON property speculativeDecodingSpec



7328
7329
7330
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7328

def speculative_decoding_spec
  @speculative_decoding_spec
end

#statusGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployedModelStatus

Runtime status of the deployed model. Corresponds to the JSON property status



7333
7334
7335
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7333

def status
  @status
end

#system_labelsHash<String,String>

System labels to apply to Model Garden deployments. System labels are managed by Google for internal use only. Corresponds to the JSON property systemLabels

Returns:

  • (Hash<String,String>)


7339
7340
7341
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7339

def system_labels
  @system_labels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7346
7347
7348
7349
7350
7351
7352
7353
7354
7355
7356
7357
7358
7359
7360
7361
7362
7363
7364
7365
7366
7367
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7346

def update!(**args)
  @automatic_resources = args[:automatic_resources] if args.key?(:automatic_resources)
  @checkpoint_id = args[:checkpoint_id] if args.key?(:checkpoint_id)
  @create_time = args[:create_time] if args.key?(:create_time)
  @dedicated_resources = args[:dedicated_resources] if args.key?(:dedicated_resources)
  @disable_container_logging = args[:disable_container_logging] if args.key?(:disable_container_logging)
  @disable_explanations = args[:disable_explanations] if args.key?(:disable_explanations)
  @display_name = args[:display_name] if args.key?(:display_name)
  @enable_access_logging = args[:enable_access_logging] if args.key?(:enable_access_logging)
  @explanation_spec = args[:explanation_spec] if args.key?(:explanation_spec)
  @faster_deployment_config = args[:faster_deployment_config] if args.key?(:faster_deployment_config)
  @gdc_connected_model = args[:gdc_connected_model] if args.key?(:gdc_connected_model)
  @id = args[:id] if args.key?(:id)
  @model = args[:model] if args.key?(:model)
  @model_version_id = args[:model_version_id] if args.key?(:model_version_id)
  @private_endpoints = args[:private_endpoints] if args.key?(:private_endpoints)
  @service_account = args[:service_account] if args.key?(:service_account)
  @shared_resources = args[:shared_resources] if args.key?(:shared_resources)
  @speculative_decoding_spec = args[:speculative_decoding_spec] if args.key?(:speculative_decoding_spec)
  @status = args[:status] if args.key?(:status)
  @system_labels = args[:system_labels] if args.key?(:system_labels)
end