Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployedModel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A deployment of a Model. Endpoints contain one or more DeployedModels.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1DeployedModel

Returns a new instance of GoogleCloudAiplatformV1DeployedModel.



6253
6254
6255
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6253

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#automatic_resourcesGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1AutomaticResources

A description of resources that to large degree are decided by Vertex AI, and require only a modest additional configuration. Each Model supporting these resources documents its specific guidelines. Corresponds to the JSON property automaticResources



6130
6131
6132
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6130

def automatic_resources
  @automatic_resources
end

#checkpoint_idString

The checkpoint id of the model. Corresponds to the JSON property checkpointId

Returns:

  • (String)


6135
6136
6137
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6135

def checkpoint_id
  @checkpoint_id
end

#create_timeString

Output only. Timestamp when the DeployedModel was created. Corresponds to the JSON property createTime

Returns:

  • (String)


6140
6141
6142
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6140

def create_time
  @create_time
end

#dedicated_resourcesGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1DedicatedResources

A description of resources that are dedicated to a DeployedModel or DeployedIndex, and that need a higher degree of manual configuration. Corresponds to the JSON property dedicatedResources



6146
6147
6148
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6146

def dedicated_resources
  @dedicated_resources
end

#disable_container_loggingBoolean Also known as: disable_container_logging?

For custom-trained Models and AutoML Tabular Models, the container of the DeployedModel instances will send stderr and stdout streams to Cloud Logging by default. Please note that the logs incur cost, which are subject to Cloud Logging pricing. User can disable container logging by setting this flag to true. Corresponds to the JSON property disableContainerLogging

Returns:

  • (Boolean)


6155
6156
6157
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6155

def disable_container_logging
  @disable_container_logging
end

#disable_explanationsBoolean Also known as: disable_explanations?

If true, deploy the model without explainable feature, regardless the existence of Model.explanation_spec or explanation_spec. Corresponds to the JSON property disableExplanations

Returns:

  • (Boolean)


6162
6163
6164
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6162

def disable_explanations
  @disable_explanations
end

#display_nameString

The display name of the DeployedModel. If not provided upon creation, the Model's display_name is used. Corresponds to the JSON property displayName

Returns:

  • (String)


6169
6170
6171
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6169

def display_name
  @display_name
end

#enable_access_loggingBoolean Also known as: enable_access_logging?

If true, online prediction access logs are sent to Cloud Logging. These logs are like standard server access logs, containing information like timestamp and latency for each prediction request. Note that logs may incur a cost, especially if your project receives prediction requests at a high queries per second rate (QPS). Estimate your costs before enabling this option. Corresponds to the JSON property enableAccessLogging

Returns:

  • (Boolean)


6178
6179
6180
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6178

def enable_access_logging
  @enable_access_logging
end

#explanation_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationSpec

Specification of Model explanation. Corresponds to the JSON property explanationSpec



6184
6185
6186
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6184

def explanation_spec
  @explanation_spec
end

#faster_deployment_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FasterDeploymentConfig

Configuration for faster model deployment. Corresponds to the JSON property fasterDeploymentConfig



6189
6190
6191
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6189

def faster_deployment_config
  @faster_deployment_config
end

#idString

Immutable. The ID of the DeployedModel. If not provided upon deployment, Vertex AI will generate a value for this ID. This value should be 1-10 characters, and valid characters are /[0-9]/. Corresponds to the JSON property id

Returns:

  • (String)


6196
6197
6198
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6196

def id
  @id
end

#modelString

Required. The resource name of the Model that this is the deployment of. Note that the Model may be in a different location than the DeployedModel's Endpoint. The resource name may contain version id or version alias to specify the version. Example: projects/project/locations/location/models/model@ 2 or projects/project/locations/location/models/model@golden if no version is specified, the default version will be deployed. Corresponds to the JSON property model

Returns:

  • (String)


6206
6207
6208
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6206

def model
  @model
end

#model_version_idString

Output only. The version ID of the model that is deployed. Corresponds to the JSON property modelVersionId

Returns:

  • (String)


6211
6212
6213
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6211

def model_version_id
  @model_version_id
end

#private_endpointsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PrivateEndpoints

PrivateEndpoints proto is used to provide paths for users to send requests privately. To send request via private service access, use predict_http_uri, explain_http_uri or health_http_uri. To send request via private service connect, use service_attachment. Corresponds to the JSON property privateEndpoints



6219
6220
6221
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6219

def private_endpoints
  @private_endpoints
end

#service_accountString

The service account that the DeployedModel's container runs as. Specify the email address of the service account. If this service account is not specified, the container runs as a service account that doesn't have access to the resource project. Users deploying the Model must have the iam.serviceAccounts. actAs permission on this service account. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


6228
6229
6230
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6228

def 
  @service_account
end

#shared_resourcesString

The resource name of the shared DeploymentResourcePool to deploy on. Format: projects/project/locations/location/deploymentResourcePools/ deployment_resource_pool` Corresponds to the JSON propertysharedResources`

Returns:

  • (String)


6235
6236
6237
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6235

def shared_resources
  @shared_resources
end

#speculative_decoding_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SpeculativeDecodingSpec

Configuration for Speculative Decoding. Corresponds to the JSON property speculativeDecodingSpec



6240
6241
6242
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6240

def speculative_decoding_spec
  @speculative_decoding_spec
end

#statusGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployedModelStatus

Runtime status of the deployed model. Corresponds to the JSON property status



6245
6246
6247
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6245

def status
  @status
end

#system_labelsHash<String,String>

System labels to apply to Model Garden deployments. System labels are managed by Google for internal use only. Corresponds to the JSON property systemLabels

Returns:

  • (Hash<String,String>)


6251
6252
6253
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6251

def system_labels
  @system_labels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6258
6259
6260
6261
6262
6263
6264
6265
6266
6267
6268
6269
6270
6271
6272
6273
6274
6275
6276
6277
6278
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6258

def update!(**args)
  @automatic_resources = args[:automatic_resources] if args.key?(:automatic_resources)
  @checkpoint_id = args[:checkpoint_id] if args.key?(:checkpoint_id)
  @create_time = args[:create_time] if args.key?(:create_time)
  @dedicated_resources = args[:dedicated_resources] if args.key?(:dedicated_resources)
  @disable_container_logging = args[:disable_container_logging] if args.key?(:disable_container_logging)
  @disable_explanations = args[:disable_explanations] if args.key?(:disable_explanations)
  @display_name = args[:display_name] if args.key?(:display_name)
  @enable_access_logging = args[:enable_access_logging] if args.key?(:enable_access_logging)
  @explanation_spec = args[:explanation_spec] if args.key?(:explanation_spec)
  @faster_deployment_config = args[:faster_deployment_config] if args.key?(:faster_deployment_config)
  @id = args[:id] if args.key?(:id)
  @model = args[:model] if args.key?(:model)
  @model_version_id = args[:model_version_id] if args.key?(:model_version_id)
  @private_endpoints = args[:private_endpoints] if args.key?(:private_endpoints)
  @service_account = args[:service_account] if args.key?(:service_account)
  @shared_resources = args[:shared_resources] if args.key?(:shared_resources)
  @speculative_decoding_spec = args[:speculative_decoding_spec] if args.key?(:speculative_decoding_spec)
  @status = args[:status] if args.key?(:status)
  @system_labels = args[:system_labels] if args.key?(:system_labels)
end