Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployedModel
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployedModel
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A deployment of a Model. Endpoints contain one or more DeployedModels.
Instance Attribute Summary collapse
-
#automatic_resources ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AutomaticResources
A description of resources that to large degree are decided by Vertex AI, and require only a modest additional configuration.
-
#create_time ⇒ String
Output only.
-
#dedicated_resources ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DedicatedResources
A description of resources that are dedicated to a DeployedModel, and that need a higher degree of manual configuration.
-
#disable_container_logging ⇒ Boolean
(also: #disable_container_logging?)
For custom-trained Models and AutoML Tabular Models, the container of the DeployedModel instances will send
stderrandstdoutstreams to Cloud Logging by default. -
#disable_explanations ⇒ Boolean
(also: #disable_explanations?)
If true, deploy the model without explainable feature, regardless the existence of Model.explanation_spec or explanation_spec.
-
#display_name ⇒ String
The display name of the DeployedModel.
-
#enable_access_logging ⇒ Boolean
(also: #enable_access_logging?)
If true, online prediction access logs are sent to Cloud Logging.
-
#explanation_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationSpec
Specification of Model explanation.
-
#id ⇒ String
Immutable.
-
#model ⇒ String
Required.
-
#model_version_id ⇒ String
Output only.
-
#private_endpoints ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PrivateEndpoints
PrivateEndpoints proto is used to provide paths for users to send requests privately.
-
#service_account ⇒ String
The service account that the DeployedModel's container runs as.
-
#shared_resources ⇒ String
The resource name of the shared DeploymentResourcePool to deploy on.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1DeployedModel
constructor
A new instance of GoogleCloudAiplatformV1DeployedModel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1DeployedModel
Returns a new instance of GoogleCloudAiplatformV1DeployedModel.
5413 5414 5415 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5413 def initialize(**args) update!(**args) end |
Instance Attribute Details
#automatic_resources ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AutomaticResources
A description of resources that to large degree are decided by Vertex AI, and
require only a modest additional configuration. Each Model supporting these
resources documents its specific guidelines.
Corresponds to the JSON property automaticResources
5316 5317 5318 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5316 def automatic_resources @automatic_resources end |
#create_time ⇒ String
Output only. Timestamp when the DeployedModel was created.
Corresponds to the JSON property createTime
5321 5322 5323 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5321 def create_time @create_time end |
#dedicated_resources ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DedicatedResources
A description of resources that are dedicated to a DeployedModel, and that
need a higher degree of manual configuration.
Corresponds to the JSON property dedicatedResources
5327 5328 5329 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5327 def dedicated_resources @dedicated_resources end |
#disable_container_logging ⇒ Boolean Also known as: disable_container_logging?
For custom-trained Models and AutoML Tabular Models, the container of the
DeployedModel instances will send stderr and stdout streams to Cloud
Logging by default. Please note that the logs incur cost, which are subject to
Cloud Logging pricing. User can
disable container logging by setting this flag to true.
Corresponds to the JSON property disableContainerLogging
5336 5337 5338 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5336 def disable_container_logging @disable_container_logging end |
#disable_explanations ⇒ Boolean Also known as: disable_explanations?
If true, deploy the model without explainable feature, regardless the
existence of Model.explanation_spec or explanation_spec.
Corresponds to the JSON property disableExplanations
5343 5344 5345 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5343 def disable_explanations @disable_explanations end |
#display_name ⇒ String
The display name of the DeployedModel. If not provided upon creation, the
Model's display_name is used.
Corresponds to the JSON property displayName
5350 5351 5352 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5350 def display_name @display_name end |
#enable_access_logging ⇒ Boolean Also known as: enable_access_logging?
If true, online prediction access logs are sent to Cloud Logging. These logs
are like standard server access logs, containing information like timestamp
and latency for each prediction request. Note that logs may incur a cost,
especially if your project receives prediction requests at a high queries per
second rate (QPS). Estimate your costs before enabling this option.
Corresponds to the JSON property enableAccessLogging
5359 5360 5361 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5359 def enable_access_logging @enable_access_logging end |
#explanation_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationSpec
Specification of Model explanation.
Corresponds to the JSON property explanationSpec
5365 5366 5367 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5365 def explanation_spec @explanation_spec end |
#id ⇒ String
Immutable. The ID of the DeployedModel. If not provided upon deployment,
Vertex AI will generate a value for this ID. This value should be 1-10
characters, and valid characters are /[0-9]/.
Corresponds to the JSON property id
5372 5373 5374 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5372 def id @id end |
#model ⇒ String
Required. The resource name of the Model that this is the deployment of. Note
that the Model may be in a different location than the DeployedModel's
Endpoint. The resource name may contain version id or version alias to specify
the version. Example: projects/project/locations/location/models/model@
2 or projects/project/locations/location/models/model@golden if no
version is specified, the default version will be deployed.
Corresponds to the JSON property model
5382 5383 5384 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5382 def model @model end |
#model_version_id ⇒ String
Output only. The version ID of the model that is deployed.
Corresponds to the JSON property modelVersionId
5387 5388 5389 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5387 def model_version_id @model_version_id end |
#private_endpoints ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PrivateEndpoints
PrivateEndpoints proto is used to provide paths for users to send requests
privately. To send request via private service access, use predict_http_uri,
explain_http_uri or health_http_uri. To send request via private service
connect, use service_attachment.
Corresponds to the JSON property privateEndpoints
5395 5396 5397 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5395 def private_endpoints @private_endpoints end |
#service_account ⇒ String
The service account that the DeployedModel's container runs as. Specify the
email address of the service account. If this service account is not specified,
the container runs as a service account that doesn't have access to the
resource project. Users deploying the Model must have the iam.serviceAccounts.
actAs permission on this service account.
Corresponds to the JSON property serviceAccount
5404 5405 5406 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5404 def service_account @service_account end |
#shared_resources ⇒ String
The resource name of the shared DeploymentResourcePool to deploy on. Format:
projects/project/locations/location/deploymentResourcePools/
deployment_resource_pool`
Corresponds to the JSON propertysharedResources`
5411 5412 5413 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5411 def shared_resources @shared_resources end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5418 5419 5420 5421 5422 5423 5424 5425 5426 5427 5428 5429 5430 5431 5432 5433 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5418 def update!(**args) @automatic_resources = args[:automatic_resources] if args.key?(:automatic_resources) @create_time = args[:create_time] if args.key?(:create_time) @dedicated_resources = args[:dedicated_resources] if args.key?(:dedicated_resources) @disable_container_logging = args[:disable_container_logging] if args.key?(:disable_container_logging) @disable_explanations = args[:disable_explanations] if args.key?(:disable_explanations) @display_name = args[:display_name] if args.key?(:display_name) @enable_access_logging = args[:enable_access_logging] if args.key?(:enable_access_logging) @explanation_spec = args[:explanation_spec] if args.key?(:explanation_spec) @id = args[:id] if args.key?(:id) @model = args[:model] if args.key?(:model) @model_version_id = args[:model_version_id] if args.key?(:model_version_id) @private_endpoints = args[:private_endpoints] if args.key?(:private_endpoints) @service_account = args[:service_account] if args.key?(:service_account) @shared_resources = args[:shared_resources] if args.key?(:shared_resources) end |