Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployedModel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A deployment of a Model. Endpoints contain one or more DeployedModels.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1DeployedModel

Returns a new instance of GoogleCloudAiplatformV1DeployedModel.



5224
5225
5226
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5224

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#automatic_resourcesGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1AutomaticResources

A description of resources that to large degree are decided by Vertex AI, and require only a modest additional configuration. Each Model supporting these resources documents its specific guidelines. Corresponds to the JSON property automaticResources



5127
5128
5129
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5127

def automatic_resources
  @automatic_resources
end

#create_timeString

Output only. Timestamp when the DeployedModel was created. Corresponds to the JSON property createTime

Returns:

  • (String)


5132
5133
5134
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5132

def create_time
  @create_time
end

#dedicated_resourcesGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1DedicatedResources

A description of resources that are dedicated to a DeployedModel, and that need a higher degree of manual configuration. Corresponds to the JSON property dedicatedResources



5138
5139
5140
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5138

def dedicated_resources
  @dedicated_resources
end

#disable_container_loggingBoolean Also known as: disable_container_logging?

For custom-trained Models and AutoML Tabular Models, the container of the DeployedModel instances will send stderr and stdout streams to Cloud Logging by default. Please note that the logs incur cost, which are subject to Cloud Logging pricing. User can disable container logging by setting this flag to true. Corresponds to the JSON property disableContainerLogging

Returns:

  • (Boolean)


5147
5148
5149
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5147

def disable_container_logging
  @disable_container_logging
end

#disable_explanationsBoolean Also known as: disable_explanations?

If true, deploy the model without explainable feature, regardless the existence of Model.explanation_spec or explanation_spec. Corresponds to the JSON property disableExplanations

Returns:

  • (Boolean)


5154
5155
5156
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5154

def disable_explanations
  @disable_explanations
end

#display_nameString

The display name of the DeployedModel. If not provided upon creation, the Model's display_name is used. Corresponds to the JSON property displayName

Returns:

  • (String)


5161
5162
5163
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5161

def display_name
  @display_name
end

#enable_access_loggingBoolean Also known as: enable_access_logging?

If true, online prediction access logs are sent to Cloud Logging. These logs are like standard server access logs, containing information like timestamp and latency for each prediction request. Note that logs may incur a cost, especially if your project receives prediction requests at a high queries per second rate (QPS). Estimate your costs before enabling this option. Corresponds to the JSON property enableAccessLogging

Returns:

  • (Boolean)


5170
5171
5172
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5170

def enable_access_logging
  @enable_access_logging
end

#explanation_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationSpec

Specification of Model explanation. Corresponds to the JSON property explanationSpec



5176
5177
5178
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5176

def explanation_spec
  @explanation_spec
end

#idString

Immutable. The ID of the DeployedModel. If not provided upon deployment, Vertex AI will generate a value for this ID. This value should be 1-10 characters, and valid characters are /[0-9]/. Corresponds to the JSON property id

Returns:

  • (String)


5183
5184
5185
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5183

def id
  @id
end

#modelString

Required. The resource name of the Model that this is the deployment of. Note that the Model may be in a different location than the DeployedModel's Endpoint. The resource name may contain version id or version alias to specify the version. Example: projects/project/locations/location/models/model@ 2 or projects/project/locations/location/models/model@golden if no version is specified, the default version will be deployed. Corresponds to the JSON property model

Returns:

  • (String)


5193
5194
5195
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5193

def model
  @model
end

#model_version_idString

Output only. The version ID of the model that is deployed. Corresponds to the JSON property modelVersionId

Returns:

  • (String)


5198
5199
5200
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5198

def model_version_id
  @model_version_id
end

#private_endpointsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PrivateEndpoints

PrivateEndpoints proto is used to provide paths for users to send requests privately. To send request via private service access, use predict_http_uri, explain_http_uri or health_http_uri. To send request via private service connect, use service_attachment. Corresponds to the JSON property privateEndpoints



5206
5207
5208
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5206

def private_endpoints
  @private_endpoints
end

#service_accountString

The service account that the DeployedModel's container runs as. Specify the email address of the service account. If this service account is not specified, the container runs as a service account that doesn't have access to the resource project. Users deploying the Model must have the iam.serviceAccounts. actAs permission on this service account. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


5215
5216
5217
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5215

def 
  @service_account
end

#shared_resourcesString

The resource name of the shared DeploymentResourcePool to deploy on. Format: projects/project/locations/location/deploymentResourcePools/ deployment_resource_pool` Corresponds to the JSON propertysharedResources`

Returns:

  • (String)


5222
5223
5224
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5222

def shared_resources
  @shared_resources
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5229
5230
5231
5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
5242
5243
5244
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5229

def update!(**args)
  @automatic_resources = args[:automatic_resources] if args.key?(:automatic_resources)
  @create_time = args[:create_time] if args.key?(:create_time)
  @dedicated_resources = args[:dedicated_resources] if args.key?(:dedicated_resources)
  @disable_container_logging = args[:disable_container_logging] if args.key?(:disable_container_logging)
  @disable_explanations = args[:disable_explanations] if args.key?(:disable_explanations)
  @display_name = args[:display_name] if args.key?(:display_name)
  @enable_access_logging = args[:enable_access_logging] if args.key?(:enable_access_logging)
  @explanation_spec = args[:explanation_spec] if args.key?(:explanation_spec)
  @id = args[:id] if args.key?(:id)
  @model = args[:model] if args.key?(:model)
  @model_version_id = args[:model_version_id] if args.key?(:model_version_id)
  @private_endpoints = args[:private_endpoints] if args.key?(:private_endpoints)
  @service_account = args[:service_account] if args.key?(:service_account)
  @shared_resources = args[:shared_resources] if args.key?(:shared_resources)
end