Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployedModelStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Runtime status of the deployed model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1DeployedModelStatus

Returns a new instance of GoogleCloudAiplatformV1DeployedModelStatus.



8486
8487
8488
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8486

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#available_replica_countFixnum

Output only. The number of available replicas of the deployed model. Corresponds to the JSON property availableReplicaCount

Returns:

  • (Fixnum)


8474
8475
8476
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8474

def available_replica_count
  @available_replica_count
end

#last_update_timeString

Output only. The time at which the status was last updated. Corresponds to the JSON property lastUpdateTime

Returns:

  • (String)


8479
8480
8481
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8479

def last_update_time
  @last_update_time
end

#messageString

Output only. The latest deployed model's status message (if any). Corresponds to the JSON property message

Returns:

  • (String)


8484
8485
8486
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8484

def message
  @message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8491
8492
8493
8494
8495
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8491

def update!(**args)
  @available_replica_count = args[:available_replica_count] if args.key?(:available_replica_count)
  @last_update_time = args[:last_update_time] if args.key?(:last_update_time)
  @message = args[:message] if args.key?(:message)
end