Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeploymentResourcePool
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeploymentResourcePool
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A description of resources that can be shared by multiple DeployedModels, whose underlying specification consists of a DedicatedResources.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#dedicated_resources ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DedicatedResources
A description of resources that are dedicated to a DeployedModel or DeployedIndex, and that need a higher degree of manual configuration.
-
#disable_container_logging ⇒ Boolean
(also: #disable_container_logging?)
If the DeploymentResourcePool is deployed with custom-trained Models or AutoML Tabular Models, the container(s) of the DeploymentResourcePool will send
stderrandstdoutstreams to Cloud Logging by default. -
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.
-
#name ⇒ String
Immutable.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#service_account ⇒ String
The service account that the DeploymentResourcePool's container(s) run as.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1DeploymentResourcePool
constructor
A new instance of GoogleCloudAiplatformV1DeploymentResourcePool.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1DeploymentResourcePool
Returns a new instance of GoogleCloudAiplatformV1DeploymentResourcePool.
9157 9158 9159 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9157 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this DeploymentResourcePool was created.
Corresponds to the JSON property createTime
9103 9104 9105 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9103 def create_time @create_time end |
#dedicated_resources ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DedicatedResources
A description of resources that are dedicated to a DeployedModel or
DeployedIndex, and that need a higher degree of manual configuration.
Corresponds to the JSON property dedicatedResources
9109 9110 9111 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9109 def dedicated_resources @dedicated_resources end |
#disable_container_logging ⇒ Boolean Also known as: disable_container_logging?
If the DeploymentResourcePool is deployed with custom-trained Models or AutoML
Tabular Models, the container(s) of the DeploymentResourcePool will send
stderr and stdout streams to Cloud Logging by default. Please note that the
logs incur cost, which are subject to Cloud Logging pricing. User can disable container logging by setting
this flag to true.
Corresponds to the JSON property disableContainerLogging
9119 9120 9121 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9119 def disable_container_logging @disable_container_logging end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied
to a Vertex AI resource.
Corresponds to the JSON property encryptionSpec
9126 9127 9128 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9126 def encryption_spec @encryption_spec end |
#name ⇒ String
Immutable. The resource name of the DeploymentResourcePool. Format: projects/
project/locations/location/deploymentResourcePools/
deployment_resource_pool`
Corresponds to the JSON propertyname`
9133 9134 9135 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9133 def name @name end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
9138 9139 9140 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9138 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
9144 9145 9146 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9144 def satisfies_pzs @satisfies_pzs end |
#service_account ⇒ String
The service account that the DeploymentResourcePool's container(s) run as.
Specify the email address of the service account. If this service account is
not specified, the container(s) run as a service account that doesn't have
access to the resource project. Users deploying the Models to this
DeploymentResourcePool must have the iam.serviceAccounts.actAs permission on
this service account.
Corresponds to the JSON property serviceAccount
9155 9156 9157 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9155 def service_account @service_account end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9162 9163 9164 9165 9166 9167 9168 9169 9170 9171 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9162 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @dedicated_resources = args[:dedicated_resources] if args.key?(:dedicated_resources) @disable_container_logging = args[:disable_container_logging] if args.key?(:disable_container_logging) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @name = args[:name] if args.key?(:name) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @service_account = args[:service_account] if args.key?(:service_account) end |