Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeploymentResourcePool
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeploymentResourcePool
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A description of resources that can be shared by multiple DeployedModels, whose underlying specification consists of a DedicatedResources.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#dedicated_resources ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DedicatedResources
A description of resources that are dedicated to a DeployedModel or DeployedIndex, and that need a higher degree of manual configuration.
-
#disable_container_logging ⇒ Boolean
(also: #disable_container_logging?)
If the DeploymentResourcePool is deployed with custom-trained Models or AutoML Tabular Models, the container(s) of the DeploymentResourcePool will send
stderrandstdoutstreams to Cloud Logging by default. -
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top- level resource.
-
#name ⇒ String
Immutable.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#service_account ⇒ String
The service account that the DeploymentResourcePool's container(s) run as.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1DeploymentResourcePool
constructor
A new instance of GoogleCloudAiplatformV1DeploymentResourcePool.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1DeploymentResourcePool
Returns a new instance of GoogleCloudAiplatformV1DeploymentResourcePool.
6652 6653 6654 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6652 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this DeploymentResourcePool was created.
Corresponds to the JSON property createTime
6598 6599 6600 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6598 def create_time @create_time end |
#dedicated_resources ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DedicatedResources
A description of resources that are dedicated to a DeployedModel or
DeployedIndex, and that need a higher degree of manual configuration.
Corresponds to the JSON property dedicatedResources
6604 6605 6606 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6604 def dedicated_resources @dedicated_resources end |
#disable_container_logging ⇒ Boolean Also known as: disable_container_logging?
If the DeploymentResourcePool is deployed with custom-trained Models or AutoML
Tabular Models, the container(s) of the DeploymentResourcePool will send
stderr and stdout streams to Cloud Logging by default. Please note that the
logs incur cost, which are subject to Cloud Logging pricing. User can disable container logging by setting
this flag to true.
Corresponds to the JSON property disableContainerLogging
6614 6615 6616 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6614 def disable_container_logging @disable_container_logging end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top-
level resource.
Corresponds to the JSON property encryptionSpec
6621 6622 6623 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6621 def encryption_spec @encryption_spec end |
#name ⇒ String
Immutable. The resource name of the DeploymentResourcePool. Format: projects/
project/locations/location/deploymentResourcePools/
deployment_resource_pool`
Corresponds to the JSON propertyname`
6628 6629 6630 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6628 def name @name end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
6633 6634 6635 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6633 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
6639 6640 6641 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6639 def satisfies_pzs @satisfies_pzs end |
#service_account ⇒ String
The service account that the DeploymentResourcePool's container(s) run as.
Specify the email address of the service account. If this service account is
not specified, the container(s) run as a service account that doesn't have
access to the resource project. Users deploying the Models to this
DeploymentResourcePool must have the iam.serviceAccounts.actAs permission on
this service account.
Corresponds to the JSON property serviceAccount
6650 6651 6652 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6650 def service_account @service_account end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6657 6658 6659 6660 6661 6662 6663 6664 6665 6666 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6657 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @dedicated_resources = args[:dedicated_resources] if args.key?(:dedicated_resources) @disable_container_logging = args[:disable_container_logging] if args.key?(:disable_container_logging) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @name = args[:name] if args.key?(:name) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @service_account = args[:service_account] if args.key?(:service_account) end |