Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeploymentResourcePool

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A description of resources that can be shared by multiple DeployedModels, whose underlying specification consists of a DedicatedResources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1DeploymentResourcePool

Returns a new instance of GoogleCloudAiplatformV1DeploymentResourcePool.



6360
6361
6362
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6360

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this DeploymentResourcePool was created. Corresponds to the JSON property createTime

Returns:

  • (String)


6306
6307
6308
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6306

def create_time
  @create_time
end

#dedicated_resourcesGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1DedicatedResources

A description of resources that are dedicated to a DeployedModel or DeployedIndex, and that need a higher degree of manual configuration. Corresponds to the JSON property dedicatedResources



6312
6313
6314
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6312

def dedicated_resources
  @dedicated_resources
end

#disable_container_loggingBoolean Also known as: disable_container_logging?

If the DeploymentResourcePool is deployed with custom-trained Models or AutoML Tabular Models, the container(s) of the DeploymentResourcePool will send stderr and stdout streams to Cloud Logging by default. Please note that the logs incur cost, which are subject to Cloud Logging pricing. User can disable container logging by setting this flag to true. Corresponds to the JSON property disableContainerLogging

Returns:

  • (Boolean)


6322
6323
6324
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6322

def disable_container_logging
  @disable_container_logging
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key spec that can be applied to a top- level resource. Corresponds to the JSON property encryptionSpec



6329
6330
6331
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6329

def encryption_spec
  @encryption_spec
end

#nameString

Immutable. The resource name of the DeploymentResourcePool. Format: projects/ project/locations/location/deploymentResourcePools/ deployment_resource_pool` Corresponds to the JSON propertyname`

Returns:

  • (String)


6336
6337
6338
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6336

def name
  @name
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


6341
6342
6343
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6341

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


6347
6348
6349
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6347

def satisfies_pzs
  @satisfies_pzs
end

#service_accountString

The service account that the DeploymentResourcePool's container(s) run as. Specify the email address of the service account. If this service account is not specified, the container(s) run as a service account that doesn't have access to the resource project. Users deploying the Models to this DeploymentResourcePool must have the iam.serviceAccounts.actAs permission on this service account. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


6358
6359
6360
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6358

def 
  @service_account
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6365
6366
6367
6368
6369
6370
6371
6372
6373
6374
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6365

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @dedicated_resources = args[:dedicated_resources] if args.key?(:dedicated_resources)
  @disable_container_logging = args[:disable_container_logging] if args.key?(:disable_container_logging)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @name = args[:name] if args.key?(:name)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @service_account = args[:service_account] if args.key?(:service_account)
end