Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeploymentResourcePool
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeploymentResourcePool
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A description of resources that can be shared by multiple DeployedModels, whose underlying specification consists of a DedicatedResources.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#dedicated_resources ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DedicatedResources
A description of resources that are dedicated to a DeployedModel or DeployedIndex, and that need a higher degree of manual configuration.
-
#disable_container_logging ⇒ Boolean
(also: #disable_container_logging?)
If the DeploymentResourcePool is deployed with custom-trained Models or AutoML Tabular Models, the container(s) of the DeploymentResourcePool will send
stderrandstdoutstreams to Cloud Logging by default. -
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top- level resource.
-
#name ⇒ String
Immutable.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#service_account ⇒ String
The service account that the DeploymentResourcePool's container(s) run as.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1DeploymentResourcePool
constructor
A new instance of GoogleCloudAiplatformV1DeploymentResourcePool.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1DeploymentResourcePool
Returns a new instance of GoogleCloudAiplatformV1DeploymentResourcePool.
6283 6284 6285 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6283 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this DeploymentResourcePool was created.
Corresponds to the JSON property createTime
6229 6230 6231 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6229 def create_time @create_time end |
#dedicated_resources ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DedicatedResources
A description of resources that are dedicated to a DeployedModel or
DeployedIndex, and that need a higher degree of manual configuration.
Corresponds to the JSON property dedicatedResources
6235 6236 6237 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6235 def dedicated_resources @dedicated_resources end |
#disable_container_logging ⇒ Boolean Also known as: disable_container_logging?
If the DeploymentResourcePool is deployed with custom-trained Models or AutoML
Tabular Models, the container(s) of the DeploymentResourcePool will send
stderr and stdout streams to Cloud Logging by default. Please note that the
logs incur cost, which are subject to Cloud Logging pricing. User can disable container logging by setting
this flag to true.
Corresponds to the JSON property disableContainerLogging
6245 6246 6247 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6245 def disable_container_logging @disable_container_logging end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top-
level resource.
Corresponds to the JSON property encryptionSpec
6252 6253 6254 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6252 def encryption_spec @encryption_spec end |
#name ⇒ String
Immutable. The resource name of the DeploymentResourcePool. Format: projects/
project/locations/location/deploymentResourcePools/
deployment_resource_pool`
Corresponds to the JSON propertyname`
6259 6260 6261 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6259 def name @name end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
6264 6265 6266 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6264 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
6270 6271 6272 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6270 def satisfies_pzs @satisfies_pzs end |
#service_account ⇒ String
The service account that the DeploymentResourcePool's container(s) run as.
Specify the email address of the service account. If this service account is
not specified, the container(s) run as a service account that doesn't have
access to the resource project. Users deploying the Models to this
DeploymentResourcePool must have the iam.serviceAccounts.actAs permission on
this service account.
Corresponds to the JSON property serviceAccount
6281 6282 6283 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6281 def service_account @service_account end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6288 6289 6290 6291 6292 6293 6294 6295 6296 6297 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6288 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @dedicated_resources = args[:dedicated_resources] if args.key?(:dedicated_resources) @disable_container_logging = args[:disable_container_logging] if args.key?(:disable_container_logging) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @name = args[:name] if args.key?(:name) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @service_account = args[:service_account] if args.key?(:service_account) end |