Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeploymentResourcePool

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A description of resources that can be shared by multiple DeployedModels, whose underlying specification consists of a DedicatedResources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1DeploymentResourcePool

Returns a new instance of GoogleCloudAiplatformV1DeploymentResourcePool.



5866
5867
5868
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5866

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this DeploymentResourcePool was created. Corresponds to the JSON property createTime

Returns:

  • (String)


5851
5852
5853
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5851

def create_time
  @create_time
end

#dedicated_resourcesGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1DedicatedResources

A description of resources that are dedicated to a DeployedModel, and that need a higher degree of manual configuration. Corresponds to the JSON property dedicatedResources



5857
5858
5859
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5857

def dedicated_resources
  @dedicated_resources
end

#nameString

Immutable. The resource name of the DeploymentResourcePool. Format: projects/ project/locations/location/deploymentResourcePools/ deployment_resource_pool` Corresponds to the JSON propertyname`

Returns:

  • (String)


5864
5865
5866
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5864

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5871
5872
5873
5874
5875
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5871

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @dedicated_resources = args[:dedicated_resources] if args.key?(:dedicated_resources)
  @name = args[:name] if args.key?(:name)
end