Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DnsPeeringConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

DNS peering configuration. These configurations are used to create DNS peering zones in the Vertex tenant project VPC, enabling resolution of records within the specified domain hosted in the target network's Cloud DNS.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1DnsPeeringConfig

Returns a new instance of GoogleCloudAiplatformV1DnsPeeringConfig.



7146
7147
7148
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7146

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#domainString

Required. The DNS name suffix of the zone being peered to, e.g., "my-internal- domain.corp.". Must end with a dot. Corresponds to the JSON property domain

Returns:

  • (String)


7131
7132
7133
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7131

def domain
  @domain
end

#target_networkString

Required. The VPC network name in the target_project where the DNS zone specified by 'domain' is visible. Corresponds to the JSON property targetNetwork

Returns:

  • (String)


7137
7138
7139
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7137

def target_network
  @target_network
end

#target_projectString

Required. The project ID hosting the Cloud DNS managed zone that contains the ' domain'. The Vertex AI Service Agent requires the dns.peer role on this project. Corresponds to the JSON property targetProject

Returns:

  • (String)


7144
7145
7146
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7144

def target_project
  @target_project
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7151
7152
7153
7154
7155
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7151

def update!(**args)
  @domain = args[:domain] if args.key?(:domain)
  @target_network = args[:target_network] if args.key?(:target_network)
  @target_project = args[:target_project] if args.key?(:target_project)
end