Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DnsPeeringConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

DNS peering configuration. These configurations are used to create DNS peering zones in the Vertex tenant project VPC, enabling resolution of records within the specified domain hosted in the target network's Cloud DNS.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1DnsPeeringConfig

Returns a new instance of GoogleCloudAiplatformV1DnsPeeringConfig.



7117
7118
7119
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7117

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#domainString

Required. The DNS name suffix of the zone being peered to, e.g., "my-internal- domain.corp.". Must end with a dot. Corresponds to the JSON property domain

Returns:

  • (String)


7102
7103
7104
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7102

def domain
  @domain
end

#target_networkString

Required. The VPC network name in the target_project where the DNS zone specified by 'domain' is visible. Corresponds to the JSON property targetNetwork

Returns:

  • (String)


7108
7109
7110
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7108

def target_network
  @target_network
end

#target_projectString

Required. The project ID hosting the Cloud DNS managed zone that contains the ' domain'. The Vertex AI Service Agent requires the dns.peer role on this project. Corresponds to the JSON property targetProject

Returns:

  • (String)


7115
7116
7117
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7115

def target_project
  @target_project
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7122
7123
7124
7125
7126
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7122

def update!(**args)
  @domain = args[:domain] if args.key?(:domain)
  @target_network = args[:target_network] if args.key?(:target_network)
  @target_project = args[:target_project] if args.key?(:target_project)
end