Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DynamicRetrievalConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Describes the options to customize dynamic retrieval.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1DynamicRetrievalConfig

Returns a new instance of GoogleCloudAiplatformV1DynamicRetrievalConfig.



7772
7773
7774
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7772

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dynamic_thresholdFloat

Optional. The threshold to be used in dynamic retrieval. If not set, a system default value is used. Corresponds to the JSON property dynamicThreshold

Returns:

  • (Float)


7765
7766
7767
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7765

def dynamic_threshold
  @dynamic_threshold
end

#modeString

The mode of the predictor to be used in dynamic retrieval. Corresponds to the JSON property mode

Returns:

  • (String)


7770
7771
7772
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7770

def mode
  @mode
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7777
7778
7779
7780
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7777

def update!(**args)
  @dynamic_threshold = args[:dynamic_threshold] if args.key?(:dynamic_threshold)
  @mode = args[:mode] if args.key?(:mode)
end