Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DynamicRetrievalConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Describes the options to customize dynamic retrieval.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1DynamicRetrievalConfig

Returns a new instance of GoogleCloudAiplatformV1DynamicRetrievalConfig.



6868
6869
6870
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6868

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dynamic_thresholdFloat

Optional. The threshold to be used in dynamic retrieval. If not set, a system default value is used. Corresponds to the JSON property dynamicThreshold

Returns:

  • (Float)


6861
6862
6863
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6861

def dynamic_threshold
  @dynamic_threshold
end

#modeString

The mode of the predictor to be used in dynamic retrieval. Corresponds to the JSON property mode

Returns:

  • (String)


6866
6867
6868
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6866

def mode
  @mode
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6873
6874
6875
6876
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6873

def update!(**args)
  @dynamic_threshold = args[:dynamic_threshold] if args.key?(:dynamic_threshold)
  @mode = args[:mode] if args.key?(:mode)
end