Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EmbedContentRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for PredictionService.EmbedContent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1EmbedContentRequest

Returns a new instance of GoogleCloudAiplatformV1EmbedContentRequest.



8370
8371
8372
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8370

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_truncateBoolean Also known as: auto_truncate?

Optional. Deprecated: Please use EmbedContentConfig.auto_truncate instead. Whether to silently truncate the input content if it's longer than the maximum sequence length. Corresponds to the JSON property autoTruncate

Returns:

  • (Boolean)


8336
8337
8338
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8336

def auto_truncate
  @auto_truncate
end

#contentGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Content

The structured data content of a message. A Content message contains a role field, which indicates the producer of the content, and a parts field, which contains the multi-part data of the message. Corresponds to the JSON property content



8344
8345
8346
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8344

def content
  @content
end

#embed_content_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EmbedContentRequestEmbedContentConfig

Configurations for the EmbedContent API. Corresponds to the JSON property embedContentConfig



8349
8350
8351
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8349

def embed_content_config
  @embed_content_config
end

#output_dimensionalityFixnum

Optional. Deprecated: Please use EmbedContentConfig.output_dimensionality instead. Reduced dimension for the output embedding. If set, excessive values in the output embedding are truncated from the end. Corresponds to the JSON property outputDimensionality

Returns:

  • (Fixnum)


8356
8357
8358
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8356

def output_dimensionality
  @output_dimensionality
end

#task_typeString

Optional. Deprecated: Please use EmbedContentConfig.task_type instead. The task type of the embedding. Corresponds to the JSON property taskType

Returns:

  • (String)


8362
8363
8364
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8362

def task_type
  @task_type
end

#titleString

Optional. Deprecated: Please use EmbedContentConfig.title instead. The title for the text. Corresponds to the JSON property title

Returns:

  • (String)


8368
8369
8370
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8368

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8375
8376
8377
8378
8379
8380
8381
8382
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8375

def update!(**args)
  @auto_truncate = args[:auto_truncate] if args.key?(:auto_truncate)
  @content = args[:content] if args.key?(:content)
  @embed_content_config = args[:embed_content_config] if args.key?(:embed_content_config)
  @output_dimensionality = args[:output_dimensionality] if args.key?(:output_dimensionality)
  @task_type = args[:task_type] if args.key?(:task_type)
  @title = args[:title] if args.key?(:title)
end