Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EmbedContentRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for PredictionService.EmbedContent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1EmbedContentRequest

Returns a new instance of GoogleCloudAiplatformV1EmbedContentRequest.



7817
7818
7819
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7817

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_truncateBoolean Also known as: auto_truncate?

Optional. Whether to silently truncate the input content if it's longer than the maximum sequence length. Corresponds to the JSON property autoTruncate

Returns:

  • (Boolean)


7791
7792
7793
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7791

def auto_truncate
  @auto_truncate
end

#contentGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Content

The structured data content of a message. A Content message contains a role field, which indicates the producer of the content, and a parts field, which contains the multi-part data of the message. Corresponds to the JSON property content



7799
7800
7801
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7799

def content
  @content
end

#output_dimensionalityFixnum

Optional. Optional reduced dimension for the output embedding. If set, excessive values in the output embedding are truncated from the end. Corresponds to the JSON property outputDimensionality

Returns:

  • (Fixnum)


7805
7806
7807
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7805

def output_dimensionality
  @output_dimensionality
end

#task_typeString

Optional. The task type of the embedding. Corresponds to the JSON property taskType

Returns:

  • (String)


7810
7811
7812
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7810

def task_type
  @task_type
end

#titleString

Optional. An optional title for the text. Corresponds to the JSON property title

Returns:

  • (String)


7815
7816
7817
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7815

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7822
7823
7824
7825
7826
7827
7828
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7822

def update!(**args)
  @auto_truncate = args[:auto_truncate] if args.key?(:auto_truncate)
  @content = args[:content] if args.key?(:content)
  @output_dimensionality = args[:output_dimensionality] if args.key?(:output_dimensionality)
  @task_type = args[:task_type] if args.key?(:task_type)
  @title = args[:title] if args.key?(:title)
end