Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EmbedContentRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EmbedContentRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Request message for PredictionService.EmbedContent.
Instance Attribute Summary collapse
-
#auto_truncate ⇒ Boolean
(also: #auto_truncate?)
Optional.
-
#content ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content
The structured data content of a message.
-
#output_dimensionality ⇒ Fixnum
Optional.
-
#task_type ⇒ String
Optional.
-
#title ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1EmbedContentRequest
constructor
A new instance of GoogleCloudAiplatformV1EmbedContentRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1EmbedContentRequest
Returns a new instance of GoogleCloudAiplatformV1EmbedContentRequest.
7792 7793 7794 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7792 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_truncate ⇒ Boolean Also known as: auto_truncate?
Optional. Whether to silently truncate the input content if it's longer than
the maximum sequence length.
Corresponds to the JSON property autoTruncate
7766 7767 7768 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7766 def auto_truncate @auto_truncate end |
#content ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content
The structured data content of a message. A Content message contains a role
field, which indicates the producer of the content, and a parts field, which
contains the multi-part data of the message.
Corresponds to the JSON property content
7774 7775 7776 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7774 def content @content end |
#output_dimensionality ⇒ Fixnum
Optional. Optional reduced dimension for the output embedding. If set,
excessive values in the output embedding are truncated from the end.
Corresponds to the JSON property outputDimensionality
7780 7781 7782 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7780 def output_dimensionality @output_dimensionality end |
#task_type ⇒ String
Optional. The task type of the embedding.
Corresponds to the JSON property taskType
7785 7786 7787 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7785 def task_type @task_type end |
#title ⇒ String
Optional. An optional title for the text.
Corresponds to the JSON property title
7790 7791 7792 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7790 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7797 7798 7799 7800 7801 7802 7803 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7797 def update!(**args) @auto_truncate = args[:auto_truncate] if args.key?(:auto_truncate) @content = args[:content] if args.key?(:content) @output_dimensionality = args[:output_dimensionality] if args.key?(:output_dimensionality) @task_type = args[:task_type] if args.key?(:task_type) @title = args[:title] if args.key?(:title) end |