Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EmbedContentRequestEmbedContentConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Configurations for the EmbedContent API.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1EmbedContentRequestEmbedContentConfig

Returns a new instance of GoogleCloudAiplatformV1EmbedContentRequestEmbedContentConfig.



8937
8938
8939
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8937

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audio_track_extractionBoolean Also known as: audio_track_extraction?

Optional. Whether to extract audio from video content. Corresponds to the JSON property audioTrackExtraction

Returns:

  • (Boolean)


8903
8904
8905
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8903

def audio_track_extraction
  @audio_track_extraction
end

#auto_truncateBoolean Also known as: auto_truncate?

Optional. Whether to silently truncate the input content if it's longer than the maximum sequence length. Only applicable to text-only embedding models. Corresponds to the JSON property autoTruncate

Returns:

  • (Boolean)


8910
8911
8912
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8910

def auto_truncate
  @auto_truncate
end

#document_ocrBoolean Also known as: document_ocr?

Optional. Whether to enable OCR for document content. Corresponds to the JSON property documentOcr

Returns:

  • (Boolean)


8916
8917
8918
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8916

def document_ocr
  @document_ocr
end

#output_dimensionalityFixnum

Optional. Reduced dimension for the output embedding. If set, excessive values in the output embedding are truncated from the end. Corresponds to the JSON property outputDimensionality

Returns:

  • (Fixnum)


8923
8924
8925
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8923

def output_dimensionality
  @output_dimensionality
end

#task_typeString

Optional. The task type of the embedding. Only applicable to text-only embedding models. Corresponds to the JSON property taskType

Returns:

  • (String)


8929
8930
8931
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8929

def task_type
  @task_type
end

#titleString

Optional. The title for the text. Only applicable to text-only embedding models. Corresponds to the JSON property title

Returns:

  • (String)


8935
8936
8937
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8935

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8942
8943
8944
8945
8946
8947
8948
8949
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8942

def update!(**args)
  @audio_track_extraction = args[:audio_track_extraction] if args.key?(:audio_track_extraction)
  @auto_truncate = args[:auto_truncate] if args.key?(:auto_truncate)
  @document_ocr = args[:document_ocr] if args.key?(:document_ocr)
  @output_dimensionality = args[:output_dimensionality] if args.key?(:output_dimensionality)
  @task_type = args[:task_type] if args.key?(:task_type)
  @title = args[:title] if args.key?(:title)
end