Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EmbedContentRequestEmbedContentConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Configurations for the EmbedContent API.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1EmbedContentRequestEmbedContentConfig

Returns a new instance of GoogleCloudAiplatformV1EmbedContentRequestEmbedContentConfig.



8266
8267
8268
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8266

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audio_track_extractionBoolean Also known as: audio_track_extraction?

Optional. Whether to extract audio from video content. Corresponds to the JSON property audioTrackExtraction

Returns:

  • (Boolean)


8232
8233
8234
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8232

def audio_track_extraction
  @audio_track_extraction
end

#auto_truncateBoolean Also known as: auto_truncate?

Optional. Whether to silently truncate the input content if it's longer than the maximum sequence length. Only applicable to text-only embedding models. Corresponds to the JSON property autoTruncate

Returns:

  • (Boolean)


8239
8240
8241
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8239

def auto_truncate
  @auto_truncate
end

#document_ocrBoolean Also known as: document_ocr?

Optional. Whether to enable OCR for document content. Corresponds to the JSON property documentOcr

Returns:

  • (Boolean)


8245
8246
8247
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8245

def document_ocr
  @document_ocr
end

#output_dimensionalityFixnum

Optional. Reduced dimension for the output embedding. If set, excessive values in the output embedding are truncated from the end. Corresponds to the JSON property outputDimensionality

Returns:

  • (Fixnum)


8252
8253
8254
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8252

def output_dimensionality
  @output_dimensionality
end

#task_typeString

Optional. The task type of the embedding. Only applicable to text-only embedding models. Corresponds to the JSON property taskType

Returns:

  • (String)


8258
8259
8260
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8258

def task_type
  @task_type
end

#titleString

Optional. The title for the text. Only applicable to text-only embedding models. Corresponds to the JSON property title

Returns:

  • (String)


8264
8265
8266
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8264

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8271
8272
8273
8274
8275
8276
8277
8278
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8271

def update!(**args)
  @audio_track_extraction = args[:audio_track_extraction] if args.key?(:audio_track_extraction)
  @auto_truncate = args[:auto_truncate] if args.key?(:auto_truncate)
  @document_ocr = args[:document_ocr] if args.key?(:document_ocr)
  @output_dimensionality = args[:output_dimensionality] if args.key?(:output_dimensionality)
  @task_type = args[:task_type] if args.key?(:task_type)
  @title = args[:title] if args.key?(:title)
end