Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EmbedContentResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Response message for PredictionService.EmbedContent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1EmbedContentResponse

Returns a new instance of GoogleCloudAiplatformV1EmbedContentResponse.



8255
8256
8257
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8255

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#embeddingGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EmbedContentResponseEmbedding

A list of floats representing an embedding. Corresponds to the JSON property embedding



8241
8242
8243
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8241

def embedding
  @embedding
end

#truncatedBoolean Also known as: truncated?

Whether the input content was truncated before generating the embedding. Corresponds to the JSON property truncated

Returns:

  • (Boolean)


8246
8247
8248
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8246

def truncated
  @truncated
end

#usage_metadataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1UsageMetadata

Usage metadata about the content generation request and response. This message provides a detailed breakdown of token usage and other relevant metrics. Corresponds to the JSON property usageMetadata



8253
8254
8255
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8253

def 
  @usage_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8260
8261
8262
8263
8264
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8260

def update!(**args)
  @embedding = args[:embedding] if args.key?(:embedding)
  @truncated = args[:truncated] if args.key?(:truncated)
  @usage_metadata = args[:usage_metadata] if args.key?(:usage_metadata)
end