Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EmbedContentResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EmbedContentResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Response message for PredictionService.EmbedContent.
Instance Attribute Summary collapse
-
#embedding ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EmbedContentResponseEmbedding
A list of floats representing an embedding.
-
#truncated ⇒ Boolean
(also: #truncated?)
Whether the input content was truncated before generating the embedding.
-
#usage_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1UsageMetadata
Usage metadata about the content generation request and response.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1EmbedContentResponse
constructor
A new instance of GoogleCloudAiplatformV1EmbedContentResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1EmbedContentResponse
Returns a new instance of GoogleCloudAiplatformV1EmbedContentResponse.
7852 7853 7854 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7852 def initialize(**args) update!(**args) end |
Instance Attribute Details
#embedding ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EmbedContentResponseEmbedding
A list of floats representing an embedding.
Corresponds to the JSON property embedding
7838 7839 7840 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7838 def @embedding end |
#truncated ⇒ Boolean Also known as: truncated?
Whether the input content was truncated before generating the embedding.
Corresponds to the JSON property truncated
7843 7844 7845 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7843 def truncated @truncated end |
#usage_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1UsageMetadata
Usage metadata about the content generation request and response. This message
provides a detailed breakdown of token usage and other relevant metrics.
Corresponds to the JSON property usageMetadata
7850 7851 7852 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7850 def @usage_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7857 7858 7859 7860 7861 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7857 def update!(**args) @embedding = args[:embedding] if args.key?(:embedding) @truncated = args[:truncated] if args.key?(:truncated) @usage_metadata = args[:usage_metadata] if args.key?(:usage_metadata) end |