Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1EncryptionSpec

Returns a new instance of GoogleCloudAiplatformV1EncryptionSpec.



8506
8507
8508
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8506

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kms_key_nameString

Required. Resource name of the Cloud KMS key used to protect the resource. The Cloud KMS key must be in the same region as the resource. It must have the format projects/project/locations/location/keyRings/key_ring/cryptoKeys/ crypto_key`. Corresponds to the JSON propertykmsKeyName`

Returns:

  • (String)


8504
8505
8506
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8504

def kms_key_name
  @kms_key_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8511
8512
8513
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8511

def update!(**args)
  @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name)
end