Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.
Instance Attribute Summary collapse
-
#kms_key_name ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1EncryptionSpec
constructor
A new instance of GoogleCloudAiplatformV1EncryptionSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1EncryptionSpec
Returns a new instance of GoogleCloudAiplatformV1EncryptionSpec.
7871 7872 7873 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7871 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kms_key_name ⇒ String
Required. Resource name of the Cloud KMS key used to protect the resource. The
Cloud KMS key must be in the same region as the resource. It must have the
format projects/project/locations/location/keyRings/key_ring/cryptoKeys/
crypto_key`.
Corresponds to the JSON propertykmsKeyName`
7869 7870 7871 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7869 def kms_key_name @kms_key_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7876 7877 7878 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7876 def update!(**args) @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name) end |