Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Endpoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Models are deployed into it, and afterwards Endpoint is called to obtain predictions and explanations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Endpoint

Returns a new instance of GoogleCloudAiplatformV1Endpoint.



8033
8034
8035
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8033

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_connection_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ClientConnectionConfig

Configurations (e.g. inference timeout) that are applied on your endpoints. Corresponds to the JSON property clientConnectionConfig



7889
7890
7891
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7889

def client_connection_config
  @client_connection_config
end

#create_timeString

Output only. Timestamp when this Endpoint was created. Corresponds to the JSON property createTime

Returns:

  • (String)


7894
7895
7896
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7894

def create_time
  @create_time
end

#dedicated_endpoint_dnsString

Output only. DNS of the dedicated endpoint. Will only be populated if dedicated_endpoint_enabled is true. Depending on the features enabled, uid might be a random number or a string. For example, if fast_tryout is enabled, uid will be fasttryout. Format: https://endpoint_id.region-uid. prediction.vertexai.goog. Corresponds to the JSON property dedicatedEndpointDns

Returns:

  • (String)


7903
7904
7905
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7903

def dedicated_endpoint_dns
  @dedicated_endpoint_dns
end

#dedicated_endpoint_enabledBoolean Also known as: dedicated_endpoint_enabled?

If true, the endpoint will be exposed through a dedicated DNS [Endpoint. dedicated_endpoint_dns]. Your request to the dedicated DNS will be isolated from other users' traffic and will have better performance and reliability. Note: Once you enabled dedicated endpoint, you won't be able to send request to the shared DNS region-aiplatform.googleapis.com. The limitation will be removed soon. Corresponds to the JSON property dedicatedEndpointEnabled

Returns:

  • (Boolean)


7913
7914
7915
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7913

def dedicated_endpoint_enabled
  @dedicated_endpoint_enabled
end

#deployed_modelsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployedModel>

Output only. The models deployed in this Endpoint. To add or remove DeployedModels use EndpointService.DeployModel and EndpointService. UndeployModel respectively. Corresponds to the JSON property deployedModels



7921
7922
7923
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7921

def deployed_models
  @deployed_models
end

#descriptionString

The description of the Endpoint. Corresponds to the JSON property description

Returns:

  • (String)


7926
7927
7928
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7926

def description
  @description
end

#display_nameString

Required. The display name of the Endpoint. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


7932
7933
7934
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7932

def display_name
  @display_name
end

#enable_private_service_connectBoolean Also known as: enable_private_service_connect?

Deprecated: If true, expose the Endpoint via private service connect. Only one of the fields, network or enable_private_service_connect, can be set. Corresponds to the JSON property enablePrivateServiceConnect

Returns:

  • (Boolean)


7938
7939
7940
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7938

def enable_private_service_connect
  @enable_private_service_connect
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



7945
7946
7947
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7945

def encryption_spec
  @encryption_spec
end

#etagString

Used to perform consistent read-modify-write updates. If not set, a blind " overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


7951
7952
7953
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7951

def etag
  @etag
end

#gdc_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GdcConfig

Google Distributed Cloud (GDC) config. Corresponds to the JSON property gdcConfig



7956
7957
7958
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7956

def gdc_config
  @gdc_config
end

#gen_ai_advanced_features_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GenAiAdvancedFeaturesConfig

Configuration for GenAiAdvancedFeatures. Corresponds to the JSON property genAiAdvancedFeaturesConfig



7961
7962
7963
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7961

def gen_ai_advanced_features_config
  @gen_ai_advanced_features_config
end

#labelsHash<String,String>

The labels with user-defined metadata to organize your Endpoints. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


7970
7971
7972
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7970

def labels
  @labels
end

#model_deployment_monitoring_jobString

Output only. Resource name of the Model Monitoring job associated with this Endpoint if monitoring is enabled by JobService. CreateModelDeploymentMonitoringJob. Format: projects/project/locations/ location/modelDeploymentMonitoringJobs/model_deployment_monitoring_job` Corresponds to the JSON propertymodelDeploymentMonitoringJob`

Returns:

  • (String)


7978
7979
7980
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7978

def model_deployment_monitoring_job
  @model_deployment_monitoring_job
end

#nameString

Identifier. The resource name of the Endpoint. Corresponds to the JSON property name

Returns:

  • (String)


7983
7984
7985
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7983

def name
  @name
end

#networkString

Optional. The full name of the Google Compute Engine network to which the Endpoint should be peered. Private services access must already be configured for the network. If left unspecified, the Endpoint is not peered with any network. Only one of the fields, network or enable_private_service_connect, can be set. Format: projects/project/global/networks/network. Where projectis a project number, as in `12345`, andnetwork`is network name. Corresponds to the JSON propertynetwork`

Returns:

  • (String)


7995
7996
7997
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7995

def network
  @network
end

#predict_request_response_logging_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PredictRequestResponseLoggingConfig

Configuration for logging request-response to a BigQuery table. Corresponds to the JSON property predictRequestResponseLoggingConfig



8000
8001
8002
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8000

def predict_request_response_logging_config
  @predict_request_response_logging_config
end

#private_service_connect_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PrivateServiceConnectConfig

Represents configuration for private service connect. Corresponds to the JSON property privateServiceConnectConfig



8005
8006
8007
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8005

def private_service_connect_config
  @private_service_connect_config
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


8010
8011
8012
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8010

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


8016
8017
8018
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8016

def satisfies_pzs
  @satisfies_pzs
end

#traffic_splitHash<String,Fixnum>

A map from a DeployedModel's ID to the percentage of this Endpoint's traffic that should be forwarded to that DeployedModel. If a DeployedModel's ID is not listed in this map, then it receives no traffic. The traffic percentage values must add up to 100, or map must be empty if the Endpoint is to not accept any traffic at a moment. Corresponds to the JSON property trafficSplit

Returns:

  • (Hash<String,Fixnum>)


8026
8027
8028
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8026

def traffic_split
  @traffic_split
end

#update_timeString

Output only. Timestamp when this Endpoint was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


8031
8032
8033
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8031

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8038
8039
8040
8041
8042
8043
8044
8045
8046
8047
8048
8049
8050
8051
8052
8053
8054
8055
8056
8057
8058
8059
8060
8061
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8038

def update!(**args)
  @client_connection_config = args[:client_connection_config] if args.key?(:client_connection_config)
  @create_time = args[:create_time] if args.key?(:create_time)
  @dedicated_endpoint_dns = args[:dedicated_endpoint_dns] if args.key?(:dedicated_endpoint_dns)
  @dedicated_endpoint_enabled = args[:dedicated_endpoint_enabled] if args.key?(:dedicated_endpoint_enabled)
  @deployed_models = args[:deployed_models] if args.key?(:deployed_models)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @enable_private_service_connect = args[:enable_private_service_connect] if args.key?(:enable_private_service_connect)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @etag = args[:etag] if args.key?(:etag)
  @gdc_config = args[:gdc_config] if args.key?(:gdc_config)
  @gen_ai_advanced_features_config = args[:gen_ai_advanced_features_config] if args.key?(:gen_ai_advanced_features_config)
  @labels = args[:labels] if args.key?(:labels)
  @model_deployment_monitoring_job = args[:model_deployment_monitoring_job] if args.key?(:model_deployment_monitoring_job)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @predict_request_response_logging_config = args[:predict_request_response_logging_config] if args.key?(:predict_request_response_logging_config)
  @private_service_connect_config = args[:private_service_connect_config] if args.key?(:private_service_connect_config)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @traffic_split = args[:traffic_split] if args.key?(:traffic_split)
  @update_time = args[:update_time] if args.key?(:update_time)
end