Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Endpoint
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Endpoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Models are deployed into it, and afterwards Endpoint is called to obtain predictions and explanations.
Instance Attribute Summary collapse
-
#client_connection_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ClientConnectionConfig
Configurations (e.g. inference timeout) that are applied on your endpoints.
-
#create_time ⇒ String
Output only.
-
#dedicated_endpoint_dns ⇒ String
Output only.
-
#dedicated_endpoint_enabled ⇒ Boolean
(also: #dedicated_endpoint_enabled?)
If true, the endpoint will be exposed through a dedicated DNS [Endpoint. dedicated_endpoint_dns].
-
#deployed_models ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployedModel>
Output only.
-
#description ⇒ String
The description of the Endpoint.
-
#display_name ⇒ String
Required.
-
#enable_private_service_connect ⇒ Boolean
(also: #enable_private_service_connect?)
Deprecated: If true, expose the Endpoint via private service connect.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top- level resource.
-
#etag ⇒ String
Used to perform consistent read-modify-write updates.
-
#gdc_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GdcConfig
Google Distributed Cloud (GDC) config.
-
#gen_ai_advanced_features_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenAiAdvancedFeaturesConfig
Configuration for GenAiAdvancedFeatures.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your Endpoints.
-
#model_deployment_monitoring_job ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#network ⇒ String
Optional.
-
#predict_request_response_logging_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PredictRequestResponseLoggingConfig
Configuration for logging request-response to a BigQuery table.
-
#private_service_connect_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PrivateServiceConnectConfig
Represents configuration for private service connect.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#traffic_split ⇒ Hash<String,Fixnum>
A map from a DeployedModel's ID to the percentage of this Endpoint's traffic that should be forwarded to that DeployedModel.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Endpoint
constructor
A new instance of GoogleCloudAiplatformV1Endpoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Endpoint
Returns a new instance of GoogleCloudAiplatformV1Endpoint.
7378 7379 7380 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7378 def initialize(**args) update!(**args) end |
Instance Attribute Details
#client_connection_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ClientConnectionConfig
Configurations (e.g. inference timeout) that are applied on your endpoints.
Corresponds to the JSON property clientConnectionConfig
7234 7235 7236 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7234 def client_connection_config @client_connection_config end |
#create_time ⇒ String
Output only. Timestamp when this Endpoint was created.
Corresponds to the JSON property createTime
7239 7240 7241 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7239 def create_time @create_time end |
#dedicated_endpoint_dns ⇒ String
Output only. DNS of the dedicated endpoint. Will only be populated if
dedicated_endpoint_enabled is true. Depending on the features enabled, uid
might be a random number or a string. For example, if fast_tryout is enabled,
uid will be fasttryout. Format: https://endpoint_id.region-uid.
prediction.vertexai.goog.
Corresponds to the JSON property dedicatedEndpointDns
7248 7249 7250 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7248 def dedicated_endpoint_dns @dedicated_endpoint_dns end |
#dedicated_endpoint_enabled ⇒ Boolean Also known as: dedicated_endpoint_enabled?
If true, the endpoint will be exposed through a dedicated DNS [Endpoint.
dedicated_endpoint_dns]. Your request to the dedicated DNS will be isolated
from other users' traffic and will have better performance and reliability.
Note: Once you enabled dedicated endpoint, you won't be able to send request
to the shared DNS region-aiplatform.googleapis.com. The limitation will be
removed soon.
Corresponds to the JSON property dedicatedEndpointEnabled
7258 7259 7260 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7258 def dedicated_endpoint_enabled @dedicated_endpoint_enabled end |
#deployed_models ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployedModel>
Output only. The models deployed in this Endpoint. To add or remove
DeployedModels use EndpointService.DeployModel and EndpointService.
UndeployModel respectively.
Corresponds to the JSON property deployedModels
7266 7267 7268 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7266 def deployed_models @deployed_models end |
#description ⇒ String
The description of the Endpoint.
Corresponds to the JSON property description
7271 7272 7273 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7271 def description @description end |
#display_name ⇒ String
Required. The display name of the Endpoint. The name can be up to 128
characters long and can consist of any UTF-8 characters.
Corresponds to the JSON property displayName
7277 7278 7279 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7277 def display_name @display_name end |
#enable_private_service_connect ⇒ Boolean Also known as: enable_private_service_connect?
Deprecated: If true, expose the Endpoint via private service connect. Only one
of the fields, network or enable_private_service_connect, can be set.
Corresponds to the JSON property enablePrivateServiceConnect
7283 7284 7285 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7283 def enable_private_service_connect @enable_private_service_connect end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top-
level resource.
Corresponds to the JSON property encryptionSpec
7290 7291 7292 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7290 def encryption_spec @encryption_spec end |
#etag ⇒ String
Used to perform consistent read-modify-write updates. If not set, a blind "
overwrite" update happens.
Corresponds to the JSON property etag
7296 7297 7298 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7296 def etag @etag end |
#gdc_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GdcConfig
Google Distributed Cloud (GDC) config.
Corresponds to the JSON property gdcConfig
7301 7302 7303 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7301 def gdc_config @gdc_config end |
#gen_ai_advanced_features_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenAiAdvancedFeaturesConfig
Configuration for GenAiAdvancedFeatures.
Corresponds to the JSON property genAiAdvancedFeaturesConfig
7306 7307 7308 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7306 def gen_ai_advanced_features_config @gen_ai_advanced_features_config end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your Endpoints. Label keys
and values can be no longer than 64 characters (Unicode codepoints), can only
contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. See https://goo.gl/xmQnxf for more
information and examples of labels.
Corresponds to the JSON property labels
7315 7316 7317 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7315 def labels @labels end |
#model_deployment_monitoring_job ⇒ String
Output only. Resource name of the Model Monitoring job associated with this
Endpoint if monitoring is enabled by JobService.
CreateModelDeploymentMonitoringJob. Format: projects/project/locations/
location/modelDeploymentMonitoringJobs/model_deployment_monitoring_job`
Corresponds to the JSON propertymodelDeploymentMonitoringJob`
7323 7324 7325 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7323 def model_deployment_monitoring_job @model_deployment_monitoring_job end |
#name ⇒ String
Output only. The resource name of the Endpoint.
Corresponds to the JSON property name
7328 7329 7330 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7328 def name @name end |
#network ⇒ String
Optional. The full name of the Google Compute Engine network to which the
Endpoint should be peered. Private services access must already be configured
for the network. If left unspecified, the Endpoint is not peered with any
network. Only one of the fields, network or enable_private_service_connect,
can be set. Format: projects/project/global/networks/network. Where
projectis a project number, as in `12345`, andnetwork`is network name.
Corresponds to the JSON propertynetwork`
7340 7341 7342 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7340 def network @network end |
#predict_request_response_logging_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PredictRequestResponseLoggingConfig
Configuration for logging request-response to a BigQuery table.
Corresponds to the JSON property predictRequestResponseLoggingConfig
7345 7346 7347 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7345 def predict_request_response_logging_config @predict_request_response_logging_config end |
#private_service_connect_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PrivateServiceConnectConfig
Represents configuration for private service connect.
Corresponds to the JSON property privateServiceConnectConfig
7350 7351 7352 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7350 def private_service_connect_config @private_service_connect_config end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
7355 7356 7357 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7355 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
7361 7362 7363 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7361 def satisfies_pzs @satisfies_pzs end |
#traffic_split ⇒ Hash<String,Fixnum>
A map from a DeployedModel's ID to the percentage of this Endpoint's traffic
that should be forwarded to that DeployedModel. If a DeployedModel's ID is not
listed in this map, then it receives no traffic. The traffic percentage values
must add up to 100, or map must be empty if the Endpoint is to not accept any
traffic at a moment.
Corresponds to the JSON property trafficSplit
7371 7372 7373 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7371 def traffic_split @traffic_split end |
#update_time ⇒ String
Output only. Timestamp when this Endpoint was last updated.
Corresponds to the JSON property updateTime
7376 7377 7378 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7376 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7383 7384 7385 7386 7387 7388 7389 7390 7391 7392 7393 7394 7395 7396 7397 7398 7399 7400 7401 7402 7403 7404 7405 7406 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7383 def update!(**args) @client_connection_config = args[:client_connection_config] if args.key?(:client_connection_config) @create_time = args[:create_time] if args.key?(:create_time) @dedicated_endpoint_dns = args[:dedicated_endpoint_dns] if args.key?(:dedicated_endpoint_dns) @dedicated_endpoint_enabled = args[:dedicated_endpoint_enabled] if args.key?(:dedicated_endpoint_enabled) @deployed_models = args[:deployed_models] if args.key?(:deployed_models) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @enable_private_service_connect = args[:enable_private_service_connect] if args.key?(:enable_private_service_connect) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @etag = args[:etag] if args.key?(:etag) @gdc_config = args[:gdc_config] if args.key?(:gdc_config) @gen_ai_advanced_features_config = args[:gen_ai_advanced_features_config] if args.key?(:gen_ai_advanced_features_config) @labels = args[:labels] if args.key?(:labels) @model_deployment_monitoring_job = args[:model_deployment_monitoring_job] if args.key?(:model_deployment_monitoring_job) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @predict_request_response_logging_config = args[:predict_request_response_logging_config] if args.key?(:predict_request_response_logging_config) @private_service_connect_config = args[:private_service_connect_config] if args.key?(:private_service_connect_config) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @traffic_split = args[:traffic_split] if args.key?(:traffic_split) @update_time = args[:update_time] if args.key?(:update_time) end |