Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Endpoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Models are deployed into it, and afterwards Endpoint is called to obtain predictions and explanations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Endpoint

Returns a new instance of GoogleCloudAiplatformV1Endpoint.



7344
7345
7346
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7344

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_connection_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ClientConnectionConfig

Configurations (e.g. inference timeout) that are applied on your endpoints. Corresponds to the JSON property clientConnectionConfig



7205
7206
7207
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7205

def client_connection_config
  @client_connection_config
end

#create_timeString

Output only. Timestamp when this Endpoint was created. Corresponds to the JSON property createTime

Returns:

  • (String)


7210
7211
7212
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7210

def create_time
  @create_time
end

#dedicated_endpoint_dnsString

Output only. DNS of the dedicated endpoint. Will only be populated if dedicated_endpoint_enabled is true. Depending on the features enabled, uid might be a random number or a string. For example, if fast_tryout is enabled, uid will be fasttryout. Format: https://endpoint_id.region-uid. prediction.vertexai.goog. Corresponds to the JSON property dedicatedEndpointDns

Returns:

  • (String)


7219
7220
7221
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7219

def dedicated_endpoint_dns
  @dedicated_endpoint_dns
end

#dedicated_endpoint_enabledBoolean Also known as: dedicated_endpoint_enabled?

If true, the endpoint will be exposed through a dedicated DNS [Endpoint. dedicated_endpoint_dns]. Your request to the dedicated DNS will be isolated from other users' traffic and will have better performance and reliability. Note: Once you enabled dedicated endpoint, you won't be able to send request to the shared DNS region-aiplatform.googleapis.com. The limitation will be removed soon. Corresponds to the JSON property dedicatedEndpointEnabled

Returns:

  • (Boolean)


7229
7230
7231
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7229

def dedicated_endpoint_enabled
  @dedicated_endpoint_enabled
end

#deployed_modelsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployedModel>

Output only. The models deployed in this Endpoint. To add or remove DeployedModels use EndpointService.DeployModel and EndpointService. UndeployModel respectively. Corresponds to the JSON property deployedModels



7237
7238
7239
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7237

def deployed_models
  @deployed_models
end

#descriptionString

The description of the Endpoint. Corresponds to the JSON property description

Returns:

  • (String)


7242
7243
7244
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7242

def description
  @description
end

#display_nameString

Required. The display name of the Endpoint. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


7248
7249
7250
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7248

def display_name
  @display_name
end

#enable_private_service_connectBoolean Also known as: enable_private_service_connect?

Deprecated: If true, expose the Endpoint via private service connect. Only one of the fields, network or enable_private_service_connect, can be set. Corresponds to the JSON property enablePrivateServiceConnect

Returns:

  • (Boolean)


7254
7255
7256
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7254

def enable_private_service_connect
  @enable_private_service_connect
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key spec that can be applied to a top- level resource. Corresponds to the JSON property encryptionSpec



7261
7262
7263
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7261

def encryption_spec
  @encryption_spec
end

#etagString

Used to perform consistent read-modify-write updates. If not set, a blind " overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


7267
7268
7269
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7267

def etag
  @etag
end

#gen_ai_advanced_features_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GenAiAdvancedFeaturesConfig

Configuration for GenAiAdvancedFeatures. Corresponds to the JSON property genAiAdvancedFeaturesConfig



7272
7273
7274
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7272

def gen_ai_advanced_features_config
  @gen_ai_advanced_features_config
end

#labelsHash<String,String>

The labels with user-defined metadata to organize your Endpoints. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


7281
7282
7283
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7281

def labels
  @labels
end

#model_deployment_monitoring_jobString

Output only. Resource name of the Model Monitoring job associated with this Endpoint if monitoring is enabled by JobService. CreateModelDeploymentMonitoringJob. Format: projects/project/locations/ location/modelDeploymentMonitoringJobs/model_deployment_monitoring_job` Corresponds to the JSON propertymodelDeploymentMonitoringJob`

Returns:

  • (String)


7289
7290
7291
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7289

def model_deployment_monitoring_job
  @model_deployment_monitoring_job
end

#nameString

Output only. The resource name of the Endpoint. Corresponds to the JSON property name

Returns:

  • (String)


7294
7295
7296
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7294

def name
  @name
end

#networkString

Optional. The full name of the Google Compute Engine network to which the Endpoint should be peered. Private services access must already be configured for the network. If left unspecified, the Endpoint is not peered with any network. Only one of the fields, network or enable_private_service_connect, can be set. Format: projects/project/global/networks/network. Where projectis a project number, as in `12345`, andnetwork`is network name. Corresponds to the JSON propertynetwork`

Returns:

  • (String)


7306
7307
7308
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7306

def network
  @network
end

#predict_request_response_logging_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PredictRequestResponseLoggingConfig

Configuration for logging request-response to a BigQuery table. Corresponds to the JSON property predictRequestResponseLoggingConfig



7311
7312
7313
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7311

def predict_request_response_logging_config
  @predict_request_response_logging_config
end

#private_service_connect_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PrivateServiceConnectConfig

Represents configuration for private service connect. Corresponds to the JSON property privateServiceConnectConfig



7316
7317
7318
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7316

def private_service_connect_config
  @private_service_connect_config
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


7321
7322
7323
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7321

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


7327
7328
7329
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7327

def satisfies_pzs
  @satisfies_pzs
end

#traffic_splitHash<String,Fixnum>

A map from a DeployedModel's ID to the percentage of this Endpoint's traffic that should be forwarded to that DeployedModel. If a DeployedModel's ID is not listed in this map, then it receives no traffic. The traffic percentage values must add up to 100, or map must be empty if the Endpoint is to not accept any traffic at a moment. Corresponds to the JSON property trafficSplit

Returns:

  • (Hash<String,Fixnum>)


7337
7338
7339
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7337

def traffic_split
  @traffic_split
end

#update_timeString

Output only. Timestamp when this Endpoint was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


7342
7343
7344
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7342

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7349
7350
7351
7352
7353
7354
7355
7356
7357
7358
7359
7360
7361
7362
7363
7364
7365
7366
7367
7368
7369
7370
7371
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7349

def update!(**args)
  @client_connection_config = args[:client_connection_config] if args.key?(:client_connection_config)
  @create_time = args[:create_time] if args.key?(:create_time)
  @dedicated_endpoint_dns = args[:dedicated_endpoint_dns] if args.key?(:dedicated_endpoint_dns)
  @dedicated_endpoint_enabled = args[:dedicated_endpoint_enabled] if args.key?(:dedicated_endpoint_enabled)
  @deployed_models = args[:deployed_models] if args.key?(:deployed_models)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @enable_private_service_connect = args[:enable_private_service_connect] if args.key?(:enable_private_service_connect)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @etag = args[:etag] if args.key?(:etag)
  @gen_ai_advanced_features_config = args[:gen_ai_advanced_features_config] if args.key?(:gen_ai_advanced_features_config)
  @labels = args[:labels] if args.key?(:labels)
  @model_deployment_monitoring_job = args[:model_deployment_monitoring_job] if args.key?(:model_deployment_monitoring_job)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @predict_request_response_logging_config = args[:predict_request_response_logging_config] if args.key?(:predict_request_response_logging_config)
  @private_service_connect_config = args[:private_service_connect_config] if args.key?(:private_service_connect_config)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @traffic_split = args[:traffic_split] if args.key?(:traffic_split)
  @update_time = args[:update_time] if args.key?(:update_time)
end