Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Endpoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Models are deployed into it, and afterwards Endpoint is called to obtain predictions and explanations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Endpoint

Returns a new instance of GoogleCloudAiplatformV1Endpoint.



6796
6797
6798
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6796

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_connection_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ClientConnectionConfig

Configurations (e.g. inference timeout) that are applied on your endpoints. Corresponds to the JSON property clientConnectionConfig



6657
6658
6659
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6657

def client_connection_config
  @client_connection_config
end

#create_timeString

Output only. Timestamp when this Endpoint was created. Corresponds to the JSON property createTime

Returns:

  • (String)


6662
6663
6664
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6662

def create_time
  @create_time
end

#dedicated_endpoint_dnsString

Output only. DNS of the dedicated endpoint. Will only be populated if dedicated_endpoint_enabled is true. Depending on the features enabled, uid might be a random number or a string. For example, if fast_tryout is enabled, uid will be fasttryout. Format: https://endpoint_id.region-uid. prediction.vertexai.goog. Corresponds to the JSON property dedicatedEndpointDns

Returns:

  • (String)


6671
6672
6673
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6671

def dedicated_endpoint_dns
  @dedicated_endpoint_dns
end

#dedicated_endpoint_enabledBoolean Also known as: dedicated_endpoint_enabled?

If true, the endpoint will be exposed through a dedicated DNS [Endpoint. dedicated_endpoint_dns]. Your request to the dedicated DNS will be isolated from other users' traffic and will have better performance and reliability. Note: Once you enabled dedicated endpoint, you won't be able to send request to the shared DNS region-aiplatform.googleapis.com. The limitation will be removed soon. Corresponds to the JSON property dedicatedEndpointEnabled

Returns:

  • (Boolean)


6681
6682
6683
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6681

def dedicated_endpoint_enabled
  @dedicated_endpoint_enabled
end

#deployed_modelsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployedModel>

Output only. The models deployed in this Endpoint. To add or remove DeployedModels use EndpointService.DeployModel and EndpointService. UndeployModel respectively. Corresponds to the JSON property deployedModels



6689
6690
6691
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6689

def deployed_models
  @deployed_models
end

#descriptionString

The description of the Endpoint. Corresponds to the JSON property description

Returns:

  • (String)


6694
6695
6696
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6694

def description
  @description
end

#display_nameString

Required. The display name of the Endpoint. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


6700
6701
6702
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6700

def display_name
  @display_name
end

#enable_private_service_connectBoolean Also known as: enable_private_service_connect?

Deprecated: If true, expose the Endpoint via private service connect. Only one of the fields, network or enable_private_service_connect, can be set. Corresponds to the JSON property enablePrivateServiceConnect

Returns:

  • (Boolean)


6706
6707
6708
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6706

def enable_private_service_connect
  @enable_private_service_connect
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key spec that can be applied to a top- level resource. Corresponds to the JSON property encryptionSpec



6713
6714
6715
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6713

def encryption_spec
  @encryption_spec
end

#etagString

Used to perform consistent read-modify-write updates. If not set, a blind " overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


6719
6720
6721
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6719

def etag
  @etag
end

#gen_ai_advanced_features_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GenAiAdvancedFeaturesConfig

Configuration for GenAiAdvancedFeatures. Corresponds to the JSON property genAiAdvancedFeaturesConfig



6724
6725
6726
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6724

def gen_ai_advanced_features_config
  @gen_ai_advanced_features_config
end

#labelsHash<String,String>

The labels with user-defined metadata to organize your Endpoints. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


6733
6734
6735
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6733

def labels
  @labels
end

#model_deployment_monitoring_jobString

Output only. Resource name of the Model Monitoring job associated with this Endpoint if monitoring is enabled by JobService. CreateModelDeploymentMonitoringJob. Format: projects/project/locations/ location/modelDeploymentMonitoringJobs/model_deployment_monitoring_job` Corresponds to the JSON propertymodelDeploymentMonitoringJob`

Returns:

  • (String)


6741
6742
6743
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6741

def model_deployment_monitoring_job
  @model_deployment_monitoring_job
end

#nameString

Output only. The resource name of the Endpoint. Corresponds to the JSON property name

Returns:

  • (String)


6746
6747
6748
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6746

def name
  @name
end

#networkString

Optional. The full name of the Google Compute Engine network to which the Endpoint should be peered. Private services access must already be configured for the network. If left unspecified, the Endpoint is not peered with any network. Only one of the fields, network or enable_private_service_connect, can be set. Format: projects/project/global/networks/network. Where projectis a project number, as in `12345`, andnetwork`is network name. Corresponds to the JSON propertynetwork`

Returns:

  • (String)


6758
6759
6760
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6758

def network
  @network
end

#predict_request_response_logging_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PredictRequestResponseLoggingConfig

Configuration for logging request-response to a BigQuery table. Corresponds to the JSON property predictRequestResponseLoggingConfig



6763
6764
6765
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6763

def predict_request_response_logging_config
  @predict_request_response_logging_config
end

#private_service_connect_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PrivateServiceConnectConfig

Represents configuration for private service connect. Corresponds to the JSON property privateServiceConnectConfig



6768
6769
6770
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6768

def private_service_connect_config
  @private_service_connect_config
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


6773
6774
6775
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6773

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


6779
6780
6781
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6779

def satisfies_pzs
  @satisfies_pzs
end

#traffic_splitHash<String,Fixnum>

A map from a DeployedModel's ID to the percentage of this Endpoint's traffic that should be forwarded to that DeployedModel. If a DeployedModel's ID is not listed in this map, then it receives no traffic. The traffic percentage values must add up to 100, or map must be empty if the Endpoint is to not accept any traffic at a moment. Corresponds to the JSON property trafficSplit

Returns:

  • (Hash<String,Fixnum>)


6789
6790
6791
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6789

def traffic_split
  @traffic_split
end

#update_timeString

Output only. Timestamp when this Endpoint was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


6794
6795
6796
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6794

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6801
6802
6803
6804
6805
6806
6807
6808
6809
6810
6811
6812
6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
6823
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6801

def update!(**args)
  @client_connection_config = args[:client_connection_config] if args.key?(:client_connection_config)
  @create_time = args[:create_time] if args.key?(:create_time)
  @dedicated_endpoint_dns = args[:dedicated_endpoint_dns] if args.key?(:dedicated_endpoint_dns)
  @dedicated_endpoint_enabled = args[:dedicated_endpoint_enabled] if args.key?(:dedicated_endpoint_enabled)
  @deployed_models = args[:deployed_models] if args.key?(:deployed_models)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @enable_private_service_connect = args[:enable_private_service_connect] if args.key?(:enable_private_service_connect)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @etag = args[:etag] if args.key?(:etag)
  @gen_ai_advanced_features_config = args[:gen_ai_advanced_features_config] if args.key?(:gen_ai_advanced_features_config)
  @labels = args[:labels] if args.key?(:labels)
  @model_deployment_monitoring_job = args[:model_deployment_monitoring_job] if args.key?(:model_deployment_monitoring_job)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @predict_request_response_logging_config = args[:predict_request_response_logging_config] if args.key?(:predict_request_response_logging_config)
  @private_service_connect_config = args[:private_service_connect_config] if args.key?(:private_service_connect_config)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @traffic_split = args[:traffic_split] if args.key?(:traffic_split)
  @update_time = args[:update_time] if args.key?(:update_time)
end