Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Endpoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Models are deployed into it, and afterwards Endpoint is called to obtain predictions and explanations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Endpoint

Returns a new instance of GoogleCloudAiplatformV1Endpoint.



6677
6678
6679
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6677

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_connection_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ClientConnectionConfig

Configurations (e.g. inference timeout) that are applied on your endpoints. Corresponds to the JSON property clientConnectionConfig



6540
6541
6542
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6540

def client_connection_config
  @client_connection_config
end

#create_timeString

Output only. Timestamp when this Endpoint was created. Corresponds to the JSON property createTime

Returns:

  • (String)


6545
6546
6547
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6545

def create_time
  @create_time
end

#dedicated_endpoint_dnsString

Output only. DNS of the dedicated endpoint. Will only be populated if dedicated_endpoint_enabled is true. Format: https://endpoint_id.region- project_number.prediction.vertexai.goog. Corresponds to the JSON property dedicatedEndpointDns

Returns:

  • (String)


6552
6553
6554
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6552

def dedicated_endpoint_dns
  @dedicated_endpoint_dns
end

#dedicated_endpoint_enabledBoolean Also known as: dedicated_endpoint_enabled?

If true, the endpoint will be exposed through a dedicated DNS [Endpoint. dedicated_endpoint_dns]. Your request to the dedicated DNS will be isolated from other users' traffic and will have better performance and reliability. Note: Once you enabled dedicated endpoint, you won't be able to send request to the shared DNS region-aiplatform.googleapis.com. The limitation will be removed soon. Corresponds to the JSON property dedicatedEndpointEnabled

Returns:

  • (Boolean)


6562
6563
6564
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6562

def dedicated_endpoint_enabled
  @dedicated_endpoint_enabled
end

#deployed_modelsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployedModel>

Output only. The models deployed in this Endpoint. To add or remove DeployedModels use EndpointService.DeployModel and EndpointService. UndeployModel respectively. Corresponds to the JSON property deployedModels



6570
6571
6572
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6570

def deployed_models
  @deployed_models
end

#descriptionString

The description of the Endpoint. Corresponds to the JSON property description

Returns:

  • (String)


6575
6576
6577
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6575

def description
  @description
end

#display_nameString

Required. The display name of the Endpoint. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


6581
6582
6583
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6581

def display_name
  @display_name
end

#enable_private_service_connectBoolean Also known as: enable_private_service_connect?

Deprecated: If true, expose the Endpoint via private service connect. Only one of the fields, network or enable_private_service_connect, can be set. Corresponds to the JSON property enablePrivateServiceConnect

Returns:

  • (Boolean)


6587
6588
6589
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6587

def enable_private_service_connect
  @enable_private_service_connect
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key spec that can be applied to a top- level resource. Corresponds to the JSON property encryptionSpec



6594
6595
6596
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6594

def encryption_spec
  @encryption_spec
end

#etagString

Used to perform consistent read-modify-write updates. If not set, a blind " overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


6600
6601
6602
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6600

def etag
  @etag
end

#gen_ai_advanced_features_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GenAiAdvancedFeaturesConfig

Configuration for GenAiAdvancedFeatures. Corresponds to the JSON property genAiAdvancedFeaturesConfig



6605
6606
6607
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6605

def gen_ai_advanced_features_config
  @gen_ai_advanced_features_config
end

#labelsHash<String,String>

The labels with user-defined metadata to organize your Endpoints. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


6614
6615
6616
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6614

def labels
  @labels
end

#model_deployment_monitoring_jobString

Output only. Resource name of the Model Monitoring job associated with this Endpoint if monitoring is enabled by JobService. CreateModelDeploymentMonitoringJob. Format: projects/project/locations/ location/modelDeploymentMonitoringJobs/model_deployment_monitoring_job` Corresponds to the JSON propertymodelDeploymentMonitoringJob`

Returns:

  • (String)


6622
6623
6624
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6622

def model_deployment_monitoring_job
  @model_deployment_monitoring_job
end

#nameString

Output only. The resource name of the Endpoint. Corresponds to the JSON property name

Returns:

  • (String)


6627
6628
6629
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6627

def name
  @name
end

#networkString

Optional. The full name of the Google Compute Engine network to which the Endpoint should be peered. Private services access must already be configured for the network. If left unspecified, the Endpoint is not peered with any network. Only one of the fields, network or enable_private_service_connect, can be set. Format: projects/project/global/networks/network. Where projectis a project number, as in `12345`, andnetwork`is network name. Corresponds to the JSON propertynetwork`

Returns:

  • (String)


6639
6640
6641
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6639

def network
  @network
end

#predict_request_response_logging_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PredictRequestResponseLoggingConfig

Configuration for logging request-response to a BigQuery table. Corresponds to the JSON property predictRequestResponseLoggingConfig



6644
6645
6646
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6644

def predict_request_response_logging_config
  @predict_request_response_logging_config
end

#private_service_connect_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PrivateServiceConnectConfig

Represents configuration for private service connect. Corresponds to the JSON property privateServiceConnectConfig



6649
6650
6651
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6649

def private_service_connect_config
  @private_service_connect_config
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


6654
6655
6656
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6654

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


6660
6661
6662
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6660

def satisfies_pzs
  @satisfies_pzs
end

#traffic_splitHash<String,Fixnum>

A map from a DeployedModel's ID to the percentage of this Endpoint's traffic that should be forwarded to that DeployedModel. If a DeployedModel's ID is not listed in this map, then it receives no traffic. The traffic percentage values must add up to 100, or map must be empty if the Endpoint is to not accept any traffic at a moment. Corresponds to the JSON property trafficSplit

Returns:

  • (Hash<String,Fixnum>)


6670
6671
6672
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6670

def traffic_split
  @traffic_split
end

#update_timeString

Output only. Timestamp when this Endpoint was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


6675
6676
6677
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6675

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6682
6683
6684
6685
6686
6687
6688
6689
6690
6691
6692
6693
6694
6695
6696
6697
6698
6699
6700
6701
6702
6703
6704
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6682

def update!(**args)
  @client_connection_config = args[:client_connection_config] if args.key?(:client_connection_config)
  @create_time = args[:create_time] if args.key?(:create_time)
  @dedicated_endpoint_dns = args[:dedicated_endpoint_dns] if args.key?(:dedicated_endpoint_dns)
  @dedicated_endpoint_enabled = args[:dedicated_endpoint_enabled] if args.key?(:dedicated_endpoint_enabled)
  @deployed_models = args[:deployed_models] if args.key?(:deployed_models)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @enable_private_service_connect = args[:enable_private_service_connect] if args.key?(:enable_private_service_connect)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @etag = args[:etag] if args.key?(:etag)
  @gen_ai_advanced_features_config = args[:gen_ai_advanced_features_config] if args.key?(:gen_ai_advanced_features_config)
  @labels = args[:labels] if args.key?(:labels)
  @model_deployment_monitoring_job = args[:model_deployment_monitoring_job] if args.key?(:model_deployment_monitoring_job)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @predict_request_response_logging_config = args[:predict_request_response_logging_config] if args.key?(:predict_request_response_logging_config)
  @private_service_connect_config = args[:private_service_connect_config] if args.key?(:private_service_connect_config)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @traffic_split = args[:traffic_split] if args.key?(:traffic_split)
  @update_time = args[:update_time] if args.key?(:update_time)
end