Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Endpoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Models are deployed into it, and afterwards Endpoint is called to obtain predictions and explanations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Endpoint

Returns a new instance of GoogleCloudAiplatformV1Endpoint.



5825
5826
5827
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5825

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this Endpoint was created. Corresponds to the JSON property createTime

Returns:

  • (String)


5698
5699
5700
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5698

def create_time
  @create_time
end

#dedicated_endpoint_dnsString

Output only. DNS of the dedicated endpoint. Will only be populated if dedicated_endpoint_enabled is true. Format: https://endpoint_id.region- project_number.prediction.vertexai.goog. Corresponds to the JSON property dedicatedEndpointDns

Returns:

  • (String)


5705
5706
5707
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5705

def dedicated_endpoint_dns
  @dedicated_endpoint_dns
end

#dedicated_endpoint_enabledBoolean Also known as: dedicated_endpoint_enabled?

If true, the endpoint will be exposed through a dedicated DNS [Endpoint. dedicated_endpoint_dns]. Your request to the dedicated DNS will be isolated from other users' traffic and will have better performance and reliability. Note: Once you enabled dedicated endpoint, you won't be able to send request to the shared DNS region-aiplatform.googleapis.com. The limitation will be removed soon. Corresponds to the JSON property dedicatedEndpointEnabled

Returns:

  • (Boolean)


5715
5716
5717
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5715

def dedicated_endpoint_enabled
  @dedicated_endpoint_enabled
end

#deployed_modelsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployedModel>

Output only. The models deployed in this Endpoint. To add or remove DeployedModels use EndpointService.DeployModel and EndpointService. UndeployModel respectively. Corresponds to the JSON property deployedModels



5723
5724
5725
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5723

def deployed_models
  @deployed_models
end

#descriptionString

The description of the Endpoint. Corresponds to the JSON property description

Returns:

  • (String)


5728
5729
5730
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5728

def description
  @description
end

#display_nameString

Required. The display name of the Endpoint. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


5734
5735
5736
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5734

def display_name
  @display_name
end

#enable_private_service_connectBoolean Also known as: enable_private_service_connect?

Deprecated: If true, expose the Endpoint via private service connect. Only one of the fields, network or enable_private_service_connect, can be set. Corresponds to the JSON property enablePrivateServiceConnect

Returns:

  • (Boolean)


5740
5741
5742
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5740

def enable_private_service_connect
  @enable_private_service_connect
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key spec that can be applied to a top- level resource. Corresponds to the JSON property encryptionSpec



5747
5748
5749
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5747

def encryption_spec
  @encryption_spec
end

#etagString

Used to perform consistent read-modify-write updates. If not set, a blind " overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


5753
5754
5755
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5753

def etag
  @etag
end

#labelsHash<String,String>

The labels with user-defined metadata to organize your Endpoints. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


5762
5763
5764
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5762

def labels
  @labels
end

#model_deployment_monitoring_jobString

Output only. Resource name of the Model Monitoring job associated with this Endpoint if monitoring is enabled by JobService. CreateModelDeploymentMonitoringJob. Format: projects/project/locations/ location/modelDeploymentMonitoringJobs/model_deployment_monitoring_job` Corresponds to the JSON propertymodelDeploymentMonitoringJob`

Returns:

  • (String)


5770
5771
5772
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5770

def model_deployment_monitoring_job
  @model_deployment_monitoring_job
end

#nameString

Output only. The resource name of the Endpoint. Corresponds to the JSON property name

Returns:

  • (String)


5775
5776
5777
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5775

def name
  @name
end

#networkString

Optional. The full name of the Google Compute Engine network to which the Endpoint should be peered. Private services access must already be configured for the network. If left unspecified, the Endpoint is not peered with any network. Only one of the fields, network or enable_private_service_connect, can be set. Format: projects/project/global/networks/network. Where projectis a project number, as in `12345`, andnetwork`is network name. Corresponds to the JSON propertynetwork`

Returns:

  • (String)


5787
5788
5789
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5787

def network
  @network
end

#predict_request_response_logging_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PredictRequestResponseLoggingConfig

Configuration for logging request-response to a BigQuery table. Corresponds to the JSON property predictRequestResponseLoggingConfig



5792
5793
5794
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5792

def predict_request_response_logging_config
  @predict_request_response_logging_config
end

#private_service_connect_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PrivateServiceConnectConfig

Represents configuration for private service connect. Corresponds to the JSON property privateServiceConnectConfig



5797
5798
5799
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5797

def private_service_connect_config
  @private_service_connect_config
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


5802
5803
5804
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5802

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


5808
5809
5810
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5808

def satisfies_pzs
  @satisfies_pzs
end

#traffic_splitHash<String,Fixnum>

A map from a DeployedModel's ID to the percentage of this Endpoint's traffic that should be forwarded to that DeployedModel. If a DeployedModel's ID is not listed in this map, then it receives no traffic. The traffic percentage values must add up to 100, or map must be empty if the Endpoint is to not accept any traffic at a moment. Corresponds to the JSON property trafficSplit

Returns:

  • (Hash<String,Fixnum>)


5818
5819
5820
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5818

def traffic_split
  @traffic_split
end

#update_timeString

Output only. Timestamp when this Endpoint was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


5823
5824
5825
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5823

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5830
5831
5832
5833
5834
5835
5836
5837
5838
5839
5840
5841
5842
5843
5844
5845
5846
5847
5848
5849
5850
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5830

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @dedicated_endpoint_dns = args[:dedicated_endpoint_dns] if args.key?(:dedicated_endpoint_dns)
  @dedicated_endpoint_enabled = args[:dedicated_endpoint_enabled] if args.key?(:dedicated_endpoint_enabled)
  @deployed_models = args[:deployed_models] if args.key?(:deployed_models)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @enable_private_service_connect = args[:enable_private_service_connect] if args.key?(:enable_private_service_connect)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @model_deployment_monitoring_job = args[:model_deployment_monitoring_job] if args.key?(:model_deployment_monitoring_job)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @predict_request_response_logging_config = args[:predict_request_response_logging_config] if args.key?(:predict_request_response_logging_config)
  @private_service_connect_config = args[:private_service_connect_config] if args.key?(:private_service_connect_config)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @traffic_split = args[:traffic_split] if args.key?(:traffic_split)
  @update_time = args[:update_time] if args.key?(:update_time)
end