Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EnterpriseWebSearch
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EnterpriseWebSearch
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Tool to search public web data, powered by Vertex AI Search and Sec4 compliance.
Instance Attribute Summary collapse
-
#blocking_confidence ⇒ String
Optional.
-
#exclude_domains ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1EnterpriseWebSearch
constructor
A new instance of GoogleCloudAiplatformV1EnterpriseWebSearch.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1EnterpriseWebSearch
Returns a new instance of GoogleCloudAiplatformV1EnterpriseWebSearch.
8106 8107 8108 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8106 def initialize(**args) update!(**args) end |
Instance Attribute Details
#blocking_confidence ⇒ String
Optional. Sites with confidence level chosen & above this value will be
blocked from the search results.
Corresponds to the JSON property blockingConfidence
8098 8099 8100 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8098 def blocking_confidence @blocking_confidence end |
#exclude_domains ⇒ Array<String>
Optional. List of domains to be excluded from the search results. The default
limit is 2000 domains.
Corresponds to the JSON property excludeDomains
8104 8105 8106 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8104 def exclude_domains @exclude_domains end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8111 8112 8113 8114 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8111 def update!(**args) @blocking_confidence = args[:blocking_confidence] if args.key?(:blocking_confidence) @exclude_domains = args[:exclude_domains] if args.key?(:exclude_domains) end |