Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EnterpriseWebSearch

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Tool to search public web data, powered by Vertex AI Search and Sec4 compliance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1EnterpriseWebSearch

Returns a new instance of GoogleCloudAiplatformV1EnterpriseWebSearch.



8081
8082
8083
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8081

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blocking_confidenceString

Optional. Sites with confidence level chosen & above this value will be blocked from the search results. Corresponds to the JSON property blockingConfidence

Returns:

  • (String)


8073
8074
8075
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8073

def blocking_confidence
  @blocking_confidence
end

#exclude_domainsArray<String>

Optional. List of domains to be excluded from the search results. The default limit is 2000 domains. Corresponds to the JSON property excludeDomains

Returns:

  • (Array<String>)


8079
8080
8081
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8079

def exclude_domains
  @exclude_domains
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8086
8087
8088
8089
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8086

def update!(**args)
  @blocking_confidence = args[:blocking_confidence] if args.key?(:blocking_confidence)
  @exclude_domains = args[:exclude_domains] if args.key?(:exclude_domains)
end