Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EnterpriseWebSearch

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Tool to search public web data, powered by Vertex AI Search and Sec4 compliance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1EnterpriseWebSearch

Returns a new instance of GoogleCloudAiplatformV1EnterpriseWebSearch.



7441
7442
7443
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7441

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#exclude_domainsArray<String>

Optional. List of domains to be excluded from the search results. The default limit is 2000 domains. Corresponds to the JSON property excludeDomains

Returns:

  • (Array<String>)


7439
7440
7441
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7439

def exclude_domains
  @exclude_domains
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7446
7447
7448
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7446

def update!(**args)
  @exclude_domains = args[:exclude_domains] if args.key?(:exclude_domains)
end