Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ErrorAnalysisAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Model error analysis for each annotation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ErrorAnalysisAnnotation

Returns a new instance of GoogleCloudAiplatformV1ErrorAnalysisAnnotation.



9673
9674
9675
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9673

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attributed_itemsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ErrorAnalysisAnnotationAttributedItem>

Attributed items for a given annotation, typically representing neighbors from the training sets constrained by the query type. Corresponds to the JSON property attributedItems



9655
9656
9657
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9655

def attributed_items
  @attributed_items
end

#outlier_scoreFloat

The outlier score of this annotated item. Usually defined as the min of all distances from attributed items. Corresponds to the JSON property outlierScore

Returns:

  • (Float)


9661
9662
9663
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9661

def outlier_score
  @outlier_score
end

#outlier_thresholdFloat

The threshold used to determine if this annotation is an outlier or not. Corresponds to the JSON property outlierThreshold

Returns:

  • (Float)


9666
9667
9668
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9666

def outlier_threshold
  @outlier_threshold
end

#query_typeString

The query type used for finding the attributed items. Corresponds to the JSON property queryType

Returns:

  • (String)


9671
9672
9673
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9671

def query_type
  @query_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9678
9679
9680
9681
9682
9683
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9678

def update!(**args)
  @attributed_items = args[:attributed_items] if args.key?(:attributed_items)
  @outlier_score = args[:outlier_score] if args.key?(:outlier_score)
  @outlier_threshold = args[:outlier_threshold] if args.key?(:outlier_threshold)
  @query_type = args[:query_type] if args.key?(:query_type)
end