Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ErrorAnalysisAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Model error analysis for each annotation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ErrorAnalysisAnnotation

Returns a new instance of GoogleCloudAiplatformV1ErrorAnalysisAnnotation.



5756
5757
5758
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5756

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attributed_itemsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ErrorAnalysisAnnotationAttributedItem>

Attributed items for a given annotation, typically representing neighbors from the training sets constrained by the query type. Corresponds to the JSON property attributedItems



5738
5739
5740
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5738

def attributed_items
  @attributed_items
end

#outlier_scoreFloat

The outlier score of this annotated item. Usually defined as the min of all distances from attributed items. Corresponds to the JSON property outlierScore

Returns:

  • (Float)


5744
5745
5746
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5744

def outlier_score
  @outlier_score
end

#outlier_thresholdFloat

The threshold used to determine if this annotation is an outlier or not. Corresponds to the JSON property outlierThreshold

Returns:

  • (Float)


5749
5750
5751
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5749

def outlier_threshold
  @outlier_threshold
end

#query_typeString

The query type used for finding the attributed items. Corresponds to the JSON property queryType

Returns:

  • (String)


5754
5755
5756
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5754

def query_type
  @query_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5761
5762
5763
5764
5765
5766
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5761

def update!(**args)
  @attributed_items = args[:attributed_items] if args.key?(:attributed_items)
  @outlier_score = args[:outlier_score] if args.key?(:outlier_score)
  @outlier_threshold = args[:outlier_threshold] if args.key?(:outlier_threshold)
  @query_type = args[:query_type] if args.key?(:query_type)
end