Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ErrorAnalysisAnnotation
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ErrorAnalysisAnnotation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Model error analysis for each annotation.
Instance Attribute Summary collapse
-
#attributed_items ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ErrorAnalysisAnnotationAttributedItem>
Attributed items for a given annotation, typically representing neighbors from the training sets constrained by the query type.
-
#outlier_score ⇒ Float
The outlier score of this annotated item.
-
#outlier_threshold ⇒ Float
The threshold used to determine if this annotation is an outlier or not.
-
#query_type ⇒ String
The query type used for finding the attributed items.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ErrorAnalysisAnnotation
constructor
A new instance of GoogleCloudAiplatformV1ErrorAnalysisAnnotation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ErrorAnalysisAnnotation
Returns a new instance of GoogleCloudAiplatformV1ErrorAnalysisAnnotation.
5425 5426 5427 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5425 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attributed_items ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ErrorAnalysisAnnotationAttributedItem>
Attributed items for a given annotation, typically representing neighbors from
the training sets constrained by the query type.
Corresponds to the JSON property attributedItems
5407 5408 5409 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5407 def attributed_items @attributed_items end |
#outlier_score ⇒ Float
The outlier score of this annotated item. Usually defined as the min of all
distances from attributed items.
Corresponds to the JSON property outlierScore
5413 5414 5415 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5413 def outlier_score @outlier_score end |
#outlier_threshold ⇒ Float
The threshold used to determine if this annotation is an outlier or not.
Corresponds to the JSON property outlierThreshold
5418 5419 5420 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5418 def outlier_threshold @outlier_threshold end |
#query_type ⇒ String
The query type used for finding the attributed items.
Corresponds to the JSON property queryType
5423 5424 5425 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5423 def query_type @query_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5430 5431 5432 5433 5434 5435 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5430 def update!(**args) @attributed_items = args[:attributed_items] if args.key?(:attributed_items) @outlier_score = args[:outlier_score] if args.key?(:outlier_score) @outlier_threshold = args[:outlier_threshold] if args.key?(:outlier_threshold) @query_type = args[:query_type] if args.key?(:query_type) end |