Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ErrorAnalysisAnnotationAttributedItem

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Attributed items for a given annotation, typically representing neighbors from the training sets constrained by the query type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ErrorAnalysisAnnotationAttributedItem

Returns a new instance of GoogleCloudAiplatformV1ErrorAnalysisAnnotationAttributedItem.



8818
8819
8820
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8818

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotation_resource_nameString

The unique ID for each annotation. Used by FE to allocate the annotation in DB. Corresponds to the JSON property annotationResourceName

Returns:

  • (String)


8811
8812
8813
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8811

def annotation_resource_name
  @annotation_resource_name
end

#distanceFloat

The distance of this item to the annotation. Corresponds to the JSON property distance

Returns:

  • (Float)


8816
8817
8818
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8816

def distance
  @distance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8823
8824
8825
8826
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8823

def update!(**args)
  @annotation_resource_name = args[:annotation_resource_name] if args.key?(:annotation_resource_name)
  @distance = args[:distance] if args.key?(:distance)
end