Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ErrorAnalysisAnnotationAttributedItem
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ErrorAnalysisAnnotationAttributedItem
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Attributed items for a given annotation, typically representing neighbors from the training sets constrained by the query type.
Instance Attribute Summary collapse
-
#annotation_resource_name ⇒ String
The unique ID for each annotation.
-
#distance ⇒ Float
The distance of this item to the annotation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ErrorAnalysisAnnotationAttributedItem
constructor
A new instance of GoogleCloudAiplatformV1ErrorAnalysisAnnotationAttributedItem.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ErrorAnalysisAnnotationAttributedItem
Returns a new instance of GoogleCloudAiplatformV1ErrorAnalysisAnnotationAttributedItem.
7302 7303 7304 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7302 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotation_resource_name ⇒ String
The unique ID for each annotation. Used by FE to allocate the annotation in DB.
Corresponds to the JSON property annotationResourceName
7295 7296 7297 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7295 def annotation_resource_name @annotation_resource_name end |
#distance ⇒ Float
The distance of this item to the annotation.
Corresponds to the JSON property distance
7300 7301 7302 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7300 def distance @distance end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7307 7308 7309 7310 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7307 def update!(**args) @annotation_resource_name = args[:annotation_resource_name] if args.key?(:annotation_resource_name) @distance = args[:distance] if args.key?(:distance) end |