Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluateDatasetResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The results from an evaluation run performed by the EvaluationService.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluateDatasetResponse

Returns a new instance of GoogleCloudAiplatformV1EvaluateDatasetResponse.



9000
9001
9002
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9000

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aggregation_outputGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1AggregationOutput

The aggregation result for the entire dataset and all metrics. Corresponds to the JSON property aggregationOutput



8993
8994
8995
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8993

def aggregation_output
  @aggregation_output
end

#output_infoGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1OutputInfo

Describes the info for output of EvaluationService. Corresponds to the JSON property outputInfo



8998
8999
9000
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8998

def output_info
  @output_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9005
9006
9007
9008
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9005

def update!(**args)
  @aggregation_output = args[:aggregation_output] if args.key?(:aggregation_output)
  @output_info = args[:output_info] if args.key?(:output_info)
end