Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluateDatasetResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluateDatasetResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The results from an evaluation run performed by the EvaluationService.
Instance Attribute Summary collapse
-
#aggregation_output ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AggregationOutput
The aggregation result for the entire dataset and all metrics.
-
#output_info ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1OutputInfo
Describes the info for output of EvaluationService.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluateDatasetResponse
constructor
A new instance of GoogleCloudAiplatformV1EvaluateDatasetResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluateDatasetResponse
Returns a new instance of GoogleCloudAiplatformV1EvaluateDatasetResponse.
8365 8366 8367 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8365 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aggregation_output ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AggregationOutput
The aggregation result for the entire dataset and all metrics.
Corresponds to the JSON property aggregationOutput
8358 8359 8360 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8358 def aggregation_output @aggregation_output end |
#output_info ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1OutputInfo
Describes the info for output of EvaluationService.
Corresponds to the JSON property outputInfo
8363 8364 8365 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8363 def output_info @output_info end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8370 8371 8372 8373 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8370 def update!(**args) @aggregation_output = args[:aggregation_output] if args.key?(:aggregation_output) @output_info = args[:output_info] if args.key?(:output_info) end |