Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluateDatasetRun

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Evaluate Dataset Run Result for Tuning Job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluateDatasetRun

Returns a new instance of GoogleCloudAiplatformV1EvaluateDatasetRun.



9818
9819
9820
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9818

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#checkpoint_idString

Output only. The checkpoint id used in the evaluation run. Only populated when evaluating checkpoints. Corresponds to the JSON property checkpointId

Returns:

  • (String)


9790
9791
9792
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9790

def checkpoint_id
  @checkpoint_id
end

#errorGoogle::Apis::AiplatformV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



9800
9801
9802
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9800

def error
  @error
end

#evaluate_dataset_responseGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluateDatasetResponse

The results from an evaluation run performed by the EvaluationService. Corresponds to the JSON property evaluateDatasetResponse



9805
9806
9807
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9805

def evaluate_dataset_response
  @evaluate_dataset_response
end

#evaluation_runString

Output only. The resource name of the evaluation run. Format: projects/ project/locations/location/evaluationRuns/evaluation_run_id`. Corresponds to the JSON propertyevaluationRun`

Returns:

  • (String)


9811
9812
9813
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9811

def evaluation_run
  @evaluation_run
end

#operation_nameString

Output only. Deprecated: The updated architecture uses evaluation_run instead. Corresponds to the JSON property operationName

Returns:

  • (String)


9816
9817
9818
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9816

def operation_name
  @operation_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9823
9824
9825
9826
9827
9828
9829
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9823

def update!(**args)
  @checkpoint_id = args[:checkpoint_id] if args.key?(:checkpoint_id)
  @error = args[:error] if args.key?(:error)
  @evaluate_dataset_response = args[:evaluate_dataset_response] if args.key?(:evaluate_dataset_response)
  @evaluation_run = args[:evaluation_run] if args.key?(:evaluation_run)
  @operation_name = args[:operation_name] if args.key?(:operation_name)
end