Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluateDatasetRun

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Evaluate Dataset Run Result for Tuning Job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluateDatasetRun

Returns a new instance of GoogleCloudAiplatformV1EvaluateDatasetRun.



9558
9559
9560
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9558

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#checkpoint_idString

Output only. The checkpoint id used in the evaluation run. Only populated when evaluating checkpoints. Corresponds to the JSON property checkpointId

Returns:

  • (String)


9530
9531
9532
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9530

def checkpoint_id
  @checkpoint_id
end

#errorGoogle::Apis::AiplatformV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



9540
9541
9542
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9540

def error
  @error
end

#evaluate_dataset_responseGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluateDatasetResponse

The results from an evaluation run performed by the EvaluationService. Corresponds to the JSON property evaluateDatasetResponse



9545
9546
9547
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9545

def evaluate_dataset_response
  @evaluate_dataset_response
end

#evaluation_runString

Output only. The resource name of the evaluation run. Format: projects/ project/locations/location/evaluationRuns/evaluation_run_id`. Corresponds to the JSON propertyevaluationRun`

Returns:

  • (String)


9551
9552
9553
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9551

def evaluation_run
  @evaluation_run
end

#operation_nameString

Output only. Deprecated: The updated architecture uses evaluation_run instead. Corresponds to the JSON property operationName

Returns:

  • (String)


9556
9557
9558
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9556

def operation_name
  @operation_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9563
9564
9565
9566
9567
9568
9569
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9563

def update!(**args)
  @checkpoint_id = args[:checkpoint_id] if args.key?(:checkpoint_id)
  @error = args[:error] if args.key?(:error)
  @evaluate_dataset_response = args[:evaluate_dataset_response] if args.key?(:evaluate_dataset_response)
  @evaluation_run = args[:evaluation_run] if args.key?(:evaluation_run)
  @operation_name = args[:operation_name] if args.key?(:operation_name)
end