Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluateDatasetRun

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Evaluate Dataset Run Result for Tuning Job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluateDatasetRun

Returns a new instance of GoogleCloudAiplatformV1EvaluateDatasetRun.



9357
9358
9359
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9357

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#checkpoint_idString

Output only. The checkpoint id used in the evaluation run. Only populated when evaluating checkpoints. Corresponds to the JSON property checkpointId

Returns:

  • (String)


9329
9330
9331
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9329

def checkpoint_id
  @checkpoint_id
end

#errorGoogle::Apis::AiplatformV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



9339
9340
9341
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9339

def error
  @error
end

#evaluate_dataset_responseGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluateDatasetResponse

The results from an evaluation run performed by the EvaluationService. Corresponds to the JSON property evaluateDatasetResponse



9344
9345
9346
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9344

def evaluate_dataset_response
  @evaluate_dataset_response
end

#evaluation_runString

Output only. The resource name of the evaluation run. Format: projects/ project/locations/location/evaluationRuns/evaluation_run_id`. Corresponds to the JSON propertyevaluationRun`

Returns:

  • (String)


9350
9351
9352
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9350

def evaluation_run
  @evaluation_run
end

#operation_nameString

Output only. Deprecated: The updated architecture uses evaluation_run instead. Corresponds to the JSON property operationName

Returns:

  • (String)


9355
9356
9357
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9355

def operation_name
  @operation_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9362
9363
9364
9365
9366
9367
9368
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9362

def update!(**args)
  @checkpoint_id = args[:checkpoint_id] if args.key?(:checkpoint_id)
  @error = args[:error] if args.key?(:error)
  @evaluate_dataset_response = args[:evaluate_dataset_response] if args.key?(:evaluate_dataset_response)
  @evaluation_run = args[:evaluation_run] if args.key?(:evaluation_run)
  @operation_name = args[:operation_name] if args.key?(:operation_name)
end