Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluateDatasetRun
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluateDatasetRun
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Evaluate Dataset Run Result for Tuning Job.
Instance Attribute Summary collapse
-
#checkpoint_id ⇒ String
Output only.
-
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#evaluate_dataset_response ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluateDatasetResponse
The results from an evaluation run performed by the EvaluationService.
-
#evaluation_run ⇒ String
Output only.
-
#operation_name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluateDatasetRun
constructor
A new instance of GoogleCloudAiplatformV1EvaluateDatasetRun.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluateDatasetRun
Returns a new instance of GoogleCloudAiplatformV1EvaluateDatasetRun.
8935 8936 8937 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8935 def initialize(**args) update!(**args) end |
Instance Attribute Details
#checkpoint_id ⇒ String
Output only. The checkpoint id used in the evaluation run. Only populated when
evaluating checkpoints.
Corresponds to the JSON property checkpointId
8907 8908 8909 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8907 def checkpoint_id @checkpoint_id end |
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
8917 8918 8919 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8917 def error @error end |
#evaluate_dataset_response ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluateDatasetResponse
The results from an evaluation run performed by the EvaluationService.
Corresponds to the JSON property evaluateDatasetResponse
8922 8923 8924 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8922 def evaluate_dataset_response @evaluate_dataset_response end |
#evaluation_run ⇒ String
Output only. The resource name of the evaluation run. Format: projects/
project/locations/location/evaluationRuns/evaluation_run_id`.
Corresponds to the JSON propertyevaluationRun`
8928 8929 8930 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8928 def evaluation_run @evaluation_run end |
#operation_name ⇒ String
Output only. Deprecated: The updated architecture uses evaluation_run instead.
Corresponds to the JSON property operationName
8933 8934 8935 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8933 def operation_name @operation_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8940 8941 8942 8943 8944 8945 8946 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8940 def update!(**args) @checkpoint_id = args[:checkpoint_id] if args.key?(:checkpoint_id) @error = args[:error] if args.key?(:error) @evaluate_dataset_response = args[:evaluate_dataset_response] if args.key?(:evaluate_dataset_response) @evaluation_run = args[:evaluation_run] if args.key?(:evaluation_run) @operation_name = args[:operation_name] if args.key?(:operation_name) end |