Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluateDatasetRun

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Evaluate Dataset Run Result for Tuning Job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluateDatasetRun

Returns a new instance of GoogleCloudAiplatformV1EvaluateDatasetRun.



8887
8888
8889
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8887

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#checkpoint_idString

Output only. The checkpoint id used in the evaluation run. Only populated when evaluating checkpoints. Corresponds to the JSON property checkpointId

Returns:

  • (String)


8859
8860
8861
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8859

def checkpoint_id
  @checkpoint_id
end

#errorGoogle::Apis::AiplatformV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



8869
8870
8871
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8869

def error
  @error
end

#evaluate_dataset_responseGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluateDatasetResponse

The results from an evaluation run performed by the EvaluationService. Corresponds to the JSON property evaluateDatasetResponse



8874
8875
8876
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8874

def evaluate_dataset_response
  @evaluate_dataset_response
end

#evaluation_runString

Output only. The resource name of the evaluation run. Format: projects/ project/locations/location/evaluationRuns/evaluation_run_id`. Corresponds to the JSON propertyevaluationRun`

Returns:

  • (String)


8880
8881
8882
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8880

def evaluation_run
  @evaluation_run
end

#operation_nameString

Output only. Deprecated: The updated architecture uses evaluation_run instead. Corresponds to the JSON property operationName

Returns:

  • (String)


8885
8886
8887
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8885

def operation_name
  @operation_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8892
8893
8894
8895
8896
8897
8898
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8892

def update!(**args)
  @checkpoint_id = args[:checkpoint_id] if args.key?(:checkpoint_id)
  @error = args[:error] if args.key?(:error)
  @evaluate_dataset_response = args[:evaluate_dataset_response] if args.key?(:evaluate_dataset_response)
  @evaluation_run = args[:evaluation_run] if args.key?(:evaluation_run)
  @operation_name = args[:operation_name] if args.key?(:operation_name)
end