Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluateInstancesResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluateInstancesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Response message for EvaluationService.EvaluateInstances.
Instance Attribute Summary collapse
-
#bleu_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BleuResults
Results for bleu metric.
-
#coherence_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CoherenceResult
Spec for coherence result.
-
#comet_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CometResult
Spec for Comet result - calculates the comet score for the given instance using the version specified in the spec.
-
#exact_match_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExactMatchResults
Results for exact match metric.
-
#fluency_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FluencyResult
Spec for fluency result.
-
#fulfillment_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FulfillmentResult
Spec for fulfillment result.
-
#groundedness_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundednessResult
Spec for groundedness result.
-
#metric_results ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetricResult>
Metric results for each instance.
-
#metricx_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetricxResult
Spec for MetricX result - calculates the MetricX score for the given instance using the version specified in the spec.
-
#pairwise_metric_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PairwiseMetricResult
Spec for pairwise metric result.
-
#pairwise_question_answering_quality_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PairwiseQuestionAnsweringQualityResult
Spec for pairwise question answering quality result.
-
#pairwise_summarization_quality_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PairwiseSummarizationQualityResult
Spec for pairwise summarization quality result.
-
#pointwise_metric_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PointwiseMetricResult
Spec for pointwise metric result.
-
#question_answering_correctness_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringCorrectnessResult
Spec for question answering correctness result.
-
#question_answering_helpfulness_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringHelpfulnessResult
Spec for question answering helpfulness result.
-
#question_answering_quality_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringQualityResult
Spec for question answering quality result.
-
#question_answering_relevance_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringRelevanceResult
Spec for question answering relevance result.
-
#rouge_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RougeResults
Results for rouge metric.
-
#rubric_based_instruction_following_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricBasedInstructionFollowingResult
Result for RubricBasedInstructionFollowing metric.
-
#safety_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetyResult
Spec for safety result.
-
#summarization_helpfulness_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SummarizationHelpfulnessResult
Spec for summarization helpfulness result.
-
#summarization_quality_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SummarizationQualityResult
Spec for summarization quality result.
-
#summarization_verbosity_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SummarizationVerbosityResult
Spec for summarization verbosity result.
-
#tool_call_valid_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolCallValidResults
Results for tool call valid metric.
-
#tool_name_match_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolNameMatchResults
Results for tool name match metric.
-
#tool_parameter_key_match_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolParameterKeyMatchResults
Results for tool parameter key match metric.
-
#tool_parameter_kv_match_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolParameterKvMatchResults
Results for tool parameter key value match metric.
-
#trajectory_any_order_match_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryAnyOrderMatchResults
Results for TrajectoryAnyOrderMatch metric.
-
#trajectory_exact_match_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryExactMatchResults
Results for TrajectoryExactMatch metric.
-
#trajectory_in_order_match_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryInOrderMatchResults
Results for TrajectoryInOrderMatch metric.
-
#trajectory_precision_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryPrecisionResults
Results for TrajectoryPrecision metric.
-
#trajectory_recall_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryRecallResults
Results for TrajectoryRecall metric.
-
#trajectory_single_tool_use_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectorySingleToolUseResults
Results for TrajectorySingleToolUse metric.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluateInstancesResponse
constructor
A new instance of GoogleCloudAiplatformV1EvaluateInstancesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluateInstancesResponse
Returns a new instance of GoogleCloudAiplatformV1EvaluateInstancesResponse.
10592 10593 10594 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10592 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bleu_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BleuResults
Results for bleu metric.
Corresponds to the JSON property bleuResults
10427 10428 10429 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10427 def bleu_results @bleu_results end |
#coherence_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CoherenceResult
Spec for coherence result.
Corresponds to the JSON property coherenceResult
10432 10433 10434 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10432 def coherence_result @coherence_result end |
#comet_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CometResult
Spec for Comet result - calculates the comet score for the given instance
using the version specified in the spec.
Corresponds to the JSON property cometResult
10438 10439 10440 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10438 def comet_result @comet_result end |
#exact_match_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExactMatchResults
Results for exact match metric.
Corresponds to the JSON property exactMatchResults
10443 10444 10445 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10443 def exact_match_results @exact_match_results end |
#fluency_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FluencyResult
Spec for fluency result.
Corresponds to the JSON property fluencyResult
10448 10449 10450 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10448 def fluency_result @fluency_result end |
#fulfillment_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FulfillmentResult
Spec for fulfillment result.
Corresponds to the JSON property fulfillmentResult
10453 10454 10455 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10453 def fulfillment_result @fulfillment_result end |
#groundedness_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundednessResult
Spec for groundedness result.
Corresponds to the JSON property groundednessResult
10458 10459 10460 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10458 def groundedness_result @groundedness_result end |
#metric_results ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetricResult>
Metric results for each instance. The order of the metric results is
guaranteed to be the same as the order of the instances in the request.
Corresponds to the JSON property metricResults
10464 10465 10466 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10464 def metric_results @metric_results end |
#metricx_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetricxResult
Spec for MetricX result - calculates the MetricX score for the given instance
using the version specified in the spec.
Corresponds to the JSON property metricxResult
10470 10471 10472 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10470 def metricx_result @metricx_result end |
#pairwise_metric_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PairwiseMetricResult
Spec for pairwise metric result.
Corresponds to the JSON property pairwiseMetricResult
10475 10476 10477 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10475 def pairwise_metric_result @pairwise_metric_result end |
#pairwise_question_answering_quality_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PairwiseQuestionAnsweringQualityResult
Spec for pairwise question answering quality result.
Corresponds to the JSON property pairwiseQuestionAnsweringQualityResult
10480 10481 10482 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10480 def pairwise_question_answering_quality_result @pairwise_question_answering_quality_result end |
#pairwise_summarization_quality_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PairwiseSummarizationQualityResult
Spec for pairwise summarization quality result.
Corresponds to the JSON property pairwiseSummarizationQualityResult
10485 10486 10487 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10485 def pairwise_summarization_quality_result @pairwise_summarization_quality_result end |
#pointwise_metric_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PointwiseMetricResult
Spec for pointwise metric result.
Corresponds to the JSON property pointwiseMetricResult
10490 10491 10492 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10490 def pointwise_metric_result @pointwise_metric_result end |
#question_answering_correctness_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringCorrectnessResult
Spec for question answering correctness result.
Corresponds to the JSON property questionAnsweringCorrectnessResult
10495 10496 10497 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10495 def question_answering_correctness_result @question_answering_correctness_result end |
#question_answering_helpfulness_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringHelpfulnessResult
Spec for question answering helpfulness result.
Corresponds to the JSON property questionAnsweringHelpfulnessResult
10500 10501 10502 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10500 def question_answering_helpfulness_result @question_answering_helpfulness_result end |
#question_answering_quality_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringQualityResult
Spec for question answering quality result.
Corresponds to the JSON property questionAnsweringQualityResult
10505 10506 10507 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10505 def question_answering_quality_result @question_answering_quality_result end |
#question_answering_relevance_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringRelevanceResult
Spec for question answering relevance result.
Corresponds to the JSON property questionAnsweringRelevanceResult
10510 10511 10512 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10510 def question_answering_relevance_result @question_answering_relevance_result end |
#rouge_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RougeResults
Results for rouge metric.
Corresponds to the JSON property rougeResults
10515 10516 10517 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10515 def rouge_results @rouge_results end |
#rubric_based_instruction_following_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricBasedInstructionFollowingResult
Result for RubricBasedInstructionFollowing metric.
Corresponds to the JSON property rubricBasedInstructionFollowingResult
10520 10521 10522 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10520 def rubric_based_instruction_following_result @rubric_based_instruction_following_result end |
#safety_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetyResult
Spec for safety result.
Corresponds to the JSON property safetyResult
10525 10526 10527 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10525 def safety_result @safety_result end |
#summarization_helpfulness_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SummarizationHelpfulnessResult
Spec for summarization helpfulness result.
Corresponds to the JSON property summarizationHelpfulnessResult
10530 10531 10532 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10530 def summarization_helpfulness_result @summarization_helpfulness_result end |
#summarization_quality_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SummarizationQualityResult
Spec for summarization quality result.
Corresponds to the JSON property summarizationQualityResult
10535 10536 10537 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10535 def summarization_quality_result @summarization_quality_result end |
#summarization_verbosity_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SummarizationVerbosityResult
Spec for summarization verbosity result.
Corresponds to the JSON property summarizationVerbosityResult
10540 10541 10542 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10540 def summarization_verbosity_result @summarization_verbosity_result end |
#tool_call_valid_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolCallValidResults
Results for tool call valid metric.
Corresponds to the JSON property toolCallValidResults
10545 10546 10547 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10545 def tool_call_valid_results @tool_call_valid_results end |
#tool_name_match_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolNameMatchResults
Results for tool name match metric.
Corresponds to the JSON property toolNameMatchResults
10550 10551 10552 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10550 def tool_name_match_results @tool_name_match_results end |
#tool_parameter_key_match_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolParameterKeyMatchResults
Results for tool parameter key match metric.
Corresponds to the JSON property toolParameterKeyMatchResults
10555 10556 10557 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10555 def tool_parameter_key_match_results @tool_parameter_key_match_results end |
#tool_parameter_kv_match_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolParameterKvMatchResults
Results for tool parameter key value match metric.
Corresponds to the JSON property toolParameterKvMatchResults
10560 10561 10562 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10560 def tool_parameter_kv_match_results @tool_parameter_kv_match_results end |
#trajectory_any_order_match_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryAnyOrderMatchResults
Results for TrajectoryAnyOrderMatch metric.
Corresponds to the JSON property trajectoryAnyOrderMatchResults
10565 10566 10567 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10565 def trajectory_any_order_match_results @trajectory_any_order_match_results end |
#trajectory_exact_match_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryExactMatchResults
Results for TrajectoryExactMatch metric.
Corresponds to the JSON property trajectoryExactMatchResults
10570 10571 10572 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10570 def trajectory_exact_match_results @trajectory_exact_match_results end |
#trajectory_in_order_match_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryInOrderMatchResults
Results for TrajectoryInOrderMatch metric.
Corresponds to the JSON property trajectoryInOrderMatchResults
10575 10576 10577 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10575 def trajectory_in_order_match_results @trajectory_in_order_match_results end |
#trajectory_precision_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryPrecisionResults
Results for TrajectoryPrecision metric.
Corresponds to the JSON property trajectoryPrecisionResults
10580 10581 10582 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10580 def trajectory_precision_results @trajectory_precision_results end |
#trajectory_recall_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryRecallResults
Results for TrajectoryRecall metric.
Corresponds to the JSON property trajectoryRecallResults
10585 10586 10587 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10585 def trajectory_recall_results @trajectory_recall_results end |
#trajectory_single_tool_use_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectorySingleToolUseResults
Results for TrajectorySingleToolUse metric.
Corresponds to the JSON property trajectorySingleToolUseResults
10590 10591 10592 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10590 def trajectory_single_tool_use_results @trajectory_single_tool_use_results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10597 10598 10599 10600 10601 10602 10603 10604 10605 10606 10607 10608 10609 10610 10611 10612 10613 10614 10615 10616 10617 10618 10619 10620 10621 10622 10623 10624 10625 10626 10627 10628 10629 10630 10631 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10597 def update!(**args) @bleu_results = args[:bleu_results] if args.key?(:bleu_results) @coherence_result = args[:coherence_result] if args.key?(:coherence_result) @comet_result = args[:comet_result] if args.key?(:comet_result) @exact_match_results = args[:exact_match_results] if args.key?(:exact_match_results) @fluency_result = args[:fluency_result] if args.key?(:fluency_result) @fulfillment_result = args[:fulfillment_result] if args.key?(:fulfillment_result) @groundedness_result = args[:groundedness_result] if args.key?(:groundedness_result) @metric_results = args[:metric_results] if args.key?(:metric_results) @metricx_result = args[:metricx_result] if args.key?(:metricx_result) @pairwise_metric_result = args[:pairwise_metric_result] if args.key?(:pairwise_metric_result) @pairwise_question_answering_quality_result = args[:pairwise_question_answering_quality_result] if args.key?(:pairwise_question_answering_quality_result) @pairwise_summarization_quality_result = args[:pairwise_summarization_quality_result] if args.key?(:pairwise_summarization_quality_result) @pointwise_metric_result = args[:pointwise_metric_result] if args.key?(:pointwise_metric_result) @question_answering_correctness_result = args[:question_answering_correctness_result] if args.key?(:question_answering_correctness_result) @question_answering_helpfulness_result = args[:question_answering_helpfulness_result] if args.key?(:question_answering_helpfulness_result) @question_answering_quality_result = args[:question_answering_quality_result] if args.key?(:question_answering_quality_result) @question_answering_relevance_result = args[:question_answering_relevance_result] if args.key?(:question_answering_relevance_result) @rouge_results = args[:rouge_results] if args.key?(:rouge_results) @rubric_based_instruction_following_result = args[:rubric_based_instruction_following_result] if args.key?(:rubric_based_instruction_following_result) @safety_result = args[:safety_result] if args.key?(:safety_result) @summarization_helpfulness_result = args[:summarization_helpfulness_result] if args.key?(:summarization_helpfulness_result) @summarization_quality_result = args[:summarization_quality_result] if args.key?(:summarization_quality_result) @summarization_verbosity_result = args[:summarization_verbosity_result] if args.key?(:summarization_verbosity_result) @tool_call_valid_results = args[:tool_call_valid_results] if args.key?(:tool_call_valid_results) @tool_name_match_results = args[:tool_name_match_results] if args.key?(:tool_name_match_results) @tool_parameter_key_match_results = args[:tool_parameter_key_match_results] if args.key?(:tool_parameter_key_match_results) @tool_parameter_kv_match_results = args[:tool_parameter_kv_match_results] if args.key?(:tool_parameter_kv_match_results) @trajectory_any_order_match_results = args[:trajectory_any_order_match_results] if args.key?(:trajectory_any_order_match_results) @trajectory_exact_match_results = args[:trajectory_exact_match_results] if args.key?(:trajectory_exact_match_results) @trajectory_in_order_match_results = args[:trajectory_in_order_match_results] if args.key?(:trajectory_in_order_match_results) @trajectory_precision_results = args[:trajectory_precision_results] if args.key?(:trajectory_precision_results) @trajectory_recall_results = args[:trajectory_recall_results] if args.key?(:trajectory_recall_results) @trajectory_single_tool_use_results = args[:trajectory_single_tool_use_results] if args.key?(:trajectory_single_tool_use_results) end |