Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluateInstancesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Response message for EvaluationService.EvaluateInstances.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluateInstancesResponse

Returns a new instance of GoogleCloudAiplatformV1EvaluateInstancesResponse.



10577
10578
10579
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10577

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bleu_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1BleuResults

Results for bleu metric. Corresponds to the JSON property bleuResults



10412
10413
10414
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10412

def bleu_results
  @bleu_results
end

#coherence_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1CoherenceResult

Spec for coherence result. Corresponds to the JSON property coherenceResult



10417
10418
10419
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10417

def coherence_result
  @coherence_result
end

#comet_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1CometResult

Spec for Comet result - calculates the comet score for the given instance using the version specified in the spec. Corresponds to the JSON property cometResult



10423
10424
10425
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10423

def comet_result
  @comet_result
end

#exact_match_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ExactMatchResults

Results for exact match metric. Corresponds to the JSON property exactMatchResults



10428
10429
10430
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10428

def exact_match_results
  @exact_match_results
end

#fluency_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FluencyResult

Spec for fluency result. Corresponds to the JSON property fluencyResult



10433
10434
10435
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10433

def fluency_result
  @fluency_result
end

#fulfillment_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FulfillmentResult

Spec for fulfillment result. Corresponds to the JSON property fulfillmentResult



10438
10439
10440
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10438

def fulfillment_result
  @fulfillment_result
end

#groundedness_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundednessResult

Spec for groundedness result. Corresponds to the JSON property groundednessResult



10443
10444
10445
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10443

def groundedness_result
  @groundedness_result
end

#metric_resultsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetricResult>

Metric results for each instance. The order of the metric results is guaranteed to be the same as the order of the instances in the request. Corresponds to the JSON property metricResults



10449
10450
10451
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10449

def metric_results
  @metric_results
end

#metricx_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1MetricxResult

Spec for MetricX result - calculates the MetricX score for the given instance using the version specified in the spec. Corresponds to the JSON property metricxResult



10455
10456
10457
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10455

def metricx_result
  @metricx_result
end

#pairwise_metric_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PairwiseMetricResult

Spec for pairwise metric result. Corresponds to the JSON property pairwiseMetricResult



10460
10461
10462
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10460

def pairwise_metric_result
  @pairwise_metric_result
end

#pairwise_question_answering_quality_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PairwiseQuestionAnsweringQualityResult

Spec for pairwise question answering quality result. Corresponds to the JSON property pairwiseQuestionAnsweringQualityResult



10465
10466
10467
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10465

def pairwise_question_answering_quality_result
  @pairwise_question_answering_quality_result
end

#pairwise_summarization_quality_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PairwiseSummarizationQualityResult

Spec for pairwise summarization quality result. Corresponds to the JSON property pairwiseSummarizationQualityResult



10470
10471
10472
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10470

def pairwise_summarization_quality_result
  @pairwise_summarization_quality_result
end

#pointwise_metric_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PointwiseMetricResult

Spec for pointwise metric result. Corresponds to the JSON property pointwiseMetricResult



10475
10476
10477
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10475

def pointwise_metric_result
  @pointwise_metric_result
end

#question_answering_correctness_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringCorrectnessResult

Spec for question answering correctness result. Corresponds to the JSON property questionAnsweringCorrectnessResult



10480
10481
10482
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10480

def question_answering_correctness_result
  @question_answering_correctness_result
end

#question_answering_helpfulness_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringHelpfulnessResult

Spec for question answering helpfulness result. Corresponds to the JSON property questionAnsweringHelpfulnessResult



10485
10486
10487
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10485

def question_answering_helpfulness_result
  @question_answering_helpfulness_result
end

#question_answering_quality_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringQualityResult

Spec for question answering quality result. Corresponds to the JSON property questionAnsweringQualityResult



10490
10491
10492
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10490

def question_answering_quality_result
  @question_answering_quality_result
end

#question_answering_relevance_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringRelevanceResult

Spec for question answering relevance result. Corresponds to the JSON property questionAnsweringRelevanceResult



10495
10496
10497
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10495

def question_answering_relevance_result
  @question_answering_relevance_result
end

#rouge_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RougeResults

Results for rouge metric. Corresponds to the JSON property rougeResults



10500
10501
10502
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10500

def rouge_results
  @rouge_results
end

#rubric_based_instruction_following_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricBasedInstructionFollowingResult

Result for RubricBasedInstructionFollowing metric. Corresponds to the JSON property rubricBasedInstructionFollowingResult



10505
10506
10507
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10505

def rubric_based_instruction_following_result
  @rubric_based_instruction_following_result
end

#safety_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetyResult

Spec for safety result. Corresponds to the JSON property safetyResult



10510
10511
10512
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10510

def safety_result
  @safety_result
end

#summarization_helpfulness_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SummarizationHelpfulnessResult

Spec for summarization helpfulness result. Corresponds to the JSON property summarizationHelpfulnessResult



10515
10516
10517
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10515

def summarization_helpfulness_result
  @summarization_helpfulness_result
end

#summarization_quality_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SummarizationQualityResult

Spec for summarization quality result. Corresponds to the JSON property summarizationQualityResult



10520
10521
10522
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10520

def summarization_quality_result
  @summarization_quality_result
end

#summarization_verbosity_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SummarizationVerbosityResult

Spec for summarization verbosity result. Corresponds to the JSON property summarizationVerbosityResult



10525
10526
10527
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10525

def summarization_verbosity_result
  @summarization_verbosity_result
end

#tool_call_valid_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolCallValidResults

Results for tool call valid metric. Corresponds to the JSON property toolCallValidResults



10530
10531
10532
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10530

def tool_call_valid_results
  @tool_call_valid_results
end

#tool_name_match_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolNameMatchResults

Results for tool name match metric. Corresponds to the JSON property toolNameMatchResults



10535
10536
10537
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10535

def tool_name_match_results
  @tool_name_match_results
end

#tool_parameter_key_match_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolParameterKeyMatchResults

Results for tool parameter key match metric. Corresponds to the JSON property toolParameterKeyMatchResults



10540
10541
10542
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10540

def tool_parameter_key_match_results
  @tool_parameter_key_match_results
end

#tool_parameter_kv_match_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolParameterKvMatchResults

Results for tool parameter key value match metric. Corresponds to the JSON property toolParameterKvMatchResults



10545
10546
10547
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10545

def tool_parameter_kv_match_results
  @tool_parameter_kv_match_results
end

#trajectory_any_order_match_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryAnyOrderMatchResults

Results for TrajectoryAnyOrderMatch metric. Corresponds to the JSON property trajectoryAnyOrderMatchResults



10550
10551
10552
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10550

def trajectory_any_order_match_results
  @trajectory_any_order_match_results
end

#trajectory_exact_match_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryExactMatchResults

Results for TrajectoryExactMatch metric. Corresponds to the JSON property trajectoryExactMatchResults



10555
10556
10557
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10555

def trajectory_exact_match_results
  @trajectory_exact_match_results
end

#trajectory_in_order_match_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryInOrderMatchResults

Results for TrajectoryInOrderMatch metric. Corresponds to the JSON property trajectoryInOrderMatchResults



10560
10561
10562
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10560

def trajectory_in_order_match_results
  @trajectory_in_order_match_results
end

#trajectory_precision_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryPrecisionResults

Results for TrajectoryPrecision metric. Corresponds to the JSON property trajectoryPrecisionResults



10565
10566
10567
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10565

def trajectory_precision_results
  @trajectory_precision_results
end

#trajectory_recall_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryRecallResults

Results for TrajectoryRecall metric. Corresponds to the JSON property trajectoryRecallResults



10570
10571
10572
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10570

def trajectory_recall_results
  @trajectory_recall_results
end

#trajectory_single_tool_use_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectorySingleToolUseResults

Results for TrajectorySingleToolUse metric. Corresponds to the JSON property trajectorySingleToolUseResults



10575
10576
10577
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10575

def trajectory_single_tool_use_results
  @trajectory_single_tool_use_results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10582
10583
10584
10585
10586
10587
10588
10589
10590
10591
10592
10593
10594
10595
10596
10597
10598
10599
10600
10601
10602
10603
10604
10605
10606
10607
10608
10609
10610
10611
10612
10613
10614
10615
10616
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10582

def update!(**args)
  @bleu_results = args[:bleu_results] if args.key?(:bleu_results)
  @coherence_result = args[:coherence_result] if args.key?(:coherence_result)
  @comet_result = args[:comet_result] if args.key?(:comet_result)
  @exact_match_results = args[:exact_match_results] if args.key?(:exact_match_results)
  @fluency_result = args[:fluency_result] if args.key?(:fluency_result)
  @fulfillment_result = args[:fulfillment_result] if args.key?(:fulfillment_result)
  @groundedness_result = args[:groundedness_result] if args.key?(:groundedness_result)
  @metric_results = args[:metric_results] if args.key?(:metric_results)
  @metricx_result = args[:metricx_result] if args.key?(:metricx_result)
  @pairwise_metric_result = args[:pairwise_metric_result] if args.key?(:pairwise_metric_result)
  @pairwise_question_answering_quality_result = args[:pairwise_question_answering_quality_result] if args.key?(:pairwise_question_answering_quality_result)
  @pairwise_summarization_quality_result = args[:pairwise_summarization_quality_result] if args.key?(:pairwise_summarization_quality_result)
  @pointwise_metric_result = args[:pointwise_metric_result] if args.key?(:pointwise_metric_result)
  @question_answering_correctness_result = args[:question_answering_correctness_result] if args.key?(:question_answering_correctness_result)
  @question_answering_helpfulness_result = args[:question_answering_helpfulness_result] if args.key?(:question_answering_helpfulness_result)
  @question_answering_quality_result = args[:question_answering_quality_result] if args.key?(:question_answering_quality_result)
  @question_answering_relevance_result = args[:question_answering_relevance_result] if args.key?(:question_answering_relevance_result)
  @rouge_results = args[:rouge_results] if args.key?(:rouge_results)
  @rubric_based_instruction_following_result = args[:rubric_based_instruction_following_result] if args.key?(:rubric_based_instruction_following_result)
  @safety_result = args[:safety_result] if args.key?(:safety_result)
  @summarization_helpfulness_result = args[:summarization_helpfulness_result] if args.key?(:summarization_helpfulness_result)
  @summarization_quality_result = args[:summarization_quality_result] if args.key?(:summarization_quality_result)
  @summarization_verbosity_result = args[:summarization_verbosity_result] if args.key?(:summarization_verbosity_result)
  @tool_call_valid_results = args[:tool_call_valid_results] if args.key?(:tool_call_valid_results)
  @tool_name_match_results = args[:tool_name_match_results] if args.key?(:tool_name_match_results)
  @tool_parameter_key_match_results = args[:tool_parameter_key_match_results] if args.key?(:tool_parameter_key_match_results)
  @tool_parameter_kv_match_results = args[:tool_parameter_kv_match_results] if args.key?(:tool_parameter_kv_match_results)
  @trajectory_any_order_match_results = args[:trajectory_any_order_match_results] if args.key?(:trajectory_any_order_match_results)
  @trajectory_exact_match_results = args[:trajectory_exact_match_results] if args.key?(:trajectory_exact_match_results)
  @trajectory_in_order_match_results = args[:trajectory_in_order_match_results] if args.key?(:trajectory_in_order_match_results)
  @trajectory_precision_results = args[:trajectory_precision_results] if args.key?(:trajectory_precision_results)
  @trajectory_recall_results = args[:trajectory_recall_results] if args.key?(:trajectory_recall_results)
  @trajectory_single_tool_use_results = args[:trajectory_single_tool_use_results] if args.key?(:trajectory_single_tool_use_results)
end