Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluateInstancesResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluateInstancesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Response message for EvaluationService.EvaluateInstances.
Instance Attribute Summary collapse
-
#bleu_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BleuResults
Results for bleu metric.
-
#coherence_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CoherenceResult
Spec for coherence result.
-
#comet_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CometResult
Spec for Comet result - calculates the comet score for the given instance using the version specified in the spec.
-
#exact_match_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExactMatchResults
Results for exact match metric.
-
#fluency_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FluencyResult
Spec for fluency result.
-
#fulfillment_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FulfillmentResult
Spec for fulfillment result.
-
#groundedness_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundednessResult
Spec for groundedness result.
-
#metric_results ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetricResult>
Metric results for each instance.
-
#metricx_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetricxResult
Spec for MetricX result - calculates the MetricX score for the given instance using the version specified in the spec.
-
#pairwise_metric_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PairwiseMetricResult
Spec for pairwise metric result.
-
#pairwise_question_answering_quality_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PairwiseQuestionAnsweringQualityResult
Spec for pairwise question answering quality result.
-
#pairwise_summarization_quality_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PairwiseSummarizationQualityResult
Spec for pairwise summarization quality result.
-
#pointwise_metric_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PointwiseMetricResult
Spec for pointwise metric result.
-
#question_answering_correctness_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringCorrectnessResult
Spec for question answering correctness result.
-
#question_answering_helpfulness_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringHelpfulnessResult
Spec for question answering helpfulness result.
-
#question_answering_quality_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringQualityResult
Spec for question answering quality result.
-
#question_answering_relevance_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringRelevanceResult
Spec for question answering relevance result.
-
#rouge_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RougeResults
Results for rouge metric.
-
#rubric_based_instruction_following_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricBasedInstructionFollowingResult
Result for RubricBasedInstructionFollowing metric.
-
#safety_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetyResult
Spec for safety result.
-
#summarization_helpfulness_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SummarizationHelpfulnessResult
Spec for summarization helpfulness result.
-
#summarization_quality_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SummarizationQualityResult
Spec for summarization quality result.
-
#summarization_verbosity_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SummarizationVerbosityResult
Spec for summarization verbosity result.
-
#tool_call_valid_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolCallValidResults
Results for tool call valid metric.
-
#tool_name_match_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolNameMatchResults
Results for tool name match metric.
-
#tool_parameter_key_match_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolParameterKeyMatchResults
Results for tool parameter key match metric.
-
#tool_parameter_kv_match_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolParameterKvMatchResults
Results for tool parameter key value match metric.
-
#trajectory_any_order_match_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryAnyOrderMatchResults
Results for TrajectoryAnyOrderMatch metric.
-
#trajectory_exact_match_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryExactMatchResults
Results for TrajectoryExactMatch metric.
-
#trajectory_in_order_match_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryInOrderMatchResults
Results for TrajectoryInOrderMatch metric.
-
#trajectory_precision_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryPrecisionResults
Results for TrajectoryPrecision metric.
-
#trajectory_recall_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryRecallResults
Results for TrajectoryRecall metric.
-
#trajectory_single_tool_use_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectorySingleToolUseResults
Results for TrajectorySingleToolUse metric.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluateInstancesResponse
constructor
A new instance of GoogleCloudAiplatformV1EvaluateInstancesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluateInstancesResponse
Returns a new instance of GoogleCloudAiplatformV1EvaluateInstancesResponse.
9476 9477 9478 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9476 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bleu_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BleuResults
Results for bleu metric.
Corresponds to the JSON property bleuResults
9311 9312 9313 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9311 def bleu_results @bleu_results end |
#coherence_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CoherenceResult
Spec for coherence result.
Corresponds to the JSON property coherenceResult
9316 9317 9318 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9316 def coherence_result @coherence_result end |
#comet_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CometResult
Spec for Comet result - calculates the comet score for the given instance
using the version specified in the spec.
Corresponds to the JSON property cometResult
9322 9323 9324 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9322 def comet_result @comet_result end |
#exact_match_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExactMatchResults
Results for exact match metric.
Corresponds to the JSON property exactMatchResults
9327 9328 9329 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9327 def exact_match_results @exact_match_results end |
#fluency_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FluencyResult
Spec for fluency result.
Corresponds to the JSON property fluencyResult
9332 9333 9334 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9332 def fluency_result @fluency_result end |
#fulfillment_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FulfillmentResult
Spec for fulfillment result.
Corresponds to the JSON property fulfillmentResult
9337 9338 9339 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9337 def fulfillment_result @fulfillment_result end |
#groundedness_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundednessResult
Spec for groundedness result.
Corresponds to the JSON property groundednessResult
9342 9343 9344 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9342 def groundedness_result @groundedness_result end |
#metric_results ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetricResult>
Metric results for each instance. The order of the metric results is
guaranteed to be the same as the order of the instances in the request.
Corresponds to the JSON property metricResults
9348 9349 9350 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9348 def metric_results @metric_results end |
#metricx_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetricxResult
Spec for MetricX result - calculates the MetricX score for the given instance
using the version specified in the spec.
Corresponds to the JSON property metricxResult
9354 9355 9356 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9354 def metricx_result @metricx_result end |
#pairwise_metric_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PairwiseMetricResult
Spec for pairwise metric result.
Corresponds to the JSON property pairwiseMetricResult
9359 9360 9361 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9359 def pairwise_metric_result @pairwise_metric_result end |
#pairwise_question_answering_quality_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PairwiseQuestionAnsweringQualityResult
Spec for pairwise question answering quality result.
Corresponds to the JSON property pairwiseQuestionAnsweringQualityResult
9364 9365 9366 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9364 def pairwise_question_answering_quality_result @pairwise_question_answering_quality_result end |
#pairwise_summarization_quality_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PairwiseSummarizationQualityResult
Spec for pairwise summarization quality result.
Corresponds to the JSON property pairwiseSummarizationQualityResult
9369 9370 9371 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9369 def pairwise_summarization_quality_result @pairwise_summarization_quality_result end |
#pointwise_metric_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PointwiseMetricResult
Spec for pointwise metric result.
Corresponds to the JSON property pointwiseMetricResult
9374 9375 9376 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9374 def pointwise_metric_result @pointwise_metric_result end |
#question_answering_correctness_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringCorrectnessResult
Spec for question answering correctness result.
Corresponds to the JSON property questionAnsweringCorrectnessResult
9379 9380 9381 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9379 def question_answering_correctness_result @question_answering_correctness_result end |
#question_answering_helpfulness_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringHelpfulnessResult
Spec for question answering helpfulness result.
Corresponds to the JSON property questionAnsweringHelpfulnessResult
9384 9385 9386 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9384 def question_answering_helpfulness_result @question_answering_helpfulness_result end |
#question_answering_quality_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringQualityResult
Spec for question answering quality result.
Corresponds to the JSON property questionAnsweringQualityResult
9389 9390 9391 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9389 def question_answering_quality_result @question_answering_quality_result end |
#question_answering_relevance_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringRelevanceResult
Spec for question answering relevance result.
Corresponds to the JSON property questionAnsweringRelevanceResult
9394 9395 9396 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9394 def question_answering_relevance_result @question_answering_relevance_result end |
#rouge_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RougeResults
Results for rouge metric.
Corresponds to the JSON property rougeResults
9399 9400 9401 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9399 def rouge_results @rouge_results end |
#rubric_based_instruction_following_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricBasedInstructionFollowingResult
Result for RubricBasedInstructionFollowing metric.
Corresponds to the JSON property rubricBasedInstructionFollowingResult
9404 9405 9406 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9404 def rubric_based_instruction_following_result @rubric_based_instruction_following_result end |
#safety_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetyResult
Spec for safety result.
Corresponds to the JSON property safetyResult
9409 9410 9411 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9409 def safety_result @safety_result end |
#summarization_helpfulness_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SummarizationHelpfulnessResult
Spec for summarization helpfulness result.
Corresponds to the JSON property summarizationHelpfulnessResult
9414 9415 9416 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9414 def summarization_helpfulness_result @summarization_helpfulness_result end |
#summarization_quality_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SummarizationQualityResult
Spec for summarization quality result.
Corresponds to the JSON property summarizationQualityResult
9419 9420 9421 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9419 def summarization_quality_result @summarization_quality_result end |
#summarization_verbosity_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SummarizationVerbosityResult
Spec for summarization verbosity result.
Corresponds to the JSON property summarizationVerbosityResult
9424 9425 9426 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9424 def summarization_verbosity_result @summarization_verbosity_result end |
#tool_call_valid_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolCallValidResults
Results for tool call valid metric.
Corresponds to the JSON property toolCallValidResults
9429 9430 9431 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9429 def tool_call_valid_results @tool_call_valid_results end |
#tool_name_match_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolNameMatchResults
Results for tool name match metric.
Corresponds to the JSON property toolNameMatchResults
9434 9435 9436 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9434 def tool_name_match_results @tool_name_match_results end |
#tool_parameter_key_match_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolParameterKeyMatchResults
Results for tool parameter key match metric.
Corresponds to the JSON property toolParameterKeyMatchResults
9439 9440 9441 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9439 def tool_parameter_key_match_results @tool_parameter_key_match_results end |
#tool_parameter_kv_match_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolParameterKvMatchResults
Results for tool parameter key value match metric.
Corresponds to the JSON property toolParameterKvMatchResults
9444 9445 9446 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9444 def tool_parameter_kv_match_results @tool_parameter_kv_match_results end |
#trajectory_any_order_match_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryAnyOrderMatchResults
Results for TrajectoryAnyOrderMatch metric.
Corresponds to the JSON property trajectoryAnyOrderMatchResults
9449 9450 9451 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9449 def trajectory_any_order_match_results @trajectory_any_order_match_results end |
#trajectory_exact_match_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryExactMatchResults
Results for TrajectoryExactMatch metric.
Corresponds to the JSON property trajectoryExactMatchResults
9454 9455 9456 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9454 def trajectory_exact_match_results @trajectory_exact_match_results end |
#trajectory_in_order_match_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryInOrderMatchResults
Results for TrajectoryInOrderMatch metric.
Corresponds to the JSON property trajectoryInOrderMatchResults
9459 9460 9461 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9459 def trajectory_in_order_match_results @trajectory_in_order_match_results end |
#trajectory_precision_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryPrecisionResults
Results for TrajectoryPrecision metric.
Corresponds to the JSON property trajectoryPrecisionResults
9464 9465 9466 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9464 def trajectory_precision_results @trajectory_precision_results end |
#trajectory_recall_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryRecallResults
Results for TrajectoryRecall metric.
Corresponds to the JSON property trajectoryRecallResults
9469 9470 9471 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9469 def trajectory_recall_results @trajectory_recall_results end |
#trajectory_single_tool_use_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectorySingleToolUseResults
Results for TrajectorySingleToolUse metric.
Corresponds to the JSON property trajectorySingleToolUseResults
9474 9475 9476 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9474 def trajectory_single_tool_use_results @trajectory_single_tool_use_results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 9494 9495 9496 9497 9498 9499 9500 9501 9502 9503 9504 9505 9506 9507 9508 9509 9510 9511 9512 9513 9514 9515 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9481 def update!(**args) @bleu_results = args[:bleu_results] if args.key?(:bleu_results) @coherence_result = args[:coherence_result] if args.key?(:coherence_result) @comet_result = args[:comet_result] if args.key?(:comet_result) @exact_match_results = args[:exact_match_results] if args.key?(:exact_match_results) @fluency_result = args[:fluency_result] if args.key?(:fluency_result) @fulfillment_result = args[:fulfillment_result] if args.key?(:fulfillment_result) @groundedness_result = args[:groundedness_result] if args.key?(:groundedness_result) @metric_results = args[:metric_results] if args.key?(:metric_results) @metricx_result = args[:metricx_result] if args.key?(:metricx_result) @pairwise_metric_result = args[:pairwise_metric_result] if args.key?(:pairwise_metric_result) @pairwise_question_answering_quality_result = args[:pairwise_question_answering_quality_result] if args.key?(:pairwise_question_answering_quality_result) @pairwise_summarization_quality_result = args[:pairwise_summarization_quality_result] if args.key?(:pairwise_summarization_quality_result) @pointwise_metric_result = args[:pointwise_metric_result] if args.key?(:pointwise_metric_result) @question_answering_correctness_result = args[:question_answering_correctness_result] if args.key?(:question_answering_correctness_result) @question_answering_helpfulness_result = args[:question_answering_helpfulness_result] if args.key?(:question_answering_helpfulness_result) @question_answering_quality_result = args[:question_answering_quality_result] if args.key?(:question_answering_quality_result) @question_answering_relevance_result = args[:question_answering_relevance_result] if args.key?(:question_answering_relevance_result) @rouge_results = args[:rouge_results] if args.key?(:rouge_results) @rubric_based_instruction_following_result = args[:rubric_based_instruction_following_result] if args.key?(:rubric_based_instruction_following_result) @safety_result = args[:safety_result] if args.key?(:safety_result) @summarization_helpfulness_result = args[:summarization_helpfulness_result] if args.key?(:summarization_helpfulness_result) @summarization_quality_result = args[:summarization_quality_result] if args.key?(:summarization_quality_result) @summarization_verbosity_result = args[:summarization_verbosity_result] if args.key?(:summarization_verbosity_result) @tool_call_valid_results = args[:tool_call_valid_results] if args.key?(:tool_call_valid_results) @tool_name_match_results = args[:tool_name_match_results] if args.key?(:tool_name_match_results) @tool_parameter_key_match_results = args[:tool_parameter_key_match_results] if args.key?(:tool_parameter_key_match_results) @tool_parameter_kv_match_results = args[:tool_parameter_kv_match_results] if args.key?(:tool_parameter_kv_match_results) @trajectory_any_order_match_results = args[:trajectory_any_order_match_results] if args.key?(:trajectory_any_order_match_results) @trajectory_exact_match_results = args[:trajectory_exact_match_results] if args.key?(:trajectory_exact_match_results) @trajectory_in_order_match_results = args[:trajectory_in_order_match_results] if args.key?(:trajectory_in_order_match_results) @trajectory_precision_results = args[:trajectory_precision_results] if args.key?(:trajectory_precision_results) @trajectory_recall_results = args[:trajectory_recall_results] if args.key?(:trajectory_recall_results) @trajectory_single_tool_use_results = args[:trajectory_single_tool_use_results] if args.key?(:trajectory_single_tool_use_results) end |