Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluateInstancesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Response message for EvaluationService.EvaluateInstances.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluateInstancesResponse

Returns a new instance of GoogleCloudAiplatformV1EvaluateInstancesResponse.



9316
9317
9318
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9316

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bleu_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1BleuResults

Results for bleu metric. Corresponds to the JSON property bleuResults



9151
9152
9153
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9151

def bleu_results
  @bleu_results
end

#coherence_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1CoherenceResult

Spec for coherence result. Corresponds to the JSON property coherenceResult



9156
9157
9158
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9156

def coherence_result
  @coherence_result
end

#comet_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1CometResult

Spec for Comet result - calculates the comet score for the given instance using the version specified in the spec. Corresponds to the JSON property cometResult



9162
9163
9164
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9162

def comet_result
  @comet_result
end

#exact_match_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ExactMatchResults

Results for exact match metric. Corresponds to the JSON property exactMatchResults



9167
9168
9169
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9167

def exact_match_results
  @exact_match_results
end

#fluency_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FluencyResult

Spec for fluency result. Corresponds to the JSON property fluencyResult



9172
9173
9174
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9172

def fluency_result
  @fluency_result
end

#fulfillment_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FulfillmentResult

Spec for fulfillment result. Corresponds to the JSON property fulfillmentResult



9177
9178
9179
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9177

def fulfillment_result
  @fulfillment_result
end

#groundedness_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundednessResult

Spec for groundedness result. Corresponds to the JSON property groundednessResult



9182
9183
9184
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9182

def groundedness_result
  @groundedness_result
end

#metric_resultsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetricResult>

Metric results for each instance. The order of the metric results is guaranteed to be the same as the order of the instances in the request. Corresponds to the JSON property metricResults



9188
9189
9190
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9188

def metric_results
  @metric_results
end

#metricx_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1MetricxResult

Spec for MetricX result - calculates the MetricX score for the given instance using the version specified in the spec. Corresponds to the JSON property metricxResult



9194
9195
9196
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9194

def metricx_result
  @metricx_result
end

#pairwise_metric_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PairwiseMetricResult

Spec for pairwise metric result. Corresponds to the JSON property pairwiseMetricResult



9199
9200
9201
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9199

def pairwise_metric_result
  @pairwise_metric_result
end

#pairwise_question_answering_quality_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PairwiseQuestionAnsweringQualityResult

Spec for pairwise question answering quality result. Corresponds to the JSON property pairwiseQuestionAnsweringQualityResult



9204
9205
9206
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9204

def pairwise_question_answering_quality_result
  @pairwise_question_answering_quality_result
end

#pairwise_summarization_quality_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PairwiseSummarizationQualityResult

Spec for pairwise summarization quality result. Corresponds to the JSON property pairwiseSummarizationQualityResult



9209
9210
9211
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9209

def pairwise_summarization_quality_result
  @pairwise_summarization_quality_result
end

#pointwise_metric_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PointwiseMetricResult

Spec for pointwise metric result. Corresponds to the JSON property pointwiseMetricResult



9214
9215
9216
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9214

def pointwise_metric_result
  @pointwise_metric_result
end

#question_answering_correctness_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringCorrectnessResult

Spec for question answering correctness result. Corresponds to the JSON property questionAnsweringCorrectnessResult



9219
9220
9221
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9219

def question_answering_correctness_result
  @question_answering_correctness_result
end

#question_answering_helpfulness_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringHelpfulnessResult

Spec for question answering helpfulness result. Corresponds to the JSON property questionAnsweringHelpfulnessResult



9224
9225
9226
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9224

def question_answering_helpfulness_result
  @question_answering_helpfulness_result
end

#question_answering_quality_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringQualityResult

Spec for question answering quality result. Corresponds to the JSON property questionAnsweringQualityResult



9229
9230
9231
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9229

def question_answering_quality_result
  @question_answering_quality_result
end

#question_answering_relevance_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringRelevanceResult

Spec for question answering relevance result. Corresponds to the JSON property questionAnsweringRelevanceResult



9234
9235
9236
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9234

def question_answering_relevance_result
  @question_answering_relevance_result
end

#rouge_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RougeResults

Results for rouge metric. Corresponds to the JSON property rougeResults



9239
9240
9241
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9239

def rouge_results
  @rouge_results
end

#rubric_based_instruction_following_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricBasedInstructionFollowingResult

Result for RubricBasedInstructionFollowing metric. Corresponds to the JSON property rubricBasedInstructionFollowingResult



9244
9245
9246
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9244

def rubric_based_instruction_following_result
  @rubric_based_instruction_following_result
end

#safety_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetyResult

Spec for safety result. Corresponds to the JSON property safetyResult



9249
9250
9251
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9249

def safety_result
  @safety_result
end

#summarization_helpfulness_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SummarizationHelpfulnessResult

Spec for summarization helpfulness result. Corresponds to the JSON property summarizationHelpfulnessResult



9254
9255
9256
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9254

def summarization_helpfulness_result
  @summarization_helpfulness_result
end

#summarization_quality_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SummarizationQualityResult

Spec for summarization quality result. Corresponds to the JSON property summarizationQualityResult



9259
9260
9261
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9259

def summarization_quality_result
  @summarization_quality_result
end

#summarization_verbosity_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SummarizationVerbosityResult

Spec for summarization verbosity result. Corresponds to the JSON property summarizationVerbosityResult



9264
9265
9266
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9264

def summarization_verbosity_result
  @summarization_verbosity_result
end

#tool_call_valid_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolCallValidResults

Results for tool call valid metric. Corresponds to the JSON property toolCallValidResults



9269
9270
9271
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9269

def tool_call_valid_results
  @tool_call_valid_results
end

#tool_name_match_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolNameMatchResults

Results for tool name match metric. Corresponds to the JSON property toolNameMatchResults



9274
9275
9276
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9274

def tool_name_match_results
  @tool_name_match_results
end

#tool_parameter_key_match_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolParameterKeyMatchResults

Results for tool parameter key match metric. Corresponds to the JSON property toolParameterKeyMatchResults



9279
9280
9281
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9279

def tool_parameter_key_match_results
  @tool_parameter_key_match_results
end

#tool_parameter_kv_match_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolParameterKvMatchResults

Results for tool parameter key value match metric. Corresponds to the JSON property toolParameterKvMatchResults



9284
9285
9286
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9284

def tool_parameter_kv_match_results
  @tool_parameter_kv_match_results
end

#trajectory_any_order_match_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryAnyOrderMatchResults

Results for TrajectoryAnyOrderMatch metric. Corresponds to the JSON property trajectoryAnyOrderMatchResults



9289
9290
9291
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9289

def trajectory_any_order_match_results
  @trajectory_any_order_match_results
end

#trajectory_exact_match_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryExactMatchResults

Results for TrajectoryExactMatch metric. Corresponds to the JSON property trajectoryExactMatchResults



9294
9295
9296
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9294

def trajectory_exact_match_results
  @trajectory_exact_match_results
end

#trajectory_in_order_match_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryInOrderMatchResults

Results for TrajectoryInOrderMatch metric. Corresponds to the JSON property trajectoryInOrderMatchResults



9299
9300
9301
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9299

def trajectory_in_order_match_results
  @trajectory_in_order_match_results
end

#trajectory_precision_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryPrecisionResults

Results for TrajectoryPrecision metric. Corresponds to the JSON property trajectoryPrecisionResults



9304
9305
9306
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9304

def trajectory_precision_results
  @trajectory_precision_results
end

#trajectory_recall_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryRecallResults

Results for TrajectoryRecall metric. Corresponds to the JSON property trajectoryRecallResults



9309
9310
9311
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9309

def trajectory_recall_results
  @trajectory_recall_results
end

#trajectory_single_tool_use_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectorySingleToolUseResults

Results for TrajectorySingleToolUse metric. Corresponds to the JSON property trajectorySingleToolUseResults



9314
9315
9316
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9314

def trajectory_single_tool_use_results
  @trajectory_single_tool_use_results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9321
9322
9323
9324
9325
9326
9327
9328
9329
9330
9331
9332
9333
9334
9335
9336
9337
9338
9339
9340
9341
9342
9343
9344
9345
9346
9347
9348
9349
9350
9351
9352
9353
9354
9355
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9321

def update!(**args)
  @bleu_results = args[:bleu_results] if args.key?(:bleu_results)
  @coherence_result = args[:coherence_result] if args.key?(:coherence_result)
  @comet_result = args[:comet_result] if args.key?(:comet_result)
  @exact_match_results = args[:exact_match_results] if args.key?(:exact_match_results)
  @fluency_result = args[:fluency_result] if args.key?(:fluency_result)
  @fulfillment_result = args[:fulfillment_result] if args.key?(:fulfillment_result)
  @groundedness_result = args[:groundedness_result] if args.key?(:groundedness_result)
  @metric_results = args[:metric_results] if args.key?(:metric_results)
  @metricx_result = args[:metricx_result] if args.key?(:metricx_result)
  @pairwise_metric_result = args[:pairwise_metric_result] if args.key?(:pairwise_metric_result)
  @pairwise_question_answering_quality_result = args[:pairwise_question_answering_quality_result] if args.key?(:pairwise_question_answering_quality_result)
  @pairwise_summarization_quality_result = args[:pairwise_summarization_quality_result] if args.key?(:pairwise_summarization_quality_result)
  @pointwise_metric_result = args[:pointwise_metric_result] if args.key?(:pointwise_metric_result)
  @question_answering_correctness_result = args[:question_answering_correctness_result] if args.key?(:question_answering_correctness_result)
  @question_answering_helpfulness_result = args[:question_answering_helpfulness_result] if args.key?(:question_answering_helpfulness_result)
  @question_answering_quality_result = args[:question_answering_quality_result] if args.key?(:question_answering_quality_result)
  @question_answering_relevance_result = args[:question_answering_relevance_result] if args.key?(:question_answering_relevance_result)
  @rouge_results = args[:rouge_results] if args.key?(:rouge_results)
  @rubric_based_instruction_following_result = args[:rubric_based_instruction_following_result] if args.key?(:rubric_based_instruction_following_result)
  @safety_result = args[:safety_result] if args.key?(:safety_result)
  @summarization_helpfulness_result = args[:summarization_helpfulness_result] if args.key?(:summarization_helpfulness_result)
  @summarization_quality_result = args[:summarization_quality_result] if args.key?(:summarization_quality_result)
  @summarization_verbosity_result = args[:summarization_verbosity_result] if args.key?(:summarization_verbosity_result)
  @tool_call_valid_results = args[:tool_call_valid_results] if args.key?(:tool_call_valid_results)
  @tool_name_match_results = args[:tool_name_match_results] if args.key?(:tool_name_match_results)
  @tool_parameter_key_match_results = args[:tool_parameter_key_match_results] if args.key?(:tool_parameter_key_match_results)
  @tool_parameter_kv_match_results = args[:tool_parameter_kv_match_results] if args.key?(:tool_parameter_kv_match_results)
  @trajectory_any_order_match_results = args[:trajectory_any_order_match_results] if args.key?(:trajectory_any_order_match_results)
  @trajectory_exact_match_results = args[:trajectory_exact_match_results] if args.key?(:trajectory_exact_match_results)
  @trajectory_in_order_match_results = args[:trajectory_in_order_match_results] if args.key?(:trajectory_in_order_match_results)
  @trajectory_precision_results = args[:trajectory_precision_results] if args.key?(:trajectory_precision_results)
  @trajectory_recall_results = args[:trajectory_recall_results] if args.key?(:trajectory_recall_results)
  @trajectory_single_tool_use_results = args[:trajectory_single_tool_use_results] if args.key?(:trajectory_single_tool_use_results)
end