Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluateInstancesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Response message for EvaluationService.EvaluateInstances.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluateInstancesResponse

Returns a new instance of GoogleCloudAiplatformV1EvaluateInstancesResponse.



8053
8054
8055
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8053

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bleu_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1BleuResults

Results for bleu metric. Corresponds to the JSON property bleuResults



7894
7895
7896
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7894

def bleu_results
  @bleu_results
end

#coherence_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1CoherenceResult

Spec for coherence result. Corresponds to the JSON property coherenceResult



7899
7900
7901
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7899

def coherence_result
  @coherence_result
end

#comet_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1CometResult

Spec for Comet result - calculates the comet score for the given instance using the version specified in the spec. Corresponds to the JSON property cometResult



7905
7906
7907
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7905

def comet_result
  @comet_result
end

#exact_match_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ExactMatchResults

Results for exact match metric. Corresponds to the JSON property exactMatchResults



7910
7911
7912
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7910

def exact_match_results
  @exact_match_results
end

#fluency_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FluencyResult

Spec for fluency result. Corresponds to the JSON property fluencyResult



7915
7916
7917
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7915

def fluency_result
  @fluency_result
end

#fulfillment_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FulfillmentResult

Spec for fulfillment result. Corresponds to the JSON property fulfillmentResult



7920
7921
7922
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7920

def fulfillment_result
  @fulfillment_result
end

#groundedness_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundednessResult

Spec for groundedness result. Corresponds to the JSON property groundednessResult



7925
7926
7927
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7925

def groundedness_result
  @groundedness_result
end

#metricx_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1MetricxResult

Spec for MetricX result - calculates the MetricX score for the given instance using the version specified in the spec. Corresponds to the JSON property metricxResult



7931
7932
7933
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7931

def metricx_result
  @metricx_result
end

#pairwise_metric_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PairwiseMetricResult

Spec for pairwise metric result. Corresponds to the JSON property pairwiseMetricResult



7936
7937
7938
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7936

def pairwise_metric_result
  @pairwise_metric_result
end

#pairwise_question_answering_quality_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PairwiseQuestionAnsweringQualityResult

Spec for pairwise question answering quality result. Corresponds to the JSON property pairwiseQuestionAnsweringQualityResult



7941
7942
7943
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7941

def pairwise_question_answering_quality_result
  @pairwise_question_answering_quality_result
end

#pairwise_summarization_quality_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PairwiseSummarizationQualityResult

Spec for pairwise summarization quality result. Corresponds to the JSON property pairwiseSummarizationQualityResult



7946
7947
7948
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7946

def pairwise_summarization_quality_result
  @pairwise_summarization_quality_result
end

#pointwise_metric_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PointwiseMetricResult

Spec for pointwise metric result. Corresponds to the JSON property pointwiseMetricResult



7951
7952
7953
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7951

def pointwise_metric_result
  @pointwise_metric_result
end

#question_answering_correctness_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringCorrectnessResult

Spec for question answering correctness result. Corresponds to the JSON property questionAnsweringCorrectnessResult



7956
7957
7958
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7956

def question_answering_correctness_result
  @question_answering_correctness_result
end

#question_answering_helpfulness_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringHelpfulnessResult

Spec for question answering helpfulness result. Corresponds to the JSON property questionAnsweringHelpfulnessResult



7961
7962
7963
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7961

def question_answering_helpfulness_result
  @question_answering_helpfulness_result
end

#question_answering_quality_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringQualityResult

Spec for question answering quality result. Corresponds to the JSON property questionAnsweringQualityResult



7966
7967
7968
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7966

def question_answering_quality_result
  @question_answering_quality_result
end

#question_answering_relevance_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringRelevanceResult

Spec for question answering relevance result. Corresponds to the JSON property questionAnsweringRelevanceResult



7971
7972
7973
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7971

def question_answering_relevance_result
  @question_answering_relevance_result
end

#rouge_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RougeResults

Results for rouge metric. Corresponds to the JSON property rougeResults



7976
7977
7978
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7976

def rouge_results
  @rouge_results
end

#rubric_based_instruction_following_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricBasedInstructionFollowingResult

Result for RubricBasedInstructionFollowing metric. Corresponds to the JSON property rubricBasedInstructionFollowingResult



7981
7982
7983
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7981

def rubric_based_instruction_following_result
  @rubric_based_instruction_following_result
end

#safety_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetyResult

Spec for safety result. Corresponds to the JSON property safetyResult



7986
7987
7988
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7986

def safety_result
  @safety_result
end

#summarization_helpfulness_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SummarizationHelpfulnessResult

Spec for summarization helpfulness result. Corresponds to the JSON property summarizationHelpfulnessResult



7991
7992
7993
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7991

def summarization_helpfulness_result
  @summarization_helpfulness_result
end

#summarization_quality_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SummarizationQualityResult

Spec for summarization quality result. Corresponds to the JSON property summarizationQualityResult



7996
7997
7998
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7996

def summarization_quality_result
  @summarization_quality_result
end

#summarization_verbosity_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SummarizationVerbosityResult

Spec for summarization verbosity result. Corresponds to the JSON property summarizationVerbosityResult



8001
8002
8003
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8001

def summarization_verbosity_result
  @summarization_verbosity_result
end

#tool_call_valid_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolCallValidResults

Results for tool call valid metric. Corresponds to the JSON property toolCallValidResults



8006
8007
8008
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8006

def tool_call_valid_results
  @tool_call_valid_results
end

#tool_name_match_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolNameMatchResults

Results for tool name match metric. Corresponds to the JSON property toolNameMatchResults



8011
8012
8013
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8011

def tool_name_match_results
  @tool_name_match_results
end

#tool_parameter_key_match_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolParameterKeyMatchResults

Results for tool parameter key match metric. Corresponds to the JSON property toolParameterKeyMatchResults



8016
8017
8018
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8016

def tool_parameter_key_match_results
  @tool_parameter_key_match_results
end

#tool_parameter_kv_match_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolParameterKvMatchResults

Results for tool parameter key value match metric. Corresponds to the JSON property toolParameterKvMatchResults



8021
8022
8023
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8021

def tool_parameter_kv_match_results
  @tool_parameter_kv_match_results
end

#trajectory_any_order_match_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryAnyOrderMatchResults

Results for TrajectoryAnyOrderMatch metric. Corresponds to the JSON property trajectoryAnyOrderMatchResults



8026
8027
8028
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8026

def trajectory_any_order_match_results
  @trajectory_any_order_match_results
end

#trajectory_exact_match_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryExactMatchResults

Results for TrajectoryExactMatch metric. Corresponds to the JSON property trajectoryExactMatchResults



8031
8032
8033
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8031

def trajectory_exact_match_results
  @trajectory_exact_match_results
end

#trajectory_in_order_match_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryInOrderMatchResults

Results for TrajectoryInOrderMatch metric. Corresponds to the JSON property trajectoryInOrderMatchResults



8036
8037
8038
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8036

def trajectory_in_order_match_results
  @trajectory_in_order_match_results
end

#trajectory_precision_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryPrecisionResults

Results for TrajectoryPrecision metric. Corresponds to the JSON property trajectoryPrecisionResults



8041
8042
8043
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8041

def trajectory_precision_results
  @trajectory_precision_results
end

#trajectory_recall_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryRecallResults

Results for TrajectoryRecall metric. Corresponds to the JSON property trajectoryRecallResults



8046
8047
8048
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8046

def trajectory_recall_results
  @trajectory_recall_results
end

#trajectory_single_tool_use_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectorySingleToolUseResults

Results for TrajectorySingleToolUse metric. Corresponds to the JSON property trajectorySingleToolUseResults



8051
8052
8053
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8051

def trajectory_single_tool_use_results
  @trajectory_single_tool_use_results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8058
8059
8060
8061
8062
8063
8064
8065
8066
8067
8068
8069
8070
8071
8072
8073
8074
8075
8076
8077
8078
8079
8080
8081
8082
8083
8084
8085
8086
8087
8088
8089
8090
8091
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8058

def update!(**args)
  @bleu_results = args[:bleu_results] if args.key?(:bleu_results)
  @coherence_result = args[:coherence_result] if args.key?(:coherence_result)
  @comet_result = args[:comet_result] if args.key?(:comet_result)
  @exact_match_results = args[:exact_match_results] if args.key?(:exact_match_results)
  @fluency_result = args[:fluency_result] if args.key?(:fluency_result)
  @fulfillment_result = args[:fulfillment_result] if args.key?(:fulfillment_result)
  @groundedness_result = args[:groundedness_result] if args.key?(:groundedness_result)
  @metricx_result = args[:metricx_result] if args.key?(:metricx_result)
  @pairwise_metric_result = args[:pairwise_metric_result] if args.key?(:pairwise_metric_result)
  @pairwise_question_answering_quality_result = args[:pairwise_question_answering_quality_result] if args.key?(:pairwise_question_answering_quality_result)
  @pairwise_summarization_quality_result = args[:pairwise_summarization_quality_result] if args.key?(:pairwise_summarization_quality_result)
  @pointwise_metric_result = args[:pointwise_metric_result] if args.key?(:pointwise_metric_result)
  @question_answering_correctness_result = args[:question_answering_correctness_result] if args.key?(:question_answering_correctness_result)
  @question_answering_helpfulness_result = args[:question_answering_helpfulness_result] if args.key?(:question_answering_helpfulness_result)
  @question_answering_quality_result = args[:question_answering_quality_result] if args.key?(:question_answering_quality_result)
  @question_answering_relevance_result = args[:question_answering_relevance_result] if args.key?(:question_answering_relevance_result)
  @rouge_results = args[:rouge_results] if args.key?(:rouge_results)
  @rubric_based_instruction_following_result = args[:rubric_based_instruction_following_result] if args.key?(:rubric_based_instruction_following_result)
  @safety_result = args[:safety_result] if args.key?(:safety_result)
  @summarization_helpfulness_result = args[:summarization_helpfulness_result] if args.key?(:summarization_helpfulness_result)
  @summarization_quality_result = args[:summarization_quality_result] if args.key?(:summarization_quality_result)
  @summarization_verbosity_result = args[:summarization_verbosity_result] if args.key?(:summarization_verbosity_result)
  @tool_call_valid_results = args[:tool_call_valid_results] if args.key?(:tool_call_valid_results)
  @tool_name_match_results = args[:tool_name_match_results] if args.key?(:tool_name_match_results)
  @tool_parameter_key_match_results = args[:tool_parameter_key_match_results] if args.key?(:tool_parameter_key_match_results)
  @tool_parameter_kv_match_results = args[:tool_parameter_kv_match_results] if args.key?(:tool_parameter_kv_match_results)
  @trajectory_any_order_match_results = args[:trajectory_any_order_match_results] if args.key?(:trajectory_any_order_match_results)
  @trajectory_exact_match_results = args[:trajectory_exact_match_results] if args.key?(:trajectory_exact_match_results)
  @trajectory_in_order_match_results = args[:trajectory_in_order_match_results] if args.key?(:trajectory_in_order_match_results)
  @trajectory_precision_results = args[:trajectory_precision_results] if args.key?(:trajectory_precision_results)
  @trajectory_recall_results = args[:trajectory_recall_results] if args.key?(:trajectory_recall_results)
  @trajectory_single_tool_use_results = args[:trajectory_single_tool_use_results] if args.key?(:trajectory_single_tool_use_results)
end