Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluateInstancesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Response message for EvaluationService.EvaluateInstances.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluateInstancesResponse

Returns a new instance of GoogleCloudAiplatformV1EvaluateInstancesResponse.



7729
7730
7731
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7729

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bleu_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1BleuResults

Results for bleu metric. Corresponds to the JSON property bleuResults



7570
7571
7572
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7570

def bleu_results
  @bleu_results
end

#coherence_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1CoherenceResult

Spec for coherence result. Corresponds to the JSON property coherenceResult



7575
7576
7577
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7575

def coherence_result
  @coherence_result
end

#comet_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1CometResult

Spec for Comet result - calculates the comet score for the given instance using the version specified in the spec. Corresponds to the JSON property cometResult



7581
7582
7583
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7581

def comet_result
  @comet_result
end

#exact_match_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ExactMatchResults

Results for exact match metric. Corresponds to the JSON property exactMatchResults



7586
7587
7588
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7586

def exact_match_results
  @exact_match_results
end

#fluency_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FluencyResult

Spec for fluency result. Corresponds to the JSON property fluencyResult



7591
7592
7593
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7591

def fluency_result
  @fluency_result
end

#fulfillment_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FulfillmentResult

Spec for fulfillment result. Corresponds to the JSON property fulfillmentResult



7596
7597
7598
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7596

def fulfillment_result
  @fulfillment_result
end

#groundedness_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundednessResult

Spec for groundedness result. Corresponds to the JSON property groundednessResult



7601
7602
7603
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7601

def groundedness_result
  @groundedness_result
end

#metricx_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1MetricxResult

Spec for MetricX result - calculates the MetricX score for the given instance using the version specified in the spec. Corresponds to the JSON property metricxResult



7607
7608
7609
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7607

def metricx_result
  @metricx_result
end

#pairwise_metric_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PairwiseMetricResult

Spec for pairwise metric result. Corresponds to the JSON property pairwiseMetricResult



7612
7613
7614
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7612

def pairwise_metric_result
  @pairwise_metric_result
end

#pairwise_question_answering_quality_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PairwiseQuestionAnsweringQualityResult

Spec for pairwise question answering quality result. Corresponds to the JSON property pairwiseQuestionAnsweringQualityResult



7617
7618
7619
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7617

def pairwise_question_answering_quality_result
  @pairwise_question_answering_quality_result
end

#pairwise_summarization_quality_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PairwiseSummarizationQualityResult

Spec for pairwise summarization quality result. Corresponds to the JSON property pairwiseSummarizationQualityResult



7622
7623
7624
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7622

def pairwise_summarization_quality_result
  @pairwise_summarization_quality_result
end

#pointwise_metric_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PointwiseMetricResult

Spec for pointwise metric result. Corresponds to the JSON property pointwiseMetricResult



7627
7628
7629
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7627

def pointwise_metric_result
  @pointwise_metric_result
end

#question_answering_correctness_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringCorrectnessResult

Spec for question answering correctness result. Corresponds to the JSON property questionAnsweringCorrectnessResult



7632
7633
7634
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7632

def question_answering_correctness_result
  @question_answering_correctness_result
end

#question_answering_helpfulness_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringHelpfulnessResult

Spec for question answering helpfulness result. Corresponds to the JSON property questionAnsweringHelpfulnessResult



7637
7638
7639
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7637

def question_answering_helpfulness_result
  @question_answering_helpfulness_result
end

#question_answering_quality_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringQualityResult

Spec for question answering quality result. Corresponds to the JSON property questionAnsweringQualityResult



7642
7643
7644
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7642

def question_answering_quality_result
  @question_answering_quality_result
end

#question_answering_relevance_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringRelevanceResult

Spec for question answering relevance result. Corresponds to the JSON property questionAnsweringRelevanceResult



7647
7648
7649
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7647

def question_answering_relevance_result
  @question_answering_relevance_result
end

#rouge_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RougeResults

Results for rouge metric. Corresponds to the JSON property rougeResults



7652
7653
7654
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7652

def rouge_results
  @rouge_results
end

#rubric_based_instruction_following_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricBasedInstructionFollowingResult

Result for RubricBasedInstructionFollowing metric. Corresponds to the JSON property rubricBasedInstructionFollowingResult



7657
7658
7659
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7657

def rubric_based_instruction_following_result
  @rubric_based_instruction_following_result
end

#safety_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetyResult

Spec for safety result. Corresponds to the JSON property safetyResult



7662
7663
7664
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7662

def safety_result
  @safety_result
end

#summarization_helpfulness_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SummarizationHelpfulnessResult

Spec for summarization helpfulness result. Corresponds to the JSON property summarizationHelpfulnessResult



7667
7668
7669
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7667

def summarization_helpfulness_result
  @summarization_helpfulness_result
end

#summarization_quality_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SummarizationQualityResult

Spec for summarization quality result. Corresponds to the JSON property summarizationQualityResult



7672
7673
7674
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7672

def summarization_quality_result
  @summarization_quality_result
end

#summarization_verbosity_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SummarizationVerbosityResult

Spec for summarization verbosity result. Corresponds to the JSON property summarizationVerbosityResult



7677
7678
7679
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7677

def summarization_verbosity_result
  @summarization_verbosity_result
end

#tool_call_valid_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolCallValidResults

Results for tool call valid metric. Corresponds to the JSON property toolCallValidResults



7682
7683
7684
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7682

def tool_call_valid_results
  @tool_call_valid_results
end

#tool_name_match_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolNameMatchResults

Results for tool name match metric. Corresponds to the JSON property toolNameMatchResults



7687
7688
7689
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7687

def tool_name_match_results
  @tool_name_match_results
end

#tool_parameter_key_match_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolParameterKeyMatchResults

Results for tool parameter key match metric. Corresponds to the JSON property toolParameterKeyMatchResults



7692
7693
7694
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7692

def tool_parameter_key_match_results
  @tool_parameter_key_match_results
end

#tool_parameter_kv_match_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolParameterKvMatchResults

Results for tool parameter key value match metric. Corresponds to the JSON property toolParameterKvMatchResults



7697
7698
7699
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7697

def tool_parameter_kv_match_results
  @tool_parameter_kv_match_results
end

#trajectory_any_order_match_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryAnyOrderMatchResults

Results for TrajectoryAnyOrderMatch metric. Corresponds to the JSON property trajectoryAnyOrderMatchResults



7702
7703
7704
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7702

def trajectory_any_order_match_results
  @trajectory_any_order_match_results
end

#trajectory_exact_match_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryExactMatchResults

Results for TrajectoryExactMatch metric. Corresponds to the JSON property trajectoryExactMatchResults



7707
7708
7709
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7707

def trajectory_exact_match_results
  @trajectory_exact_match_results
end

#trajectory_in_order_match_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryInOrderMatchResults

Results for TrajectoryInOrderMatch metric. Corresponds to the JSON property trajectoryInOrderMatchResults



7712
7713
7714
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7712

def trajectory_in_order_match_results
  @trajectory_in_order_match_results
end

#trajectory_precision_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryPrecisionResults

Results for TrajectoryPrecision metric. Corresponds to the JSON property trajectoryPrecisionResults



7717
7718
7719
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7717

def trajectory_precision_results
  @trajectory_precision_results
end

#trajectory_recall_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryRecallResults

Results for TrajectoryRecall metric. Corresponds to the JSON property trajectoryRecallResults



7722
7723
7724
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7722

def trajectory_recall_results
  @trajectory_recall_results
end

#trajectory_single_tool_use_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectorySingleToolUseResults

Results for TrajectorySingleToolUse metric. Corresponds to the JSON property trajectorySingleToolUseResults



7727
7728
7729
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7727

def trajectory_single_tool_use_results
  @trajectory_single_tool_use_results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7734
7735
7736
7737
7738
7739
7740
7741
7742
7743
7744
7745
7746
7747
7748
7749
7750
7751
7752
7753
7754
7755
7756
7757
7758
7759
7760
7761
7762
7763
7764
7765
7766
7767
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7734

def update!(**args)
  @bleu_results = args[:bleu_results] if args.key?(:bleu_results)
  @coherence_result = args[:coherence_result] if args.key?(:coherence_result)
  @comet_result = args[:comet_result] if args.key?(:comet_result)
  @exact_match_results = args[:exact_match_results] if args.key?(:exact_match_results)
  @fluency_result = args[:fluency_result] if args.key?(:fluency_result)
  @fulfillment_result = args[:fulfillment_result] if args.key?(:fulfillment_result)
  @groundedness_result = args[:groundedness_result] if args.key?(:groundedness_result)
  @metricx_result = args[:metricx_result] if args.key?(:metricx_result)
  @pairwise_metric_result = args[:pairwise_metric_result] if args.key?(:pairwise_metric_result)
  @pairwise_question_answering_quality_result = args[:pairwise_question_answering_quality_result] if args.key?(:pairwise_question_answering_quality_result)
  @pairwise_summarization_quality_result = args[:pairwise_summarization_quality_result] if args.key?(:pairwise_summarization_quality_result)
  @pointwise_metric_result = args[:pointwise_metric_result] if args.key?(:pointwise_metric_result)
  @question_answering_correctness_result = args[:question_answering_correctness_result] if args.key?(:question_answering_correctness_result)
  @question_answering_helpfulness_result = args[:question_answering_helpfulness_result] if args.key?(:question_answering_helpfulness_result)
  @question_answering_quality_result = args[:question_answering_quality_result] if args.key?(:question_answering_quality_result)
  @question_answering_relevance_result = args[:question_answering_relevance_result] if args.key?(:question_answering_relevance_result)
  @rouge_results = args[:rouge_results] if args.key?(:rouge_results)
  @rubric_based_instruction_following_result = args[:rubric_based_instruction_following_result] if args.key?(:rubric_based_instruction_following_result)
  @safety_result = args[:safety_result] if args.key?(:safety_result)
  @summarization_helpfulness_result = args[:summarization_helpfulness_result] if args.key?(:summarization_helpfulness_result)
  @summarization_quality_result = args[:summarization_quality_result] if args.key?(:summarization_quality_result)
  @summarization_verbosity_result = args[:summarization_verbosity_result] if args.key?(:summarization_verbosity_result)
  @tool_call_valid_results = args[:tool_call_valid_results] if args.key?(:tool_call_valid_results)
  @tool_name_match_results = args[:tool_name_match_results] if args.key?(:tool_name_match_results)
  @tool_parameter_key_match_results = args[:tool_parameter_key_match_results] if args.key?(:tool_parameter_key_match_results)
  @tool_parameter_kv_match_results = args[:tool_parameter_kv_match_results] if args.key?(:tool_parameter_kv_match_results)
  @trajectory_any_order_match_results = args[:trajectory_any_order_match_results] if args.key?(:trajectory_any_order_match_results)
  @trajectory_exact_match_results = args[:trajectory_exact_match_results] if args.key?(:trajectory_exact_match_results)
  @trajectory_in_order_match_results = args[:trajectory_in_order_match_results] if args.key?(:trajectory_in_order_match_results)
  @trajectory_precision_results = args[:trajectory_precision_results] if args.key?(:trajectory_precision_results)
  @trajectory_recall_results = args[:trajectory_recall_results] if args.key?(:trajectory_recall_results)
  @trajectory_single_tool_use_results = args[:trajectory_single_tool_use_results] if args.key?(:trajectory_single_tool_use_results)
end