Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluateInstancesResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluateInstancesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Response message for EvaluationService.EvaluateInstances.
Instance Attribute Summary collapse
-
#bleu_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BleuResults
Results for bleu metric.
-
#coherence_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CoherenceResult
Spec for coherence result.
-
#comet_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CometResult
Spec for Comet result - calculates the comet score for the given instance using the version specified in the spec.
-
#exact_match_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExactMatchResults
Results for exact match metric.
-
#fluency_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FluencyResult
Spec for fluency result.
-
#fulfillment_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FulfillmentResult
Spec for fulfillment result.
-
#groundedness_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundednessResult
Spec for groundedness result.
-
#metricx_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetricxResult
Spec for MetricX result - calculates the MetricX score for the given instance using the version specified in the spec.
-
#pairwise_metric_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PairwiseMetricResult
Spec for pairwise metric result.
-
#pairwise_question_answering_quality_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PairwiseQuestionAnsweringQualityResult
Spec for pairwise question answering quality result.
-
#pairwise_summarization_quality_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PairwiseSummarizationQualityResult
Spec for pairwise summarization quality result.
-
#pointwise_metric_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PointwiseMetricResult
Spec for pointwise metric result.
-
#question_answering_correctness_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringCorrectnessResult
Spec for question answering correctness result.
-
#question_answering_helpfulness_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringHelpfulnessResult
Spec for question answering helpfulness result.
-
#question_answering_quality_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringQualityResult
Spec for question answering quality result.
-
#question_answering_relevance_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringRelevanceResult
Spec for question answering relevance result.
-
#rouge_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RougeResults
Results for rouge metric.
-
#rubric_based_instruction_following_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricBasedInstructionFollowingResult
Result for RubricBasedInstructionFollowing metric.
-
#safety_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetyResult
Spec for safety result.
-
#summarization_helpfulness_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SummarizationHelpfulnessResult
Spec for summarization helpfulness result.
-
#summarization_quality_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SummarizationQualityResult
Spec for summarization quality result.
-
#summarization_verbosity_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SummarizationVerbosityResult
Spec for summarization verbosity result.
-
#tool_call_valid_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolCallValidResults
Results for tool call valid metric.
-
#tool_name_match_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolNameMatchResults
Results for tool name match metric.
-
#tool_parameter_key_match_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolParameterKeyMatchResults
Results for tool parameter key match metric.
-
#tool_parameter_kv_match_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolParameterKvMatchResults
Results for tool parameter key value match metric.
-
#trajectory_any_order_match_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryAnyOrderMatchResults
Results for TrajectoryAnyOrderMatch metric.
-
#trajectory_exact_match_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryExactMatchResults
Results for TrajectoryExactMatch metric.
-
#trajectory_in_order_match_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryInOrderMatchResults
Results for TrajectoryInOrderMatch metric.
-
#trajectory_precision_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryPrecisionResults
Results for TrajectoryPrecision metric.
-
#trajectory_recall_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryRecallResults
Results for TrajectoryRecall metric.
-
#trajectory_single_tool_use_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectorySingleToolUseResults
Results for TrajectorySingleToolUse metric.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluateInstancesResponse
constructor
A new instance of GoogleCloudAiplatformV1EvaluateInstancesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluateInstancesResponse
Returns a new instance of GoogleCloudAiplatformV1EvaluateInstancesResponse.
7470 7471 7472 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7470 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bleu_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BleuResults
Results for bleu metric.
Corresponds to the JSON property bleuResults
7311 7312 7313 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7311 def bleu_results @bleu_results end |
#coherence_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CoherenceResult
Spec for coherence result.
Corresponds to the JSON property coherenceResult
7316 7317 7318 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7316 def coherence_result @coherence_result end |
#comet_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CometResult
Spec for Comet result - calculates the comet score for the given instance
using the version specified in the spec.
Corresponds to the JSON property cometResult
7322 7323 7324 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7322 def comet_result @comet_result end |
#exact_match_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExactMatchResults
Results for exact match metric.
Corresponds to the JSON property exactMatchResults
7327 7328 7329 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7327 def exact_match_results @exact_match_results end |
#fluency_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FluencyResult
Spec for fluency result.
Corresponds to the JSON property fluencyResult
7332 7333 7334 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7332 def fluency_result @fluency_result end |
#fulfillment_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FulfillmentResult
Spec for fulfillment result.
Corresponds to the JSON property fulfillmentResult
7337 7338 7339 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7337 def fulfillment_result @fulfillment_result end |
#groundedness_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundednessResult
Spec for groundedness result.
Corresponds to the JSON property groundednessResult
7342 7343 7344 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7342 def groundedness_result @groundedness_result end |
#metricx_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetricxResult
Spec for MetricX result - calculates the MetricX score for the given instance
using the version specified in the spec.
Corresponds to the JSON property metricxResult
7348 7349 7350 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7348 def metricx_result @metricx_result end |
#pairwise_metric_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PairwiseMetricResult
Spec for pairwise metric result.
Corresponds to the JSON property pairwiseMetricResult
7353 7354 7355 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7353 def pairwise_metric_result @pairwise_metric_result end |
#pairwise_question_answering_quality_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PairwiseQuestionAnsweringQualityResult
Spec for pairwise question answering quality result.
Corresponds to the JSON property pairwiseQuestionAnsweringQualityResult
7358 7359 7360 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7358 def pairwise_question_answering_quality_result @pairwise_question_answering_quality_result end |
#pairwise_summarization_quality_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PairwiseSummarizationQualityResult
Spec for pairwise summarization quality result.
Corresponds to the JSON property pairwiseSummarizationQualityResult
7363 7364 7365 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7363 def pairwise_summarization_quality_result @pairwise_summarization_quality_result end |
#pointwise_metric_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PointwiseMetricResult
Spec for pointwise metric result.
Corresponds to the JSON property pointwiseMetricResult
7368 7369 7370 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7368 def pointwise_metric_result @pointwise_metric_result end |
#question_answering_correctness_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringCorrectnessResult
Spec for question answering correctness result.
Corresponds to the JSON property questionAnsweringCorrectnessResult
7373 7374 7375 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7373 def question_answering_correctness_result @question_answering_correctness_result end |
#question_answering_helpfulness_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringHelpfulnessResult
Spec for question answering helpfulness result.
Corresponds to the JSON property questionAnsweringHelpfulnessResult
7378 7379 7380 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7378 def question_answering_helpfulness_result @question_answering_helpfulness_result end |
#question_answering_quality_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringQualityResult
Spec for question answering quality result.
Corresponds to the JSON property questionAnsweringQualityResult
7383 7384 7385 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7383 def question_answering_quality_result @question_answering_quality_result end |
#question_answering_relevance_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringRelevanceResult
Spec for question answering relevance result.
Corresponds to the JSON property questionAnsweringRelevanceResult
7388 7389 7390 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7388 def question_answering_relevance_result @question_answering_relevance_result end |
#rouge_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RougeResults
Results for rouge metric.
Corresponds to the JSON property rougeResults
7393 7394 7395 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7393 def rouge_results @rouge_results end |
#rubric_based_instruction_following_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricBasedInstructionFollowingResult
Result for RubricBasedInstructionFollowing metric.
Corresponds to the JSON property rubricBasedInstructionFollowingResult
7398 7399 7400 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7398 def rubric_based_instruction_following_result @rubric_based_instruction_following_result end |
#safety_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetyResult
Spec for safety result.
Corresponds to the JSON property safetyResult
7403 7404 7405 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7403 def safety_result @safety_result end |
#summarization_helpfulness_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SummarizationHelpfulnessResult
Spec for summarization helpfulness result.
Corresponds to the JSON property summarizationHelpfulnessResult
7408 7409 7410 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7408 def summarization_helpfulness_result @summarization_helpfulness_result end |
#summarization_quality_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SummarizationQualityResult
Spec for summarization quality result.
Corresponds to the JSON property summarizationQualityResult
7413 7414 7415 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7413 def summarization_quality_result @summarization_quality_result end |
#summarization_verbosity_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SummarizationVerbosityResult
Spec for summarization verbosity result.
Corresponds to the JSON property summarizationVerbosityResult
7418 7419 7420 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7418 def summarization_verbosity_result @summarization_verbosity_result end |
#tool_call_valid_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolCallValidResults
Results for tool call valid metric.
Corresponds to the JSON property toolCallValidResults
7423 7424 7425 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7423 def tool_call_valid_results @tool_call_valid_results end |
#tool_name_match_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolNameMatchResults
Results for tool name match metric.
Corresponds to the JSON property toolNameMatchResults
7428 7429 7430 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7428 def tool_name_match_results @tool_name_match_results end |
#tool_parameter_key_match_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolParameterKeyMatchResults
Results for tool parameter key match metric.
Corresponds to the JSON property toolParameterKeyMatchResults
7433 7434 7435 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7433 def tool_parameter_key_match_results @tool_parameter_key_match_results end |
#tool_parameter_kv_match_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolParameterKvMatchResults
Results for tool parameter key value match metric.
Corresponds to the JSON property toolParameterKvMatchResults
7438 7439 7440 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7438 def tool_parameter_kv_match_results @tool_parameter_kv_match_results end |
#trajectory_any_order_match_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryAnyOrderMatchResults
Results for TrajectoryAnyOrderMatch metric.
Corresponds to the JSON property trajectoryAnyOrderMatchResults
7443 7444 7445 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7443 def trajectory_any_order_match_results @trajectory_any_order_match_results end |
#trajectory_exact_match_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryExactMatchResults
Results for TrajectoryExactMatch metric.
Corresponds to the JSON property trajectoryExactMatchResults
7448 7449 7450 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7448 def trajectory_exact_match_results @trajectory_exact_match_results end |
#trajectory_in_order_match_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryInOrderMatchResults
Results for TrajectoryInOrderMatch metric.
Corresponds to the JSON property trajectoryInOrderMatchResults
7453 7454 7455 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7453 def trajectory_in_order_match_results @trajectory_in_order_match_results end |
#trajectory_precision_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryPrecisionResults
Results for TrajectoryPrecision metric.
Corresponds to the JSON property trajectoryPrecisionResults
7458 7459 7460 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7458 def trajectory_precision_results @trajectory_precision_results end |
#trajectory_recall_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryRecallResults
Results for TrajectoryRecall metric.
Corresponds to the JSON property trajectoryRecallResults
7463 7464 7465 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7463 def trajectory_recall_results @trajectory_recall_results end |
#trajectory_single_tool_use_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectorySingleToolUseResults
Results for TrajectorySingleToolUse metric.
Corresponds to the JSON property trajectorySingleToolUseResults
7468 7469 7470 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7468 def trajectory_single_tool_use_results @trajectory_single_tool_use_results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 7487 7488 7489 7490 7491 7492 7493 7494 7495 7496 7497 7498 7499 7500 7501 7502 7503 7504 7505 7506 7507 7508 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7475 def update!(**args) @bleu_results = args[:bleu_results] if args.key?(:bleu_results) @coherence_result = args[:coherence_result] if args.key?(:coherence_result) @comet_result = args[:comet_result] if args.key?(:comet_result) @exact_match_results = args[:exact_match_results] if args.key?(:exact_match_results) @fluency_result = args[:fluency_result] if args.key?(:fluency_result) @fulfillment_result = args[:fulfillment_result] if args.key?(:fulfillment_result) @groundedness_result = args[:groundedness_result] if args.key?(:groundedness_result) @metricx_result = args[:metricx_result] if args.key?(:metricx_result) @pairwise_metric_result = args[:pairwise_metric_result] if args.key?(:pairwise_metric_result) @pairwise_question_answering_quality_result = args[:pairwise_question_answering_quality_result] if args.key?(:pairwise_question_answering_quality_result) @pairwise_summarization_quality_result = args[:pairwise_summarization_quality_result] if args.key?(:pairwise_summarization_quality_result) @pointwise_metric_result = args[:pointwise_metric_result] if args.key?(:pointwise_metric_result) @question_answering_correctness_result = args[:question_answering_correctness_result] if args.key?(:question_answering_correctness_result) @question_answering_helpfulness_result = args[:question_answering_helpfulness_result] if args.key?(:question_answering_helpfulness_result) @question_answering_quality_result = args[:question_answering_quality_result] if args.key?(:question_answering_quality_result) @question_answering_relevance_result = args[:question_answering_relevance_result] if args.key?(:question_answering_relevance_result) @rouge_results = args[:rouge_results] if args.key?(:rouge_results) @rubric_based_instruction_following_result = args[:rubric_based_instruction_following_result] if args.key?(:rubric_based_instruction_following_result) @safety_result = args[:safety_result] if args.key?(:safety_result) @summarization_helpfulness_result = args[:summarization_helpfulness_result] if args.key?(:summarization_helpfulness_result) @summarization_quality_result = args[:summarization_quality_result] if args.key?(:summarization_quality_result) @summarization_verbosity_result = args[:summarization_verbosity_result] if args.key?(:summarization_verbosity_result) @tool_call_valid_results = args[:tool_call_valid_results] if args.key?(:tool_call_valid_results) @tool_name_match_results = args[:tool_name_match_results] if args.key?(:tool_name_match_results) @tool_parameter_key_match_results = args[:tool_parameter_key_match_results] if args.key?(:tool_parameter_key_match_results) @tool_parameter_kv_match_results = args[:tool_parameter_kv_match_results] if args.key?(:tool_parameter_kv_match_results) @trajectory_any_order_match_results = args[:trajectory_any_order_match_results] if args.key?(:trajectory_any_order_match_results) @trajectory_exact_match_results = args[:trajectory_exact_match_results] if args.key?(:trajectory_exact_match_results) @trajectory_in_order_match_results = args[:trajectory_in_order_match_results] if args.key?(:trajectory_in_order_match_results) @trajectory_precision_results = args[:trajectory_precision_results] if args.key?(:trajectory_precision_results) @trajectory_recall_results = args[:trajectory_recall_results] if args.key?(:trajectory_recall_results) @trajectory_single_tool_use_results = args[:trajectory_single_tool_use_results] if args.key?(:trajectory_single_tool_use_results) end |