Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluateInstancesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Response message for EvaluationService.EvaluateInstances.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluateInstancesResponse

Returns a new instance of GoogleCloudAiplatformV1EvaluateInstancesResponse.



7283
7284
7285
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7283

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bleu_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1BleuResults

Results for bleu metric. Corresponds to the JSON property bleuResults



7129
7130
7131
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7129

def bleu_results
  @bleu_results
end

#coherence_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1CoherenceResult

Spec for coherence result. Corresponds to the JSON property coherenceResult



7134
7135
7136
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7134

def coherence_result
  @coherence_result
end

#comet_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1CometResult

Spec for Comet result - calculates the comet score for the given instance using the version specified in the spec. Corresponds to the JSON property cometResult



7140
7141
7142
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7140

def comet_result
  @comet_result
end

#exact_match_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ExactMatchResults

Results for exact match metric. Corresponds to the JSON property exactMatchResults



7145
7146
7147
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7145

def exact_match_results
  @exact_match_results
end

#fluency_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FluencyResult

Spec for fluency result. Corresponds to the JSON property fluencyResult



7150
7151
7152
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7150

def fluency_result
  @fluency_result
end

#fulfillment_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FulfillmentResult

Spec for fulfillment result. Corresponds to the JSON property fulfillmentResult



7155
7156
7157
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7155

def fulfillment_result
  @fulfillment_result
end

#groundedness_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundednessResult

Spec for groundedness result. Corresponds to the JSON property groundednessResult



7160
7161
7162
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7160

def groundedness_result
  @groundedness_result
end

#metricx_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1MetricxResult

Spec for MetricX result - calculates the MetricX score for the given instance using the version specified in the spec. Corresponds to the JSON property metricxResult



7166
7167
7168
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7166

def metricx_result
  @metricx_result
end

#pairwise_metric_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PairwiseMetricResult

Spec for pairwise metric result. Corresponds to the JSON property pairwiseMetricResult



7171
7172
7173
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7171

def pairwise_metric_result
  @pairwise_metric_result
end

#pairwise_question_answering_quality_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PairwiseQuestionAnsweringQualityResult

Spec for pairwise question answering quality result. Corresponds to the JSON property pairwiseQuestionAnsweringQualityResult



7176
7177
7178
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7176

def pairwise_question_answering_quality_result
  @pairwise_question_answering_quality_result
end

#pairwise_summarization_quality_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PairwiseSummarizationQualityResult

Spec for pairwise summarization quality result. Corresponds to the JSON property pairwiseSummarizationQualityResult



7181
7182
7183
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7181

def pairwise_summarization_quality_result
  @pairwise_summarization_quality_result
end

#pointwise_metric_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PointwiseMetricResult

Spec for pointwise metric result. Corresponds to the JSON property pointwiseMetricResult



7186
7187
7188
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7186

def pointwise_metric_result
  @pointwise_metric_result
end

#question_answering_correctness_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringCorrectnessResult

Spec for question answering correctness result. Corresponds to the JSON property questionAnsweringCorrectnessResult



7191
7192
7193
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7191

def question_answering_correctness_result
  @question_answering_correctness_result
end

#question_answering_helpfulness_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringHelpfulnessResult

Spec for question answering helpfulness result. Corresponds to the JSON property questionAnsweringHelpfulnessResult



7196
7197
7198
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7196

def question_answering_helpfulness_result
  @question_answering_helpfulness_result
end

#question_answering_quality_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringQualityResult

Spec for question answering quality result. Corresponds to the JSON property questionAnsweringQualityResult



7201
7202
7203
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7201

def question_answering_quality_result
  @question_answering_quality_result
end

#question_answering_relevance_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1QuestionAnsweringRelevanceResult

Spec for question answering relevance result. Corresponds to the JSON property questionAnsweringRelevanceResult



7206
7207
7208
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7206

def question_answering_relevance_result
  @question_answering_relevance_result
end

#rouge_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RougeResults

Results for rouge metric. Corresponds to the JSON property rougeResults



7211
7212
7213
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7211

def rouge_results
  @rouge_results
end

#safety_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetyResult

Spec for safety result. Corresponds to the JSON property safetyResult



7216
7217
7218
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7216

def safety_result
  @safety_result
end

#summarization_helpfulness_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SummarizationHelpfulnessResult

Spec for summarization helpfulness result. Corresponds to the JSON property summarizationHelpfulnessResult



7221
7222
7223
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7221

def summarization_helpfulness_result
  @summarization_helpfulness_result
end

#summarization_quality_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SummarizationQualityResult

Spec for summarization quality result. Corresponds to the JSON property summarizationQualityResult



7226
7227
7228
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7226

def summarization_quality_result
  @summarization_quality_result
end

#summarization_verbosity_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SummarizationVerbosityResult

Spec for summarization verbosity result. Corresponds to the JSON property summarizationVerbosityResult



7231
7232
7233
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7231

def summarization_verbosity_result
  @summarization_verbosity_result
end

#tool_call_valid_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolCallValidResults

Results for tool call valid metric. Corresponds to the JSON property toolCallValidResults



7236
7237
7238
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7236

def tool_call_valid_results
  @tool_call_valid_results
end

#tool_name_match_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolNameMatchResults

Results for tool name match metric. Corresponds to the JSON property toolNameMatchResults



7241
7242
7243
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7241

def tool_name_match_results
  @tool_name_match_results
end

#tool_parameter_key_match_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolParameterKeyMatchResults

Results for tool parameter key match metric. Corresponds to the JSON property toolParameterKeyMatchResults



7246
7247
7248
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7246

def tool_parameter_key_match_results
  @tool_parameter_key_match_results
end

#tool_parameter_kv_match_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolParameterKvMatchResults

Results for tool parameter key value match metric. Corresponds to the JSON property toolParameterKvMatchResults



7251
7252
7253
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7251

def tool_parameter_kv_match_results
  @tool_parameter_kv_match_results
end

#trajectory_any_order_match_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryAnyOrderMatchResults

Results for TrajectoryAnyOrderMatch metric. Corresponds to the JSON property trajectoryAnyOrderMatchResults



7256
7257
7258
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7256

def trajectory_any_order_match_results
  @trajectory_any_order_match_results
end

#trajectory_exact_match_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryExactMatchResults

Results for TrajectoryExactMatch metric. Corresponds to the JSON property trajectoryExactMatchResults



7261
7262
7263
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7261

def trajectory_exact_match_results
  @trajectory_exact_match_results
end

#trajectory_in_order_match_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryInOrderMatchResults

Results for TrajectoryInOrderMatch metric. Corresponds to the JSON property trajectoryInOrderMatchResults



7266
7267
7268
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7266

def trajectory_in_order_match_results
  @trajectory_in_order_match_results
end

#trajectory_precision_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryPrecisionResults

Results for TrajectoryPrecision metric. Corresponds to the JSON property trajectoryPrecisionResults



7271
7272
7273
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7271

def trajectory_precision_results
  @trajectory_precision_results
end

#trajectory_recall_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryRecallResults

Results for TrajectoryRecall metric. Corresponds to the JSON property trajectoryRecallResults



7276
7277
7278
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7276

def trajectory_recall_results
  @trajectory_recall_results
end

#trajectory_single_tool_use_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectorySingleToolUseResults

Results for TrajectorySingleToolUse metric. Corresponds to the JSON property trajectorySingleToolUseResults



7281
7282
7283
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7281

def trajectory_single_tool_use_results
  @trajectory_single_tool_use_results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7288
7289
7290
7291
7292
7293
7294
7295
7296
7297
7298
7299
7300
7301
7302
7303
7304
7305
7306
7307
7308
7309
7310
7311
7312
7313
7314
7315
7316
7317
7318
7319
7320
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7288

def update!(**args)
  @bleu_results = args[:bleu_results] if args.key?(:bleu_results)
  @coherence_result = args[:coherence_result] if args.key?(:coherence_result)
  @comet_result = args[:comet_result] if args.key?(:comet_result)
  @exact_match_results = args[:exact_match_results] if args.key?(:exact_match_results)
  @fluency_result = args[:fluency_result] if args.key?(:fluency_result)
  @fulfillment_result = args[:fulfillment_result] if args.key?(:fulfillment_result)
  @groundedness_result = args[:groundedness_result] if args.key?(:groundedness_result)
  @metricx_result = args[:metricx_result] if args.key?(:metricx_result)
  @pairwise_metric_result = args[:pairwise_metric_result] if args.key?(:pairwise_metric_result)
  @pairwise_question_answering_quality_result = args[:pairwise_question_answering_quality_result] if args.key?(:pairwise_question_answering_quality_result)
  @pairwise_summarization_quality_result = args[:pairwise_summarization_quality_result] if args.key?(:pairwise_summarization_quality_result)
  @pointwise_metric_result = args[:pointwise_metric_result] if args.key?(:pointwise_metric_result)
  @question_answering_correctness_result = args[:question_answering_correctness_result] if args.key?(:question_answering_correctness_result)
  @question_answering_helpfulness_result = args[:question_answering_helpfulness_result] if args.key?(:question_answering_helpfulness_result)
  @question_answering_quality_result = args[:question_answering_quality_result] if args.key?(:question_answering_quality_result)
  @question_answering_relevance_result = args[:question_answering_relevance_result] if args.key?(:question_answering_relevance_result)
  @rouge_results = args[:rouge_results] if args.key?(:rouge_results)
  @safety_result = args[:safety_result] if args.key?(:safety_result)
  @summarization_helpfulness_result = args[:summarization_helpfulness_result] if args.key?(:summarization_helpfulness_result)
  @summarization_quality_result = args[:summarization_quality_result] if args.key?(:summarization_quality_result)
  @summarization_verbosity_result = args[:summarization_verbosity_result] if args.key?(:summarization_verbosity_result)
  @tool_call_valid_results = args[:tool_call_valid_results] if args.key?(:tool_call_valid_results)
  @tool_name_match_results = args[:tool_name_match_results] if args.key?(:tool_name_match_results)
  @tool_parameter_key_match_results = args[:tool_parameter_key_match_results] if args.key?(:tool_parameter_key_match_results)
  @tool_parameter_kv_match_results = args[:tool_parameter_kv_match_results] if args.key?(:tool_parameter_kv_match_results)
  @trajectory_any_order_match_results = args[:trajectory_any_order_match_results] if args.key?(:trajectory_any_order_match_results)
  @trajectory_exact_match_results = args[:trajectory_exact_match_results] if args.key?(:trajectory_exact_match_results)
  @trajectory_in_order_match_results = args[:trajectory_in_order_match_results] if args.key?(:trajectory_in_order_match_results)
  @trajectory_precision_results = args[:trajectory_precision_results] if args.key?(:trajectory_precision_results)
  @trajectory_recall_results = args[:trajectory_recall_results] if args.key?(:trajectory_recall_results)
  @trajectory_single_tool_use_results = args[:trajectory_single_tool_use_results] if args.key?(:trajectory_single_tool_use_results)
end