Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluatedAnnotation
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluatedAnnotation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
True positive, false positive, or false negative. EvaluatedAnnotation is only
available under ModelEvaluationSlice with slice of annotationSpec dimension.
Instance Attribute Summary collapse
-
#data_item_payload ⇒ Object
Output only.
-
#error_analysis_annotations ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ErrorAnalysisAnnotation>
Annotations of model error analysis results.
-
#evaluated_data_item_view_id ⇒ String
Output only.
-
#explanations ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluatedAnnotationExplanation>
Explanations of predictions.
-
#ground_truths ⇒ Array<Object>
Output only.
-
#predictions ⇒ Array<Object>
Output only.
-
#type ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluatedAnnotation
constructor
A new instance of GoogleCloudAiplatformV1EvaluatedAnnotation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluatedAnnotation
Returns a new instance of GoogleCloudAiplatformV1EvaluatedAnnotation.
7533 7534 7535 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7533 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_item_payload ⇒ Object
Output only. The data item payload that the Model predicted this
EvaluatedAnnotation on.
Corresponds to the JSON property dataItemPayload
7481 7482 7483 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7481 def data_item_payload @data_item_payload end |
#error_analysis_annotations ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ErrorAnalysisAnnotation>
Annotations of model error analysis results.
Corresponds to the JSON property errorAnalysisAnnotations
7486 7487 7488 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7486 def error_analysis_annotations @error_analysis_annotations end |
#evaluated_data_item_view_id ⇒ String
Output only. ID of the EvaluatedDataItemView under the same ancestor
ModelEvaluation. The EvaluatedDataItemView consists of all ground truths and
predictions on data_item_payload.
Corresponds to the JSON property evaluatedDataItemViewId
7493 7494 7495 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7493 def evaluated_data_item_view_id @evaluated_data_item_view_id end |
#explanations ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluatedAnnotationExplanation>
Explanations of predictions. Each element of the explanations indicates the
explanation for one explanation Method. The attributions list in the
EvaluatedAnnotationExplanation.explanation object corresponds to the
predictions list. For example, the second element in the attributions list
explains the second element in the predictions list.
Corresponds to the JSON property explanations
7502 7503 7504 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7502 def explanations @explanations end |
#ground_truths ⇒ Array<Object>
Output only. The ground truth Annotations, i.e. the Annotations that exist in
the test data the Model is evaluated on. For true positive, there is one and
only one ground truth annotation, which matches the only prediction in
predictions. For false positive, there are zero or more ground truth
annotations that are similar to the only prediction in predictions, but not
enough for a match. For false negative, there is one and only one ground truth
annotation, which doesn't match any predictions created by the model. The
schema of the ground truth is stored in ModelEvaluation.annotation_schema_uri
Corresponds to the JSON property groundTruths
7514 7515 7516 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7514 def ground_truths @ground_truths end |
#predictions ⇒ Array<Object>
Output only. The model predicted annotations. For true positive, there is one
and only one prediction, which matches the only one ground truth annotation in
ground_truths. For false positive, there is one and only one prediction, which
doesn't match any ground truth annotation of the corresponding
data_item_view_id. For false negative, there are zero or more predictions
which are similar to the only ground truth annotation in ground_truths but not
enough for a match. The schema of the prediction is stored in ModelEvaluation.
annotation_schema_uri
Corresponds to the JSON property predictions
7526 7527 7528 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7526 def predictions @predictions end |
#type ⇒ String
Output only. Type of the EvaluatedAnnotation.
Corresponds to the JSON property type
7531 7532 7533 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7531 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7538 7539 7540 7541 7542 7543 7544 7545 7546 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7538 def update!(**args) @data_item_payload = args[:data_item_payload] if args.key?(:data_item_payload) @error_analysis_annotations = args[:error_analysis_annotations] if args.key?(:error_analysis_annotations) @evaluated_data_item_view_id = args[:evaluated_data_item_view_id] if args.key?(:evaluated_data_item_view_id) @explanations = args[:explanations] if args.key?(:explanations) @ground_truths = args[:ground_truths] if args.key?(:ground_truths) @predictions = args[:predictions] if args.key?(:predictions) @type = args[:type] if args.key?(:type) end |