Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluatedAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

True positive, false positive, or false negative. EvaluatedAnnotation is only available under ModelEvaluationSlice with slice of annotationSpec dimension.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluatedAnnotation

Returns a new instance of GoogleCloudAiplatformV1EvaluatedAnnotation.



5525
5526
5527
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5525

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_item_payloadObject

Output only. The data item payload that the Model predicted this EvaluatedAnnotation on. Corresponds to the JSON property dataItemPayload

Returns:

  • (Object)


5473
5474
5475
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5473

def data_item_payload
  @data_item_payload
end

#error_analysis_annotationsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ErrorAnalysisAnnotation>

Annotations of model error analysis results. Corresponds to the JSON property errorAnalysisAnnotations



5478
5479
5480
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5478

def error_analysis_annotations
  @error_analysis_annotations
end

#evaluated_data_item_view_idString

Output only. ID of the EvaluatedDataItemView under the same ancestor ModelEvaluation. The EvaluatedDataItemView consists of all ground truths and predictions on data_item_payload. Corresponds to the JSON property evaluatedDataItemViewId

Returns:

  • (String)


5485
5486
5487
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5485

def evaluated_data_item_view_id
  @evaluated_data_item_view_id
end

#explanationsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluatedAnnotationExplanation>

Explanations of predictions. Each element of the explanations indicates the explanation for one explanation Method. The attributions list in the EvaluatedAnnotationExplanation.explanation object corresponds to the predictions list. For example, the second element in the attributions list explains the second element in the predictions list. Corresponds to the JSON property explanations



5494
5495
5496
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5494

def explanations
  @explanations
end

#ground_truthsArray<Object>

Output only. The ground truth Annotations, i.e. the Annotations that exist in the test data the Model is evaluated on. For true positive, there is one and only one ground truth annotation, which matches the only prediction in predictions. For false positive, there are zero or more ground truth annotations that are similar to the only prediction in predictions, but not enough for a match. For false negative, there is one and only one ground truth annotation, which doesn't match any predictions created by the model. The schema of the ground truth is stored in ModelEvaluation.annotation_schema_uri Corresponds to the JSON property groundTruths

Returns:

  • (Array<Object>)


5506
5507
5508
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5506

def ground_truths
  @ground_truths
end

#predictionsArray<Object>

Output only. The model predicted annotations. For true positive, there is one and only one prediction, which matches the only one ground truth annotation in ground_truths. For false positive, there is one and only one prediction, which doesn't match any ground truth annotation of the corresponding data_item_view_id. For false negative, there are zero or more predictions which are similar to the only ground truth annotation in ground_truths but not enough for a match. The schema of the prediction is stored in ModelEvaluation. annotation_schema_uri Corresponds to the JSON property predictions

Returns:

  • (Array<Object>)


5518
5519
5520
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5518

def predictions
  @predictions
end

#typeString

Output only. Type of the EvaluatedAnnotation. Corresponds to the JSON property type

Returns:

  • (String)


5523
5524
5525
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5523

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5530
5531
5532
5533
5534
5535
5536
5537
5538
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5530

def update!(**args)
  @data_item_payload = args[:data_item_payload] if args.key?(:data_item_payload)
  @error_analysis_annotations = args[:error_analysis_annotations] if args.key?(:error_analysis_annotations)
  @evaluated_data_item_view_id = args[:evaluated_data_item_view_id] if args.key?(:evaluated_data_item_view_id)
  @explanations = args[:explanations] if args.key?(:explanations)
  @ground_truths = args[:ground_truths] if args.key?(:ground_truths)
  @predictions = args[:predictions] if args.key?(:predictions)
  @type = args[:type] if args.key?(:type)
end