Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstance
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstance
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A single instance to be evaluated. Instances are used to specify the input data for evaluation, from simple string comparisons to complex, multi-turn model evaluations
Instance Attribute Summary collapse
-
#agent_data ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentData
Deprecated: Use
agent_eval_datainstead. -
#interactions_data_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInteractionsDataSource
Source for populating
AgentDatafrom an Interactions API interaction. -
#other_data ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceMapInstance
Instance data specified as a map.
-
#prompt ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
-
#reference ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
-
#response ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
-
#rubric_groups ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricGroup>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationInstance
constructor
A new instance of GoogleCloudAiplatformV1EvaluationInstance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationInstance
Returns a new instance of GoogleCloudAiplatformV1EvaluationInstance.
10838 10839 10840 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10838 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_data ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentData
Deprecated: Use agent_eval_data instead. Contains data specific to agent
evaluations.
Corresponds to the JSON property agentData
10804 10805 10806 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10804 def agent_data @agent_data end |
#interactions_data_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInteractionsDataSource
Source for populating AgentData from an Interactions API interaction.
Corresponds to the JSON property interactionsDataSource
10809 10810 10811 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10809 def interactions_data_source @interactions_data_source end |
#other_data ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceMapInstance
Instance data specified as a map.
Corresponds to the JSON property otherData
10814 10815 10816 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10814 def other_data @other_data end |
#prompt ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
Corresponds to the JSON property prompt
10819 10820 10821 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10819 def prompt @prompt end |
#reference ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
Corresponds to the JSON property reference
10824 10825 10826 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10824 def reference @reference end |
#response ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
Corresponds to the JSON property response
10829 10830 10831 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10829 def response @response end |
#rubric_groups ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricGroup>
Optional. Named groups of rubrics associated with the prompt. This is used for
rubric-based evaluations where rubrics can be referenced by a key. The key
could represent versions, associated metrics, etc.
Corresponds to the JSON property rubricGroups
10836 10837 10838 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10836 def rubric_groups @rubric_groups end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10843 10844 10845 10846 10847 10848 10849 10850 10851 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10843 def update!(**args) @agent_data = args[:agent_data] if args.key?(:agent_data) @interactions_data_source = args[:interactions_data_source] if args.key?(:interactions_data_source) @other_data = args[:other_data] if args.key?(:other_data) @prompt = args[:prompt] if args.key?(:prompt) @reference = args[:reference] if args.key?(:reference) @response = args[:response] if args.key?(:response) @rubric_groups = args[:rubric_groups] if args.key?(:rubric_groups) end |