Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A single instance to be evaluated. Instances are used to specify the input data for evaluation, from simple string comparisons to complex, multi-turn model evaluations

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationInstance

Returns a new instance of GoogleCloudAiplatformV1EvaluationInstance.



10243
10244
10245
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10243

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_dataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentData

Deprecated: Use agent_eval_data instead. Contains data specific to agent evaluations. Corresponds to the JSON property agentData



10214
10215
10216
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10214

def agent_data
  @agent_data
end

#other_dataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceMapInstance

Instance data specified as a map. Corresponds to the JSON property otherData



10219
10220
10221
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10219

def other_data
  @other_data
end

#promptGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData

Instance data used to populate placeholders in a metric prompt template. Corresponds to the JSON property prompt



10224
10225
10226
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10224

def prompt
  @prompt
end

#referenceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData

Instance data used to populate placeholders in a metric prompt template. Corresponds to the JSON property reference



10229
10230
10231
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10229

def reference
  @reference
end

#responseGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData

Instance data used to populate placeholders in a metric prompt template. Corresponds to the JSON property response



10234
10235
10236
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10234

def response
  @response
end

#rubric_groupsHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricGroup>

Optional. Named groups of rubrics associated with the prompt. This is used for rubric-based evaluations where rubrics can be referenced by a key. The key could represent versions, associated metrics, etc. Corresponds to the JSON property rubricGroups



10241
10242
10243
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10241

def rubric_groups
  @rubric_groups
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10248
10249
10250
10251
10252
10253
10254
10255
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10248

def update!(**args)
  @agent_data = args[:agent_data] if args.key?(:agent_data)
  @other_data = args[:other_data] if args.key?(:other_data)
  @prompt = args[:prompt] if args.key?(:prompt)
  @reference = args[:reference] if args.key?(:reference)
  @response = args[:response] if args.key?(:response)
  @rubric_groups = args[:rubric_groups] if args.key?(:rubric_groups)
end