Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A single instance to be evaluated. Instances are used to specify the input data for evaluation, from simple string comparisons to complex, multi-turn model evaluations

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationInstance

Returns a new instance of GoogleCloudAiplatformV1EvaluationInstance.



10042
10043
10044
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10042

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_dataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentData

Deprecated: Use agent_eval_data instead. Contains data specific to agent evaluations. Corresponds to the JSON property agentData



10013
10014
10015
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10013

def agent_data
  @agent_data
end

#other_dataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceMapInstance

Instance data specified as a map. Corresponds to the JSON property otherData



10018
10019
10020
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10018

def other_data
  @other_data
end

#promptGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData

Instance data used to populate placeholders in a metric prompt template. Corresponds to the JSON property prompt



10023
10024
10025
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10023

def prompt
  @prompt
end

#referenceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData

Instance data used to populate placeholders in a metric prompt template. Corresponds to the JSON property reference



10028
10029
10030
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10028

def reference
  @reference
end

#responseGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData

Instance data used to populate placeholders in a metric prompt template. Corresponds to the JSON property response



10033
10034
10035
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10033

def response
  @response
end

#rubric_groupsHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricGroup>

Optional. Named groups of rubrics associated with the prompt. This is used for rubric-based evaluations where rubrics can be referenced by a key. The key could represent versions, associated metrics, etc. Corresponds to the JSON property rubricGroups



10040
10041
10042
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10040

def rubric_groups
  @rubric_groups
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10047
10048
10049
10050
10051
10052
10053
10054
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10047

def update!(**args)
  @agent_data = args[:agent_data] if args.key?(:agent_data)
  @other_data = args[:other_data] if args.key?(:other_data)
  @prompt = args[:prompt] if args.key?(:prompt)
  @reference = args[:reference] if args.key?(:reference)
  @response = args[:response] if args.key?(:response)
  @rubric_groups = args[:rubric_groups] if args.key?(:rubric_groups)
end