Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstance
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstance
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A single instance to be evaluated. Instances are used to specify the input data for evaluation, from simple string comparisons to complex, multi-turn model evaluations
Instance Attribute Summary collapse
-
#agent_data ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentData
Deprecated: Use
agent_eval_datainstead. -
#other_data ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceMapInstance
Instance data specified as a map.
-
#prompt ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
-
#reference ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
-
#response ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
-
#rubric_groups ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricGroup>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationInstance
constructor
A new instance of GoogleCloudAiplatformV1EvaluationInstance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationInstance
Returns a new instance of GoogleCloudAiplatformV1EvaluationInstance.
9572 9573 9574 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9572 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_data ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentData
Deprecated: Use agent_eval_data instead. Contains data specific to agent
evaluations.
Corresponds to the JSON property agentData
9543 9544 9545 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9543 def agent_data @agent_data end |
#other_data ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceMapInstance
Instance data specified as a map.
Corresponds to the JSON property otherData
9548 9549 9550 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9548 def other_data @other_data end |
#prompt ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
Corresponds to the JSON property prompt
9553 9554 9555 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9553 def prompt @prompt end |
#reference ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
Corresponds to the JSON property reference
9558 9559 9560 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9558 def reference @reference end |
#response ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
Corresponds to the JSON property response
9563 9564 9565 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9563 def response @response end |
#rubric_groups ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricGroup>
Optional. Named groups of rubrics associated with the prompt. This is used for
rubric-based evaluations where rubrics can be referenced by a key. The key
could represent versions, associated metrics, etc.
Corresponds to the JSON property rubricGroups
9570 9571 9572 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9570 def rubric_groups @rubric_groups end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9577 9578 9579 9580 9581 9582 9583 9584 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9577 def update!(**args) @agent_data = args[:agent_data] if args.key?(:agent_data) @other_data = args[:other_data] if args.key?(:other_data) @prompt = args[:prompt] if args.key?(:prompt) @reference = args[:reference] if args.key?(:reference) @response = args[:response] if args.key?(:response) @rubric_groups = args[:rubric_groups] if args.key?(:rubric_groups) end |