Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstance
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstance
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A single instance to be evaluated. Instances are used to specify the input data for evaluation, from simple string comparisons to complex, multi-turn model evaluations
Instance Attribute Summary collapse
-
#agent_data ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentData
Deprecated: Use
agent_eval_datainstead. -
#other_data ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceMapInstance
Instance data specified as a map.
-
#prompt ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
-
#reference ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
-
#response ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
-
#rubric_groups ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricGroup>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationInstance
constructor
A new instance of GoogleCloudAiplatformV1EvaluationInstance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationInstance
Returns a new instance of GoogleCloudAiplatformV1EvaluationInstance.
9525 9526 9527 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9525 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_data ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentData
Deprecated: Use agent_eval_data instead. Contains data specific to agent
evaluations.
Corresponds to the JSON property agentData
9496 9497 9498 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9496 def agent_data @agent_data end |
#other_data ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceMapInstance
Instance data specified as a map.
Corresponds to the JSON property otherData
9501 9502 9503 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9501 def other_data @other_data end |
#prompt ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
Corresponds to the JSON property prompt
9506 9507 9508 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9506 def prompt @prompt end |
#reference ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
Corresponds to the JSON property reference
9511 9512 9513 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9511 def reference @reference end |
#response ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
Corresponds to the JSON property response
9516 9517 9518 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9516 def response @response end |
#rubric_groups ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricGroup>
Optional. Named groups of rubrics associated with the prompt. This is used for
rubric-based evaluations where rubrics can be referenced by a key. The key
could represent versions, associated metrics, etc.
Corresponds to the JSON property rubricGroups
9523 9524 9525 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9523 def rubric_groups @rubric_groups end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9530 9531 9532 9533 9534 9535 9536 9537 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9530 def update!(**args) @agent_data = args[:agent_data] if args.key?(:agent_data) @other_data = args[:other_data] if args.key?(:other_data) @prompt = args[:prompt] if args.key?(:prompt) @reference = args[:reference] if args.key?(:reference) @response = args[:response] if args.key?(:response) @rubric_groups = args[:rubric_groups] if args.key?(:rubric_groups) end |