Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstance
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstance
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A single instance to be evaluated. Instances are used to specify the input data for evaluation, from simple string comparisons to complex, multi-turn model evaluations
Instance Attribute Summary collapse
-
#agent_data ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceAgentData
Contains data specific to agent evaluations.
-
#agent_eval_data ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceAgentData
Contains data specific to agent evaluations.
-
#other_data ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceMapInstance
Instance data specified as a map.
-
#prompt ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
-
#reference ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
-
#response ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
-
#rubric_groups ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricGroup>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationInstance
constructor
A new instance of GoogleCloudAiplatformV1EvaluationInstance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationInstance
Returns a new instance of GoogleCloudAiplatformV1EvaluationInstance.
9022 9023 9024 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9022 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_data ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceAgentData
Contains data specific to agent evaluations.
Corresponds to the JSON property agentData
8988 8989 8990 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8988 def agent_data @agent_data end |
#agent_eval_data ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceAgentData
Contains data specific to agent evaluations.
Corresponds to the JSON property agentEvalData
8993 8994 8995 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8993 def agent_eval_data @agent_eval_data end |
#other_data ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceMapInstance
Instance data specified as a map.
Corresponds to the JSON property otherData
8998 8999 9000 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8998 def other_data @other_data end |
#prompt ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
Corresponds to the JSON property prompt
9003 9004 9005 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9003 def prompt @prompt end |
#reference ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
Corresponds to the JSON property reference
9008 9009 9010 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9008 def reference @reference end |
#response ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
Corresponds to the JSON property response
9013 9014 9015 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9013 def response @response end |
#rubric_groups ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricGroup>
Optional. Named groups of rubrics associated with the prompt. This is used for
rubric-based evaluations where rubrics can be referenced by a key. The key
could represent versions, associated metrics, etc.
Corresponds to the JSON property rubricGroups
9020 9021 9022 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9020 def rubric_groups @rubric_groups end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9027 9028 9029 9030 9031 9032 9033 9034 9035 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9027 def update!(**args) @agent_data = args[:agent_data] if args.key?(:agent_data) @agent_eval_data = args[:agent_eval_data] if args.key?(:agent_eval_data) @other_data = args[:other_data] if args.key?(:other_data) @prompt = args[:prompt] if args.key?(:prompt) @reference = args[:reference] if args.key?(:reference) @response = args[:response] if args.key?(:response) @rubric_groups = args[:rubric_groups] if args.key?(:rubric_groups) end |