Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A single instance to be evaluated. Instances are used to specify the input data for evaluation, from simple string comparisons to complex, multi-turn model evaluations

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationInstance

Returns a new instance of GoogleCloudAiplatformV1EvaluationInstance.



8992
8993
8994
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8992

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_dataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceAgentData

Contains data specific to agent evaluations. Corresponds to the JSON property agentData



8963
8964
8965
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8963

def agent_data
  @agent_data
end

#other_dataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceMapInstance

Instance data specified as a map. Corresponds to the JSON property otherData



8968
8969
8970
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8968

def other_data
  @other_data
end

#promptGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData

Instance data used to populate placeholders in a metric prompt template. Corresponds to the JSON property prompt



8973
8974
8975
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8973

def prompt
  @prompt
end

#referenceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData

Instance data used to populate placeholders in a metric prompt template. Corresponds to the JSON property reference



8978
8979
8980
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8978

def reference
  @reference
end

#responseGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData

Instance data used to populate placeholders in a metric prompt template. Corresponds to the JSON property response



8983
8984
8985
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8983

def response
  @response
end

#rubric_groupsHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricGroup>

Optional. Named groups of rubrics associated with the prompt. This is used for rubric-based evaluations where rubrics can be referenced by a key. The key could represent versions, associated metrics, etc. Corresponds to the JSON property rubricGroups



8990
8991
8992
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8990

def rubric_groups
  @rubric_groups
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8997
8998
8999
9000
9001
9002
9003
9004
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8997

def update!(**args)
  @agent_data = args[:agent_data] if args.key?(:agent_data)
  @other_data = args[:other_data] if args.key?(:other_data)
  @prompt = args[:prompt] if args.key?(:prompt)
  @reference = args[:reference] if args.key?(:reference)
  @response = args[:response] if args.key?(:response)
  @rubric_groups = args[:rubric_groups] if args.key?(:rubric_groups)
end