Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceAgentConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceAgentConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Configuration for an Agent.
Instance Attribute Summary collapse
-
#developer_instruction ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
-
#tools ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceAgentConfigTools
Represents a list of tools for an agent.
-
#tools_text ⇒ String
A JSON string containing a list of tools available to an agent with info such as name, description, parameters and required parameters.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationInstanceAgentConfig
constructor
A new instance of GoogleCloudAiplatformV1EvaluationInstanceAgentConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationInstanceAgentConfig
Returns a new instance of GoogleCloudAiplatformV1EvaluationInstanceAgentConfig.
9027 9028 9029 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9027 def initialize(**args) update!(**args) end |
Instance Attribute Details
#developer_instruction ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
Corresponds to the JSON property developerInstruction
9014 9015 9016 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9014 def developer_instruction @developer_instruction end |
#tools ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceAgentConfigTools
Represents a list of tools for an agent.
Corresponds to the JSON property tools
9019 9020 9021 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9019 def tools @tools end |
#tools_text ⇒ String
A JSON string containing a list of tools available to an agent with info such
as name, description, parameters and required parameters.
Corresponds to the JSON property toolsText
9025 9026 9027 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9025 def tools_text @tools_text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9032 9033 9034 9035 9036 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9032 def update!(**args) @developer_instruction = args[:developer_instruction] if args.key?(:developer_instruction) @tools = args[:tools] if args.key?(:tools) @tools_text = args[:tools_text] if args.key?(:tools_text) end |