Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceAgentData
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceAgentData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Contains data specific to agent evaluations.
Instance Attribute Summary collapse
-
#agent_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceAgentConfig
Configuration for an Agent.
-
#agents ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceAgentConfig>
Optional.
-
#developer_instruction ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
-
#events ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceAgentDataEvents
Represents a list of events for an agent.
-
#tools ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceAgentDataTools
Deprecated.
-
#tools_text ⇒ String
A JSON string containing a list of tools available to an agent with info such as name, description, parameters and required parameters.
-
#turns ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceAgentDataConversationTurn>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationInstanceAgentData
constructor
A new instance of GoogleCloudAiplatformV1EvaluationInstanceAgentData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationInstanceAgentData
Returns a new instance of GoogleCloudAiplatformV1EvaluationInstanceAgentData.
9162 9163 9164 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9162 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceAgentConfig
Configuration for an Agent.
Corresponds to the JSON property agentConfig
9126 9127 9128 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9126 def agent_config @agent_config end |
#agents ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceAgentConfig>
Optional. The static Agent Configuration. This map defines the graph structure
of the agent system. Key: agent_id (matches the author field in events).
Value: The static configuration of the agent (tools, instructions, sub-agents).
Corresponds to the JSON property agents
9133 9134 9135 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9133 def agents @agents end |
#developer_instruction ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
Corresponds to the JSON property developerInstruction
9138 9139 9140 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9138 def developer_instruction @developer_instruction end |
#events ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceAgentDataEvents
Represents a list of events for an agent.
Corresponds to the JSON property events
9143 9144 9145 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9143 def events @events end |
#tools ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceAgentDataTools
Deprecated. Represents a list of tools for an agent.
Corresponds to the JSON property tools
9148 9149 9150 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9148 def tools @tools end |
#tools_text ⇒ String
A JSON string containing a list of tools available to an agent with info such
as name, description, parameters and required parameters.
Corresponds to the JSON property toolsText
9154 9155 9156 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9154 def tools_text @tools_text end |
#turns ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceAgentDataConversationTurn>
Optional. The chronological list of conversation turns. Each turn represents a
logical execution cycle (e.g., User Input -> Agent Response).
Corresponds to the JSON property turns
9160 9161 9162 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9160 def turns @turns end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9167 9168 9169 9170 9171 9172 9173 9174 9175 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9167 def update!(**args) @agent_config = args[:agent_config] if args.key?(:agent_config) @agents = args[:agents] if args.key?(:agents) @developer_instruction = args[:developer_instruction] if args.key?(:developer_instruction) @events = args[:events] if args.key?(:events) @tools = args[:tools] if args.key?(:tools) @tools_text = args[:tools_text] if args.key?(:tools_text) @turns = args[:turns] if args.key?(:turns) end |