Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceAgentData

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Contains data specific to agent evaluations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationInstanceAgentData

Returns a new instance of GoogleCloudAiplatformV1EvaluationInstanceAgentData.



9093
9094
9095
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9093

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceAgentConfig

Configuration for an Agent. Corresponds to the JSON property agentConfig



9065
9066
9067
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9065

def agent_config
  @agent_config
end

#developer_instructionGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData

Instance data used to populate placeholders in a metric prompt template. Corresponds to the JSON property developerInstruction



9070
9071
9072
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9070

def developer_instruction
  @developer_instruction
end

#eventsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceAgentDataEvents

Represents a list of events for an agent. Corresponds to the JSON property events



9075
9076
9077
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9075

def events
  @events
end

#toolsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceAgentDataTools

Represents a list of tools for an agent. Corresponds to the JSON property tools



9080
9081
9082
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9080

def tools
  @tools
end

#tools_textString

A JSON string containing a list of tools available to an agent with info such as name, description, parameters and required parameters. Example: [ "name": "search_actors", "description": "Search for actors in a movie. Returns a list of actors, their roles, their birthdate, and their place of birth.", " parameters": [ "name": "movie_name", "description": "The name of the movie." , "name": "character_name", "description": "The name of the character." ], "required": ["movie_name", "character_name"] ] Corresponds to the JSON property toolsText

Returns:

  • (String)


9091
9092
9093
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9091

def tools_text
  @tools_text
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9098
9099
9100
9101
9102
9103
9104
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9098

def update!(**args)
  @agent_config = args[:agent_config] if args.key?(:agent_config)
  @developer_instruction = args[:developer_instruction] if args.key?(:developer_instruction)
  @events = args[:events] if args.key?(:events)
  @tools = args[:tools] if args.key?(:tools)
  @tools_text = args[:tools_text] if args.key?(:tools_text)
end