Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Deprecated: Use google.cloud.aiplatform.master.AgentConfig in
agent_eval_data instead. Configuration for an Agent.
Instance Attribute Summary collapse
-
#agent_id ⇒ String
Optional.
-
#agent_type ⇒ String
Optional.
-
#description ⇒ String
Optional.
-
#developer_instruction ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
-
#sub_agents ⇒ Array<String>
Optional.
-
#tools ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentConfigTools
Represents a list of tools for an agent.
-
#tools_text ⇒ String
A JSON string containing a list of tools available to an agent with info such as name, description, parameters and required parameters.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentConfig
constructor
A new instance of GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentConfig
Returns a new instance of GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentConfig.
10565 10566 10567 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10565 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_id ⇒ String
Optional. Unique identifier of the agent. This ID is used to refer to this
agent, e.g., in AgentEvent.author, or in the sub_agents field. It must be
unique within the agents map.
Corresponds to the JSON property agentId
10528 10529 10530 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10528 def agent_id @agent_id end |
#agent_type ⇒ String
Optional. The type or class of the agent (e.g., "LlmAgent", "RouterAgent", "
ToolUseAgent"). Useful for the autorater to understand the expected behavior
of the agent.
Corresponds to the JSON property agentType
10535 10536 10537 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10535 def agent_type @agent_type end |
#description ⇒ String
Optional. A high-level description of the agent's role and responsibilities.
Critical for evaluating if the agent is routing tasks correctly.
Corresponds to the JSON property description
10541 10542 10543 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10541 def description @description end |
#developer_instruction ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
Corresponds to the JSON property developerInstruction
10546 10547 10548 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10546 def developer_instruction @developer_instruction end |
#sub_agents ⇒ Array<String>
Optional. The list of valid agent IDs (names) that this agent can delegate to.
This defines the directed edges in the agent system graph topology.
Corresponds to the JSON property subAgents
10552 10553 10554 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10552 def sub_agents @sub_agents end |
#tools ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentConfigTools
Represents a list of tools for an agent.
Corresponds to the JSON property tools
10557 10558 10559 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10557 def tools @tools end |
#tools_text ⇒ String
A JSON string containing a list of tools available to an agent with info such
as name, description, parameters and required parameters.
Corresponds to the JSON property toolsText
10563 10564 10565 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10563 def tools_text @tools_text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10570 10571 10572 10573 10574 10575 10576 10577 10578 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10570 def update!(**args) @agent_id = args[:agent_id] if args.key?(:agent_id) @agent_type = args[:agent_type] if args.key?(:agent_type) @description = args[:description] if args.key?(:description) @developer_instruction = args[:developer_instruction] if args.key?(:developer_instruction) @sub_agents = args[:sub_agents] if args.key?(:sub_agents) @tools = args[:tools] if args.key?(:tools) @tools_text = args[:tools_text] if args.key?(:tools_text) end |