Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Deprecated: Use google.cloud.aiplatform.master.AgentConfig in
agent_eval_data instead. Configuration for an Agent.
Instance Attribute Summary collapse
-
#agent_id ⇒ String
Optional.
-
#agent_type ⇒ String
Optional.
-
#description ⇒ String
Optional.
-
#developer_instruction ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
-
#sub_agents ⇒ Array<String>
Optional.
-
#tools ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentConfigTools
Represents a list of tools for an agent.
-
#tools_text ⇒ String
A JSON string containing a list of tools available to an agent with info such as name, description, parameters and required parameters.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentConfig
constructor
A new instance of GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentConfig
Returns a new instance of GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentConfig.
9794 9795 9796 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9794 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_id ⇒ String
Optional. Unique identifier of the agent. This ID is used to refer to this
agent, e.g., in AgentEvent.author, or in the sub_agents field. It must be
unique within the agents map.
Corresponds to the JSON property agentId
9757 9758 9759 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9757 def agent_id @agent_id end |
#agent_type ⇒ String
Optional. The type or class of the agent (e.g., "LlmAgent", "RouterAgent", "
ToolUseAgent"). Useful for the autorater to understand the expected behavior
of the agent.
Corresponds to the JSON property agentType
9764 9765 9766 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9764 def agent_type @agent_type end |
#description ⇒ String
Optional. A high-level description of the agent's role and responsibilities.
Critical for evaluating if the agent is routing tasks correctly.
Corresponds to the JSON property description
9770 9771 9772 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9770 def description @description end |
#developer_instruction ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
Corresponds to the JSON property developerInstruction
9775 9776 9777 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9775 def developer_instruction @developer_instruction end |
#sub_agents ⇒ Array<String>
Optional. The list of valid agent IDs (names) that this agent can delegate to.
This defines the directed edges in the agent system graph topology.
Corresponds to the JSON property subAgents
9781 9782 9783 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9781 def sub_agents @sub_agents end |
#tools ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentConfigTools
Represents a list of tools for an agent.
Corresponds to the JSON property tools
9786 9787 9788 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9786 def tools @tools end |
#tools_text ⇒ String
A JSON string containing a list of tools available to an agent with info such
as name, description, parameters and required parameters.
Corresponds to the JSON property toolsText
9792 9793 9794 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9792 def tools_text @tools_text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9799 9800 9801 9802 9803 9804 9805 9806 9807 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9799 def update!(**args) @agent_id = args[:agent_id] if args.key?(:agent_id) @agent_type = args[:agent_type] if args.key?(:agent_type) @description = args[:description] if args.key?(:description) @developer_instruction = args[:developer_instruction] if args.key?(:developer_instruction) @sub_agents = args[:sub_agents] if args.key?(:sub_agents) @tools = args[:tools] if args.key?(:tools) @tools_text = args[:tools_text] if args.key?(:tools_text) end |