Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Deprecated: Use google.cloud.aiplatform.master.AgentConfig in agent_eval_data instead. Configuration for an Agent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentConfig

Returns a new instance of GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentConfig.



9682
9683
9684
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9682

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_idString

Optional. Unique identifier of the agent. This ID is used to refer to this agent, e.g., in AgentEvent.author, or in the sub_agents field. It must be unique within the agents map. Corresponds to the JSON property agentId

Returns:

  • (String)


9645
9646
9647
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9645

def agent_id
  @agent_id
end

#agent_typeString

Optional. The type or class of the agent (e.g., "LlmAgent", "RouterAgent", " ToolUseAgent"). Useful for the autorater to understand the expected behavior of the agent. Corresponds to the JSON property agentType

Returns:

  • (String)


9652
9653
9654
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9652

def agent_type
  @agent_type
end

#descriptionString

Optional. A high-level description of the agent's role and responsibilities. Critical for evaluating if the agent is routing tasks correctly. Corresponds to the JSON property description

Returns:

  • (String)


9658
9659
9660
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9658

def description
  @description
end

#developer_instructionGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData

Instance data used to populate placeholders in a metric prompt template. Corresponds to the JSON property developerInstruction



9663
9664
9665
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9663

def developer_instruction
  @developer_instruction
end

#sub_agentsArray<String>

Optional. The list of valid agent IDs (names) that this agent can delegate to. This defines the directed edges in the agent system graph topology. Corresponds to the JSON property subAgents

Returns:

  • (Array<String>)


9669
9670
9671
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9669

def sub_agents
  @sub_agents
end

#toolsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentConfigTools

Represents a list of tools for an agent. Corresponds to the JSON property tools



9674
9675
9676
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9674

def tools
  @tools
end

#tools_textString

A JSON string containing a list of tools available to an agent with info such as name, description, parameters and required parameters. Corresponds to the JSON property toolsText

Returns:

  • (String)


9680
9681
9682
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9680

def tools_text
  @tools_text
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9687
9688
9689
9690
9691
9692
9693
9694
9695
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9687

def update!(**args)
  @agent_id = args[:agent_id] if args.key?(:agent_id)
  @agent_type = args[:agent_type] if args.key?(:agent_type)
  @description = args[:description] if args.key?(:description)
  @developer_instruction = args[:developer_instruction] if args.key?(:developer_instruction)
  @sub_agents = args[:sub_agents] if args.key?(:sub_agents)
  @tools = args[:tools] if args.key?(:tools)
  @tools_text = args[:tools_text] if args.key?(:tools_text)
end