Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentData
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Deprecated: Use agent_eval_data instead. Contains data specific to agent
evaluations.
Instance Attribute Summary collapse
-
#agent_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentConfig
Deprecated: Use
google.cloud.aiplatform.master.AgentConfiginagent_eval_datainstead. -
#agents ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentConfig>
Optional.
-
#developer_instruction ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
-
#events ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentDataEvents
Represents a list of events for an agent.
-
#tools ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentDataTools
Deprecated: Use
agent_eval_datainstead. -
#tools_text ⇒ String
A JSON string containing a list of tools available to an agent with info such as name, description, parameters and required parameters.
-
#turns ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentDataConversationTurn>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentData
constructor
A new instance of GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentData
Returns a new instance of GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentData.
10185 10186 10187 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10185 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentConfig
Deprecated: Use google.cloud.aiplatform.master.AgentConfig in
agent_eval_data instead. Configuration for an Agent.
Corresponds to the JSON property agentConfig
10148 10149 10150 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10148 def agent_config @agent_config end |
#agents ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentConfig>
Optional. The static Agent Configuration. This map defines the graph structure
of the agent system. Key: agent_id (matches the author field in events).
Value: The static configuration of the agent (tools, instructions, sub-agents).
Corresponds to the JSON property agents
10155 10156 10157 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10155 def agents @agents end |
#developer_instruction ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
Corresponds to the JSON property developerInstruction
10160 10161 10162 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10160 def developer_instruction @developer_instruction end |
#events ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentDataEvents
Represents a list of events for an agent.
Corresponds to the JSON property events
10165 10166 10167 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10165 def events @events end |
#tools ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentDataTools
Deprecated: Use agent_eval_data instead. Represents a list of tools for an
agent.
Corresponds to the JSON property tools
10171 10172 10173 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10171 def tools @tools end |
#tools_text ⇒ String
A JSON string containing a list of tools available to an agent with info such
as name, description, parameters and required parameters.
Corresponds to the JSON property toolsText
10177 10178 10179 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10177 def tools_text @tools_text end |
#turns ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentDataConversationTurn>
Optional. The chronological list of conversation turns. Each turn represents a
logical execution cycle (e.g., User Input -> Agent Response).
Corresponds to the JSON property turns
10183 10184 10185 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10183 def turns @turns end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10190 10191 10192 10193 10194 10195 10196 10197 10198 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10190 def update!(**args) @agent_config = args[:agent_config] if args.key?(:agent_config) @agents = args[:agents] if args.key?(:agents) @developer_instruction = args[:developer_instruction] if args.key?(:developer_instruction) @events = args[:events] if args.key?(:events) @tools = args[:tools] if args.key?(:tools) @tools_text = args[:tools_text] if args.key?(:tools_text) @turns = args[:turns] if args.key?(:turns) end |