Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentData

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Deprecated: Use agent_eval_data instead. Contains data specific to agent evaluations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentData

Returns a new instance of GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentData.



9715
9716
9717
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9715

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentConfig

Deprecated: Use google.cloud.aiplatform.master.AgentConfig in agent_eval_data instead. Configuration for an Agent. Corresponds to the JSON property agentConfig



9678
9679
9680
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9678

def agent_config
  @agent_config
end

#agentsHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentConfig>

Optional. The static Agent Configuration. This map defines the graph structure of the agent system. Key: agent_id (matches the author field in events). Value: The static configuration of the agent (tools, instructions, sub-agents). Corresponds to the JSON property agents



9685
9686
9687
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9685

def agents
  @agents
end

#developer_instructionGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData

Instance data used to populate placeholders in a metric prompt template. Corresponds to the JSON property developerInstruction



9690
9691
9692
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9690

def developer_instruction
  @developer_instruction
end

#eventsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentDataEvents

Represents a list of events for an agent. Corresponds to the JSON property events



9695
9696
9697
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9695

def events
  @events
end

#toolsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentDataTools

Deprecated: Use agent_eval_data instead. Represents a list of tools for an agent. Corresponds to the JSON property tools



9701
9702
9703
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9701

def tools
  @tools
end

#tools_textString

A JSON string containing a list of tools available to an agent with info such as name, description, parameters and required parameters. Corresponds to the JSON property toolsText

Returns:

  • (String)


9707
9708
9709
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9707

def tools_text
  @tools_text
end

#turnsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentDataConversationTurn>

Optional. The chronological list of conversation turns. Each turn represents a logical execution cycle (e.g., User Input -> Agent Response). Corresponds to the JSON property turns



9713
9714
9715
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9713

def turns
  @turns
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9720
9721
9722
9723
9724
9725
9726
9727
9728
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9720

def update!(**args)
  @agent_config = args[:agent_config] if args.key?(:agent_config)
  @agents = args[:agents] if args.key?(:agents)
  @developer_instruction = args[:developer_instruction] if args.key?(:developer_instruction)
  @events = args[:events] if args.key?(:events)
  @tools = args[:tools] if args.key?(:tools)
  @tools_text = args[:tools_text] if args.key?(:tools_text)
  @turns = args[:turns] if args.key?(:turns)
end