Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentData
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Deprecated: Use agent_eval_data instead. Contains data specific to agent
evaluations.
Instance Attribute Summary collapse
-
#agent_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentConfig
Deprecated: Use
google.cloud.aiplatform.master.AgentConfiginagent_eval_datainstead. -
#agents ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentConfig>
Optional.
-
#developer_instruction ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
-
#events ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentDataEvents
Represents a list of events for an agent.
-
#tools ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentDataTools
Deprecated: Use
agent_eval_datainstead. -
#tools_text ⇒ String
A JSON string containing a list of tools available to an agent with info such as name, description, parameters and required parameters.
-
#turns ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentDataConversationTurn>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentData
constructor
A new instance of GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentData
Returns a new instance of GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentData.
9668 9669 9670 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9668 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentConfig
Deprecated: Use google.cloud.aiplatform.master.AgentConfig in
agent_eval_data instead. Configuration for an Agent.
Corresponds to the JSON property agentConfig
9631 9632 9633 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9631 def agent_config @agent_config end |
#agents ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentConfig>
Optional. The static Agent Configuration. This map defines the graph structure
of the agent system. Key: agent_id (matches the author field in events).
Value: The static configuration of the agent (tools, instructions, sub-agents).
Corresponds to the JSON property agents
9638 9639 9640 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9638 def agents @agents end |
#developer_instruction ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceInstanceData
Instance data used to populate placeholders in a metric prompt template.
Corresponds to the JSON property developerInstruction
9643 9644 9645 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9643 def developer_instruction @developer_instruction end |
#events ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentDataEvents
Represents a list of events for an agent.
Corresponds to the JSON property events
9648 9649 9650 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9648 def events @events end |
#tools ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentDataTools
Deprecated: Use agent_eval_data instead. Represents a list of tools for an
agent.
Corresponds to the JSON property tools
9654 9655 9656 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9654 def tools @tools end |
#tools_text ⇒ String
A JSON string containing a list of tools available to an agent with info such
as name, description, parameters and required parameters.
Corresponds to the JSON property toolsText
9660 9661 9662 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9660 def tools_text @tools_text end |
#turns ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentDataConversationTurn>
Optional. The chronological list of conversation turns. Each turn represents a
logical execution cycle (e.g., User Input -> Agent Response).
Corresponds to the JSON property turns
9666 9667 9668 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9666 def turns @turns end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9673 9674 9675 9676 9677 9678 9679 9680 9681 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9673 def update!(**args) @agent_config = args[:agent_config] if args.key?(:agent_config) @agents = args[:agents] if args.key?(:agents) @developer_instruction = args[:developer_instruction] if args.key?(:developer_instruction) @events = args[:events] if args.key?(:events) @tools = args[:tools] if args.key?(:tools) @tools_text = args[:tools_text] if args.key?(:tools_text) @turns = args[:turns] if args.key?(:turns) end |