Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentDataAgentEvent
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentDataAgentEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A single event in the execution trace.
Instance Attribute Summary collapse
-
#active_tools ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tool>
Optional.
-
#author ⇒ String
Required.
-
#content ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content
The structured data content of a message.
-
#event_time ⇒ String
Optional.
-
#state_delta ⇒ Hash<String,Object>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentDataAgentEvent
constructor
A new instance of GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentDataAgentEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentDataAgentEvent
Returns a new instance of GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentDataAgentEvent.
9717 9718 9719 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9717 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active_tools ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tool>
Optional. The list of tools that were active/available to the agent at the
time of this event. This overrides the AgentConfig.tools if set.
Corresponds to the JSON property activeTools
9692 9693 9694 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9692 def active_tools @active_tools end |
#author ⇒ String
Required. The ID of the agent or entity that generated this event.
Corresponds to the JSON property author
9697 9698 9699 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9697 def @author end |
#content ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content
The structured data content of a message. A Content message contains a role
field, which indicates the producer of the content, and a parts field, which
contains the multi-part data of the message.
Corresponds to the JSON property content
9704 9705 9706 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9704 def content @content end |
#event_time ⇒ String
Optional. The timestamp when the event occurred.
Corresponds to the JSON property eventTime
9709 9710 9711 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9709 def event_time @event_time end |
#state_delta ⇒ Hash<String,Object>
Optional. The change in the session state caused by this event. This is a key-
value map of fields that were modified or added by the event.
Corresponds to the JSON property stateDelta
9715 9716 9717 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9715 def state_delta @state_delta end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9722 9723 9724 9725 9726 9727 9728 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9722 def update!(**args) @active_tools = args[:active_tools] if args.key?(:active_tools) @author = args[:author] if args.key?(:author) @content = args[:content] if args.key?(:content) @event_time = args[:event_time] if args.key?(:event_time) @state_delta = args[:state_delta] if args.key?(:state_delta) end |