Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentDataConversationTurn
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentDataConversationTurn
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Represents a single turn/invocation in the conversation.
Instance Attribute Summary collapse
-
#events ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentDataAgentEvent>
Optional.
-
#turn_id ⇒ String
Optional.
-
#turn_index ⇒ Fixnum
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentDataConversationTurn
constructor
A new instance of GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentDataConversationTurn.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentDataConversationTurn
Returns a new instance of GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentDataConversationTurn.
9846 9847 9848 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9846 def initialize(**args) update!(**args) end |
Instance Attribute Details
#events ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentDataAgentEvent>
Optional. The list of events that occurred during this turn.
Corresponds to the JSON property events
9833 9834 9835 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9833 def events @events end |
#turn_id ⇒ String
Optional. A unique identifier for the turn. Useful for referencing specific
turns across systems.
Corresponds to the JSON property turnId
9839 9840 9841 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9839 def turn_id @turn_id end |
#turn_index ⇒ Fixnum
Required. The 0-based index of the turn in the conversation sequence.
Corresponds to the JSON property turnIndex
9844 9845 9846 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9844 def turn_index @turn_index end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9851 9852 9853 9854 9855 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9851 def update!(**args) @events = args[:events] if args.key?(:events) @turn_id = args[:turn_id] if args.key?(:turn_id) @turn_index = args[:turn_index] if args.key?(:turn_index) end |