Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentDataConversationTurn

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents a single turn/invocation in the conversation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentDataConversationTurn

Returns a new instance of GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentDataConversationTurn.



9751
9752
9753
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9751

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#eventsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentDataAgentEvent>

Optional. The list of events that occurred during this turn. Corresponds to the JSON property events



9738
9739
9740
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9738

def events
  @events
end

#turn_idString

Optional. A unique identifier for the turn. Useful for referencing specific turns across systems. Corresponds to the JSON property turnId

Returns:

  • (String)


9744
9745
9746
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9744

def turn_id
  @turn_id
end

#turn_indexFixnum

Required. The 0-based index of the turn in the conversation sequence. Corresponds to the JSON property turnIndex

Returns:

  • (Fixnum)


9749
9750
9751
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9749

def turn_index
  @turn_index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9756
9757
9758
9759
9760
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9756

def update!(**args)
  @events = args[:events] if args.key?(:events)
  @turn_id = args[:turn_id] if args.key?(:turn_id)
  @turn_index = args[:turn_index] if args.key?(:turn_index)
end