Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationItem
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationItem
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
EvaluationItem is a single evaluation request or result. The content of an EvaluationItem is immutable - it cannot be updated once created. EvaluationItems can be deleted when no longer needed.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Required.
-
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#evaluation_item_type ⇒ String
Required.
-
#evaluation_request ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRequest
A single evaluation request supporting input for both single-turn model generation and multi-turn agent execution traces.
-
#evaluation_response ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationResult
Evaluation result.
-
#gcs_uri ⇒ String
The Cloud Storage object where the request or response is stored.
-
#labels ⇒ Hash<String,String>
Optional.
-
#metadata ⇒ Object
Optional.
-
#name ⇒ String
Identifier.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationItem
constructor
A new instance of GoogleCloudAiplatformV1EvaluationItem.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationItem
Returns a new instance of GoogleCloudAiplatformV1EvaluationItem.
10657 10658 10659 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10657 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this item was created.
Corresponds to the JSON property createTime
10598 10599 10600 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10598 def create_time @create_time end |
#display_name ⇒ String
Required. The display name of the EvaluationItem.
Corresponds to the JSON property displayName
10603 10604 10605 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10603 def display_name @display_name end |
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
10613 10614 10615 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10613 def error @error end |
#evaluation_item_type ⇒ String
Required. The type of the EvaluationItem.
Corresponds to the JSON property evaluationItemType
10618 10619 10620 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10618 def evaluation_item_type @evaluation_item_type end |
#evaluation_request ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRequest
A single evaluation request supporting input for both single-turn model
generation and multi-turn agent execution traces. Valid input modes: 1.
Inference Mode: prompt is set (containing text or AgentData context). 2.
Offline Eval Mode: prompt is unset, and candidate_responses contains
agent_data (the completed execution trace). Validation Rule: Either prompt
must be set, OR at least one of the candidate_responses must contain
agent_data.
Corresponds to the JSON property evaluationRequest
10629 10630 10631 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10629 def evaluation_request @evaluation_request end |
#evaluation_response ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationResult
Evaluation result.
Corresponds to the JSON property evaluationResponse
10634 10635 10636 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10634 def evaluation_response @evaluation_response end |
#gcs_uri ⇒ String
The Cloud Storage object where the request or response is stored.
Corresponds to the JSON property gcsUri
10639 10640 10641 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10639 def gcs_uri @gcs_uri end |
#labels ⇒ Hash<String,String>
Optional. Labels for the EvaluationItem.
Corresponds to the JSON property labels
10644 10645 10646 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10644 def labels @labels end |
#metadata ⇒ Object
Optional. Metadata for the EvaluationItem.
Corresponds to the JSON property metadata
10649 10650 10651 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10649 def @metadata end |
#name ⇒ String
Identifier. The resource name of the EvaluationItem. Format: projects/
project/locations/location/evaluationItems/evaluation_item`
Corresponds to the JSON propertyname`
10655 10656 10657 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10655 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10662 10663 10664 10665 10666 10667 10668 10669 10670 10671 10672 10673 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10662 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @error = args[:error] if args.key?(:error) @evaluation_item_type = args[:evaluation_item_type] if args.key?(:evaluation_item_type) @evaluation_request = args[:evaluation_request] if args.key?(:evaluation_request) @evaluation_response = args[:evaluation_response] if args.key?(:evaluation_response) @gcs_uri = args[:gcs_uri] if args.key?(:gcs_uri) @labels = args[:labels] if args.key?(:labels) @metadata = args[:metadata] if args.key?(:metadata) @name = args[:name] if args.key?(:name) end |