Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationItem
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationItem
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
EvaluationItem is a single evaluation request or result. The content of an EvaluationItem is immutable - it cannot be updated once created. EvaluationItems can be deleted when no longer needed.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Required.
-
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#evaluation_item_type ⇒ String
Required.
-
#evaluation_request ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRequest
A single evaluation request supporting input for both single-turn model generation and multi-turn agent execution traces.
-
#evaluation_response ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationResult
Evaluation result.
-
#gcs_uri ⇒ String
The Cloud Storage object where the request or response is stored.
-
#labels ⇒ Hash<String,String>
Optional.
-
#metadata ⇒ Object
Optional.
-
#name ⇒ String
Identifier.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationItem
constructor
A new instance of GoogleCloudAiplatformV1EvaluationItem.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationItem
Returns a new instance of GoogleCloudAiplatformV1EvaluationItem.
10450 10451 10452 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10450 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this item was created.
Corresponds to the JSON property createTime
10391 10392 10393 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10391 def create_time @create_time end |
#display_name ⇒ String
Required. The display name of the EvaluationItem.
Corresponds to the JSON property displayName
10396 10397 10398 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10396 def display_name @display_name end |
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
10406 10407 10408 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10406 def error @error end |
#evaluation_item_type ⇒ String
Required. The type of the EvaluationItem.
Corresponds to the JSON property evaluationItemType
10411 10412 10413 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10411 def evaluation_item_type @evaluation_item_type end |
#evaluation_request ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRequest
A single evaluation request supporting input for both single-turn model
generation and multi-turn agent execution traces. Valid input modes: 1.
Inference Mode: prompt is set (containing text or AgentData context). 2.
Offline Eval Mode: prompt is unset, and candidate_responses contains
agent_data (the completed execution trace). Validation Rule: Either prompt
must be set, OR at least one of the candidate_responses must contain
agent_data.
Corresponds to the JSON property evaluationRequest
10422 10423 10424 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10422 def evaluation_request @evaluation_request end |
#evaluation_response ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationResult
Evaluation result.
Corresponds to the JSON property evaluationResponse
10427 10428 10429 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10427 def evaluation_response @evaluation_response end |
#gcs_uri ⇒ String
The Cloud Storage object where the request or response is stored.
Corresponds to the JSON property gcsUri
10432 10433 10434 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10432 def gcs_uri @gcs_uri end |
#labels ⇒ Hash<String,String>
Optional. Labels for the EvaluationItem.
Corresponds to the JSON property labels
10437 10438 10439 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10437 def labels @labels end |
#metadata ⇒ Object
Optional. Metadata for the EvaluationItem.
Corresponds to the JSON property metadata
10442 10443 10444 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10442 def @metadata end |
#name ⇒ String
Identifier. The resource name of the EvaluationItem. Format: projects/
project/locations/location/evaluationItems/evaluation_item`
Corresponds to the JSON propertyname`
10448 10449 10450 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10448 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10455 10456 10457 10458 10459 10460 10461 10462 10463 10464 10465 10466 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10455 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @error = args[:error] if args.key?(:error) @evaluation_item_type = args[:evaluation_item_type] if args.key?(:evaluation_item_type) @evaluation_request = args[:evaluation_request] if args.key?(:evaluation_request) @evaluation_response = args[:evaluation_response] if args.key?(:evaluation_response) @gcs_uri = args[:gcs_uri] if args.key?(:gcs_uri) @labels = args[:labels] if args.key?(:labels) @metadata = args[:metadata] if args.key?(:metadata) @name = args[:name] if args.key?(:name) end |