Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationItem

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

EvaluationItem is a single evaluation request or result. The content of an EvaluationItem is immutable - it cannot be updated once created. EvaluationItems can be deleted when no longer needed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationItem

Returns a new instance of GoogleCloudAiplatformV1EvaluationItem.



9270
9271
9272
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9270

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this item was created. Corresponds to the JSON property createTime

Returns:

  • (String)


9217
9218
9219
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9217

def create_time
  @create_time
end

#display_nameString

Required. The display name of the EvaluationItem. Corresponds to the JSON property displayName

Returns:

  • (String)


9222
9223
9224
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9222

def display_name
  @display_name
end

#errorGoogle::Apis::AiplatformV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



9232
9233
9234
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9232

def error
  @error
end

#evaluation_item_typeString

Required. The type of the EvaluationItem. Corresponds to the JSON property evaluationItemType

Returns:

  • (String)


9237
9238
9239
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9237

def evaluation_item_type
  @evaluation_item_type
end

#evaluation_requestGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRequest

Single evaluation request. Corresponds to the JSON property evaluationRequest



9242
9243
9244
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9242

def evaluation_request
  @evaluation_request
end

#evaluation_responseGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationResult

Evaluation result. Corresponds to the JSON property evaluationResponse



9247
9248
9249
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9247

def evaluation_response
  @evaluation_response
end

#gcs_uriString

The Cloud Storage object where the request or response is stored. Corresponds to the JSON property gcsUri

Returns:

  • (String)


9252
9253
9254
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9252

def gcs_uri
  @gcs_uri
end

#labelsHash<String,String>

Optional. Labels for the EvaluationItem. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


9257
9258
9259
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9257

def labels
  @labels
end

#metadataObject

Optional. Metadata for the EvaluationItem. Corresponds to the JSON property metadata

Returns:

  • (Object)


9262
9263
9264
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9262

def 
  @metadata
end

#nameString

Identifier. The resource name of the EvaluationItem. Format: projects/ project/locations/location/evaluationItems/evaluation_item` Corresponds to the JSON propertyname`

Returns:

  • (String)


9268
9269
9270
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9268

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9275
9276
9277
9278
9279
9280
9281
9282
9283
9284
9285
9286
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9275

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @error = args[:error] if args.key?(:error)
  @evaluation_item_type = args[:evaluation_item_type] if args.key?(:evaluation_item_type)
  @evaluation_request = args[:evaluation_request] if args.key?(:evaluation_request)
  @evaluation_response = args[:evaluation_response] if args.key?(:evaluation_response)
  @gcs_uri = args[:gcs_uri] if args.key?(:gcs_uri)
  @labels = args[:labels] if args.key?(:labels)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
end