Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationMetric
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationMetric
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
EvaluationMetric is a resource that represents a reusable metric configuration.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Required.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.
-
#gcs_uri ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#metric ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Metric
The metric used for running evaluations.
-
#name ⇒ String
Identifier.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationMetric
constructor
A new instance of GoogleCloudAiplatformV1EvaluationMetric.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationMetric
Returns a new instance of GoogleCloudAiplatformV1EvaluationMetric.
11344 11345 11346 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11344 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time when the EvaluationMetric was created.
Corresponds to the JSON property createTime
11300 11301 11302 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11300 def create_time @create_time end |
#description ⇒ String
Optional. A description of the EvaluationMetric.
Corresponds to the JSON property description
11305 11306 11307 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11305 def description @description end |
#display_name ⇒ String
Required. The user-friendly display name for the EvaluationMetric.
Corresponds to the JSON property displayName
11310 11311 11312 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11310 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied
to a Vertex AI resource.
Corresponds to the JSON property encryptionSpec
11316 11317 11318 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11316 def encryption_spec @encryption_spec end |
#gcs_uri ⇒ String
Optional. The Google Cloud Storage URI that stores the metric specification..
Corresponds to the JSON property gcsUri
11321 11322 11323 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11321 def gcs_uri @gcs_uri end |
#labels ⇒ Hash<String,String>
Optional. Labels for the evaluation metric.
Corresponds to the JSON property labels
11326 11327 11328 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11326 def labels @labels end |
#metric ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Metric
The metric used for running evaluations.
Corresponds to the JSON property metric
11331 11332 11333 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11331 def metric @metric end |
#name ⇒ String
Identifier. The resource name of the EvaluationMetric. Format: projects/
project/locations/location/evaluationMetrics/evaluation_metric`
Corresponds to the JSON propertyname`
11337 11338 11339 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11337 def name @name end |
#update_time ⇒ String
Output only. The time when the EvaluationMetric was last updated.
Corresponds to the JSON property updateTime
11342 11343 11344 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11342 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11349 11350 11351 11352 11353 11354 11355 11356 11357 11358 11359 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11349 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @gcs_uri = args[:gcs_uri] if args.key?(:gcs_uri) @labels = args[:labels] if args.key?(:labels) @metric = args[:metric] if args.key?(:metric) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) end |