Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationMetric
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationMetric
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
EvaluationMetric is a resource that represents a reusable metric configuration.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Required.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.
-
#gcs_uri ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#metric ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Metric
The metric used for running evaluations.
-
#name ⇒ String
Identifier.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationMetric
constructor
A new instance of GoogleCloudAiplatformV1EvaluationMetric.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationMetric
Returns a new instance of GoogleCloudAiplatformV1EvaluationMetric.
10981 10982 10983 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10981 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time when the EvaluationMetric was created.
Corresponds to the JSON property createTime
10937 10938 10939 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10937 def create_time @create_time end |
#description ⇒ String
Optional. A description of the EvaluationMetric.
Corresponds to the JSON property description
10942 10943 10944 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10942 def description @description end |
#display_name ⇒ String
Required. The user-friendly display name for the EvaluationMetric.
Corresponds to the JSON property displayName
10947 10948 10949 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10947 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied
to a Vertex AI resource.
Corresponds to the JSON property encryptionSpec
10953 10954 10955 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10953 def encryption_spec @encryption_spec end |
#gcs_uri ⇒ String
Optional. The Google Cloud Storage URI that stores the metric specification..
Corresponds to the JSON property gcsUri
10958 10959 10960 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10958 def gcs_uri @gcs_uri end |
#labels ⇒ Hash<String,String>
Optional. Labels for the evaluation metric.
Corresponds to the JSON property labels
10963 10964 10965 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10963 def labels @labels end |
#metric ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Metric
The metric used for running evaluations.
Corresponds to the JSON property metric
10968 10969 10970 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10968 def metric @metric end |
#name ⇒ String
Identifier. The resource name of the EvaluationMetric. Format: projects/
project/locations/location/evaluationMetrics/evaluation_metric`
Corresponds to the JSON propertyname`
10974 10975 10976 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10974 def name @name end |
#update_time ⇒ String
Output only. The time when the EvaluationMetric was last updated.
Corresponds to the JSON property updateTime
10979 10980 10981 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10979 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10986 10987 10988 10989 10990 10991 10992 10993 10994 10995 10996 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10986 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @gcs_uri = args[:gcs_uri] if args.key?(:gcs_uri) @labels = args[:labels] if args.key?(:labels) @metric = args[:metric] if args.key?(:metric) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) end |