Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationPrompt
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationPrompt
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Prompt to be evaluated. This can represent a single-turn prompt or a multi- turn conversation for agent evaluations.
Instance Attribute Summary collapse
-
#prompt_template_data ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationPromptPromptTemplateData
Message to hold a prompt template and the values to populate the template.
-
#text ⇒ String
Text prompt.
-
#value ⇒ Object
Fields and values that can be used to populate the prompt template.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationPrompt
constructor
A new instance of GoogleCloudAiplatformV1EvaluationPrompt.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationPrompt
Returns a new instance of GoogleCloudAiplatformV1EvaluationPrompt.
10070 10071 10072 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10070 def initialize(**args) update!(**args) end |
Instance Attribute Details
#prompt_template_data ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationPromptPromptTemplateData
Message to hold a prompt template and the values to populate the template.
Corresponds to the JSON property promptTemplateData
10058 10059 10060 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10058 def prompt_template_data @prompt_template_data end |
#text ⇒ String
Text prompt.
Corresponds to the JSON property text
10063 10064 10065 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10063 def text @text end |
#value ⇒ Object
Fields and values that can be used to populate the prompt template.
Corresponds to the JSON property value
10068 10069 10070 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10068 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10075 10076 10077 10078 10079 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10075 def update!(**args) @prompt_template_data = args[:prompt_template_data] if args.key?(:prompt_template_data) @text = args[:text] if args.key?(:text) @value = args[:value] if args.key?(:value) end |