Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationPromptUserScenario

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

User scenario to help simulate multi-turn agent running results.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationPromptUserScenario

Returns a new instance of GoogleCloudAiplatformV1EvaluationPromptUserScenario.



10862
10863
10864
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10862

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversation_planString

Required. The plan for the conversation, used to drive the multi-turn agent run and generate the simulated agent evaluation dataset. Corresponds to the JSON property conversationPlan

Returns:

  • (String)


10854
10855
10856
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10854

def conversation_plan
  @conversation_plan
end

#starting_promptString

Required. The prompt that starts the conversation between the simulated user and the agent under test. Corresponds to the JSON property startingPrompt

Returns:

  • (String)


10860
10861
10862
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10860

def starting_prompt
  @starting_prompt
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10867
10868
10869
10870
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10867

def update!(**args)
  @conversation_plan = args[:conversation_plan] if args.key?(:conversation_plan)
  @starting_prompt = args[:starting_prompt] if args.key?(:starting_prompt)
end