Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationResult
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Evaluation result.
Instance Attribute Summary collapse
-
#candidate_results ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CandidateResult>
Optional.
-
#evaluation_request ⇒ String
Required.
-
#evaluation_run ⇒ String
Required.
-
#metadata ⇒ Object
Optional.
-
#metric ⇒ String
Required.
-
#request ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRequest
A single evaluation request supporting input for both single-turn model generation and multi-turn agent execution traces.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationResult
constructor
A new instance of GoogleCloudAiplatformV1EvaluationResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationResult
Returns a new instance of GoogleCloudAiplatformV1EvaluationResult.
9584 9585 9586 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9584 def initialize(**args) update!(**args) end |
Instance Attribute Details
#candidate_results ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CandidateResult>
Optional. The results for the metric.
Corresponds to the JSON property candidateResults
9549 9550 9551 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9549 def candidate_results @candidate_results end |
#evaluation_request ⇒ String
Required. The request item that was evaluated. Format: projects/project/
locations/location/evaluationItems/evaluation_item
Corresponds to the JSON property evaluationRequest
9555 9556 9557 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9555 def evaluation_request @evaluation_request end |
#evaluation_run ⇒ String
Required. The evaluation run that was used to generate the result. Format:
projects/project/locations/location/evaluationRuns/evaluation_run
Corresponds to the JSON property evaluationRun
9561 9562 9563 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9561 def evaluation_run @evaluation_run end |
#metadata ⇒ Object
Optional. Metadata about the evaluation result.
Corresponds to the JSON property metadata
9566 9567 9568 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9566 def @metadata end |
#metric ⇒ String
Required. The metric that was evaluated.
Corresponds to the JSON property metric
9571 9572 9573 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9571 def metric @metric end |
#request ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRequest
A single evaluation request supporting input for both single-turn model
generation and multi-turn agent execution traces. Valid input modes: 1.
Inference Mode: prompt is set (containing text or AgentData context). 2.
Offline Eval Mode: prompt is unset, and candidate_responses contains
agent_data (the completed execution trace). Validation Rule: Either prompt
must be set, OR at least one of the candidate_responses must contain
agent_data.
Corresponds to the JSON property request
9582 9583 9584 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9582 def request @request end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9589 9590 9591 9592 9593 9594 9595 9596 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9589 def update!(**args) @candidate_results = args[:candidate_results] if args.key?(:candidate_results) @evaluation_request = args[:evaluation_request] if args.key?(:evaluation_request) @evaluation_run = args[:evaluation_run] if args.key?(:evaluation_run) @metadata = args[:metadata] if args.key?(:metadata) @metric = args[:metric] if args.key?(:metric) @request = args[:request] if args.key?(:request) end |