Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationResults
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationResults
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The results of the evaluation run.
Instance Attribute Summary collapse
-
#evaluation_set ⇒ String
The evaluation set where item level results are stored.
-
#summary_metrics ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SummaryMetrics
The summary metrics for the evaluation run.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationResults
constructor
A new instance of GoogleCloudAiplatformV1EvaluationResults.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationResults
Returns a new instance of GoogleCloudAiplatformV1EvaluationResults.
10171 10172 10173 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10171 def initialize(**args) update!(**args) end |
Instance Attribute Details
#evaluation_set ⇒ String
The evaluation set where item level results are stored.
Corresponds to the JSON property evaluationSet
10164 10165 10166 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10164 def evaluation_set @evaluation_set end |
#summary_metrics ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SummaryMetrics
The summary metrics for the evaluation run.
Corresponds to the JSON property summaryMetrics
10169 10170 10171 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10169 def summary_metrics @summary_metrics end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10176 10177 10178 10179 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10176 def update!(**args) @evaluation_set = args[:evaluation_set] if args.key?(:evaluation_set) @summary_metrics = args[:summary_metrics] if args.key?(:summary_metrics) end |