Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRubricConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRubricConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Configuration for a rubric group to be generated/saved for evaluation.
Instance Attribute Summary collapse
-
#predefined_rubric_generation_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunMetricPredefinedMetricSpec
Specification for a pre-defined metric.
-
#rubric_generation_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunMetricRubricGenerationSpec
Specification for how rubrics should be generated.
-
#rubric_group_key ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationRubricConfig
constructor
A new instance of GoogleCloudAiplatformV1EvaluationRubricConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationRubricConfig
Returns a new instance of GoogleCloudAiplatformV1EvaluationRubricConfig.
11038 11039 11040 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11038 def initialize(**args) update!(**args) end |
Instance Attribute Details
#predefined_rubric_generation_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunMetricPredefinedMetricSpec
Specification for a pre-defined metric.
Corresponds to the JSON property predefinedRubricGenerationSpec
11021 11022 11023 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11021 def predefined_rubric_generation_spec @predefined_rubric_generation_spec end |
#rubric_generation_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunMetricRubricGenerationSpec
Specification for how rubrics should be generated.
Corresponds to the JSON property rubricGenerationSpec
11026 11027 11028 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11026 def rubric_generation_spec @rubric_generation_spec end |
#rubric_group_key ⇒ String
Required. The key used to save the generated rubrics. If a generation spec is
provided, this key will be used for the name of the generated rubric group.
Otherwise, this key will be used to look up the existing rubric group on the
evaluation item. Note that if a rubric group key is specified on both a rubric
config and an evaluation metric, the key from the metric will be used to
select the rubrics for evaluation.
Corresponds to the JSON property rubricGroupKey
11036 11037 11038 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11036 def rubric_group_key @rubric_group_key end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11043 11044 11045 11046 11047 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11043 def update!(**args) @predefined_rubric_generation_spec = args[:predefined_rubric_generation_spec] if args.key?(:predefined_rubric_generation_spec) @rubric_generation_spec = args[:rubric_generation_spec] if args.key?(:rubric_generation_spec) @rubric_group_key = args[:rubric_group_key] if args.key?(:rubric_group_key) end |