Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRubricConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRubricConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Configuration for a rubric group to be generated/saved for evaluation.
Instance Attribute Summary collapse
-
#predefined_rubric_generation_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunMetricPredefinedMetricSpec
Specification for a pre-defined metric.
-
#rubric_generation_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunMetricRubricGenerationSpec
Specification for how rubrics should be generated.
-
#rubric_group_key ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationRubricConfig
constructor
A new instance of GoogleCloudAiplatformV1EvaluationRubricConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationRubricConfig
Returns a new instance of GoogleCloudAiplatformV1EvaluationRubricConfig.
10206 10207 10208 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10206 def initialize(**args) update!(**args) end |
Instance Attribute Details
#predefined_rubric_generation_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunMetricPredefinedMetricSpec
Specification for a pre-defined metric.
Corresponds to the JSON property predefinedRubricGenerationSpec
10189 10190 10191 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10189 def predefined_rubric_generation_spec @predefined_rubric_generation_spec end |
#rubric_generation_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunMetricRubricGenerationSpec
Specification for how rubrics should be generated.
Corresponds to the JSON property rubricGenerationSpec
10194 10195 10196 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10194 def rubric_generation_spec @rubric_generation_spec end |
#rubric_group_key ⇒ String
Required. The key used to save the generated rubrics. If a generation spec is
provided, this key will be used for the name of the generated rubric group.
Otherwise, this key will be used to look up the existing rubric group on the
evaluation item. Note that if a rubric group key is specified on both a rubric
config and an evaluation metric, the key from the metric will be used to
select the rubrics for evaluation.
Corresponds to the JSON property rubricGroupKey
10204 10205 10206 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10204 def rubric_group_key @rubric_group_key end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10211 10212 10213 10214 10215 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10211 def update!(**args) @predefined_rubric_generation_spec = args[:predefined_rubric_generation_spec] if args.key?(:predefined_rubric_generation_spec) @rubric_generation_spec = args[:rubric_generation_spec] if args.key?(:rubric_generation_spec) @rubric_group_key = args[:rubric_group_key] if args.key?(:rubric_group_key) end |