Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRun

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

EvaluationRun is a resource that represents a single evaluation run, which includes a set of prompts, model responses, evaluation configuration and the resulting metrics.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationRun

Returns a new instance of GoogleCloudAiplatformV1EvaluationRun.



11756
11757
11758
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11756

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#completion_timeString

Output only. Time when the evaluation run was completed. Corresponds to the JSON property completionTime

Returns:

  • (String)


11676
11677
11678
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11676

def completion_time
  @completion_time
end

#create_timeString

Output only. Time when the evaluation run was created. Corresponds to the JSON property createTime

Returns:

  • (String)


11681
11682
11683
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11681

def create_time
  @create_time
end

#data_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunDataSource

The data source for the evaluation run. Corresponds to the JSON property dataSource



11686
11687
11688
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11686

def data_source
  @data_source
end

#display_nameString

Required. The display name of the Evaluation Run. Corresponds to the JSON property displayName

Returns:

  • (String)


11691
11692
11693
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11691

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



11697
11698
11699
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11697

def encryption_spec
  @encryption_spec
end

#errorGoogle::Apis::AiplatformV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



11707
11708
11709
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11707

def error
  @error
end

#evaluation_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunEvaluationConfig

The Evalution configuration used for the evaluation run. Corresponds to the JSON property evaluationConfig



11712
11713
11714
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11712

def evaluation_config
  @evaluation_config
end

#evaluation_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationResults

The results of the evaluation run. Corresponds to the JSON property evaluationResults



11717
11718
11719
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11717

def evaluation_results
  @evaluation_results
end

#evaluation_set_snapshotString

Output only. The specific evaluation set of the evaluation run. For runs with an evaluation set input, this will be that same set. For runs with BigQuery input, it's the sampled BigQuery dataset. Corresponds to the JSON property evaluationSetSnapshot

Returns:

  • (String)


11724
11725
11726
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11724

def evaluation_set_snapshot
  @evaluation_set_snapshot
end

#inference_configsHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunInferenceConfig>

Optional. The candidate to inference config map for the evaluation run. The candidate can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property inferenceConfigs



11731
11732
11733
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11731

def inference_configs
  @inference_configs
end

#labelsHash<String,String>

Optional. Labels for the evaluation run. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


11736
11737
11738
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11736

def labels
  @labels
end

#metadataObject

Optional. Metadata about the evaluation run, can be used by the caller to store additional tracking information about the evaluation run. Corresponds to the JSON property metadata

Returns:

  • (Object)


11742
11743
11744
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11742

def 
  @metadata
end

#nameString

Identifier. The resource name of the EvaluationRun. This is a unique identifier. Format: projects/project/locations/location/evaluationRuns/ evaluation_run` Corresponds to the JSON propertyname`

Returns:

  • (String)


11749
11750
11751
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11749

def name
  @name
end

#stateString

Output only. The state of the evaluation run. Corresponds to the JSON property state

Returns:

  • (String)


11754
11755
11756
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11754

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11761
11762
11763
11764
11765
11766
11767
11768
11769
11770
11771
11772
11773
11774
11775
11776
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11761

def update!(**args)
  @completion_time = args[:completion_time] if args.key?(:completion_time)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_source = args[:data_source] if args.key?(:data_source)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @error = args[:error] if args.key?(:error)
  @evaluation_config = args[:evaluation_config] if args.key?(:evaluation_config)
  @evaluation_results = args[:evaluation_results] if args.key?(:evaluation_results)
  @evaluation_set_snapshot = args[:evaluation_set_snapshot] if args.key?(:evaluation_set_snapshot)
  @inference_configs = args[:inference_configs] if args.key?(:inference_configs)
  @labels = args[:labels] if args.key?(:labels)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
end