Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRun
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRun
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
EvaluationRun is a resource that represents a single evaluation run, which includes a set of prompts, model responses, evaluation configuration and the resulting metrics.
Instance Attribute Summary collapse
-
#completion_time ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#data_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunDataSource
The data source for the evaluation run.
-
#display_name ⇒ String
Required.
-
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#evaluation_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunEvaluationConfig
The Evalution configuration used for the evaluation run.
-
#evaluation_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationResults
The results of the evaluation run.
-
#evaluation_set_snapshot ⇒ String
Output only.
-
#inference_configs ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunInferenceConfig>
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#metadata ⇒ Object
Optional.
-
#name ⇒ String
Identifier.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationRun
constructor
A new instance of GoogleCloudAiplatformV1EvaluationRun.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationRun
Returns a new instance of GoogleCloudAiplatformV1EvaluationRun.
11120 11121 11122 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11120 def initialize(**args) update!(**args) end |
Instance Attribute Details
#completion_time ⇒ String
Output only. Time when the evaluation run was completed.
Corresponds to the JSON property completionTime
11046 11047 11048 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11046 def completion_time @completion_time end |
#create_time ⇒ String
Output only. Time when the evaluation run was created.
Corresponds to the JSON property createTime
11051 11052 11053 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11051 def create_time @create_time end |
#data_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunDataSource
The data source for the evaluation run.
Corresponds to the JSON property dataSource
11056 11057 11058 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11056 def data_source @data_source end |
#display_name ⇒ String
Required. The display name of the Evaluation Run.
Corresponds to the JSON property displayName
11061 11062 11063 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11061 def display_name @display_name end |
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
11071 11072 11073 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11071 def error @error end |
#evaluation_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunEvaluationConfig
The Evalution configuration used for the evaluation run.
Corresponds to the JSON property evaluationConfig
11076 11077 11078 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11076 def evaluation_config @evaluation_config end |
#evaluation_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationResults
The results of the evaluation run.
Corresponds to the JSON property evaluationResults
11081 11082 11083 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11081 def evaluation_results @evaluation_results end |
#evaluation_set_snapshot ⇒ String
Output only. The specific evaluation set of the evaluation run. For runs with
an evaluation set input, this will be that same set. For runs with BigQuery
input, it's the sampled BigQuery dataset.
Corresponds to the JSON property evaluationSetSnapshot
11088 11089 11090 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11088 def evaluation_set_snapshot @evaluation_set_snapshot end |
#inference_configs ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunInferenceConfig>
Optional. The candidate to inference config map for the evaluation run. The
candidate can be up to 128 characters long and can consist of any UTF-8
characters.
Corresponds to the JSON property inferenceConfigs
11095 11096 11097 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11095 def inference_configs @inference_configs end |
#labels ⇒ Hash<String,String>
Optional. Labels for the evaluation run.
Corresponds to the JSON property labels
11100 11101 11102 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11100 def labels @labels end |
#metadata ⇒ Object
Optional. Metadata about the evaluation run, can be used by the caller to
store additional tracking information about the evaluation run.
Corresponds to the JSON property metadata
11106 11107 11108 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11106 def @metadata end |
#name ⇒ String
Identifier. The resource name of the EvaluationRun. This is a unique
identifier. Format: projects/project/locations/location/evaluationRuns/
evaluation_run`
Corresponds to the JSON propertyname`
11113 11114 11115 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11113 def name @name end |
#state ⇒ String
Output only. The state of the evaluation run.
Corresponds to the JSON property state
11118 11119 11120 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11118 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11125 11126 11127 11128 11129 11130 11131 11132 11133 11134 11135 11136 11137 11138 11139 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11125 def update!(**args) @completion_time = args[:completion_time] if args.key?(:completion_time) @create_time = args[:create_time] if args.key?(:create_time) @data_source = args[:data_source] if args.key?(:data_source) @display_name = args[:display_name] if args.key?(:display_name) @error = args[:error] if args.key?(:error) @evaluation_config = args[:evaluation_config] if args.key?(:evaluation_config) @evaluation_results = args[:evaluation_results] if args.key?(:evaluation_results) @evaluation_set_snapshot = args[:evaluation_set_snapshot] if args.key?(:evaluation_set_snapshot) @inference_configs = args[:inference_configs] if args.key?(:inference_configs) @labels = args[:labels] if args.key?(:labels) @metadata = args[:metadata] if args.key?(:metadata) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) end |