Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRun

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

EvaluationRun is a resource that represents a single evaluation run, which includes a set of prompts, model responses, evaluation configuration and the resulting metrics.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationRun

Returns a new instance of GoogleCloudAiplatformV1EvaluationRun.



10396
10397
10398
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10396

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#completion_timeString

Output only. Time when the evaluation run was completed. Corresponds to the JSON property completionTime

Returns:

  • (String)


10322
10323
10324
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10322

def completion_time
  @completion_time
end

#create_timeString

Output only. Time when the evaluation run was created. Corresponds to the JSON property createTime

Returns:

  • (String)


10327
10328
10329
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10327

def create_time
  @create_time
end

#data_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunDataSource

The data source for the evaluation run. Corresponds to the JSON property dataSource



10332
10333
10334
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10332

def data_source
  @data_source
end

#display_nameString

Required. The display name of the Evaluation Run. Corresponds to the JSON property displayName

Returns:

  • (String)


10337
10338
10339
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10337

def display_name
  @display_name
end

#errorGoogle::Apis::AiplatformV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



10347
10348
10349
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10347

def error
  @error
end

#evaluation_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunEvaluationConfig

The Evalution configuration used for the evaluation run. Corresponds to the JSON property evaluationConfig



10352
10353
10354
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10352

def evaluation_config
  @evaluation_config
end

#evaluation_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationResults

The results of the evaluation run. Corresponds to the JSON property evaluationResults



10357
10358
10359
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10357

def evaluation_results
  @evaluation_results
end

#evaluation_set_snapshotString

Output only. The specific evaluation set of the evaluation run. For runs with an evaluation set input, this will be that same set. For runs with BigQuery input, it's the sampled BigQuery dataset. Corresponds to the JSON property evaluationSetSnapshot

Returns:

  • (String)


10364
10365
10366
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10364

def evaluation_set_snapshot
  @evaluation_set_snapshot
end

#inference_configsHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunInferenceConfig>

Optional. The candidate to inference config map for the evaluation run. The candidate can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property inferenceConfigs



10371
10372
10373
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10371

def inference_configs
  @inference_configs
end

#labelsHash<String,String>

Optional. Labels for the evaluation run. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


10376
10377
10378
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10376

def labels
  @labels
end

#metadataObject

Optional. Metadata about the evaluation run, can be used by the caller to store additional tracking information about the evaluation run. Corresponds to the JSON property metadata

Returns:

  • (Object)


10382
10383
10384
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10382

def 
  @metadata
end

#nameString

Identifier. The resource name of the EvaluationRun. This is a unique identifier. Format: projects/project/locations/location/evaluationRuns/ evaluation_run` Corresponds to the JSON propertyname`

Returns:

  • (String)


10389
10390
10391
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10389

def name
  @name
end

#stateString

Output only. The state of the evaluation run. Corresponds to the JSON property state

Returns:

  • (String)


10394
10395
10396
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10394

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10401
10402
10403
10404
10405
10406
10407
10408
10409
10410
10411
10412
10413
10414
10415
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10401

def update!(**args)
  @completion_time = args[:completion_time] if args.key?(:completion_time)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_source = args[:data_source] if args.key?(:data_source)
  @display_name = args[:display_name] if args.key?(:display_name)
  @error = args[:error] if args.key?(:error)
  @evaluation_config = args[:evaluation_config] if args.key?(:evaluation_config)
  @evaluation_results = args[:evaluation_results] if args.key?(:evaluation_results)
  @evaluation_set_snapshot = args[:evaluation_set_snapshot] if args.key?(:evaluation_set_snapshot)
  @inference_configs = args[:inference_configs] if args.key?(:inference_configs)
  @labels = args[:labels] if args.key?(:labels)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
end