Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRun
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRun
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
EvaluationRun is a resource that represents a single evaluation run, which includes a set of prompts, model responses, evaluation configuration and the resulting metrics.
Instance Attribute Summary collapse
-
#completion_time ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#data_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunDataSource
The data source for the evaluation run.
-
#display_name ⇒ String
Required.
-
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#evaluation_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunEvaluationConfig
The Evalution configuration used for the evaluation run.
-
#evaluation_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationResults
The results of the evaluation run.
-
#evaluation_set_snapshot ⇒ String
Output only.
-
#inference_configs ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunInferenceConfig>
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#metadata ⇒ Object
Optional.
-
#name ⇒ String
Identifier.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationRun
constructor
A new instance of GoogleCloudAiplatformV1EvaluationRun.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationRun
Returns a new instance of GoogleCloudAiplatformV1EvaluationRun.
9743 9744 9745 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9743 def initialize(**args) update!(**args) end |
Instance Attribute Details
#completion_time ⇒ String
Output only. Time when the evaluation run was completed.
Corresponds to the JSON property completionTime
9669 9670 9671 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9669 def completion_time @completion_time end |
#create_time ⇒ String
Output only. Time when the evaluation run was created.
Corresponds to the JSON property createTime
9674 9675 9676 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9674 def create_time @create_time end |
#data_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunDataSource
The data source for the evaluation run.
Corresponds to the JSON property dataSource
9679 9680 9681 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9679 def data_source @data_source end |
#display_name ⇒ String
Required. The display name of the Evaluation Run.
Corresponds to the JSON property displayName
9684 9685 9686 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9684 def display_name @display_name end |
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
9694 9695 9696 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9694 def error @error end |
#evaluation_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunEvaluationConfig
The Evalution configuration used for the evaluation run.
Corresponds to the JSON property evaluationConfig
9699 9700 9701 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9699 def evaluation_config @evaluation_config end |
#evaluation_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationResults
The results of the evaluation run.
Corresponds to the JSON property evaluationResults
9704 9705 9706 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9704 def evaluation_results @evaluation_results end |
#evaluation_set_snapshot ⇒ String
Output only. The specific evaluation set of the evaluation run. For runs with
an evaluation set input, this will be that same set. For runs with BigQuery
input, it's the sampled BigQuery dataset.
Corresponds to the JSON property evaluationSetSnapshot
9711 9712 9713 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9711 def evaluation_set_snapshot @evaluation_set_snapshot end |
#inference_configs ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunInferenceConfig>
Optional. The candidate to inference config map for the evaluation run. The
candidate can be up to 128 characters long and can consist of any UTF-8
characters.
Corresponds to the JSON property inferenceConfigs
9718 9719 9720 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9718 def inference_configs @inference_configs end |
#labels ⇒ Hash<String,String>
Optional. Labels for the evaluation run.
Corresponds to the JSON property labels
9723 9724 9725 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9723 def labels @labels end |
#metadata ⇒ Object
Optional. Metadata about the evaluation run, can be used by the caller to
store additional tracking information about the evaluation run.
Corresponds to the JSON property metadata
9729 9730 9731 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9729 def @metadata end |
#name ⇒ String
Identifier. The resource name of the EvaluationRun. This is a unique
identifier. Format: projects/project/locations/location/evaluationRuns/
evaluation_run`
Corresponds to the JSON propertyname`
9736 9737 9738 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9736 def name @name end |
#state ⇒ String
Output only. The state of the evaluation run.
Corresponds to the JSON property state
9741 9742 9743 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9741 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9748 9749 9750 9751 9752 9753 9754 9755 9756 9757 9758 9759 9760 9761 9762 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9748 def update!(**args) @completion_time = args[:completion_time] if args.key?(:completion_time) @create_time = args[:create_time] if args.key?(:create_time) @data_source = args[:data_source] if args.key?(:data_source) @display_name = args[:display_name] if args.key?(:display_name) @error = args[:error] if args.key?(:error) @evaluation_config = args[:evaluation_config] if args.key?(:evaluation_config) @evaluation_results = args[:evaluation_results] if args.key?(:evaluation_results) @evaluation_set_snapshot = args[:evaluation_set_snapshot] if args.key?(:evaluation_set_snapshot) @inference_configs = args[:inference_configs] if args.key?(:inference_configs) @labels = args[:labels] if args.key?(:labels) @metadata = args[:metadata] if args.key?(:metadata) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) end |