Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunEvaluationConfigAutoraterConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunEvaluationConfigAutoraterConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The autorater config used for the evaluation run.
Instance Attribute Summary collapse
-
#autorater_model ⇒ String
Optional.
-
#generation_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfig
Configuration for content generation.
-
#sample_count ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationRunEvaluationConfigAutoraterConfig
constructor
A new instance of GoogleCloudAiplatformV1EvaluationRunEvaluationConfigAutoraterConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationRunEvaluationConfigAutoraterConfig
Returns a new instance of GoogleCloudAiplatformV1EvaluationRunEvaluationConfigAutoraterConfig.
11914 11915 11916 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11914 def initialize(**args) update!(**args) end |
Instance Attribute Details
#autorater_model ⇒ String
Optional. The fully qualified name of the publisher model or tuned autorater
endpoint to use. Publisher model format: projects/project/locations/
location/publishers/*/models/* Tuned model endpoint format: projects/
project/locations/location/endpoints/endpoint`
Corresponds to the JSON propertyautoraterModel`
11899 11900 11901 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11899 def autorater_model @autorater_model end |
#generation_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfig
Configuration for content generation. This message contains all the parameters
that control how the model generates content. It allows you to influence the
randomness, length, and structure of the output.
Corresponds to the JSON property generationConfig
11906 11907 11908 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11906 def generation_config @generation_config end |
#sample_count ⇒ Fixnum
Optional. Number of samples for each instance in the dataset. If not specified,
the default is 4. Minimum value is 1, maximum value is 32.
Corresponds to the JSON property sampleCount
11912 11913 11914 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11912 def sample_count @sample_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11919 11920 11921 11922 11923 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11919 def update!(**args) @autorater_model = args[:autorater_model] if args.key?(:autorater_model) @generation_config = args[:generation_config] if args.key?(:generation_config) @sample_count = args[:sample_count] if args.key?(:sample_count) end |