Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunEvaluationConfigAutoraterConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The autorater config used for the evaluation run.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationRunEvaluationConfigAutoraterConfig

Returns a new instance of GoogleCloudAiplatformV1EvaluationRunEvaluationConfigAutoraterConfig.



9865
9866
9867
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9865

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#autorater_modelString

Optional. The fully qualified name of the publisher model or tuned autorater endpoint to use. Publisher model format: projects/project/locations/ location/publishers/*/models/* Tuned model endpoint format: projects/ project/locations/location/endpoints/endpoint` Corresponds to the JSON propertyautoraterModel`

Returns:

  • (String)


9850
9851
9852
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9850

def autorater_model
  @autorater_model
end

#generation_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfig

Configuration for content generation. This message contains all the parameters that control how the model generates content. It allows you to influence the randomness, length, and structure of the output. Corresponds to the JSON property generationConfig



9857
9858
9859
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9857

def generation_config
  @generation_config
end

#sample_countFixnum

Optional. Number of samples for each instance in the dataset. If not specified, the default is 4. Minimum value is 1, maximum value is 32. Corresponds to the JSON property sampleCount

Returns:

  • (Fixnum)


9863
9864
9865
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9863

def sample_count
  @sample_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9870
9871
9872
9873
9874
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9870

def update!(**args)
  @autorater_model = args[:autorater_model] if args.key?(:autorater_model)
  @generation_config = args[:generation_config] if args.key?(:generation_config)
  @sample_count = args[:sample_count] if args.key?(:sample_count)
end