Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunInferenceConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Defines the configuration for a candidate model or agent being evaluated. InferenceConfig encapsulates all the necessary information to invoke or scrape the candidate during the evaluation run. This includes direct model inference parameters, agent execution settings, and multi-turn scraping configurations (such as user simulators). It serves as the primary representation of the candidate across different stages of the evaluation process.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationRunInferenceConfig

Returns a new instance of GoogleCloudAiplatformV1EvaluationRunInferenceConfig.



12015
12016
12017
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12015

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_run_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunInferenceConfigAgentRunConfig

Configuration for Agent Run. Corresponds to the JSON property agentRunConfig



11977
11978
11979
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11977

def agent_run_config
  @agent_run_config
end

#agentsHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AgentConfig>

Optional. Contains the static configurations for each agent in the system. Key: agent_id (matches the author field in events). Value: The static configuration of the agent. Corresponds to the JSON property agents



11984
11985
11986
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11984

def agents
  @agents
end

#generation_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfig

Configuration for content generation. This message contains all the parameters that control how the model generates content. It allows you to influence the randomness, length, and structure of the output. Corresponds to the JSON property generationConfig



11991
11992
11993
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11991

def generation_config
  @generation_config
end

#modelString

Optional. The fully qualified name of the publisher model or endpoint to use. Anthropic and Llama third-party models are also supported through Model Garden. Publisher model format: projects/project/locations/location/publishers/*/ models/* Third-party model formats: projects/project/locations/location/ publishers/anthropic/models/modelor `projects/`project`/locations/` location`/publishers/llama/models/`model Endpoint format: projects/project /locations/location/endpoints/endpoint` Corresponds to the JSON propertymodel`

Returns:

  • (String)


12002
12003
12004
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12002

def model
  @model
end

#parallelismFixnum

Optional. The parallelism of the evaluation run for the inference step. If not specified, the default parallelism will be used. Corresponds to the JSON property parallelism

Returns:

  • (Fixnum)


12008
12009
12010
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12008

def parallelism
  @parallelism
end

#prompt_templateGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunEvaluationConfigPromptTemplate

Prompt template used for inference. Corresponds to the JSON property promptTemplate



12013
12014
12015
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12013

def prompt_template
  @prompt_template
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12020
12021
12022
12023
12024
12025
12026
12027
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12020

def update!(**args)
  @agent_run_config = args[:agent_run_config] if args.key?(:agent_run_config)
  @agents = args[:agents] if args.key?(:agents)
  @generation_config = args[:generation_config] if args.key?(:generation_config)
  @model = args[:model] if args.key?(:model)
  @parallelism = args[:parallelism] if args.key?(:parallelism)
  @prompt_template = args[:prompt_template] if args.key?(:prompt_template)
end