Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunInferenceConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunInferenceConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Defines the configuration for a candidate model or agent being evaluated.
InferenceConfig encapsulates all the necessary information to invoke or
scrape the candidate during the evaluation run. This includes direct model
inference parameters, agent execution settings, and multi-turn scraping
configurations (such as user simulators). It serves as the primary
representation of the candidate across different stages of the evaluation
process.
Instance Attribute Summary collapse
-
#agent_run_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunInferenceConfigAgentRunConfig
Configuration for Agent Run.
-
#agents ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AgentConfig>
Optional.
-
#generation_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfig
Configuration for content generation.
-
#model ⇒ String
Optional.
-
#parallelism ⇒ Fixnum
Optional.
-
#prompt_template ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunEvaluationConfigPromptTemplate
Prompt template used for inference.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationRunInferenceConfig
constructor
A new instance of GoogleCloudAiplatformV1EvaluationRunInferenceConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationRunInferenceConfig
Returns a new instance of GoogleCloudAiplatformV1EvaluationRunInferenceConfig.
11645 11646 11647 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11645 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_run_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunInferenceConfigAgentRunConfig
Configuration for Agent Run.
Corresponds to the JSON property agentRunConfig
11607 11608 11609 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11607 def agent_run_config @agent_run_config end |
#agents ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AgentConfig>
Optional. Contains the static configurations for each agent in the system. Key:
agent_id (matches the author field in events). Value: The static
configuration of the agent.
Corresponds to the JSON property agents
11614 11615 11616 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11614 def agents @agents end |
#generation_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfig
Configuration for content generation. This message contains all the parameters
that control how the model generates content. It allows you to influence the
randomness, length, and structure of the output.
Corresponds to the JSON property generationConfig
11621 11622 11623 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11621 def generation_config @generation_config end |
#model ⇒ String
Optional. The fully qualified name of the publisher model or endpoint to use.
Anthropic and Llama third-party models are also supported through Model Garden.
Publisher model format: projects/project/locations/location/publishers/*/
models/* Third-party model formats: projects/project/locations/location/
publishers/anthropic/models/modelor `projects/`project`/locations/`
location`/publishers/llama/models/`model Endpoint format: projects/project
/locations/location/endpoints/endpoint`
Corresponds to the JSON propertymodel`
11632 11633 11634 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11632 def model @model end |
#parallelism ⇒ Fixnum
Optional. The parallelism of the evaluation run for the inference step. If not
specified, the default parallelism will be used.
Corresponds to the JSON property parallelism
11638 11639 11640 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11638 def parallelism @parallelism end |
#prompt_template ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunEvaluationConfigPromptTemplate
Prompt template used for inference.
Corresponds to the JSON property promptTemplate
11643 11644 11645 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11643 def prompt_template @prompt_template end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11650 11651 11652 11653 11654 11655 11656 11657 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11650 def update!(**args) @agent_run_config = args[:agent_run_config] if args.key?(:agent_run_config) @agents = args[:agents] if args.key?(:agents) @generation_config = args[:generation_config] if args.key?(:generation_config) @model = args[:model] if args.key?(:model) @parallelism = args[:parallelism] if args.key?(:parallelism) @prompt_template = args[:prompt_template] if args.key?(:prompt_template) end |