Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunInferenceConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Defines the configuration for a candidate model or agent being evaluated. InferenceConfig encapsulates all the necessary information to invoke or scrape the candidate during the evaluation run. This includes direct model inference parameters, agent execution settings, and multi-turn scraping configurations (such as user simulators). It serves as the primary representation of the candidate across different stages of the evaluation process.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationRunInferenceConfig

Returns a new instance of GoogleCloudAiplatformV1EvaluationRunInferenceConfig.



10629
10630
10631
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10629

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_run_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunInferenceConfigAgentRunConfig

Configuration for Agent Run. Corresponds to the JSON property agentRunConfig



10603
10604
10605
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10603

def agent_run_config
  @agent_run_config
end

#generation_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfig

Configuration for content generation. This message contains all the parameters that control how the model generates content. It allows you to influence the randomness, length, and structure of the output. Corresponds to the JSON property generationConfig



10610
10611
10612
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10610

def generation_config
  @generation_config
end

#modelString

Optional. The fully qualified name of the publisher model or endpoint to use. Anthropic and Llama third-party models are also supported through Model Garden. Publisher model format: projects/project/locations/location/publishers/*/ models/* Third-party model formats: projects/project/locations/location/ publishers/anthropic/models/modelor `projects/`project`/locations/` location`/publishers/llama/models/`model Endpoint format: projects/project /locations/location/endpoints/endpoint` Corresponds to the JSON propertymodel`

Returns:

  • (String)


10621
10622
10623
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10621

def model
  @model
end

#parallelismFixnum

Optional. The parallelism of the evaluation run for the inference step. If not specified, the default parallelism will be used. Corresponds to the JSON property parallelism

Returns:

  • (Fixnum)


10627
10628
10629
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10627

def parallelism
  @parallelism
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10634
10635
10636
10637
10638
10639
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10634

def update!(**args)
  @agent_run_config = args[:agent_run_config] if args.key?(:agent_run_config)
  @generation_config = args[:generation_config] if args.key?(:generation_config)
  @model = args[:model] if args.key?(:model)
  @parallelism = args[:parallelism] if args.key?(:parallelism)
end