Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunInferenceConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunInferenceConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Defines the configuration for a candidate model or agent being evaluated.
InferenceConfig encapsulates all the necessary information to invoke or
scrape the candidate during the evaluation run. This includes direct model
inference parameters, agent execution settings, and multi-turn scraping
configurations (such as user simulators). It serves as the primary
representation of the candidate across different stages of the evaluation
process.
Instance Attribute Summary collapse
-
#agent_run_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunInferenceConfigAgentRunConfig
Configuration for Agent Run.
-
#generation_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfig
Configuration for content generation.
-
#model ⇒ String
Optional.
-
#parallelism ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationRunInferenceConfig
constructor
A new instance of GoogleCloudAiplatformV1EvaluationRunInferenceConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationRunInferenceConfig
Returns a new instance of GoogleCloudAiplatformV1EvaluationRunInferenceConfig.
10533 10534 10535 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10533 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_run_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunInferenceConfigAgentRunConfig
Configuration for Agent Run.
Corresponds to the JSON property agentRunConfig
10507 10508 10509 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10507 def agent_run_config @agent_run_config end |
#generation_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfig
Configuration for content generation. This message contains all the parameters
that control how the model generates content. It allows you to influence the
randomness, length, and structure of the output.
Corresponds to the JSON property generationConfig
10514 10515 10516 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10514 def generation_config @generation_config end |
#model ⇒ String
Optional. The fully qualified name of the publisher model or endpoint to use.
Anthropic and Llama third-party models are also supported through Model Garden.
Publisher model format: projects/project/locations/location/publishers/*/
models/* Third-party model formats: projects/project/locations/location/
publishers/anthropic/models/modelor `projects/`project`/locations/`
location`/publishers/llama/models/`model Endpoint format: projects/project
/locations/location/endpoints/endpoint`
Corresponds to the JSON propertymodel`
10525 10526 10527 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10525 def model @model end |
#parallelism ⇒ Fixnum
Optional. The parallelism of the evaluation run for the inference step. If not
specified, the default parallelism will be used.
Corresponds to the JSON property parallelism
10531 10532 10533 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10531 def parallelism @parallelism end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10538 10539 10540 10541 10542 10543 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10538 def update!(**args) @agent_run_config = args[:agent_run_config] if args.key?(:agent_run_config) @generation_config = args[:generation_config] if args.key?(:generation_config) @model = args[:model] if args.key?(:model) @parallelism = args[:parallelism] if args.key?(:parallelism) end |