Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunInferenceConfigAgentRunConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Configuration for Agent Run.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationRunInferenceConfigAgentRunConfig

Returns a new instance of GoogleCloudAiplatformV1EvaluationRunInferenceConfigAgentRunConfig.



10568
10569
10570
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10568

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_engineString

Optional. The resource name of the Agent Engine. Format: projects/project/ locations/location/reasoningEngines/reasoning_engine For example: projects/ 123/locations/us-central1/reasoningEngines/456 Corresponds to the JSON property agentEngine

Returns:

  • (String)


10555
10556
10557
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10555

def agent_engine
  @agent_engine
end

#session_inputGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunInferenceConfigSessionInput

Session input to run an Agent. Corresponds to the JSON property sessionInput



10560
10561
10562
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10560

def session_input
  @session_input
end

#user_simulator_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunInferenceConfigAgentRunConfigUserSimulatorConfig

Used for multi-turn agent scraping. Contains configuration for a user simulator that uses an LLM to generate messages on behalf of the user. Corresponds to the JSON property userSimulatorConfig



10566
10567
10568
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10566

def user_simulator_config
  @user_simulator_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10573
10574
10575
10576
10577
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10573

def update!(**args)
  @agent_engine = args[:agent_engine] if args.key?(:agent_engine)
  @session_input = args[:session_input] if args.key?(:session_input)
  @user_simulator_config = args[:user_simulator_config] if args.key?(:user_simulator_config)
end