Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunInferenceConfigAgentRunConfigUserSimulatorConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Used for multi-turn agent scraping. Contains configuration for a user simulator that uses an LLM to generate messages on behalf of the user.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationRunInferenceConfigAgentRunConfigUserSimulatorConfig

Returns a new instance of GoogleCloudAiplatformV1EvaluationRunInferenceConfigAgentRunConfigUserSimulatorConfig.



11453
11454
11455
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11453

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_turnFixnum

Maximum number of invocations allowed by the multi-turn agent scraping. This property allows us to stop a run-off conversation, where the agent and the user simulator get into a never ending loop. The initial fixed prompt is also counted as an invocation. Corresponds to the JSON property maxTurn

Returns:

  • (Fixnum)


11438
11439
11440
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11438

def max_turn
  @max_turn
end

#model_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfig

Configuration for content generation. This message contains all the parameters that control how the model generates content. It allows you to influence the randomness, length, and structure of the output. Corresponds to the JSON property modelConfig



11445
11446
11447
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11445

def model_config
  @model_config
end

#model_nameString

The model name to use for multi-turn agent scraping to get next user message, e.g. "gemini-3-flash-preview". Corresponds to the JSON property modelName

Returns:

  • (String)


11451
11452
11453
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11451

def model_name
  @model_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11458
11459
11460
11461
11462
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11458

def update!(**args)
  @max_turn = args[:max_turn] if args.key?(:max_turn)
  @model_config = args[:model_config] if args.key?(:model_config)
  @model_name = args[:model_name] if args.key?(:model_name)
end