Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunMetric
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunMetric
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The metric used for evaluation runs.
Instance Attribute Summary collapse
-
#computation_based_metric_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunMetricComputationBasedMetricSpec
Specification for a computation based metric.
-
#llm_based_metric_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunMetricLlmBasedMetricSpec
Specification for an LLM based metric.
-
#metric ⇒ String
Required.
-
#metric_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Metric
The metric used for running evaluations.
-
#metric_resource_name ⇒ String
Optional.
-
#predefined_metric_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunMetricPredefinedMetricSpec
Specification for a pre-defined metric.
-
#rubric_based_metric_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunMetricRubricBasedMetricSpec
Specification for a metric that is based on rubrics.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationRunMetric
constructor
A new instance of GoogleCloudAiplatformV1EvaluationRunMetric.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationRunMetric
Returns a new instance of GoogleCloudAiplatformV1EvaluationRunMetric.
11537 11538 11539 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11537 def initialize(**args) update!(**args) end |
Instance Attribute Details
#computation_based_metric_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunMetricComputationBasedMetricSpec
Specification for a computation based metric.
Corresponds to the JSON property computationBasedMetricSpec
11505 11506 11507 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11505 def computation_based_metric_spec @computation_based_metric_spec end |
#llm_based_metric_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunMetricLlmBasedMetricSpec
Specification for an LLM based metric.
Corresponds to the JSON property llmBasedMetricSpec
11510 11511 11512 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11510 def llm_based_metric_spec @llm_based_metric_spec end |
#metric ⇒ String
Required. The name of the metric.
Corresponds to the JSON property metric
11515 11516 11517 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11515 def metric @metric end |
#metric_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Metric
The metric used for running evaluations.
Corresponds to the JSON property metricConfig
11520 11521 11522 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11520 def metric_config @metric_config end |
#metric_resource_name ⇒ String
Optional. The resource name of the metric definition.
Corresponds to the JSON property metricResourceName
11525 11526 11527 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11525 def metric_resource_name @metric_resource_name end |
#predefined_metric_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunMetricPredefinedMetricSpec
Specification for a pre-defined metric.
Corresponds to the JSON property predefinedMetricSpec
11530 11531 11532 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11530 def predefined_metric_spec @predefined_metric_spec end |
#rubric_based_metric_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunMetricRubricBasedMetricSpec
Specification for a metric that is based on rubrics.
Corresponds to the JSON property rubricBasedMetricSpec
11535 11536 11537 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11535 def rubric_based_metric_spec @rubric_based_metric_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11542 11543 11544 11545 11546 11547 11548 11549 11550 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11542 def update!(**args) @computation_based_metric_spec = args[:computation_based_metric_spec] if args.key?(:computation_based_metric_spec) @llm_based_metric_spec = args[:llm_based_metric_spec] if args.key?(:llm_based_metric_spec) @metric = args[:metric] if args.key?(:metric) @metric_config = args[:metric_config] if args.key?(:metric_config) @metric_resource_name = args[:metric_resource_name] if args.key?(:metric_resource_name) @predefined_metric_spec = args[:predefined_metric_spec] if args.key?(:predefined_metric_spec) @rubric_based_metric_spec = args[:rubric_based_metric_spec] if args.key?(:rubric_based_metric_spec) end |