Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunMetric
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunMetric
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The metric used for evaluation runs.
Instance Attribute Summary collapse
-
#computation_based_metric_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunMetricComputationBasedMetricSpec
Specification for a computation based metric.
-
#llm_based_metric_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunMetricLlmBasedMetricSpec
Specification for an LLM based metric.
-
#metric ⇒ String
Required.
-
#metric_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Metric
The metric used for running evaluations.
-
#metric_resource_name ⇒ String
Optional.
-
#predefined_metric_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunMetricPredefinedMetricSpec
Specification for a pre-defined metric.
-
#rubric_based_metric_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunMetricRubricBasedMetricSpec
Specification for a metric that is based on rubrics.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationRunMetric
constructor
A new instance of GoogleCloudAiplatformV1EvaluationRunMetric.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationRunMetric
Returns a new instance of GoogleCloudAiplatformV1EvaluationRunMetric.
10737 10738 10739 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10737 def initialize(**args) update!(**args) end |
Instance Attribute Details
#computation_based_metric_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunMetricComputationBasedMetricSpec
Specification for a computation based metric.
Corresponds to the JSON property computationBasedMetricSpec
10705 10706 10707 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10705 def computation_based_metric_spec @computation_based_metric_spec end |
#llm_based_metric_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunMetricLlmBasedMetricSpec
Specification for an LLM based metric.
Corresponds to the JSON property llmBasedMetricSpec
10710 10711 10712 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10710 def llm_based_metric_spec @llm_based_metric_spec end |
#metric ⇒ String
Required. The name of the metric.
Corresponds to the JSON property metric
10715 10716 10717 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10715 def metric @metric end |
#metric_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Metric
The metric used for running evaluations.
Corresponds to the JSON property metricConfig
10720 10721 10722 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10720 def metric_config @metric_config end |
#metric_resource_name ⇒ String
Optional. The resource name of the metric definition.
Corresponds to the JSON property metricResourceName
10725 10726 10727 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10725 def metric_resource_name @metric_resource_name end |
#predefined_metric_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunMetricPredefinedMetricSpec
Specification for a pre-defined metric.
Corresponds to the JSON property predefinedMetricSpec
10730 10731 10732 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10730 def predefined_metric_spec @predefined_metric_spec end |
#rubric_based_metric_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunMetricRubricBasedMetricSpec
Specification for a metric that is based on rubrics.
Corresponds to the JSON property rubricBasedMetricSpec
10735 10736 10737 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10735 def rubric_based_metric_spec @rubric_based_metric_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10742 10743 10744 10745 10746 10747 10748 10749 10750 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10742 def update!(**args) @computation_based_metric_spec = args[:computation_based_metric_spec] if args.key?(:computation_based_metric_spec) @llm_based_metric_spec = args[:llm_based_metric_spec] if args.key?(:llm_based_metric_spec) @metric = args[:metric] if args.key?(:metric) @metric_config = args[:metric_config] if args.key?(:metric_config) @metric_resource_name = args[:metric_resource_name] if args.key?(:metric_resource_name) @predefined_metric_spec = args[:predefined_metric_spec] if args.key?(:predefined_metric_spec) @rubric_based_metric_spec = args[:rubric_based_metric_spec] if args.key?(:rubric_based_metric_spec) end |