Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunMetricRubricBasedMetricSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunMetricRubricBasedMetricSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Specification for a metric that is based on rubrics.
Instance Attribute Summary collapse
-
#inline_rubrics ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunMetricRubricBasedMetricSpecRepeatedRubrics
Defines a list of rubrics, used when providing rubrics inline.
-
#judge_autorater_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunEvaluationConfigAutoraterConfig
The autorater config used for the evaluation run.
-
#metric_prompt_template ⇒ String
Optional.
-
#rubric_generation_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunMetricRubricGenerationSpec
Specification for how rubrics should be generated.
-
#rubric_group_key ⇒ String
Use a pre-defined group of rubrics associated with the input content.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationRunMetricRubricBasedMetricSpec
constructor
A new instance of GoogleCloudAiplatformV1EvaluationRunMetricRubricBasedMetricSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationRunMetricRubricBasedMetricSpec
Returns a new instance of GoogleCloudAiplatformV1EvaluationRunMetricRubricBasedMetricSpec.
10844 10845 10846 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10844 def initialize(**args) update!(**args) end |
Instance Attribute Details
#inline_rubrics ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunMetricRubricBasedMetricSpecRepeatedRubrics
Defines a list of rubrics, used when providing rubrics inline.
Corresponds to the JSON property inlineRubrics
10820 10821 10822 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10820 def inline_rubrics @inline_rubrics end |
#judge_autorater_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunEvaluationConfigAutoraterConfig
The autorater config used for the evaluation run.
Corresponds to the JSON property judgeAutoraterConfig
10825 10826 10827 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10825 def judge_autorater_config @judge_autorater_config end |
#metric_prompt_template ⇒ String
Optional. Template for the prompt used by the judge model to evaluate against
rubrics.
Corresponds to the JSON property metricPromptTemplate
10831 10832 10833 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10831 def metric_prompt_template @metric_prompt_template end |
#rubric_generation_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunMetricRubricGenerationSpec
Specification for how rubrics should be generated.
Corresponds to the JSON property rubricGenerationSpec
10836 10837 10838 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10836 def rubric_generation_spec @rubric_generation_spec end |
#rubric_group_key ⇒ String
Use a pre-defined group of rubrics associated with the input content. This
refers to a key in the rubric_groups map of RubricEnhancedContents.
Corresponds to the JSON property rubricGroupKey
10842 10843 10844 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10842 def rubric_group_key @rubric_group_key end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10849 10850 10851 10852 10853 10854 10855 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10849 def update!(**args) @inline_rubrics = args[:inline_rubrics] if args.key?(:inline_rubrics) @judge_autorater_config = args[:judge_autorater_config] if args.key?(:judge_autorater_config) @metric_prompt_template = args[:metric_prompt_template] if args.key?(:metric_prompt_template) @rubric_generation_spec = args[:rubric_generation_spec] if args.key?(:rubric_generation_spec) @rubric_group_key = args[:rubric_group_key] if args.key?(:rubric_group_key) end |