Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunMetricRubricGenerationSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Specification for how rubrics should be generated.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationRunMetricRubricGenerationSpec

Returns a new instance of GoogleCloudAiplatformV1EvaluationRunMetricRubricGenerationSpec.



10006
10007
10008
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10006

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#model_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationRunEvaluationConfigAutoraterConfig

The autorater config used for the evaluation run. Corresponds to the JSON property modelConfig



9986
9987
9988
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9986

def model_config
  @model_config
end

#prompt_templateString

Optional. Template for the prompt used to generate rubrics. The details should be updated based on the most-recent recipe requirements. Corresponds to the JSON property promptTemplate

Returns:

  • (String)


9992
9993
9994
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9992

def prompt_template
  @prompt_template
end

#rubric_content_typeString

Optional. The type of rubric content to be generated. Corresponds to the JSON property rubricContentType

Returns:

  • (String)


9997
9998
9999
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9997

def rubric_content_type
  @rubric_content_type
end

#rubric_type_ontologyArray<String>

Optional. An optional, pre-defined list of allowed types for generated rubrics. If this field is provided, it implies include_rubric_type should be true, and the generated rubric types should be chosen from this ontology. Corresponds to the JSON property rubricTypeOntology

Returns:

  • (Array<String>)


10004
10005
10006
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10004

def rubric_type_ontology
  @rubric_type_ontology
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10011
10012
10013
10014
10015
10016
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10011

def update!(**args)
  @model_config = args[:model_config] if args.key?(:model_config)
  @prompt_template = args[:prompt_template] if args.key?(:prompt_template)
  @rubric_content_type = args[:rubric_content_type] if args.key?(:rubric_content_type)
  @rubric_type_ontology = args[:rubric_type_ontology] if args.key?(:rubric_type_ontology)
end