Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationSet
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationSet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
EvaluationSet is a collection of related EvaluationItems that are evaluated together.
Instance Attribute Summary collapse
-
#agent_configs ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AgentConfig>
Optional.
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Required.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.
-
#evaluation_items ⇒ Array<String>
Required.
-
#metadata ⇒ Object
Optional.
-
#name ⇒ String
Identifier.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationSet
constructor
A new instance of GoogleCloudAiplatformV1EvaluationSet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationSet
Returns a new instance of GoogleCloudAiplatformV1EvaluationSet.
12463 12464 12465 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12463 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_configs ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AgentConfig>
Optional. Static configurations for each agent associated with the items in
this set. Key: agent_id (matches the author field in events). Value: The
static configuration of the agent.
Corresponds to the JSON property agentConfigs
12424 12425 12426 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12424 def agent_configs @agent_configs end |
#create_time ⇒ String
Output only. Timestamp when this item was created.
Corresponds to the JSON property createTime
12429 12430 12431 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12429 def create_time @create_time end |
#display_name ⇒ String
Required. The display name of the EvaluationSet.
Corresponds to the JSON property displayName
12434 12435 12436 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12434 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied
to a Vertex AI resource.
Corresponds to the JSON property encryptionSpec
12440 12441 12442 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12440 def encryption_spec @encryption_spec end |
#evaluation_items ⇒ Array<String>
Required. The EvaluationItems that are part of this dataset.
Corresponds to the JSON property evaluationItems
12445 12446 12447 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12445 def evaluation_items @evaluation_items end |
#metadata ⇒ Object
Optional. Metadata for the EvaluationSet.
Corresponds to the JSON property metadata
12450 12451 12452 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12450 def @metadata end |
#name ⇒ String
Identifier. The resource name of the EvaluationSet. Format: projects/project
/locations/location/evaluationSets/evaluation_set`
Corresponds to the JSON propertyname`
12456 12457 12458 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12456 def name @name end |
#update_time ⇒ String
Output only. Timestamp when this item was last updated.
Corresponds to the JSON property updateTime
12461 12462 12463 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12461 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12468 12469 12470 12471 12472 12473 12474 12475 12476 12477 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12468 def update!(**args) @agent_configs = args[:agent_configs] if args.key?(:agent_configs) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @evaluation_items = args[:evaluation_items] if args.key?(:evaluation_items) @metadata = args[:metadata] if args.key?(:metadata) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) end |