Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationSet
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationSet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
EvaluationSet is a collection of related EvaluationItems that are evaluated together.
Instance Attribute Summary collapse
-
#agent_configs ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AgentConfig>
Optional.
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Required.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.
-
#evaluation_items ⇒ Array<String>
Required.
-
#metadata ⇒ Object
Optional.
-
#name ⇒ String
Identifier.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationSet
constructor
A new instance of GoogleCloudAiplatformV1EvaluationSet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1EvaluationSet
Returns a new instance of GoogleCloudAiplatformV1EvaluationSet.
12086 12087 12088 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12086 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_configs ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AgentConfig>
Optional. Static configurations for each agent associated with the items in
this set. Key: agent_id (matches the author field in events). Value: The
static configuration of the agent.
Corresponds to the JSON property agentConfigs
12047 12048 12049 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12047 def agent_configs @agent_configs end |
#create_time ⇒ String
Output only. Timestamp when this item was created.
Corresponds to the JSON property createTime
12052 12053 12054 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12052 def create_time @create_time end |
#display_name ⇒ String
Required. The display name of the EvaluationSet.
Corresponds to the JSON property displayName
12057 12058 12059 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12057 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied
to a Vertex AI resource.
Corresponds to the JSON property encryptionSpec
12063 12064 12065 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12063 def encryption_spec @encryption_spec end |
#evaluation_items ⇒ Array<String>
Required. The EvaluationItems that are part of this dataset.
Corresponds to the JSON property evaluationItems
12068 12069 12070 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12068 def evaluation_items @evaluation_items end |
#metadata ⇒ Object
Optional. Metadata for the EvaluationSet.
Corresponds to the JSON property metadata
12073 12074 12075 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12073 def @metadata end |
#name ⇒ String
Identifier. The resource name of the EvaluationSet. Format: projects/project
/locations/location/evaluationSets/evaluation_set`
Corresponds to the JSON propertyname`
12079 12080 12081 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12079 def name @name end |
#update_time ⇒ String
Output only. Timestamp when this item was last updated.
Corresponds to the JSON property updateTime
12084 12085 12086 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12084 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12091 12092 12093 12094 12095 12096 12097 12098 12099 12100 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12091 def update!(**args) @agent_configs = args[:agent_configs] if args.key?(:agent_configs) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @evaluation_items = args[:evaluation_items] if args.key?(:evaluation_items) @metadata = args[:metadata] if args.key?(:metadata) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) end |