Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Event

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

An edge describing the relationship between an Artifact and an Execution in a lineage graph.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Event

Returns a new instance of GoogleCloudAiplatformV1Event.



8223
8224
8225
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8223

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifactString

Required. The relative resource name of the Artifact in the Event. Corresponds to the JSON property artifact

Returns:

  • (String)


8195
8196
8197
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8195

def artifact
  @artifact
end

#event_timeString

Output only. Time the Event occurred. Corresponds to the JSON property eventTime

Returns:

  • (String)


8200
8201
8202
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8200

def event_time
  @event_time
end

#executionString

Output only. The relative resource name of the Execution in the Event. Corresponds to the JSON property execution

Returns:

  • (String)


8205
8206
8207
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8205

def execution
  @execution
end

#labelsHash<String,String>

The labels with user-defined metadata to annotate Events. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. No more than 64 user labels can be associated with one Event (System labels are excluded). See https://goo.gl/ xmQnxf for more information and examples of labels. System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


8216
8217
8218
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8216

def labels
  @labels
end

#typeString

Required. The type of the Event. Corresponds to the JSON property type

Returns:

  • (String)


8221
8222
8223
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8221

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8228
8229
8230
8231
8232
8233
8234
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8228

def update!(**args)
  @artifact = args[:artifact] if args.key?(:artifact)
  @event_time = args[:event_time] if args.key?(:event_time)
  @execution = args[:execution] if args.key?(:execution)
  @labels = args[:labels] if args.key?(:labels)
  @type = args[:type] if args.key?(:type)
end