Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Event
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Event
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
An edge describing the relationship between an Artifact and an Execution in a lineage graph.
Instance Attribute Summary collapse
-
#artifact ⇒ String
Required.
-
#event_time ⇒ String
Output only.
-
#execution ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to annotate Events.
-
#type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Event
constructor
A new instance of GoogleCloudAiplatformV1Event.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Event
Returns a new instance of GoogleCloudAiplatformV1Event.
7488 7489 7490 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7488 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact ⇒ String
Required. The relative resource name of the Artifact in the Event.
Corresponds to the JSON property artifact
7460 7461 7462 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7460 def artifact @artifact end |
#event_time ⇒ String
Output only. Time the Event occurred.
Corresponds to the JSON property eventTime
7465 7466 7467 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7465 def event_time @event_time end |
#execution ⇒ String
Output only. The relative resource name of the Execution in the Event.
Corresponds to the JSON property execution
7470 7471 7472 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7470 def execution @execution end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to annotate Events. Label keys and
values can be no longer than 64 characters (Unicode codepoints), can only
contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. No more than 64 user labels can be
associated with one Event (System labels are excluded). See https://goo.gl/
xmQnxf for more information and examples of labels. System reserved label keys
are prefixed with "aiplatform.googleapis.com/" and are immutable.
Corresponds to the JSON property labels
7481 7482 7483 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7481 def labels @labels end |
#type ⇒ String
Required. The type of the Event.
Corresponds to the JSON property type
7486 7487 7488 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7486 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7493 7494 7495 7496 7497 7498 7499 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7493 def update!(**args) @artifact = args[:artifact] if args.key?(:artifact) @event_time = args[:event_time] if args.key?(:event_time) @execution = args[:execution] if args.key?(:execution) @labels = args[:labels] if args.key?(:labels) @type = args[:type] if args.key?(:type) end |