Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EventActions
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EventActions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Actions are parts of events that are executed by the agent.
Instance Attribute Summary collapse
-
#artifact_delta ⇒ Hash<String,Fixnum>
Optional.
-
#escalate ⇒ Boolean
(also: #escalate?)
Optional.
-
#requested_auth_configs ⇒ Hash<String,Object>
Optional.
-
#skip_summarization ⇒ Boolean
(also: #skip_summarization?)
Optional.
-
#state_delta ⇒ Hash<String,Object>
Optional.
-
#transfer_agent ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1EventActions
constructor
A new instance of GoogleCloudAiplatformV1EventActions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1EventActions
Returns a new instance of GoogleCloudAiplatformV1EventActions.
12586 12587 12588 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12586 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_delta ⇒ Hash<String,Fixnum>
Optional. Indicates that the event is updating an artifact. key is the
filename, value is the version.
Corresponds to the JSON property artifactDelta
12553 12554 12555 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12553 def artifact_delta @artifact_delta end |
#escalate ⇒ Boolean Also known as: escalate?
Optional. The agent is escalating to a higher level agent.
Corresponds to the JSON property escalate
12558 12559 12560 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12558 def escalate @escalate end |
#requested_auth_configs ⇒ Hash<String,Object>
Optional. Will only be set by a tool response indicating tool request euc.
Struct key is the function call id since one function call response (from
model) could correspond to multiple function calls. Struct value is the
required auth config, which can be another struct.
Corresponds to the JSON property requestedAuthConfigs
12567 12568 12569 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12567 def requested_auth_configs @requested_auth_configs end |
#skip_summarization ⇒ Boolean Also known as: skip_summarization?
Optional. If true, it won't call model to summarize function response. Only
used for function_response event.
Corresponds to the JSON property skipSummarization
12573 12574 12575 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12573 def skip_summarization @skip_summarization end |
#state_delta ⇒ Hash<String,Object>
Optional. Indicates that the event is updating the state with the given delta.
Corresponds to the JSON property stateDelta
12579 12580 12581 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12579 def state_delta @state_delta end |
#transfer_agent ⇒ String
Optional. If set, the event transfers to the specified agent.
Corresponds to the JSON property transferAgent
12584 12585 12586 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12584 def transfer_agent @transfer_agent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12591 12592 12593 12594 12595 12596 12597 12598 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12591 def update!(**args) @artifact_delta = args[:artifact_delta] if args.key?(:artifact_delta) @escalate = args[:escalate] if args.key?(:escalate) @requested_auth_configs = args[:requested_auth_configs] if args.key?(:requested_auth_configs) @skip_summarization = args[:skip_summarization] if args.key?(:skip_summarization) @state_delta = args[:state_delta] if args.key?(:state_delta) @transfer_agent = args[:transfer_agent] if args.key?(:transfer_agent) end |