Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EventActions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Actions are parts of events that are executed by the agent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1EventActions

Returns a new instance of GoogleCloudAiplatformV1EventActions.



11273
11274
11275
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11273

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_deltaHash<String,Fixnum>

Optional. Indicates that the event is updating an artifact. key is the filename, value is the version. Corresponds to the JSON property artifactDelta

Returns:

  • (Hash<String,Fixnum>)


11240
11241
11242
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11240

def artifact_delta
  @artifact_delta
end

#escalateBoolean Also known as: escalate?

Optional. The agent is escalating to a higher level agent. Corresponds to the JSON property escalate

Returns:

  • (Boolean)


11245
11246
11247
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11245

def escalate
  @escalate
end

#requested_auth_configsHash<String,Object>

Optional. Will only be set by a tool response indicating tool request euc. Struct key is the function call id since one function call response (from model) could correspond to multiple function calls. Struct value is the required auth config, which can be another struct. Corresponds to the JSON property requestedAuthConfigs

Returns:

  • (Hash<String,Object>)


11254
11255
11256
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11254

def requested_auth_configs
  @requested_auth_configs
end

#skip_summarizationBoolean Also known as: skip_summarization?

Optional. If true, it won't call model to summarize function response. Only used for function_response event. Corresponds to the JSON property skipSummarization

Returns:

  • (Boolean)


11260
11261
11262
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11260

def skip_summarization
  @skip_summarization
end

#state_deltaHash<String,Object>

Optional. Indicates that the event is updating the state with the given delta. Corresponds to the JSON property stateDelta

Returns:

  • (Hash<String,Object>)


11266
11267
11268
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11266

def state_delta
  @state_delta
end

#transfer_agentString

Optional. If set, the event transfers to the specified agent. Corresponds to the JSON property transferAgent

Returns:

  • (String)


11271
11272
11273
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11271

def transfer_agent
  @transfer_agent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11278
11279
11280
11281
11282
11283
11284
11285
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11278

def update!(**args)
  @artifact_delta = args[:artifact_delta] if args.key?(:artifact_delta)
  @escalate = args[:escalate] if args.key?(:escalate)
  @requested_auth_configs = args[:requested_auth_configs] if args.key?(:requested_auth_configs)
  @skip_summarization = args[:skip_summarization] if args.key?(:skip_summarization)
  @state_delta = args[:state_delta] if args.key?(:state_delta)
  @transfer_agent = args[:transfer_agent] if args.key?(:transfer_agent)
end