Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EventMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Metadata relating to a LLM response event.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1EventMetadata

Returns a new instance of GoogleCloudAiplatformV1EventMetadata.



12271
12272
12273
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12271

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#branchString

Optional. The branch of the event. The format is like agent_1.agent_2.agent_3, where agent_1 is the parent of agent_2, and agent_2 is the parent of agent_3. Branch is used when multiple child agents shouldn't see their siblings' conversation history. Corresponds to the JSON property branch

Returns:

  • (String)


12219
12220
12221
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12219

def branch
  @branch
end

#custom_metadataHash<String,Object>

The custom metadata of the LlmResponse. Corresponds to the JSON property customMetadata

Returns:

  • (Hash<String,Object>)


12224
12225
12226
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12224

def 
  @custom_metadata
end

#grounding_metadataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingMetadata

Information about the sources that support the content of a response. When grounding is enabled, the model returns citations for claims in the response. This object contains the retrieved sources. Corresponds to the JSON property groundingMetadata



12231
12232
12233
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12231

def 
  @grounding_metadata
end

#input_transcriptionGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Transcription

Audio transcription in Server Content. Corresponds to the JSON property inputTranscription



12236
12237
12238
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12236

def input_transcription
  @input_transcription
end

#interruptedBoolean Also known as: interrupted?

Optional. Flag indicating that LLM was interrupted when generating the content. Usually it's due to user interruption during a bidi streaming. Corresponds to the JSON property interrupted

Returns:

  • (Boolean)


12242
12243
12244
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12242

def interrupted
  @interrupted
end

#long_running_tool_idsArray<String>

Optional. Set of ids of the long running function calls. Agent client will know from this field about which function call is long running. Only valid for function call event. Corresponds to the JSON property longRunningToolIds

Returns:

  • (Array<String>)


12250
12251
12252
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12250

def long_running_tool_ids
  @long_running_tool_ids
end

#output_transcriptionGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Transcription

Audio transcription in Server Content. Corresponds to the JSON property outputTranscription



12255
12256
12257
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12255

def output_transcription
  @output_transcription
end

#partialBoolean Also known as: partial?

Optional. Indicates whether the text content is part of a unfinished text stream. Only used for streaming mode and when the content is plain text. Corresponds to the JSON property partial

Returns:

  • (Boolean)


12261
12262
12263
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12261

def partial
  @partial
end

#turn_completeBoolean Also known as: turn_complete?

Optional. Indicates whether the response from the model is complete. Only used for streaming mode. Corresponds to the JSON property turnComplete

Returns:

  • (Boolean)


12268
12269
12270
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12268

def turn_complete
  @turn_complete
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12276
12277
12278
12279
12280
12281
12282
12283
12284
12285
12286
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12276

def update!(**args)
  @branch = args[:branch] if args.key?(:branch)
  @custom_metadata = args[:custom_metadata] if args.key?(:custom_metadata)
  @grounding_metadata = args[:grounding_metadata] if args.key?(:grounding_metadata)
  @input_transcription = args[:input_transcription] if args.key?(:input_transcription)
  @interrupted = args[:interrupted] if args.key?(:interrupted)
  @long_running_tool_ids = args[:long_running_tool_ids] if args.key?(:long_running_tool_ids)
  @output_transcription = args[:output_transcription] if args.key?(:output_transcription)
  @partial = args[:partial] if args.key?(:partial)
  @turn_complete = args[:turn_complete] if args.key?(:turn_complete)
end