Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EventMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Metadata relating to a LLM response event.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1EventMetadata

Returns a new instance of GoogleCloudAiplatformV1EventMetadata.



11668
11669
11670
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11668

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#branchString

Optional. The branch of the event. The format is like agent_1.agent_2.agent_3, where agent_1 is the parent of agent_2, and agent_2 is the parent of agent_3. Branch is used when multiple child agents shouldn't see their siblings' conversation history. Corresponds to the JSON property branch

Returns:

  • (String)


11616
11617
11618
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11616

def branch
  @branch
end

#custom_metadataHash<String,Object>

The custom metadata of the LlmResponse. Corresponds to the JSON property customMetadata

Returns:

  • (Hash<String,Object>)


11621
11622
11623
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11621

def 
  @custom_metadata
end

#grounding_metadataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingMetadata

Information about the sources that support the content of a response. When grounding is enabled, the model returns citations for claims in the response. This object contains the retrieved sources. Corresponds to the JSON property groundingMetadata



11628
11629
11630
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11628

def 
  @grounding_metadata
end

#input_transcriptionGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Transcription

Audio transcription in Server Content. Corresponds to the JSON property inputTranscription



11633
11634
11635
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11633

def input_transcription
  @input_transcription
end

#interruptedBoolean Also known as: interrupted?

Optional. Flag indicating that LLM was interrupted when generating the content. Usually it's due to user interruption during a bidi streaming. Corresponds to the JSON property interrupted

Returns:

  • (Boolean)


11639
11640
11641
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11639

def interrupted
  @interrupted
end

#long_running_tool_idsArray<String>

Optional. Set of ids of the long running function calls. Agent client will know from this field about which function call is long running. Only valid for function call event. Corresponds to the JSON property longRunningToolIds

Returns:

  • (Array<String>)


11647
11648
11649
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11647

def long_running_tool_ids
  @long_running_tool_ids
end

#output_transcriptionGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Transcription

Audio transcription in Server Content. Corresponds to the JSON property outputTranscription



11652
11653
11654
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11652

def output_transcription
  @output_transcription
end

#partialBoolean Also known as: partial?

Optional. Indicates whether the text content is part of a unfinished text stream. Only used for streaming mode and when the content is plain text. Corresponds to the JSON property partial

Returns:

  • (Boolean)


11658
11659
11660
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11658

def partial
  @partial
end

#turn_completeBoolean Also known as: turn_complete?

Optional. Indicates whether the response from the model is complete. Only used for streaming mode. Corresponds to the JSON property turnComplete

Returns:

  • (Boolean)


11665
11666
11667
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11665

def turn_complete
  @turn_complete
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11673
11674
11675
11676
11677
11678
11679
11680
11681
11682
11683
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11673

def update!(**args)
  @branch = args[:branch] if args.key?(:branch)
  @custom_metadata = args[:custom_metadata] if args.key?(:custom_metadata)
  @grounding_metadata = args[:grounding_metadata] if args.key?(:grounding_metadata)
  @input_transcription = args[:input_transcription] if args.key?(:input_transcription)
  @interrupted = args[:interrupted] if args.key?(:interrupted)
  @long_running_tool_ids = args[:long_running_tool_ids] if args.key?(:long_running_tool_ids)
  @output_transcription = args[:output_transcription] if args.key?(:output_transcription)
  @partial = args[:partial] if args.key?(:partial)
  @turn_complete = args[:turn_complete] if args.key?(:turn_complete)
end