Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EventMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Metadata relating to a LLM response event.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1EventMetadata

Returns a new instance of GoogleCloudAiplatformV1EventMetadata.



10429
10430
10431
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10429

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#branchString

Optional. The branch of the event. The format is like agent_1.agent_2.agent_3, where agent_1 is the parent of agent_2, and agent_2 is the parent of agent_3. Branch is used when multiple child agents shouldn't see their siblings' conversation history. Corresponds to the JSON property branch

Returns:

  • (String)


10387
10388
10389
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10387

def branch
  @branch
end

#custom_metadataHash<String,Object>

The custom metadata of the LlmResponse. Corresponds to the JSON property customMetadata

Returns:

  • (Hash<String,Object>)


10392
10393
10394
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10392

def 
  @custom_metadata
end

#grounding_metadataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingMetadata

Information about the sources that support the content of a response. When grounding is enabled, the model returns citations for claims in the response. This object contains the retrieved sources. Corresponds to the JSON property groundingMetadata



10399
10400
10401
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10399

def 
  @grounding_metadata
end

#interruptedBoolean Also known as: interrupted?

Optional. Flag indicating that LLM was interrupted when generating the content. Usually it's due to user interruption during a bidi streaming. Corresponds to the JSON property interrupted

Returns:

  • (Boolean)


10405
10406
10407
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10405

def interrupted
  @interrupted
end

#long_running_tool_idsArray<String>

Optional. Set of ids of the long running function calls. Agent client will know from this field about which function call is long running. Only valid for function call event. Corresponds to the JSON property longRunningToolIds

Returns:

  • (Array<String>)


10413
10414
10415
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10413

def long_running_tool_ids
  @long_running_tool_ids
end

#partialBoolean Also known as: partial?

Optional. Indicates whether the text content is part of a unfinished text stream. Only used for streaming mode and when the content is plain text. Corresponds to the JSON property partial

Returns:

  • (Boolean)


10419
10420
10421
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10419

def partial
  @partial
end

#turn_completeBoolean Also known as: turn_complete?

Optional. Indicates whether the response from the model is complete. Only used for streaming mode. Corresponds to the JSON property turnComplete

Returns:

  • (Boolean)


10426
10427
10428
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10426

def turn_complete
  @turn_complete
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10434
10435
10436
10437
10438
10439
10440
10441
10442
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10434

def update!(**args)
  @branch = args[:branch] if args.key?(:branch)
  @custom_metadata = args[:custom_metadata] if args.key?(:custom_metadata)
  @grounding_metadata = args[:grounding_metadata] if args.key?(:grounding_metadata)
  @interrupted = args[:interrupted] if args.key?(:interrupted)
  @long_running_tool_ids = args[:long_running_tool_ids] if args.key?(:long_running_tool_ids)
  @partial = args[:partial] if args.key?(:partial)
  @turn_complete = args[:turn_complete] if args.key?(:turn_complete)
end