Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Examples

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Example-based explainability that returns the nearest neighbors from the provided dataset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Examples

Returns a new instance of GoogleCloudAiplatformV1Examples.



10375
10376
10377
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10375

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#example_gcs_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ExamplesExampleGcsSource

The Cloud Storage input instances. Corresponds to the JSON property exampleGcsSource



10355
10356
10357
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10355

def example_gcs_source
  @example_gcs_source
end

#nearest_neighbor_search_configObject

The full configuration for the generated index, the semantics are the same as metadata and should match NearestNeighborSearchConfig. Corresponds to the JSON property nearestNeighborSearchConfig

Returns:

  • (Object)


10363
10364
10365
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10363

def nearest_neighbor_search_config
  @nearest_neighbor_search_config
end

#neighbor_countFixnum

The number of neighbors to return when querying for examples. Corresponds to the JSON property neighborCount

Returns:

  • (Fixnum)


10368
10369
10370
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10368

def neighbor_count
  @neighbor_count
end

#presetsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Presets

Preset configuration for example-based explanations Corresponds to the JSON property presets



10373
10374
10375
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10373

def presets
  @presets
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10380
10381
10382
10383
10384
10385
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10380

def update!(**args)
  @example_gcs_source = args[:example_gcs_source] if args.key?(:example_gcs_source)
  @nearest_neighbor_search_config = args[:nearest_neighbor_search_config] if args.key?(:nearest_neighbor_search_config)
  @neighbor_count = args[:neighbor_count] if args.key?(:neighbor_count)
  @presets = args[:presets] if args.key?(:presets)
end