Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Examples

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Example-based explainability that returns the nearest neighbors from the provided dataset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Examples

Returns a new instance of GoogleCloudAiplatformV1Examples.



8369
8370
8371
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8369

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#example_gcs_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ExamplesExampleGcsSource

The Cloud Storage input instances. Corresponds to the JSON property exampleGcsSource



8349
8350
8351
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8349

def example_gcs_source
  @example_gcs_source
end

#nearest_neighbor_search_configObject

The full configuration for the generated index, the semantics are the same as metadata and should match NearestNeighborSearchConfig. Corresponds to the JSON property nearestNeighborSearchConfig

Returns:

  • (Object)


8357
8358
8359
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8357

def nearest_neighbor_search_config
  @nearest_neighbor_search_config
end

#neighbor_countFixnum

The number of neighbors to return when querying for examples. Corresponds to the JSON property neighborCount

Returns:

  • (Fixnum)


8362
8363
8364
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8362

def neighbor_count
  @neighbor_count
end

#presetsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Presets

Preset configuration for example-based explanations Corresponds to the JSON property presets



8367
8368
8369
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8367

def presets
  @presets
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8374
8375
8376
8377
8378
8379
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8374

def update!(**args)
  @example_gcs_source = args[:example_gcs_source] if args.key?(:example_gcs_source)
  @nearest_neighbor_search_config = args[:nearest_neighbor_search_config] if args.key?(:nearest_neighbor_search_config)
  @neighbor_count = args[:neighbor_count] if args.key?(:neighbor_count)
  @presets = args[:presets] if args.key?(:presets)
end