Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Examples
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Examples
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Example-based explainability that returns the nearest neighbors from the provided dataset.
Instance Attribute Summary collapse
-
#example_gcs_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExamplesExampleGcsSource
The Cloud Storage input instances.
-
#nearest_neighbor_search_config ⇒ Object
The full configuration for the generated index, the semantics are the same as metadata and should match NearestNeighborSearchConfig.
-
#neighbor_count ⇒ Fixnum
The number of neighbors to return when querying for examples.
-
#presets ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Presets
Preset configuration for example-based explanations Corresponds to the JSON property
presets.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Examples
constructor
A new instance of GoogleCloudAiplatformV1Examples.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Examples
Returns a new instance of GoogleCloudAiplatformV1Examples.
7690 7691 7692 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7690 def initialize(**args) update!(**args) end |
Instance Attribute Details
#example_gcs_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExamplesExampleGcsSource
The Cloud Storage input instances.
Corresponds to the JSON property exampleGcsSource
7670 7671 7672 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7670 def example_gcs_source @example_gcs_source end |
#nearest_neighbor_search_config ⇒ Object
The full configuration for the generated index, the semantics are the same as
metadata and should match NearestNeighborSearchConfig.
Corresponds to the JSON property nearestNeighborSearchConfig
7678 7679 7680 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7678 def nearest_neighbor_search_config @nearest_neighbor_search_config end |
#neighbor_count ⇒ Fixnum
The number of neighbors to return when querying for examples.
Corresponds to the JSON property neighborCount
7683 7684 7685 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7683 def neighbor_count @neighbor_count end |
#presets ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Presets
Preset configuration for example-based explanations
Corresponds to the JSON property presets
7688 7689 7690 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7688 def presets @presets end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7695 7696 7697 7698 7699 7700 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7695 def update!(**args) @example_gcs_source = args[:example_gcs_source] if args.key?(:example_gcs_source) @nearest_neighbor_search_config = args[:nearest_neighbor_search_config] if args.key?(:nearest_neighbor_search_config) @neighbor_count = args[:neighbor_count] if args.key?(:neighbor_count) @presets = args[:presets] if args.key?(:presets) end |