Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExamplesOverride
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExamplesOverride
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Overrides for example-based explanations.
Instance Attribute Summary collapse
-
#crowding_count ⇒ Fixnum
The number of neighbors to return that have the same crowding tag.
-
#data_format ⇒ String
The format of the data being provided with each call.
-
#neighbor_count ⇒ Fixnum
The number of neighbors to return.
-
#restrictions ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExamplesRestrictionsNamespace>
Restrict the resulting nearest neighbors to respect these constraints.
-
#return_embeddings ⇒ Boolean
(also: #return_embeddings?)
If true, return the embeddings instead of neighbors.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExamplesOverride
constructor
A new instance of GoogleCloudAiplatformV1ExamplesOverride.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExamplesOverride
Returns a new instance of GoogleCloudAiplatformV1ExamplesOverride.
12228 12229 12230 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12228 def initialize(**args) update!(**args) end |
Instance Attribute Details
#crowding_count ⇒ Fixnum
The number of neighbors to return that have the same crowding tag.
Corresponds to the JSON property crowdingCount
12205 12206 12207 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12205 def crowding_count @crowding_count end |
#data_format ⇒ String
The format of the data being provided with each call.
Corresponds to the JSON property dataFormat
12210 12211 12212 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12210 def data_format @data_format end |
#neighbor_count ⇒ Fixnum
The number of neighbors to return.
Corresponds to the JSON property neighborCount
12215 12216 12217 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12215 def neighbor_count @neighbor_count end |
#restrictions ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExamplesRestrictionsNamespace>
Restrict the resulting nearest neighbors to respect these constraints.
Corresponds to the JSON property restrictions
12220 12221 12222 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12220 def restrictions @restrictions end |
#return_embeddings ⇒ Boolean Also known as: return_embeddings?
If true, return the embeddings instead of neighbors.
Corresponds to the JSON property returnEmbeddings
12225 12226 12227 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12225 def @return_embeddings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12233 12234 12235 12236 12237 12238 12239 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12233 def update!(**args) @crowding_count = args[:crowding_count] if args.key?(:crowding_count) @data_format = args[:data_format] if args.key?(:data_format) @neighbor_count = args[:neighbor_count] if args.key?(:neighbor_count) @restrictions = args[:restrictions] if args.key?(:restrictions) @return_embeddings = args[:return_embeddings] if args.key?(:return_embeddings) end |