Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExamplesOverride

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Overrides for example-based explanations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ExamplesOverride

Returns a new instance of GoogleCloudAiplatformV1ExamplesOverride.



7759
7760
7761
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7759

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#crowding_countFixnum

The number of neighbors to return that have the same crowding tag. Corresponds to the JSON property crowdingCount

Returns:

  • (Fixnum)


7736
7737
7738
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7736

def crowding_count
  @crowding_count
end

#data_formatString

The format of the data being provided with each call. Corresponds to the JSON property dataFormat

Returns:

  • (String)


7741
7742
7743
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7741

def data_format
  @data_format
end

#neighbor_countFixnum

The number of neighbors to return. Corresponds to the JSON property neighborCount

Returns:

  • (Fixnum)


7746
7747
7748
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7746

def neighbor_count
  @neighbor_count
end

#restrictionsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExamplesRestrictionsNamespace>

Restrict the resulting nearest neighbors to respect these constraints. Corresponds to the JSON property restrictions



7751
7752
7753
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7751

def restrictions
  @restrictions
end

#return_embeddingsBoolean Also known as: return_embeddings?

If true, return the embeddings instead of neighbors. Corresponds to the JSON property returnEmbeddings

Returns:

  • (Boolean)


7756
7757
7758
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7756

def return_embeddings
  @return_embeddings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7764
7765
7766
7767
7768
7769
7770
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7764

def update!(**args)
  @crowding_count = args[:crowding_count] if args.key?(:crowding_count)
  @data_format = args[:data_format] if args.key?(:data_format)
  @neighbor_count = args[:neighbor_count] if args.key?(:neighbor_count)
  @restrictions = args[:restrictions] if args.key?(:restrictions)
  @return_embeddings = args[:return_embeddings] if args.key?(:return_embeddings)
end