Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExamplesOverride

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Overrides for example-based explanations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ExamplesOverride

Returns a new instance of GoogleCloudAiplatformV1ExamplesOverride.



6010
6011
6012
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6010

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#crowding_countFixnum

The number of neighbors to return that have the same crowding tag. Corresponds to the JSON property crowdingCount

Returns:

  • (Fixnum)


5987
5988
5989
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5987

def crowding_count
  @crowding_count
end

#data_formatString

The format of the data being provided with each call. Corresponds to the JSON property dataFormat

Returns:

  • (String)


5992
5993
5994
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5992

def data_format
  @data_format
end

#neighbor_countFixnum

The number of neighbors to return. Corresponds to the JSON property neighborCount

Returns:

  • (Fixnum)


5997
5998
5999
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5997

def neighbor_count
  @neighbor_count
end

#restrictionsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExamplesRestrictionsNamespace>

Restrict the resulting nearest neighbors to respect these constraints. Corresponds to the JSON property restrictions



6002
6003
6004
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6002

def restrictions
  @restrictions
end

#return_embeddingsBoolean Also known as: return_embeddings?

If true, return the embeddings instead of neighbors. Corresponds to the JSON property returnEmbeddings

Returns:

  • (Boolean)


6007
6008
6009
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6007

def return_embeddings
  @return_embeddings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6015
6016
6017
6018
6019
6020
6021
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6015

def update!(**args)
  @crowding_count = args[:crowding_count] if args.key?(:crowding_count)
  @data_format = args[:data_format] if args.key?(:data_format)
  @neighbor_count = args[:neighbor_count] if args.key?(:neighbor_count)
  @restrictions = args[:restrictions] if args.key?(:restrictions)
  @return_embeddings = args[:return_embeddings] if args.key?(:return_embeddings)
end