Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExecutableCode

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Code generated by the model that is meant to be executed, and the result returned to the model. Generated when using the CodeExecution tool, in which the code will be automatically executed, and a corresponding CodeExecutionResult will also be generated.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ExecutableCode

Returns a new instance of GoogleCloudAiplatformV1ExecutableCode.



12934
12935
12936
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12934

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

Required. The code to be executed. Corresponds to the JSON property code

Returns:

  • (String)


12921
12922
12923
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12921

def code
  @code
end

#idString

Optional. Unique identifier of the ExecutableCode part. The server returns the CodeExecutionResult with the matching id. Corresponds to the JSON property id

Returns:

  • (String)


12927
12928
12929
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12927

def id
  @id
end

#languageString

Required. Programming language of the code. Corresponds to the JSON property language

Returns:

  • (String)


12932
12933
12934
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12932

def language
  @language
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12939
12940
12941
12942
12943
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12939

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @id = args[:id] if args.key?(:id)
  @language = args[:language] if args.key?(:language)
end