Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExecutableCode
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExecutableCode
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Code generated by the model that is meant to be executed, and the result
returned to the model. Generated when using the CodeExecution tool, in which
the code will be automatically executed, and a corresponding
CodeExecutionResult will also be generated.
Instance Attribute Summary collapse
-
#code ⇒ String
Required.
-
#id ⇒ String
Optional.
-
#language ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExecutableCode
constructor
A new instance of GoogleCloudAiplatformV1ExecutableCode.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExecutableCode
Returns a new instance of GoogleCloudAiplatformV1ExecutableCode.
12557 12558 12559 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12557 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
Required. The code to be executed.
Corresponds to the JSON property code
12544 12545 12546 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12544 def code @code end |
#id ⇒ String
Optional. Unique identifier of the ExecutableCode part. The server returns
the CodeExecutionResult with the matching id.
Corresponds to the JSON property id
12550 12551 12552 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12550 def id @id end |
#language ⇒ String
Required. Programming language of the code.
Corresponds to the JSON property language
12555 12556 12557 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12555 def language @language end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12562 12563 12564 12565 12566 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12562 def update!(**args) @code = args[:code] if args.key?(:code) @id = args[:id] if args.key?(:id) @language = args[:language] if args.key?(:language) end |