Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExecutableCode
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExecutableCode
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Code generated by the model that is meant to be executed, and the result
returned to the model. Generated when using the CodeExecution tool, in which
the code will be automatically executed, and a corresponding
CodeExecutionResult will also be generated.
Instance Attribute Summary collapse
-
#code ⇒ String
Required.
-
#language ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExecutableCode
constructor
A new instance of GoogleCloudAiplatformV1ExecutableCode.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExecutableCode
Returns a new instance of GoogleCloudAiplatformV1ExecutableCode.
11630 11631 11632 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11630 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
Required. The code to be executed.
Corresponds to the JSON property code
11623 11624 11625 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11623 def code @code end |
#language ⇒ String
Required. Programming language of the code.
Corresponds to the JSON property language
11628 11629 11630 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11628 def language @language end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11635 11636 11637 11638 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11635 def update!(**args) @code = args[:code] if args.key?(:code) @language = args[:language] if args.key?(:language) end |