Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExecutableCode

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Code generated by the model that is meant to be executed, and the result returned to the model. Generated when using the [CodeExecution] tool, in which the code will be automatically executed, and a corresponding [ CodeExecutionResult] will also be generated.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ExecutableCode

Returns a new instance of GoogleCloudAiplatformV1ExecutableCode.



10506
10507
10508
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10506

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

Required. The code to be executed. Corresponds to the JSON property code

Returns:

  • (String)


10499
10500
10501
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10499

def code
  @code
end

#languageString

Required. Programming language of the code. Corresponds to the JSON property language

Returns:

  • (String)


10504
10505
10506
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10504

def language
  @language
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10511
10512
10513
10514
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10511

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @language = args[:language] if args.key?(:language)
end