Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExecutableCode
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExecutableCode
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Code generated by the model that is meant to be executed, and the result returned to the model. Generated when using the [FunctionDeclaration] tool and [FunctionCallingConfig] mode is set to [Mode.CODE].
Instance Attribute Summary collapse
-
#code ⇒ String
Required.
-
#language ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExecutableCode
constructor
A new instance of GoogleCloudAiplatformV1ExecutableCode.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExecutableCode
Returns a new instance of GoogleCloudAiplatformV1ExecutableCode.
7951 7952 7953 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7951 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
Required. The code to be executed.
Corresponds to the JSON property code
7944 7945 7946 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7944 def code @code end |
#language ⇒ String
Required. Programming language of the code.
Corresponds to the JSON property language
7949 7950 7951 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7949 def language @language end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7956 7957 7958 7959 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7956 def update!(**args) @code = args[:code] if args.key?(:code) @language = args[:language] if args.key?(:language) end |