Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExecutableCode
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExecutableCode
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Code generated by the model that is meant to be executed, and the result returned to the model. Generated when using the [FunctionDeclaration] tool and [FunctionCallingConfig] mode is set to [Mode.CODE].
Instance Attribute Summary collapse
-
#code ⇒ String
Required.
-
#language ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExecutableCode
constructor
A new instance of GoogleCloudAiplatformV1ExecutableCode.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExecutableCode
Returns a new instance of GoogleCloudAiplatformV1ExecutableCode.
7912 7913 7914 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7912 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
Required. The code to be executed.
Corresponds to the JSON property code
7905 7906 7907 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7905 def code @code end |
#language ⇒ String
Required. Programming language of the code.
Corresponds to the JSON property language
7910 7911 7912 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7910 def language @language end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7917 7918 7919 7920 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7917 def update!(**args) @code = args[:code] if args.key?(:code) @language = args[:language] if args.key?(:language) end |