Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Execution
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Execution
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Instance of a general execution.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Description of the Execution Corresponds to the JSON property
description. -
#display_name ⇒ String
User provided display name of the Execution.
-
#etag ⇒ String
An eTag used to perform consistent read-modify-write updates.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your Executions.
-
#metadata ⇒ Hash<String,Object>
Properties of the Execution.
-
#name ⇒ String
Output only.
-
#schema_title ⇒ String
The title of the schema describing the metadata.
-
#schema_version ⇒ String
The version of the schema in
schema_titleto use. -
#state ⇒ String
The state of this Execution.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Execution
constructor
A new instance of GoogleCloudAiplatformV1Execution.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Execution
Returns a new instance of GoogleCloudAiplatformV1Execution.
12110 12111 12112 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12110 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this Execution was created.
Corresponds to the JSON property createTime
12042 12043 12044 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12042 def create_time @create_time end |
#description ⇒ String
Description of the Execution
Corresponds to the JSON property description
12047 12048 12049 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12047 def description @description end |
#display_name ⇒ String
User provided display name of the Execution. May be up to 128 Unicode
characters.
Corresponds to the JSON property displayName
12053 12054 12055 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12053 def display_name @display_name end |
#etag ⇒ String
An eTag used to perform consistent read-modify-write updates. If not set, a
blind "overwrite" update happens.
Corresponds to the JSON property etag
12059 12060 12061 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12059 def etag @etag end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your Executions. Label keys
and values can be no longer than 64 characters (Unicode codepoints), can only
contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. No more than 64 user labels can be
associated with one Execution (System labels are excluded).
Corresponds to the JSON property labels
12068 12069 12070 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12068 def labels @labels end |
#metadata ⇒ Hash<String,Object>
Properties of the Execution. Top level metadata keys' heading and trailing
spaces will be trimmed. The size of this field should not exceed 200KB.
Corresponds to the JSON property metadata
12074 12075 12076 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12074 def @metadata end |
#name ⇒ String
Output only. The resource name of the Execution.
Corresponds to the JSON property name
12079 12080 12081 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12079 def name @name end |
#schema_title ⇒ String
The title of the schema describing the metadata. Schema title and version is
expected to be registered in earlier Create Schema calls. And both are used
together as unique identifiers to identify schemas within the local metadata
store.
Corresponds to the JSON property schemaTitle
12087 12088 12089 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12087 def schema_title @schema_title end |
#schema_version ⇒ String
The version of the schema in schema_title to use. Schema title and version
is expected to be registered in earlier Create Schema calls. And both are used
together as unique identifiers to identify schemas within the local metadata
store.
Corresponds to the JSON property schemaVersion
12095 12096 12097 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12095 def schema_version @schema_version end |
#state ⇒ String
The state of this Execution. This is a property of the Execution, and does not
imply or capture any ongoing process. This property is managed by clients (
such as Vertex AI Pipelines) and the system does not prescribe or check the
validity of state transitions.
Corresponds to the JSON property state
12103 12104 12105 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12103 def state @state end |
#update_time ⇒ String
Output only. Timestamp when this Execution was last updated.
Corresponds to the JSON property updateTime
12108 12109 12110 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12108 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12115 12116 12117 12118 12119 12120 12121 12122 12123 12124 12125 12126 12127 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12115 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @metadata = args[:metadata] if args.key?(:metadata) @name = args[:name] if args.key?(:name) @schema_title = args[:schema_title] if args.key?(:schema_title) @schema_version = args[:schema_version] if args.key?(:schema_version) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |