Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Execution

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Instance of a general execution.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Execution

Returns a new instance of GoogleCloudAiplatformV1Execution.



6912
6913
6914
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6912

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this Execution was created. Corresponds to the JSON property createTime

Returns:

  • (String)


6844
6845
6846
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6844

def create_time
  @create_time
end

#descriptionString

Description of the Execution Corresponds to the JSON property description

Returns:

  • (String)


6849
6850
6851
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6849

def description
  @description
end

#display_nameString

User provided display name of the Execution. May be up to 128 Unicode characters. Corresponds to the JSON property displayName

Returns:

  • (String)


6855
6856
6857
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6855

def display_name
  @display_name
end

#etagString

An eTag used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


6861
6862
6863
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6861

def etag
  @etag
end

#labelsHash<String,String>

The labels with user-defined metadata to organize your Executions. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. No more than 64 user labels can be associated with one Execution (System labels are excluded). Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


6870
6871
6872
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6870

def labels
  @labels
end

#metadataHash<String,Object>

Properties of the Execution. Top level metadata keys' heading and trailing spaces will be trimmed. The size of this field should not exceed 200KB. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,Object>)


6876
6877
6878
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6876

def 
  @metadata
end

#nameString

Output only. The resource name of the Execution. Corresponds to the JSON property name

Returns:

  • (String)


6881
6882
6883
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6881

def name
  @name
end

#schema_titleString

The title of the schema describing the metadata. Schema title and version is expected to be registered in earlier Create Schema calls. And both are used together as unique identifiers to identify schemas within the local metadata store. Corresponds to the JSON property schemaTitle

Returns:

  • (String)


6889
6890
6891
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6889

def schema_title
  @schema_title
end

#schema_versionString

The version of the schema in schema_title to use. Schema title and version is expected to be registered in earlier Create Schema calls. And both are used together as unique identifiers to identify schemas within the local metadata store. Corresponds to the JSON property schemaVersion

Returns:

  • (String)


6897
6898
6899
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6897

def schema_version
  @schema_version
end

#stateString

The state of this Execution. This is a property of the Execution, and does not imply or capture any ongoing process. This property is managed by clients ( such as Vertex AI Pipelines) and the system does not prescribe or check the validity of state transitions. Corresponds to the JSON property state

Returns:

  • (String)


6905
6906
6907
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6905

def state
  @state
end

#update_timeString

Output only. Timestamp when this Execution was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


6910
6911
6912
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6910

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6917
6918
6919
6920
6921
6922
6923
6924
6925
6926
6927
6928
6929
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6917

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @schema_title = args[:schema_title] if args.key?(:schema_title)
  @schema_version = args[:schema_version] if args.key?(:schema_version)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end