Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Execution
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Execution
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Instance of a general execution.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Description of the Execution Corresponds to the JSON property
description. -
#display_name ⇒ String
User provided display name of the Execution.
-
#etag ⇒ String
An eTag used to perform consistent read-modify-write updates.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your Executions.
-
#metadata ⇒ Hash<String,Object>
Properties of the Execution.
-
#name ⇒ String
Output only.
-
#schema_title ⇒ String
The title of the schema describing the metadata.
-
#schema_version ⇒ String
The version of the schema in
schema_titleto use. -
#state ⇒ String
The state of this Execution.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Execution
constructor
A new instance of GoogleCloudAiplatformV1Execution.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Execution
Returns a new instance of GoogleCloudAiplatformV1Execution.
5835 5836 5837 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5835 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this Execution was created.
Corresponds to the JSON property createTime
5767 5768 5769 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5767 def create_time @create_time end |
#description ⇒ String
Description of the Execution
Corresponds to the JSON property description
5772 5773 5774 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5772 def description @description end |
#display_name ⇒ String
User provided display name of the Execution. May be up to 128 Unicode
characters.
Corresponds to the JSON property displayName
5778 5779 5780 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5778 def display_name @display_name end |
#etag ⇒ String
An eTag used to perform consistent read-modify-write updates. If not set, a
blind "overwrite" update happens.
Corresponds to the JSON property etag
5784 5785 5786 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5784 def etag @etag end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your Executions. Label keys
and values can be no longer than 64 characters (Unicode codepoints), can only
contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. No more than 64 user labels can be
associated with one Execution (System labels are excluded).
Corresponds to the JSON property labels
5793 5794 5795 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5793 def labels @labels end |
#metadata ⇒ Hash<String,Object>
Properties of the Execution. Top level metadata keys' heading and trailing
spaces will be trimmed. The size of this field should not exceed 200KB.
Corresponds to the JSON property metadata
5799 5800 5801 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5799 def @metadata end |
#name ⇒ String
Output only. The resource name of the Execution.
Corresponds to the JSON property name
5804 5805 5806 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5804 def name @name end |
#schema_title ⇒ String
The title of the schema describing the metadata. Schema title and version is
expected to be registered in earlier Create Schema calls. And both are used
together as unique identifiers to identify schemas within the local metadata
store.
Corresponds to the JSON property schemaTitle
5812 5813 5814 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5812 def schema_title @schema_title end |
#schema_version ⇒ String
The version of the schema in schema_title to use. Schema title and version
is expected to be registered in earlier Create Schema calls. And both are used
together as unique identifiers to identify schemas within the local metadata
store.
Corresponds to the JSON property schemaVersion
5820 5821 5822 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5820 def schema_version @schema_version end |
#state ⇒ String
The state of this Execution. This is a property of the Execution, and does not
imply or capture any ongoing process. This property is managed by clients (
such as Vertex AI Pipelines) and the system does not prescribe or check the
validity of state transitions.
Corresponds to the JSON property state
5828 5829 5830 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5828 def state @state end |
#update_time ⇒ String
Output only. Timestamp when this Execution was last updated.
Corresponds to the JSON property updateTime
5833 5834 5835 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5833 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5840 5841 5842 5843 5844 5845 5846 5847 5848 5849 5850 5851 5852 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 5840 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @metadata = args[:metadata] if args.key?(:metadata) @name = args[:name] if args.key?(:name) @schema_title = args[:schema_title] if args.key?(:schema_title) @schema_version = args[:schema_version] if args.key?(:schema_version) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |