Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Execution
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Execution
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Instance of a general execution.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Description of the Execution Corresponds to the JSON property
description. -
#display_name ⇒ String
User provided display name of the Execution.
-
#etag ⇒ String
An eTag used to perform consistent read-modify-write updates.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your Executions.
-
#metadata ⇒ Hash<String,Object>
Properties of the Execution.
-
#name ⇒ String
Output only.
-
#schema_title ⇒ String
The title of the schema describing the metadata.
-
#schema_version ⇒ String
The version of the schema in
schema_titleto use. -
#state ⇒ String
The state of this Execution.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Execution
constructor
A new instance of GoogleCloudAiplatformV1Execution.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Execution
Returns a new instance of GoogleCloudAiplatformV1Execution.
6476 6477 6478 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6476 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this Execution was created.
Corresponds to the JSON property createTime
6408 6409 6410 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6408 def create_time @create_time end |
#description ⇒ String
Description of the Execution
Corresponds to the JSON property description
6413 6414 6415 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6413 def description @description end |
#display_name ⇒ String
User provided display name of the Execution. May be up to 128 Unicode
characters.
Corresponds to the JSON property displayName
6419 6420 6421 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6419 def display_name @display_name end |
#etag ⇒ String
An eTag used to perform consistent read-modify-write updates. If not set, a
blind "overwrite" update happens.
Corresponds to the JSON property etag
6425 6426 6427 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6425 def etag @etag end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your Executions. Label keys
and values can be no longer than 64 characters (Unicode codepoints), can only
contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. No more than 64 user labels can be
associated with one Execution (System labels are excluded).
Corresponds to the JSON property labels
6434 6435 6436 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6434 def labels @labels end |
#metadata ⇒ Hash<String,Object>
Properties of the Execution. Top level metadata keys' heading and trailing
spaces will be trimmed. The size of this field should not exceed 200KB.
Corresponds to the JSON property metadata
6440 6441 6442 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6440 def @metadata end |
#name ⇒ String
Output only. The resource name of the Execution.
Corresponds to the JSON property name
6445 6446 6447 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6445 def name @name end |
#schema_title ⇒ String
The title of the schema describing the metadata. Schema title and version is
expected to be registered in earlier Create Schema calls. And both are used
together as unique identifiers to identify schemas within the local metadata
store.
Corresponds to the JSON property schemaTitle
6453 6454 6455 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6453 def schema_title @schema_title end |
#schema_version ⇒ String
The version of the schema in schema_title to use. Schema title and version
is expected to be registered in earlier Create Schema calls. And both are used
together as unique identifiers to identify schemas within the local metadata
store.
Corresponds to the JSON property schemaVersion
6461 6462 6463 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6461 def schema_version @schema_version end |
#state ⇒ String
The state of this Execution. This is a property of the Execution, and does not
imply or capture any ongoing process. This property is managed by clients (
such as Vertex AI Pipelines) and the system does not prescribe or check the
validity of state transitions.
Corresponds to the JSON property state
6469 6470 6471 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6469 def state @state end |
#update_time ⇒ String
Output only. Timestamp when this Execution was last updated.
Corresponds to the JSON property updateTime
6474 6475 6476 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6474 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6481 6482 6483 6484 6485 6486 6487 6488 6489 6490 6491 6492 6493 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6481 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @metadata = args[:metadata] if args.key?(:metadata) @name = args[:name] if args.key?(:name) @schema_title = args[:schema_title] if args.key?(:schema_title) @schema_version = args[:schema_version] if args.key?(:schema_version) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |