Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplainRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for PredictionService.Explain.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ExplainRequest

Returns a new instance of GoogleCloudAiplatformV1ExplainRequest.



11732
11733
11734
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11732

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deployed_model_idString

If specified, this ExplainRequest will be served by the chosen DeployedModel, overriding Endpoint.traffic_split. Corresponds to the JSON property deployedModelId

Returns:

  • (String)


11708
11709
11710
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11708

def deployed_model_id
  @deployed_model_id
end

#explanation_spec_overrideGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationSpecOverride

The ExplanationSpec entries that can be overridden at online explanation time. Corresponds to the JSON property explanationSpecOverride



11713
11714
11715
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11713

def explanation_spec_override
  @explanation_spec_override
end

#instancesArray<Object>

Required. The instances that are the input to the explanation call. A DeployedModel may have an upper limit on the number of instances it supports per request, and when it is exceeded the explanation call errors in case of AutoML Models, or, in case of customer created Models, the behaviour is as documented by that Model. The schema of any single instance may be specified via Endpoint's DeployedModels' Model's PredictSchemata's instance_schema_uri. Corresponds to the JSON property instances

Returns:

  • (Array<Object>)


11723
11724
11725
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11723

def instances
  @instances
end

#parametersObject

The parameters that govern the prediction. The schema of the parameters may be specified via Endpoint's DeployedModels' Model's PredictSchemata's parameters_schema_uri. Corresponds to the JSON property parameters

Returns:

  • (Object)


11730
11731
11732
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11730

def parameters
  @parameters
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11737
11738
11739
11740
11741
11742
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11737

def update!(**args)
  @deployed_model_id = args[:deployed_model_id] if args.key?(:deployed_model_id)
  @explanation_spec_override = args[:explanation_spec_override] if args.key?(:explanation_spec_override)
  @instances = args[:instances] if args.key?(:instances)
  @parameters = args[:parameters] if args.key?(:parameters)
end