Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplainRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplainRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Request message for PredictionService.Explain.
Instance Attribute Summary collapse
-
#deployed_model_id ⇒ String
If specified, this ExplainRequest will be served by the chosen DeployedModel, overriding Endpoint.traffic_split.
-
#explanation_spec_override ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationSpecOverride
The ExplanationSpec entries that can be overridden at online explanation time.
-
#instances ⇒ Array<Object>
Required.
-
#parameters ⇒ Object
The parameters that govern the prediction.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExplainRequest
constructor
A new instance of GoogleCloudAiplatformV1ExplainRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExplainRequest
Returns a new instance of GoogleCloudAiplatformV1ExplainRequest.
8637 8638 8639 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8637 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deployed_model_id ⇒ String
If specified, this ExplainRequest will be served by the chosen DeployedModel,
overriding Endpoint.traffic_split.
Corresponds to the JSON property deployedModelId
8613 8614 8615 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8613 def deployed_model_id @deployed_model_id end |
#explanation_spec_override ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationSpecOverride
The ExplanationSpec entries that can be overridden at online explanation time.
Corresponds to the JSON property explanationSpecOverride
8618 8619 8620 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8618 def explanation_spec_override @explanation_spec_override end |
#instances ⇒ Array<Object>
Required. The instances that are the input to the explanation call. A
DeployedModel may have an upper limit on the number of instances it supports
per request, and when it is exceeded the explanation call errors in case of
AutoML Models, or, in case of customer created Models, the behaviour is as
documented by that Model. The schema of any single instance may be specified
via Endpoint's DeployedModels' Model's PredictSchemata's instance_schema_uri.
Corresponds to the JSON property instances
8628 8629 8630 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8628 def instances @instances end |
#parameters ⇒ Object
The parameters that govern the prediction. The schema of the parameters may be
specified via Endpoint's DeployedModels' Model's PredictSchemata's
parameters_schema_uri.
Corresponds to the JSON property parameters
8635 8636 8637 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8635 def parameters @parameters end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8642 8643 8644 8645 8646 8647 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8642 def update!(**args) @deployed_model_id = args[:deployed_model_id] if args.key?(:deployed_model_id) @explanation_spec_override = args[:explanation_spec_override] if args.key?(:explanation_spec_override) @instances = args[:instances] if args.key?(:instances) @parameters = args[:parameters] if args.key?(:parameters) end |