Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplainRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplainRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Request message for PredictionService.Explain.
Instance Attribute Summary collapse
-
#deployed_model_id ⇒ String
If specified, this ExplainRequest will be served by the chosen DeployedModel, overriding Endpoint.traffic_split.
-
#explanation_spec_override ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationSpecOverride
The ExplanationSpec entries that can be overridden at online explanation time.
-
#instances ⇒ Array<Object>
Required.
-
#parameters ⇒ Object
The parameters that govern the prediction.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExplainRequest
constructor
A new instance of GoogleCloudAiplatformV1ExplainRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExplainRequest
Returns a new instance of GoogleCloudAiplatformV1ExplainRequest.
8089 8090 8091 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8089 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deployed_model_id ⇒ String
If specified, this ExplainRequest will be served by the chosen DeployedModel,
overriding Endpoint.traffic_split.
Corresponds to the JSON property deployedModelId
8065 8066 8067 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8065 def deployed_model_id @deployed_model_id end |
#explanation_spec_override ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationSpecOverride
The ExplanationSpec entries that can be overridden at online explanation time.
Corresponds to the JSON property explanationSpecOverride
8070 8071 8072 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8070 def explanation_spec_override @explanation_spec_override end |
#instances ⇒ Array<Object>
Required. The instances that are the input to the explanation call. A
DeployedModel may have an upper limit on the number of instances it supports
per request, and when it is exceeded the explanation call errors in case of
AutoML Models, or, in case of customer created Models, the behaviour is as
documented by that Model. The schema of any single instance may be specified
via Endpoint's DeployedModels' Model's PredictSchemata's instance_schema_uri.
Corresponds to the JSON property instances
8080 8081 8082 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8080 def instances @instances end |
#parameters ⇒ Object
The parameters that govern the prediction. The schema of the parameters may be
specified via Endpoint's DeployedModels' Model's PredictSchemata's
parameters_schema_uri.
Corresponds to the JSON property parameters
8087 8088 8089 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8087 def parameters @parameters end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8094 8095 8096 8097 8098 8099 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8094 def update!(**args) @deployed_model_id = args[:deployed_model_id] if args.key?(:deployed_model_id) @explanation_spec_override = args[:explanation_spec_override] if args.key?(:explanation_spec_override) @instances = args[:instances] if args.key?(:instances) @parameters = args[:parameters] if args.key?(:parameters) end |