Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplainRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for PredictionService.Explain.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ExplainRequest

Returns a new instance of GoogleCloudAiplatformV1ExplainRequest.



6817
6818
6819
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6817

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deployed_model_idString

If specified, this ExplainRequest will be served by the chosen DeployedModel, overriding Endpoint.traffic_split. Corresponds to the JSON property deployedModelId

Returns:

  • (String)


6793
6794
6795
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6793

def deployed_model_id
  @deployed_model_id
end

#explanation_spec_overrideGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationSpecOverride

The ExplanationSpec entries that can be overridden at online explanation time. Corresponds to the JSON property explanationSpecOverride



6798
6799
6800
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6798

def explanation_spec_override
  @explanation_spec_override
end

#instancesArray<Object>

Required. The instances that are the input to the explanation call. A DeployedModel may have an upper limit on the number of instances it supports per request, and when it is exceeded the explanation call errors in case of AutoML Models, or, in case of customer created Models, the behaviour is as documented by that Model. The schema of any single instance may be specified via Endpoint's DeployedModels' Model's PredictSchemata's instance_schema_uri. Corresponds to the JSON property instances

Returns:

  • (Array<Object>)


6808
6809
6810
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6808

def instances
  @instances
end

#parametersObject

The parameters that govern the prediction. The schema of the parameters may be specified via Endpoint's DeployedModels' Model's PredictSchemata's parameters_schema_uri. Corresponds to the JSON property parameters

Returns:

  • (Object)


6815
6816
6817
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6815

def parameters
  @parameters
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6822
6823
6824
6825
6826
6827
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6822

def update!(**args)
  @deployed_model_id = args[:deployed_model_id] if args.key?(:deployed_model_id)
  @explanation_spec_override = args[:explanation_spec_override] if args.key?(:explanation_spec_override)
  @instances = args[:instances] if args.key?(:instances)
  @parameters = args[:parameters] if args.key?(:parameters)
end