Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplainResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Response message for PredictionService.Explain.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ExplainResponse

Returns a new instance of GoogleCloudAiplatformV1ExplainResponse.



8735
8736
8737
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8735

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deployed_model_idString

ID of the Endpoint's DeployedModel that served this explanation. Corresponds to the JSON property deployedModelId

Returns:

  • (String)


8721
8722
8723
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8721

def deployed_model_id
  @deployed_model_id
end

#explanationsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Explanation>

The explanations of the Model's PredictResponse.predictions. It has the same number of elements as instances to be explained. Corresponds to the JSON property explanations



8727
8728
8729
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8727

def explanations
  @explanations
end

#predictionsArray<Object>

The predictions that are the output of the predictions call. Same as PredictResponse.predictions. Corresponds to the JSON property predictions

Returns:

  • (Array<Object>)


8733
8734
8735
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8733

def predictions
  @predictions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8740
8741
8742
8743
8744
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8740

def update!(**args)
  @deployed_model_id = args[:deployed_model_id] if args.key?(:deployed_model_id)
  @explanations = args[:explanations] if args.key?(:explanations)
  @predictions = args[:predictions] if args.key?(:predictions)
end