Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Explanation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Explanation of a prediction (provided in PredictResponse.predictions) produced by the Model on a given instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Explanation

Returns a new instance of GoogleCloudAiplatformV1Explanation.



6254
6255
6256
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6254

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attributionsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Attribution>

Output only. Feature attributions grouped by predicted outputs. For Models that predict only one output, such as regression Models that predict only one score, there is only one attibution that explains the predicted output. For Models that predict multiple outputs, such as multiclass Models that predict multiple classes, each element explains one specific item. Attribution. output_index can be used to identify which output this attribution is explaining. If users set ExplanationParameters.top_k, the attributions are sorted by instance_output_value in descending order. If ExplanationParameters. output_indices is specified, the attributions are stored by Attribution. output_index in the same order as they appear in the output_indices. Corresponds to the JSON property attributions



6245
6246
6247
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6245

def attributions
  @attributions
end

#neighborsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Neighbor>

Output only. List of the nearest neighbors for example-based explanations. For models deployed with the examples explanations feature enabled, the attributions field is empty and instead the neighbors field is populated. Corresponds to the JSON property neighbors



6252
6253
6254
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6252

def neighbors
  @neighbors
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6259
6260
6261
6262
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6259

def update!(**args)
  @attributions = args[:attributions] if args.key?(:attributions)
  @neighbors = args[:neighbors] if args.key?(:neighbors)
end