Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Metadata describing the Model's input and output for explanation.
Instance Attribute Summary collapse
-
#feature_attributions_schema_uri ⇒ String
Points to a YAML file stored on Google Cloud Storage describing the format of the feature attributions.
-
#inputs ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationMetadataInputMetadata>
Required.
-
#latent_space_source ⇒ String
Name of the source to generate embeddings for example based explanations.
-
#outputs ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationMetadataOutputMetadata>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExplanationMetadata
constructor
A new instance of GoogleCloudAiplatformV1ExplanationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExplanationMetadata
Returns a new instance of GoogleCloudAiplatformV1ExplanationMetadata.
12902 12903 12904 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12902 def initialize(**args) update!(**args) end |
Instance Attribute Details
#feature_attributions_schema_uri ⇒ String
Points to a YAML file stored on Google Cloud Storage describing the format of
the feature attributions. The schema is defined as an OpenAPI 3.0.2 Schema
Object. AutoML tabular Models always have this field populated by
Vertex AI. Note: The URI given on output may be different, including the URI
scheme, than the one given on input. The output URI will point to a location
where the user only has a read access.
Corresponds to the JSON property featureAttributionsSchemaUri
12875 12876 12877 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12875 def feature_attributions_schema_uri @feature_attributions_schema_uri end |
#inputs ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationMetadataInputMetadata>
Required. Map from feature names to feature input metadata. Keys are the name
of the features. Values are the specification of the feature. An empty
InputMetadata is valid. It describes a text feature which has the name
specified as the key in ExplanationMetadata.inputs. The baseline of the empty
feature is chosen by Vertex AI. For Vertex AI-provided Tensorflow images, the
key can be any friendly name of the feature. Once specified,
featureAttributions are keyed by this key (if not grouped with another feature)
. For custom images, the key must match with the key in instance.
Corresponds to the JSON property inputs
12887 12888 12889 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12887 def inputs @inputs end |
#latent_space_source ⇒ String
Name of the source to generate embeddings for example based explanations.
Corresponds to the JSON property latentSpaceSource
12892 12893 12894 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12892 def latent_space_source @latent_space_source end |
#outputs ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationMetadataOutputMetadata>
Required. Map from output names to output metadata. For Vertex AI-provided
Tensorflow images, keys can be any user defined string that consists of any
UTF-8 characters. For custom images, keys are the name of the output field in
the prediction to be explained. Currently only one key is allowed.
Corresponds to the JSON property outputs
12900 12901 12902 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12900 def outputs @outputs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12907 12908 12909 12910 12911 12912 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12907 def update!(**args) @feature_attributions_schema_uri = args[:feature_attributions_schema_uri] if args.key?(:feature_attributions_schema_uri) @inputs = args[:inputs] if args.key?(:inputs) @latent_space_source = args[:latent_space_source] if args.key?(:latent_space_source) @outputs = args[:outputs] if args.key?(:outputs) end |