Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationMetadataInputMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationMetadataInputMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Metadata of the input of a feature. Fields other than InputMetadata. input_baselines are applicable only for Models that are using Vertex AI- provided images for Tensorflow.
Instance Attribute Summary collapse
-
#dense_shape_tensor_name ⇒ String
Specifies the shape of the values of the input if the input is a sparse representation.
-
#encoded_baselines ⇒ Array<Object>
A list of baselines for the encoded tensor.
-
#encoded_tensor_name ⇒ String
Encoded tensor is a transformation of the input tensor.
-
#encoding ⇒ String
Defines how the feature is encoded into the input tensor.
-
#feature_value_domain ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationMetadataInputMetadataFeatureValueDomain
Domain details of the input feature value.
-
#group_name ⇒ String
Name of the group that the input belongs to.
-
#index_feature_mapping ⇒ Array<String>
A list of feature names for each index in the input tensor.
-
#indices_tensor_name ⇒ String
Specifies the index of the values of the input tensor.
-
#input_baselines ⇒ Array<Object>
Baseline inputs for this feature.
-
#input_tensor_name ⇒ String
Name of the input tensor for this feature.
-
#modality ⇒ String
Modality of the feature.
-
#visualization ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationMetadataInputMetadataVisualization
Visualization configurations for image explanation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExplanationMetadataInputMetadata
constructor
A new instance of GoogleCloudAiplatformV1ExplanationMetadataInputMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExplanationMetadataInputMetadata
Returns a new instance of GoogleCloudAiplatformV1ExplanationMetadataInputMetadata.
12403 12404 12405 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12403 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dense_shape_tensor_name ⇒ String
Specifies the shape of the values of the input if the input is a sparse
representation. Refer to Tensorflow documentation for more details: https://
www.tensorflow.org/api_docs/python/tf/sparse/SparseTensor.
Corresponds to the JSON property denseShapeTensorName
12316 12317 12318 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12316 def dense_shape_tensor_name @dense_shape_tensor_name end |
#encoded_baselines ⇒ Array<Object>
A list of baselines for the encoded tensor. The shape of each baseline should
match the shape of the encoded tensor. If a scalar is provided, Vertex AI
broadcasts to the same shape as the encoded tensor.
Corresponds to the JSON property encodedBaselines
12323 12324 12325 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12323 def encoded_baselines @encoded_baselines end |
#encoded_tensor_name ⇒ String
Encoded tensor is a transformation of the input tensor. Must be provided if
choosing Integrated Gradients attribution or XRAI attribution and the input
tensor is not differentiable. An encoded tensor is generated if the input
tensor is encoded by a lookup table.
Corresponds to the JSON property encodedTensorName
12331 12332 12333 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12331 def encoded_tensor_name @encoded_tensor_name end |
#encoding ⇒ String
Defines how the feature is encoded into the input tensor. Defaults to IDENTITY.
Corresponds to the JSON property encoding
12336 12337 12338 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12336 def encoding @encoding end |
#feature_value_domain ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationMetadataInputMetadataFeatureValueDomain
Domain details of the input feature value. Provides numeric information about
the feature, such as its range (min, max). If the feature has been pre-
processed, for example with z-scoring, then it provides information about how
to recover the original feature. For example, if the input feature is an image
and it has been pre-processed to obtain 0-mean and stddev = 1 values, then
original_mean, and original_stddev refer to the mean and stddev of the
original feature (e.g. image tensor) from which input feature (with mean = 0
and stddev = 1) was obtained.
Corresponds to the JSON property featureValueDomain
12348 12349 12350 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12348 def feature_value_domain @feature_value_domain end |
#group_name ⇒ String
Name of the group that the input belongs to. Features with the same group name
will be treated as one feature when computing attributions. Features grouped
together can have different shapes in value. If provided, there will be one
single attribution generated in Attribution.feature_attributions, keyed by the
group name.
Corresponds to the JSON property groupName
12357 12358 12359 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12357 def group_name @group_name end |
#index_feature_mapping ⇒ Array<String>
A list of feature names for each index in the input tensor. Required when the
input InputMetadata.encoding is BAG_OF_FEATURES, BAG_OF_FEATURES_SPARSE,
INDICATOR.
Corresponds to the JSON property indexFeatureMapping
12364 12365 12366 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12364 def index_feature_mapping @index_feature_mapping end |
#indices_tensor_name ⇒ String
Specifies the index of the values of the input tensor. Required when the input
tensor is a sparse representation. Refer to Tensorflow documentation for more
details: https://www.tensorflow.org/api_docs/python/tf/sparse/SparseTensor.
Corresponds to the JSON property indicesTensorName
12371 12372 12373 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12371 def indices_tensor_name @indices_tensor_name end |
#input_baselines ⇒ Array<Object>
Baseline inputs for this feature. If no baseline is specified, Vertex AI
chooses the baseline for this feature. If multiple baselines are specified,
Vertex AI returns the average attributions across them in Attribution.
feature_attributions. For Vertex AI-provided Tensorflow images (both 1.x and 2.
x), the shape of each baseline must match the shape of the input tensor. If a
scalar is provided, we broadcast to the same shape as the input tensor. For
custom images, the element of the baselines must be in the same format as the
feature's input in the instance[]. The schema of any single instance may be
specified via Endpoint's DeployedModels' Model's PredictSchemata's
instance_schema_uri.
Corresponds to the JSON property inputBaselines
12385 12386 12387 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12385 def input_baselines @input_baselines end |
#input_tensor_name ⇒ String
Name of the input tensor for this feature. Required and is only applicable to
Vertex AI-provided images for Tensorflow.
Corresponds to the JSON property inputTensorName
12391 12392 12393 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12391 def input_tensor_name @input_tensor_name end |
#modality ⇒ String
Modality of the feature. Valid values are: numeric, image. Defaults to numeric.
Corresponds to the JSON property modality
12396 12397 12398 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12396 def modality @modality end |
#visualization ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationMetadataInputMetadataVisualization
Visualization configurations for image explanation.
Corresponds to the JSON property visualization
12401 12402 12403 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12401 def visualization @visualization end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12408 12409 12410 12411 12412 12413 12414 12415 12416 12417 12418 12419 12420 12421 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12408 def update!(**args) @dense_shape_tensor_name = args[:dense_shape_tensor_name] if args.key?(:dense_shape_tensor_name) @encoded_baselines = args[:encoded_baselines] if args.key?(:encoded_baselines) @encoded_tensor_name = args[:encoded_tensor_name] if args.key?(:encoded_tensor_name) @encoding = args[:encoding] if args.key?(:encoding) @feature_value_domain = args[:feature_value_domain] if args.key?(:feature_value_domain) @group_name = args[:group_name] if args.key?(:group_name) @index_feature_mapping = args[:index_feature_mapping] if args.key?(:index_feature_mapping) @indices_tensor_name = args[:indices_tensor_name] if args.key?(:indices_tensor_name) @input_baselines = args[:input_baselines] if args.key?(:input_baselines) @input_tensor_name = args[:input_tensor_name] if args.key?(:input_tensor_name) @modality = args[:modality] if args.key?(:modality) @visualization = args[:visualization] if args.key?(:visualization) end |