Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationMetadataInputMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Metadata of the input of a feature. Fields other than InputMetadata. input_baselines are applicable only for Models that are using Vertex AI- provided images for Tensorflow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ExplanationMetadataInputMetadata

Returns a new instance of GoogleCloudAiplatformV1ExplanationMetadataInputMetadata.



8878
8879
8880
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8878

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dense_shape_tensor_nameString

Specifies the shape of the values of the input if the input is a sparse representation. Refer to Tensorflow documentation for more details: https:// www.tensorflow.org/api_docs/python/tf/sparse/SparseTensor. Corresponds to the JSON property denseShapeTensorName

Returns:

  • (String)


8791
8792
8793
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8791

def dense_shape_tensor_name
  @dense_shape_tensor_name
end

#encoded_baselinesArray<Object>

A list of baselines for the encoded tensor. The shape of each baseline should match the shape of the encoded tensor. If a scalar is provided, Vertex AI broadcasts to the same shape as the encoded tensor. Corresponds to the JSON property encodedBaselines

Returns:

  • (Array<Object>)


8798
8799
8800
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8798

def encoded_baselines
  @encoded_baselines
end

#encoded_tensor_nameString

Encoded tensor is a transformation of the input tensor. Must be provided if choosing Integrated Gradients attribution or XRAI attribution and the input tensor is not differentiable. An encoded tensor is generated if the input tensor is encoded by a lookup table. Corresponds to the JSON property encodedTensorName

Returns:

  • (String)


8806
8807
8808
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8806

def encoded_tensor_name
  @encoded_tensor_name
end

#encodingString

Defines how the feature is encoded into the input tensor. Defaults to IDENTITY. Corresponds to the JSON property encoding

Returns:

  • (String)


8811
8812
8813
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8811

def encoding
  @encoding
end

#feature_value_domainGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationMetadataInputMetadataFeatureValueDomain

Domain details of the input feature value. Provides numeric information about the feature, such as its range (min, max). If the feature has been pre- processed, for example with z-scoring, then it provides information about how to recover the original feature. For example, if the input feature is an image and it has been pre-processed to obtain 0-mean and stddev = 1 values, then original_mean, and original_stddev refer to the mean and stddev of the original feature (e.g. image tensor) from which input feature (with mean = 0 and stddev = 1) was obtained. Corresponds to the JSON property featureValueDomain



8823
8824
8825
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8823

def feature_value_domain
  @feature_value_domain
end

#group_nameString

Name of the group that the input belongs to. Features with the same group name will be treated as one feature when computing attributions. Features grouped together can have different shapes in value. If provided, there will be one single attribution generated in Attribution.feature_attributions, keyed by the group name. Corresponds to the JSON property groupName

Returns:

  • (String)


8832
8833
8834
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8832

def group_name
  @group_name
end

#index_feature_mappingArray<String>

A list of feature names for each index in the input tensor. Required when the input InputMetadata.encoding is BAG_OF_FEATURES, BAG_OF_FEATURES_SPARSE, INDICATOR. Corresponds to the JSON property indexFeatureMapping

Returns:

  • (Array<String>)


8839
8840
8841
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8839

def index_feature_mapping
  @index_feature_mapping
end

#indices_tensor_nameString

Specifies the index of the values of the input tensor. Required when the input tensor is a sparse representation. Refer to Tensorflow documentation for more details: https://www.tensorflow.org/api_docs/python/tf/sparse/SparseTensor. Corresponds to the JSON property indicesTensorName

Returns:

  • (String)


8846
8847
8848
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8846

def indices_tensor_name
  @indices_tensor_name
end

#input_baselinesArray<Object>

Baseline inputs for this feature. If no baseline is specified, Vertex AI chooses the baseline for this feature. If multiple baselines are specified, Vertex AI returns the average attributions across them in Attribution. feature_attributions. For Vertex AI-provided Tensorflow images (both 1.x and 2. x), the shape of each baseline must match the shape of the input tensor. If a scalar is provided, we broadcast to the same shape as the input tensor. For custom images, the element of the baselines must be in the same format as the feature's input in the instance[]. The schema of any single instance may be specified via Endpoint's DeployedModels' Model's PredictSchemata's instance_schema_uri. Corresponds to the JSON property inputBaselines

Returns:

  • (Array<Object>)


8860
8861
8862
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8860

def input_baselines
  @input_baselines
end

#input_tensor_nameString

Name of the input tensor for this feature. Required and is only applicable to Vertex AI-provided images for Tensorflow. Corresponds to the JSON property inputTensorName

Returns:

  • (String)


8866
8867
8868
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8866

def input_tensor_name
  @input_tensor_name
end

#modalityString

Modality of the feature. Valid values are: numeric, image. Defaults to numeric. Corresponds to the JSON property modality

Returns:

  • (String)


8871
8872
8873
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8871

def modality
  @modality
end

#visualizationGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationMetadataInputMetadataVisualization

Visualization configurations for image explanation. Corresponds to the JSON property visualization



8876
8877
8878
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8876

def visualization
  @visualization
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8883
8884
8885
8886
8887
8888
8889
8890
8891
8892
8893
8894
8895
8896
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8883

def update!(**args)
  @dense_shape_tensor_name = args[:dense_shape_tensor_name] if args.key?(:dense_shape_tensor_name)
  @encoded_baselines = args[:encoded_baselines] if args.key?(:encoded_baselines)
  @encoded_tensor_name = args[:encoded_tensor_name] if args.key?(:encoded_tensor_name)
  @encoding = args[:encoding] if args.key?(:encoding)
  @feature_value_domain = args[:feature_value_domain] if args.key?(:feature_value_domain)
  @group_name = args[:group_name] if args.key?(:group_name)
  @index_feature_mapping = args[:index_feature_mapping] if args.key?(:index_feature_mapping)
  @indices_tensor_name = args[:indices_tensor_name] if args.key?(:indices_tensor_name)
  @input_baselines = args[:input_baselines] if args.key?(:input_baselines)
  @input_tensor_name = args[:input_tensor_name] if args.key?(:input_tensor_name)
  @modality = args[:modality] if args.key?(:modality)
  @visualization = args[:visualization] if args.key?(:visualization)
end