Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationMetadataInputMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationMetadataInputMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Metadata of the input of a feature. Fields other than InputMetadata. input_baselines are applicable only for Models that are using Vertex AI- provided images for Tensorflow.
Instance Attribute Summary collapse
-
#dense_shape_tensor_name ⇒ String
Specifies the shape of the values of the input if the input is a sparse representation.
-
#encoded_baselines ⇒ Array<Object>
A list of baselines for the encoded tensor.
-
#encoded_tensor_name ⇒ String
Encoded tensor is a transformation of the input tensor.
-
#encoding ⇒ String
Defines how the feature is encoded into the input tensor.
-
#feature_value_domain ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationMetadataInputMetadataFeatureValueDomain
Domain details of the input feature value.
-
#group_name ⇒ String
Name of the group that the input belongs to.
-
#index_feature_mapping ⇒ Array<String>
A list of feature names for each index in the input tensor.
-
#indices_tensor_name ⇒ String
Specifies the index of the values of the input tensor.
-
#input_baselines ⇒ Array<Object>
Baseline inputs for this feature.
-
#input_tensor_name ⇒ String
Name of the input tensor for this feature.
-
#modality ⇒ String
Modality of the feature.
-
#visualization ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationMetadataInputMetadataVisualization
Visualization configurations for image explanation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExplanationMetadataInputMetadata
constructor
A new instance of GoogleCloudAiplatformV1ExplanationMetadataInputMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExplanationMetadataInputMetadata
Returns a new instance of GoogleCloudAiplatformV1ExplanationMetadataInputMetadata.
6128 6129 6130 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6128 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dense_shape_tensor_name ⇒ String
Specifies the shape of the values of the input if the input is a sparse
representation. Refer to Tensorflow documentation for more details: https://
www.tensorflow.org/api_docs/python/tf/sparse/SparseTensor.
Corresponds to the JSON property denseShapeTensorName
6041 6042 6043 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6041 def dense_shape_tensor_name @dense_shape_tensor_name end |
#encoded_baselines ⇒ Array<Object>
A list of baselines for the encoded tensor. The shape of each baseline should
match the shape of the encoded tensor. If a scalar is provided, Vertex AI
broadcasts to the same shape as the encoded tensor.
Corresponds to the JSON property encodedBaselines
6048 6049 6050 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6048 def encoded_baselines @encoded_baselines end |
#encoded_tensor_name ⇒ String
Encoded tensor is a transformation of the input tensor. Must be provided if
choosing Integrated Gradients attribution or XRAI attribution and the input
tensor is not differentiable. An encoded tensor is generated if the input
tensor is encoded by a lookup table.
Corresponds to the JSON property encodedTensorName
6056 6057 6058 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6056 def encoded_tensor_name @encoded_tensor_name end |
#encoding ⇒ String
Defines how the feature is encoded into the input tensor. Defaults to IDENTITY.
Corresponds to the JSON property encoding
6061 6062 6063 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6061 def encoding @encoding end |
#feature_value_domain ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationMetadataInputMetadataFeatureValueDomain
Domain details of the input feature value. Provides numeric information about
the feature, such as its range (min, max). If the feature has been pre-
processed, for example with z-scoring, then it provides information about how
to recover the original feature. For example, if the input feature is an image
and it has been pre-processed to obtain 0-mean and stddev = 1 values, then
original_mean, and original_stddev refer to the mean and stddev of the
original feature (e.g. image tensor) from which input feature (with mean = 0
and stddev = 1) was obtained.
Corresponds to the JSON property featureValueDomain
6073 6074 6075 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6073 def feature_value_domain @feature_value_domain end |
#group_name ⇒ String
Name of the group that the input belongs to. Features with the same group name
will be treated as one feature when computing attributions. Features grouped
together can have different shapes in value. If provided, there will be one
single attribution generated in Attribution.feature_attributions, keyed by the
group name.
Corresponds to the JSON property groupName
6082 6083 6084 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6082 def group_name @group_name end |
#index_feature_mapping ⇒ Array<String>
A list of feature names for each index in the input tensor. Required when the
input InputMetadata.encoding is BAG_OF_FEATURES, BAG_OF_FEATURES_SPARSE,
INDICATOR.
Corresponds to the JSON property indexFeatureMapping
6089 6090 6091 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6089 def index_feature_mapping @index_feature_mapping end |
#indices_tensor_name ⇒ String
Specifies the index of the values of the input tensor. Required when the input
tensor is a sparse representation. Refer to Tensorflow documentation for more
details: https://www.tensorflow.org/api_docs/python/tf/sparse/SparseTensor.
Corresponds to the JSON property indicesTensorName
6096 6097 6098 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6096 def indices_tensor_name @indices_tensor_name end |
#input_baselines ⇒ Array<Object>
Baseline inputs for this feature. If no baseline is specified, Vertex AI
chooses the baseline for this feature. If multiple baselines are specified,
Vertex AI returns the average attributions across them in Attribution.
feature_attributions. For Vertex AI-provided Tensorflow images (both 1.x and 2.
x), the shape of each baseline must match the shape of the input tensor. If a
scalar is provided, we broadcast to the same shape as the input tensor. For
custom images, the element of the baselines must be in the same format as the
feature's input in the instance[]. The schema of any single instance may be
specified via Endpoint's DeployedModels' Model's PredictSchemata's
instance_schema_uri.
Corresponds to the JSON property inputBaselines
6110 6111 6112 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6110 def input_baselines @input_baselines end |
#input_tensor_name ⇒ String
Name of the input tensor for this feature. Required and is only applicable to
Vertex AI-provided images for Tensorflow.
Corresponds to the JSON property inputTensorName
6116 6117 6118 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6116 def input_tensor_name @input_tensor_name end |
#modality ⇒ String
Modality of the feature. Valid values are: numeric, image. Defaults to numeric.
Corresponds to the JSON property modality
6121 6122 6123 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6121 def modality @modality end |
#visualization ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationMetadataInputMetadataVisualization
Visualization configurations for image explanation.
Corresponds to the JSON property visualization
6126 6127 6128 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6126 def visualization @visualization end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6133 6134 6135 6136 6137 6138 6139 6140 6141 6142 6143 6144 6145 6146 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 6133 def update!(**args) @dense_shape_tensor_name = args[:dense_shape_tensor_name] if args.key?(:dense_shape_tensor_name) @encoded_baselines = args[:encoded_baselines] if args.key?(:encoded_baselines) @encoded_tensor_name = args[:encoded_tensor_name] if args.key?(:encoded_tensor_name) @encoding = args[:encoding] if args.key?(:encoding) @feature_value_domain = args[:feature_value_domain] if args.key?(:feature_value_domain) @group_name = args[:group_name] if args.key?(:group_name) @index_feature_mapping = args[:index_feature_mapping] if args.key?(:index_feature_mapping) @indices_tensor_name = args[:indices_tensor_name] if args.key?(:indices_tensor_name) @input_baselines = args[:input_baselines] if args.key?(:input_baselines) @input_tensor_name = args[:input_tensor_name] if args.key?(:input_tensor_name) @modality = args[:modality] if args.key?(:modality) @visualization = args[:visualization] if args.key?(:visualization) end |