Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationMetadataInputMetadataVisualization

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Visualization configurations for image explanation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ExplanationMetadataInputMetadataVisualization

Returns a new instance of GoogleCloudAiplatformV1ExplanationMetadataInputMetadataVisualization.



7320
7321
7322
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7320

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#clip_percent_lowerboundFloat

Excludes attributions below the specified percentile, from the highlighted areas. Defaults to 62. Corresponds to the JSON property clipPercentLowerbound

Returns:

  • (Float)


7281
7282
7283
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7281

def clip_percent_lowerbound
  @clip_percent_lowerbound
end

#clip_percent_upperboundFloat

Excludes attributions above the specified percentile from the highlighted areas. Using the clip_percent_upperbound and clip_percent_lowerbound together can be useful for filtering out noise and making it easier to see areas of strong attribution. Defaults to 99.9. Corresponds to the JSON property clipPercentUpperbound

Returns:

  • (Float)


7289
7290
7291
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7289

def clip_percent_upperbound
  @clip_percent_upperbound
end

#color_mapString

The color scheme used for the highlighted areas. Defaults to PINK_GREEN for Integrated Gradients attribution, which shows positive attributions in green and negative in pink. Defaults to VIRIDIS for XRAI attribution, which highlights the most influential regions in yellow and the least influential in blue. Corresponds to the JSON property colorMap

Returns:

  • (String)


7298
7299
7300
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7298

def color_map
  @color_map
end

#overlay_typeString

How the original image is displayed in the visualization. Adjusting the overlay can help increase visual clarity if the original image makes it difficult to view the visualization. Defaults to NONE. Corresponds to the JSON property overlayType

Returns:

  • (String)


7305
7306
7307
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7305

def overlay_type
  @overlay_type
end

#polarityString

Whether to only highlight pixels with positive contributions, negative or both. Defaults to POSITIVE. Corresponds to the JSON property polarity

Returns:

  • (String)


7311
7312
7313
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7311

def polarity
  @polarity
end

#typeString

Type of the image visualization. Only applicable to Integrated Gradients attribution. OUTLINES shows regions of attribution, while PIXELS shows per- pixel attribution. Defaults to OUTLINES. Corresponds to the JSON property type

Returns:

  • (String)


7318
7319
7320
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7318

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7325
7326
7327
7328
7329
7330
7331
7332
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7325

def update!(**args)
  @clip_percent_lowerbound = args[:clip_percent_lowerbound] if args.key?(:clip_percent_lowerbound)
  @clip_percent_upperbound = args[:clip_percent_upperbound] if args.key?(:clip_percent_upperbound)
  @color_map = args[:color_map] if args.key?(:color_map)
  @overlay_type = args[:overlay_type] if args.key?(:overlay_type)
  @polarity = args[:polarity] if args.key?(:polarity)
  @type = args[:type] if args.key?(:type)
end