Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationMetadataInputMetadataVisualization
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationMetadataInputMetadataVisualization
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Visualization configurations for image explanation.
Instance Attribute Summary collapse
-
#clip_percent_lowerbound ⇒ Float
Excludes attributions below the specified percentile, from the highlighted areas.
-
#clip_percent_upperbound ⇒ Float
Excludes attributions above the specified percentile from the highlighted areas.
-
#color_map ⇒ String
The color scheme used for the highlighted areas.
-
#overlay_type ⇒ String
How the original image is displayed in the visualization.
-
#polarity ⇒ String
Whether to only highlight pixels with positive contributions, negative or both.
-
#type ⇒ String
Type of the image visualization.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExplanationMetadataInputMetadataVisualization
constructor
A new instance of GoogleCloudAiplatformV1ExplanationMetadataInputMetadataVisualization.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExplanationMetadataInputMetadataVisualization
Returns a new instance of GoogleCloudAiplatformV1ExplanationMetadataInputMetadataVisualization.
7185 7186 7187 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7185 def initialize(**args) update!(**args) end |
Instance Attribute Details
#clip_percent_lowerbound ⇒ Float
Excludes attributions below the specified percentile, from the highlighted
areas. Defaults to 62.
Corresponds to the JSON property clipPercentLowerbound
7146 7147 7148 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7146 def clip_percent_lowerbound @clip_percent_lowerbound end |
#clip_percent_upperbound ⇒ Float
Excludes attributions above the specified percentile from the highlighted
areas. Using the clip_percent_upperbound and clip_percent_lowerbound together
can be useful for filtering out noise and making it easier to see areas of
strong attribution. Defaults to 99.9.
Corresponds to the JSON property clipPercentUpperbound
7154 7155 7156 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7154 def clip_percent_upperbound @clip_percent_upperbound end |
#color_map ⇒ String
The color scheme used for the highlighted areas. Defaults to PINK_GREEN for
Integrated Gradients attribution, which shows positive attributions in green
and negative in pink. Defaults to VIRIDIS for XRAI attribution, which
highlights the most influential regions in yellow and the least influential in
blue.
Corresponds to the JSON property colorMap
7163 7164 7165 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7163 def color_map @color_map end |
#overlay_type ⇒ String
How the original image is displayed in the visualization. Adjusting the
overlay can help increase visual clarity if the original image makes it
difficult to view the visualization. Defaults to NONE.
Corresponds to the JSON property overlayType
7170 7171 7172 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7170 def @overlay_type end |
#polarity ⇒ String
Whether to only highlight pixels with positive contributions, negative or both.
Defaults to POSITIVE.
Corresponds to the JSON property polarity
7176 7177 7178 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7176 def polarity @polarity end |
#type ⇒ String
Type of the image visualization. Only applicable to Integrated Gradients
attribution. OUTLINES shows regions of attribution, while PIXELS shows per-
pixel attribution. Defaults to OUTLINES.
Corresponds to the JSON property type
7183 7184 7185 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7183 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7190 7191 7192 7193 7194 7195 7196 7197 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7190 def update!(**args) @clip_percent_lowerbound = args[:clip_percent_lowerbound] if args.key?(:clip_percent_lowerbound) @clip_percent_upperbound = args[:clip_percent_upperbound] if args.key?(:clip_percent_upperbound) @color_map = args[:color_map] if args.key?(:color_map) @overlay_type = args[:overlay_type] if args.key?(:overlay_type) @polarity = args[:polarity] if args.key?(:polarity) @type = args[:type] if args.key?(:type) end |