Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationMetadataInputMetadataVisualization

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Visualization configurations for image explanation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ExplanationMetadataInputMetadataVisualization

Returns a new instance of GoogleCloudAiplatformV1ExplanationMetadataInputMetadataVisualization.



7173
7174
7175
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7173

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#clip_percent_lowerboundFloat

Excludes attributions below the specified percentile, from the highlighted areas. Defaults to 62. Corresponds to the JSON property clipPercentLowerbound

Returns:

  • (Float)


7134
7135
7136
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7134

def clip_percent_lowerbound
  @clip_percent_lowerbound
end

#clip_percent_upperboundFloat

Excludes attributions above the specified percentile from the highlighted areas. Using the clip_percent_upperbound and clip_percent_lowerbound together can be useful for filtering out noise and making it easier to see areas of strong attribution. Defaults to 99.9. Corresponds to the JSON property clipPercentUpperbound

Returns:

  • (Float)


7142
7143
7144
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7142

def clip_percent_upperbound
  @clip_percent_upperbound
end

#color_mapString

The color scheme used for the highlighted areas. Defaults to PINK_GREEN for Integrated Gradients attribution, which shows positive attributions in green and negative in pink. Defaults to VIRIDIS for XRAI attribution, which highlights the most influential regions in yellow and the least influential in blue. Corresponds to the JSON property colorMap

Returns:

  • (String)


7151
7152
7153
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7151

def color_map
  @color_map
end

#overlay_typeString

How the original image is displayed in the visualization. Adjusting the overlay can help increase visual clarity if the original image makes it difficult to view the visualization. Defaults to NONE. Corresponds to the JSON property overlayType

Returns:

  • (String)


7158
7159
7160
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7158

def overlay_type
  @overlay_type
end

#polarityString

Whether to only highlight pixels with positive contributions, negative or both. Defaults to POSITIVE. Corresponds to the JSON property polarity

Returns:

  • (String)


7164
7165
7166
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7164

def polarity
  @polarity
end

#typeString

Type of the image visualization. Only applicable to Integrated Gradients attribution. OUTLINES shows regions of attribution, while PIXELS shows per- pixel attribution. Defaults to OUTLINES. Corresponds to the JSON property type

Returns:

  • (String)


7171
7172
7173
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7171

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7178
7179
7180
7181
7182
7183
7184
7185
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7178

def update!(**args)
  @clip_percent_lowerbound = args[:clip_percent_lowerbound] if args.key?(:clip_percent_lowerbound)
  @clip_percent_upperbound = args[:clip_percent_upperbound] if args.key?(:clip_percent_upperbound)
  @color_map = args[:color_map] if args.key?(:color_map)
  @overlay_type = args[:overlay_type] if args.key?(:overlay_type)
  @polarity = args[:polarity] if args.key?(:polarity)
  @type = args[:type] if args.key?(:type)
end