Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationMetadataOutputMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Metadata of the prediction output to be explained.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ExplanationMetadataOutputMetadata

Returns a new instance of GoogleCloudAiplatformV1ExplanationMetadataOutputMetadata.



8490
8491
8492
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8490

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_name_mapping_keyString

Specify a field name in the prediction to look for the display name. Use this if the prediction contains the display names for the outputs. The display names in the prediction must have the same shape of the outputs, so that it can be located by Attribution.output_index for a specific output. Corresponds to the JSON property displayNameMappingKey

Returns:

  • (String)


8470
8471
8472
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8470

def display_name_mapping_key
  @display_name_mapping_key
end

#index_display_name_mappingObject

Static mapping between the index and display name. Use this if the outputs are a deterministic n-dimensional array, e.g. a list of scores of all the classes in a pre-defined order for a multi-classification Model. It's not feasible if the outputs are non-deterministic, e.g. the Model produces top-k classes or sort the outputs by their values. The shape of the value must be an n- dimensional array of strings. The number of dimensions must match that of the outputs to be explained. The Attribution.output_display_name is populated by locating in the mapping with Attribution.output_index. Corresponds to the JSON property indexDisplayNameMapping

Returns:

  • (Object)


8482
8483
8484
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8482

def index_display_name_mapping
  @index_display_name_mapping
end

#output_tensor_nameString

Name of the output tensor. Required and is only applicable to Vertex AI provided images for Tensorflow. Corresponds to the JSON property outputTensorName

Returns:

  • (String)


8488
8489
8490
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8488

def output_tensor_name
  @output_tensor_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8495
8496
8497
8498
8499
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8495

def update!(**args)
  @display_name_mapping_key = args[:display_name_mapping_key] if args.key?(:display_name_mapping_key)
  @index_display_name_mapping = args[:index_display_name_mapping] if args.key?(:index_display_name_mapping)
  @output_tensor_name = args[:output_tensor_name] if args.key?(:output_tensor_name)
end