Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationMetadataOverride
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationMetadataOverride
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The ExplanationMetadata entries that can be overridden at online explanation time.
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExplanationMetadataOverride
constructor
A new instance of GoogleCloudAiplatformV1ExplanationMetadataOverride.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExplanationMetadataOverride
Returns a new instance of GoogleCloudAiplatformV1ExplanationMetadataOverride.
12158 12159 12160 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12158 def initialize(**args) update!(**args) end |
Instance Attribute Details
#inputs ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationMetadataOverrideInputMetadataOverride>
Required. Overrides the input metadata of the features. The key is the name of
the feature to be overridden. The keys specified here must exist in the input
metadata to be overridden. If a feature is not specified here, the
corresponding feature's input metadata is not overridden.
Corresponds to the JSON property inputs
12156 12157 12158 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12156 def inputs @inputs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12163 12164 12165 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12163 def update!(**args) @inputs = args[:inputs] if args.key?(:inputs) end |