Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationMetadataOverride

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The ExplanationMetadata entries that can be overridden at online explanation time.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ExplanationMetadataOverride

Returns a new instance of GoogleCloudAiplatformV1ExplanationMetadataOverride.



7109
7110
7111
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7109

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#inputsHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationMetadataOverrideInputMetadataOverride>

Required. Overrides the input metadata of the features. The key is the name of the feature to be overridden. The keys specified here must exist in the input metadata to be overridden. If a feature is not specified here, the corresponding feature's input metadata is not overridden. Corresponds to the JSON property inputs



7107
7108
7109
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7107

def inputs
  @inputs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7114
7115
7116
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7114

def update!(**args)
  @inputs = args[:inputs] if args.key?(:inputs)
end