Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportDataConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportDataConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Describes what part of the Dataset is to be exported, the destination of the export and how to export.
Instance Attribute Summary collapse
-
#annotation_schema_uri ⇒ String
The Cloud Storage URI that points to a YAML file describing the annotation schema.
-
#annotations_filter ⇒ String
An expression for filtering what part of the Dataset is to be exported.
-
#export_use ⇒ String
Indicates the usage of the exported files.
-
#filter_split ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportFilterSplit
Assigns input data to training, validation, and test sets based on the given filters, data pieces not matched by any filter are ignored.
-
#fraction_split ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportFractionSplit
Assigns the input data to training, validation, and test sets as per the given fractions.
-
#gcs_destination ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsDestination
The Google Cloud Storage location where the output is to be written to.
-
#saved_query_id ⇒ String
The ID of a SavedQuery (annotation set) under the Dataset specified by ExportDataRequest.name used for filtering Annotations for training.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExportDataConfig
constructor
A new instance of GoogleCloudAiplatformV1ExportDataConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExportDataConfig
Returns a new instance of GoogleCloudAiplatformV1ExportDataConfig.
8609 8610 8611 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8609 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotation_schema_uri ⇒ String
The Cloud Storage URI that points to a YAML file describing the annotation
schema. The schema is defined as an OpenAPI 3.0.2 Schema Object.
The schema files that can be used here are found in gs://google-cloud-
aiplatform/schema/dataset/annotation/, note that the chosen schema must be
consistent with metadata of the Dataset specified by ExportDataRequest.name.
Only used for custom training data export use cases. Only applicable to
Datasets that have DataItems and Annotations. Only Annotations that both match
this schema and belong to DataItems not ignored by the split method are used
in respectively training, validation or test role, depending on the role of
the DataItem they are on. When used in conjunction with annotations_filter,
the Annotations used for training are filtered by both annotations_filter and
annotation_schema_uri.
Corresponds to the JSON property annotationSchemaUri
8558 8559 8560 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8558 def annotation_schema_uri @annotation_schema_uri end |
#annotations_filter ⇒ String
An expression for filtering what part of the Dataset is to be exported. Only
Annotations that match this filter will be exported. The filter syntax is the
same as in ListAnnotations.
Corresponds to the JSON property annotationsFilter
8565 8566 8567 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8565 def annotations_filter @annotations_filter end |
#export_use ⇒ String
Indicates the usage of the exported files.
Corresponds to the JSON property exportUse
8570 8571 8572 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8570 def export_use @export_use end |
#filter_split ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportFilterSplit
Assigns input data to training, validation, and test sets based on the given
filters, data pieces not matched by any filter are ignored. Currently only
supported for Datasets containing DataItems. If any of the filters in this
message are to match nothing, then they can be set as '-' (the minus sign).
Supported only for unstructured Datasets.
Corresponds to the JSON property filterSplit
8579 8580 8581 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8579 def filter_split @filter_split end |
#fraction_split ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportFractionSplit
Assigns the input data to training, validation, and test sets as per the given
fractions. Any of training_fraction, validation_fraction and
test_fraction may optionally be provided, they must sum to up to 1. If the
provided ones sum to less than 1, the remainder is assigned to sets as decided
by Vertex AI. If none of the fractions are set, by default roughly 80% of data
is used for training, 10% for validation, and 10% for test.
Corresponds to the JSON property fractionSplit
8589 8590 8591 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8589 def fraction_split @fraction_split end |
#gcs_destination ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsDestination
The Google Cloud Storage location where the output is to be written to.
Corresponds to the JSON property gcsDestination
8594 8595 8596 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8594 def gcs_destination @gcs_destination end |
#saved_query_id ⇒ String
The ID of a SavedQuery (annotation set) under the Dataset specified by
ExportDataRequest.name used for filtering Annotations for training. Only used
for custom training data export use cases. Only applicable to Datasets that
have SavedQueries. Only Annotations that are associated with this SavedQuery
are used in respectively training. When used in conjunction with
annotations_filter, the Annotations used for training are filtered by both
saved_query_id and annotations_filter. Only one of saved_query_id and
annotation_schema_uri should be specified as both of them represent the same
thing: problem type.
Corresponds to the JSON property savedQueryId
8607 8608 8609 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8607 def saved_query_id @saved_query_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8614 8615 8616 8617 8618 8619 8620 8621 8622 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8614 def update!(**args) @annotation_schema_uri = args[:annotation_schema_uri] if args.key?(:annotation_schema_uri) @annotations_filter = args[:annotations_filter] if args.key?(:annotations_filter) @export_use = args[:export_use] if args.key?(:export_use) @filter_split = args[:filter_split] if args.key?(:filter_split) @fraction_split = args[:fraction_split] if args.key?(:fraction_split) @gcs_destination = args[:gcs_destination] if args.key?(:gcs_destination) @saved_query_id = args[:saved_query_id] if args.key?(:saved_query_id) end |