Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportDataRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportDataRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Request message for DatasetService.ExportData.
Instance Attribute Summary collapse
-
#export_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportDataConfig
Describes what part of the Dataset is to be exported, the destination of the export and how to export.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExportDataRequest
constructor
A new instance of GoogleCloudAiplatformV1ExportDataRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExportDataRequest
Returns a new instance of GoogleCloudAiplatformV1ExportDataRequest.
9403 9404 9405 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9403 def initialize(**args) update!(**args) end |
Instance Attribute Details
#export_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportDataConfig
Describes what part of the Dataset is to be exported, the destination of the
export and how to export.
Corresponds to the JSON property exportConfig
9401 9402 9403 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9401 def export_config @export_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9408 9409 9410 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9408 def update!(**args) @export_config = args[:export_config] if args.key?(:export_config) end |