Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportDataRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for DatasetService.ExportData.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ExportDataRequest

Returns a new instance of GoogleCloudAiplatformV1ExportDataRequest.



9340
9341
9342
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9340

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#export_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportDataConfig

Describes what part of the Dataset is to be exported, the destination of the export and how to export. Corresponds to the JSON property exportConfig



9338
9339
9340
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9338

def export_config
  @export_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9345
9346
9347
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9345

def update!(**args)
  @export_config = args[:export_config] if args.key?(:export_config)
end