Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportDataRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for DatasetService.ExportData.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ExportDataRequest

Returns a new instance of GoogleCloudAiplatformV1ExportDataRequest.



8660
8661
8662
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8660

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#export_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportDataConfig

Describes what part of the Dataset is to be exported, the destination of the export and how to export. Corresponds to the JSON property exportConfig



8658
8659
8660
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8658

def export_config
  @export_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8665
8666
8667
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8665

def update!(**args)
  @export_config = args[:export_config] if args.key?(:export_config)
end