Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportDataResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Response message for DatasetService.ExportData.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ExportDataResponse

Returns a new instance of GoogleCloudAiplatformV1ExportDataResponse.



13232
13233
13234
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13232

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_statsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelDataStats

Stats of data used for train or evaluate the Model. Corresponds to the JSON property dataStats



13223
13224
13225
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13223

def data_stats
  @data_stats
end

#exported_filesArray<String>

All of the files that are exported in this export operation. For custom code training export, only three (training, validation and test) Cloud Storage paths in wildcard format are populated (for example, gs://.../training-*). Corresponds to the JSON property exportedFiles

Returns:

  • (Array<String>)


13230
13231
13232
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13230

def exported_files
  @exported_files
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13237
13238
13239
13240
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13237

def update!(**args)
  @data_stats = args[:data_stats] if args.key?(:data_stats)
  @exported_files = args[:exported_files] if args.key?(:exported_files)
end