Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportDataResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportDataResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Response message for DatasetService.ExportData.
Instance Attribute Summary collapse
-
#data_stats ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelDataStats
Stats of data used for train or evaluate the Model.
-
#exported_files ⇒ Array<String>
All of the files that are exported in this export operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExportDataResponse
constructor
A new instance of GoogleCloudAiplatformV1ExportDataResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExportDataResponse
Returns a new instance of GoogleCloudAiplatformV1ExportDataResponse.
8817 8818 8819 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8817 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_stats ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelDataStats
Stats of data used for train or evaluate the Model.
Corresponds to the JSON property dataStats
8808 8809 8810 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8808 def data_stats @data_stats end |
#exported_files ⇒ Array<String>
All of the files that are exported in this export operation. For custom code
training export, only three (training, validation and test) Cloud Storage
paths in wildcard format are populated (for example, gs://.../training-*).
Corresponds to the JSON property exportedFiles
8815 8816 8817 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8815 def exported_files @exported_files end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8822 8823 8824 8825 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8822 def update!(**args) @data_stats = args[:data_stats] if args.key?(:data_stats) @exported_files = args[:exported_files] if args.key?(:exported_files) end |