Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportDataResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportDataResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Response message for DatasetService.ExportData.
Instance Attribute Summary collapse
-
#data_stats ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelDataStats
Stats of data used for train or evaluate the Model.
-
#exported_files ⇒ Array<String>
All of the files that are exported in this export operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExportDataResponse
constructor
A new instance of GoogleCloudAiplatformV1ExportDataResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExportDataResponse
Returns a new instance of GoogleCloudAiplatformV1ExportDataResponse.
7622 7623 7624 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7622 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_stats ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelDataStats
Stats of data used for train or evaluate the Model.
Corresponds to the JSON property dataStats
7613 7614 7615 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7613 def data_stats @data_stats end |
#exported_files ⇒ Array<String>
All of the files that are exported in this export operation. For custom code
training export, only three (training, validation and test) Cloud Storage
paths in wildcard format are populated (for example, gs://.../training-*).
Corresponds to the JSON property exportedFiles
7620 7621 7622 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7620 def exported_files @exported_files end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7627 7628 7629 7630 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7627 def update!(**args) @data_stats = args[:data_stats] if args.key?(:data_stats) @exported_files = args[:exported_files] if args.key?(:exported_files) end |