Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportDataResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Response message for DatasetService.ExportData.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ExportDataResponse

Returns a new instance of GoogleCloudAiplatformV1ExportDataResponse.



7556
7557
7558
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7556

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_statsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelDataStats

Stats of data used for train or evaluate the Model. Corresponds to the JSON property dataStats



7547
7548
7549
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7547

def data_stats
  @data_stats
end

#exported_filesArray<String>

All of the files that are exported in this export operation. For custom code training export, only three (training, validation and test) Cloud Storage paths in wildcard format are populated (for example, gs://.../training-*). Corresponds to the JSON property exportedFiles

Returns:

  • (Array<String>)


7554
7555
7556
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7554

def exported_files
  @exported_files
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7561
7562
7563
7564
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7561

def update!(**args)
  @data_stats = args[:data_stats] if args.key?(:data_stats)
  @exported_files = args[:exported_files] if args.key?(:exported_files)
end