Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportFeatureValuesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for FeaturestoreService.ExportFeatureValues.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ExportFeatureValuesRequest

Returns a new instance of GoogleCloudAiplatformV1ExportFeatureValuesRequest.



12951
12952
12953
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12951

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destinationGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureValueDestination

A destination location for Feature values and format. Corresponds to the JSON property destination



12927
12928
12929
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12927

def destination
  @destination
end

#feature_selectorGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureSelector

Selector for Features of an EntityType. Corresponds to the JSON property featureSelector



12932
12933
12934
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12932

def feature_selector
  @feature_selector
end

#full_exportGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportFeatureValuesRequestFullExport

Describes exporting all historical Feature values of all entities of the EntityType between [start_time, end_time]. Corresponds to the JSON property fullExport



12938
12939
12940
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12938

def full_export
  @full_export
end

#settingsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DestinationFeatureSetting>

Per-Feature export settings. Corresponds to the JSON property settings



12943
12944
12945
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12943

def settings
  @settings
end

#snapshot_exportGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportFeatureValuesRequestSnapshotExport

Describes exporting the latest Feature values of all entities of the EntityType between [start_time, snapshot_time]. Corresponds to the JSON property snapshotExport



12949
12950
12951
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12949

def snapshot_export
  @snapshot_export
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12956
12957
12958
12959
12960
12961
12962
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12956

def update!(**args)
  @destination = args[:destination] if args.key?(:destination)
  @feature_selector = args[:feature_selector] if args.key?(:feature_selector)
  @full_export = args[:full_export] if args.key?(:full_export)
  @settings = args[:settings] if args.key?(:settings)
  @snapshot_export = args[:snapshot_export] if args.key?(:snapshot_export)
end