Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportFeatureValuesRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportFeatureValuesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Request message for FeaturestoreService.ExportFeatureValues.
Instance Attribute Summary collapse
-
#destination ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureValueDestination
A destination location for Feature values and format.
-
#feature_selector ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureSelector
Selector for Features of an EntityType.
-
#full_export ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportFeatureValuesRequestFullExport
Describes exporting all historical Feature values of all entities of the EntityType between [start_time, end_time].
-
#settings ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DestinationFeatureSetting>
Per-Feature export settings.
-
#snapshot_export ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportFeatureValuesRequestSnapshotExport
Describes exporting the latest Feature values of all entities of the EntityType between [start_time, snapshot_time].
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExportFeatureValuesRequest
constructor
A new instance of GoogleCloudAiplatformV1ExportFeatureValuesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExportFeatureValuesRequest
Returns a new instance of GoogleCloudAiplatformV1ExportFeatureValuesRequest.
9490 9491 9492 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9490 def initialize(**args) update!(**args) end |
Instance Attribute Details
#destination ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureValueDestination
A destination location for Feature values and format.
Corresponds to the JSON property destination
9466 9467 9468 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9466 def destination @destination end |
#feature_selector ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureSelector
Selector for Features of an EntityType.
Corresponds to the JSON property featureSelector
9471 9472 9473 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9471 def feature_selector @feature_selector end |
#full_export ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportFeatureValuesRequestFullExport
Describes exporting all historical Feature values of all entities of the
EntityType between [start_time, end_time].
Corresponds to the JSON property fullExport
9477 9478 9479 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9477 def full_export @full_export end |
#settings ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DestinationFeatureSetting>
Per-Feature export settings.
Corresponds to the JSON property settings
9482 9483 9484 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9482 def settings @settings end |
#snapshot_export ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportFeatureValuesRequestSnapshotExport
Describes exporting the latest Feature values of all entities of the
EntityType between [start_time, snapshot_time].
Corresponds to the JSON property snapshotExport
9488 9489 9490 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9488 def snapshot_export @snapshot_export end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9495 9496 9497 9498 9499 9500 9501 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9495 def update!(**args) @destination = args[:destination] if args.key?(:destination) @feature_selector = args[:feature_selector] if args.key?(:feature_selector) @full_export = args[:full_export] if args.key?(:full_export) @settings = args[:settings] if args.key?(:settings) @snapshot_export = args[:snapshot_export] if args.key?(:snapshot_export) end |