Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportFeatureValuesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for FeaturestoreService.ExportFeatureValues.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ExportFeatureValuesRequest

Returns a new instance of GoogleCloudAiplatformV1ExportFeatureValuesRequest.



8748
8749
8750
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8748

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destinationGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureValueDestination

A destination location for Feature values and format. Corresponds to the JSON property destination



8724
8725
8726
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8724

def destination
  @destination
end

#feature_selectorGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureSelector

Selector for Features of an EntityType. Corresponds to the JSON property featureSelector



8729
8730
8731
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8729

def feature_selector
  @feature_selector
end

#full_exportGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportFeatureValuesRequestFullExport

Describes exporting all historical Feature values of all entities of the EntityType between [start_time, end_time]. Corresponds to the JSON property fullExport



8735
8736
8737
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8735

def full_export
  @full_export
end

#settingsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DestinationFeatureSetting>

Per-Feature export settings. Corresponds to the JSON property settings



8740
8741
8742
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8740

def settings
  @settings
end

#snapshot_exportGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportFeatureValuesRequestSnapshotExport

Describes exporting the latest Feature values of all entities of the EntityType between [start_time, snapshot_time]. Corresponds to the JSON property snapshotExport



8746
8747
8748
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8746

def snapshot_export
  @snapshot_export
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8753
8754
8755
8756
8757
8758
8759
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8753

def update!(**args)
  @destination = args[:destination] if args.key?(:destination)
  @feature_selector = args[:feature_selector] if args.key?(:feature_selector)
  @full_export = args[:full_export] if args.key?(:full_export)
  @settings = args[:settings] if args.key?(:settings)
  @snapshot_export = args[:snapshot_export] if args.key?(:snapshot_export)
end