Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportFeatureValuesRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportFeatureValuesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Request message for FeaturestoreService.ExportFeatureValues.
Instance Attribute Summary collapse
-
#destination ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureValueDestination
A destination location for Feature values and format.
-
#feature_selector ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureSelector
Selector for Features of an EntityType.
-
#full_export ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportFeatureValuesRequestFullExport
Describes exporting all historical Feature values of all entities of the EntityType between [start_time, end_time].
-
#settings ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DestinationFeatureSetting>
Per-Feature export settings.
-
#snapshot_export ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportFeatureValuesRequestSnapshotExport
Describes exporting the latest Feature values of all entities of the EntityType between [start_time, snapshot_time].
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExportFeatureValuesRequest
constructor
A new instance of GoogleCloudAiplatformV1ExportFeatureValuesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExportFeatureValuesRequest
Returns a new instance of GoogleCloudAiplatformV1ExportFeatureValuesRequest.
7752 7753 7754 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7752 def initialize(**args) update!(**args) end |
Instance Attribute Details
#destination ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureValueDestination
A destination location for Feature values and format.
Corresponds to the JSON property destination
7728 7729 7730 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7728 def destination @destination end |
#feature_selector ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureSelector
Selector for Features of an EntityType.
Corresponds to the JSON property featureSelector
7733 7734 7735 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7733 def feature_selector @feature_selector end |
#full_export ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportFeatureValuesRequestFullExport
Describes exporting all historical Feature values of all entities of the
EntityType between [start_time, end_time].
Corresponds to the JSON property fullExport
7739 7740 7741 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7739 def full_export @full_export end |
#settings ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DestinationFeatureSetting>
Per-Feature export settings.
Corresponds to the JSON property settings
7744 7745 7746 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7744 def settings @settings end |
#snapshot_export ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportFeatureValuesRequestSnapshotExport
Describes exporting the latest Feature values of all entities of the
EntityType between [start_time, snapshot_time].
Corresponds to the JSON property snapshotExport
7750 7751 7752 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7750 def snapshot_export @snapshot_export end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7757 7758 7759 7760 7761 7762 7763 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7757 def update!(**args) @destination = args[:destination] if args.key?(:destination) @feature_selector = args[:feature_selector] if args.key?(:feature_selector) @full_export = args[:full_export] if args.key?(:full_export) @settings = args[:settings] if args.key?(:settings) @snapshot_export = args[:snapshot_export] if args.key?(:snapshot_export) end |