Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportFeatureValuesRequestFullExport
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportFeatureValuesRequestFullExport
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Describes exporting all historical Feature values of all entities of the EntityType between [start_time, end_time].
Instance Attribute Summary collapse
-
#end_time ⇒ String
Exports Feature values as of this timestamp.
-
#start_time ⇒ String
Excludes Feature values with feature generation timestamp before this timestamp.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExportFeatureValuesRequestFullExport
constructor
A new instance of GoogleCloudAiplatformV1ExportFeatureValuesRequestFullExport.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExportFeatureValuesRequestFullExport
Returns a new instance of GoogleCloudAiplatformV1ExportFeatureValuesRequestFullExport.
12665 12666 12667 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12665 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time ⇒ String
Exports Feature values as of this timestamp. If not set, retrieve values as of
now. Timestamp, if present, must not have higher than millisecond precision.
Corresponds to the JSON property endTime
12656 12657 12658 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12656 def end_time @end_time end |
#start_time ⇒ String
Excludes Feature values with feature generation timestamp before this
timestamp. If not set, retrieve oldest values kept in Feature Store. Timestamp,
if present, must not have higher than millisecond precision.
Corresponds to the JSON property startTime
12663 12664 12665 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12663 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12670 12671 12672 12673 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12670 def update!(**args) @end_time = args[:end_time] if args.key?(:end_time) @start_time = args[:start_time] if args.key?(:start_time) end |