Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportFeatureValuesRequestFullExport

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Describes exporting all historical Feature values of all entities of the EntityType between [start_time, end_time].

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ExportFeatureValuesRequestFullExport

Returns a new instance of GoogleCloudAiplatformV1ExportFeatureValuesRequestFullExport.



7715
7716
7717
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7715

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_timeString

Exports Feature values as of this timestamp. If not set, retrieve values as of now. Timestamp, if present, must not have higher than millisecond precision. Corresponds to the JSON property endTime

Returns:

  • (String)


7706
7707
7708
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7706

def end_time
  @end_time
end

#start_timeString

Excludes Feature values with feature generation timestamp before this timestamp. If not set, retrieve oldest values kept in Feature Store. Timestamp, if present, must not have higher than millisecond precision. Corresponds to the JSON property startTime

Returns:

  • (String)


7713
7714
7715
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7713

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7720
7721
7722
7723
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7720

def update!(**args)
  @end_time = args[:end_time] if args.key?(:end_time)
  @start_time = args[:start_time] if args.key?(:start_time)
end