Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportFeatureValuesRequestFullExport
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportFeatureValuesRequestFullExport
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Describes exporting all historical Feature values of all entities of the EntityType between [start_time, end_time].
Instance Attribute Summary collapse
-
#end_time ⇒ String
Exports Feature values as of this timestamp.
-
#start_time ⇒ String
Excludes Feature values with feature generation timestamp before this timestamp.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExportFeatureValuesRequestFullExport
constructor
A new instance of GoogleCloudAiplatformV1ExportFeatureValuesRequestFullExport.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExportFeatureValuesRequestFullExport
Returns a new instance of GoogleCloudAiplatformV1ExportFeatureValuesRequestFullExport.
7419 7420 7421 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7419 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time ⇒ String
Exports Feature values as of this timestamp. If not set, retrieve values as of
now. Timestamp, if present, must not have higher than millisecond precision.
Corresponds to the JSON property endTime
7410 7411 7412 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7410 def end_time @end_time end |
#start_time ⇒ String
Excludes Feature values with feature generation timestamp before this
timestamp. If not set, retrieve oldest values kept in Feature Store. Timestamp,
if present, must not have higher than millisecond precision.
Corresponds to the JSON property startTime
7417 7418 7419 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7417 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7424 7425 7426 7427 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7424 def update!(**args) @end_time = args[:end_time] if args.key?(:end_time) @start_time = args[:start_time] if args.key?(:start_time) end |