Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportFeatureValuesRequestSnapshotExport
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportFeatureValuesRequestSnapshotExport
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Describes exporting the latest Feature values of all entities of the EntityType between [start_time, snapshot_time].
Instance Attribute Summary collapse
-
#snapshot_time ⇒ String
Exports Feature values as of this timestamp.
-
#start_time ⇒ String
Excludes Feature values with feature generation timestamp before this timestamp.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExportFeatureValuesRequestSnapshotExport
constructor
A new instance of GoogleCloudAiplatformV1ExportFeatureValuesRequestSnapshotExport.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExportFeatureValuesRequestSnapshotExport
Returns a new instance of GoogleCloudAiplatformV1ExportFeatureValuesRequestSnapshotExport.
8900 8901 8902 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8900 def initialize(**args) update!(**args) end |
Instance Attribute Details
#snapshot_time ⇒ String
Exports Feature values as of this timestamp. If not set, retrieve values as of
now. Timestamp, if present, must not have higher than millisecond precision.
Corresponds to the JSON property snapshotTime
8891 8892 8893 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8891 def snapshot_time @snapshot_time end |
#start_time ⇒ String
Excludes Feature values with feature generation timestamp before this
timestamp. If not set, retrieve oldest values kept in Feature Store. Timestamp,
if present, must not have higher than millisecond precision.
Corresponds to the JSON property startTime
8898 8899 8900 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8898 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8905 8906 8907 8908 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8905 def update!(**args) @snapshot_time = args[:snapshot_time] if args.key?(:snapshot_time) @start_time = args[:start_time] if args.key?(:start_time) end |