Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportFeatureValuesRequestSnapshotExport

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Describes exporting the latest Feature values of all entities of the EntityType between [start_time, snapshot_time].

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ExportFeatureValuesRequestSnapshotExport

Returns a new instance of GoogleCloudAiplatformV1ExportFeatureValuesRequestSnapshotExport.



8809
8810
8811
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8809

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#snapshot_timeString

Exports Feature values as of this timestamp. If not set, retrieve values as of now. Timestamp, if present, must not have higher than millisecond precision. Corresponds to the JSON property snapshotTime

Returns:

  • (String)


8800
8801
8802
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8800

def snapshot_time
  @snapshot_time
end

#start_timeString

Excludes Feature values with feature generation timestamp before this timestamp. If not set, retrieve oldest values kept in Feature Store. Timestamp, if present, must not have higher than millisecond precision. Corresponds to the JSON property startTime

Returns:

  • (String)


8807
8808
8809
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8807

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8814
8815
8816
8817
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8814

def update!(**args)
  @snapshot_time = args[:snapshot_time] if args.key?(:snapshot_time)
  @start_time = args[:start_time] if args.key?(:start_time)
end