Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportFractionSplit
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportFractionSplit
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Assigns the input data to training, validation, and test sets as per the given
fractions. Any of training_fraction, validation_fraction and
test_fraction may optionally be provided, they must sum to up to 1. If the
provided ones sum to less than 1, the remainder is assigned to sets as decided
by Vertex AI. If none of the fractions are set, by default roughly 80% of data
is used for training, 10% for validation, and 10% for test.
Instance Attribute Summary collapse
-
#test_fraction ⇒ Float
The fraction of the input data that is to be used to evaluate the Model.
-
#training_fraction ⇒ Float
The fraction of the input data that is to be used to train the Model.
-
#validation_fraction ⇒ Float
The fraction of the input data that is to be used to validate the Model.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExportFractionSplit
constructor
A new instance of GoogleCloudAiplatformV1ExportFractionSplit.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExportFractionSplit
Returns a new instance of GoogleCloudAiplatformV1ExportFractionSplit.
12789 12790 12791 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12789 def initialize(**args) update!(**args) end |
Instance Attribute Details
#test_fraction ⇒ Float
The fraction of the input data that is to be used to evaluate the Model.
Corresponds to the JSON property testFraction
12777 12778 12779 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12777 def test_fraction @test_fraction end |
#training_fraction ⇒ Float
The fraction of the input data that is to be used to train the Model.
Corresponds to the JSON property trainingFraction
12782 12783 12784 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12782 def training_fraction @training_fraction end |
#validation_fraction ⇒ Float
The fraction of the input data that is to be used to validate the Model.
Corresponds to the JSON property validationFraction
12787 12788 12789 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12787 def validation_fraction @validation_fraction end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12794 12795 12796 12797 12798 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12794 def update!(**args) @test_fraction = args[:test_fraction] if args.key?(:test_fraction) @training_fraction = args[:training_fraction] if args.key?(:training_fraction) @validation_fraction = args[:validation_fraction] if args.key?(:validation_fraction) end |