Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportModelOperationMetadataOutputInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Further describes the output of the ExportModel. Supplements ExportModelRequest.OutputConfig.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ExportModelOperationMetadataOutputInfo

Returns a new instance of GoogleCloudAiplatformV1ExportModelOperationMetadataOutputInfo.



13505
13506
13507
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13505

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_output_uriString

Output only. If the Model artifact is being exported to Google Cloud Storage this is the full path of the directory created, into which the Model files are being written to. Corresponds to the JSON property artifactOutputUri

Returns:

  • (String)


13497
13498
13499
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13497

def artifact_output_uri
  @artifact_output_uri
end

#image_output_uriString

Output only. If the Model image is being exported to Google Container Registry or Artifact Registry this is the full path of the image created. Corresponds to the JSON property imageOutputUri

Returns:

  • (String)


13503
13504
13505
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13503

def image_output_uri
  @image_output_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13510
13511
13512
13513
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13510

def update!(**args)
  @artifact_output_uri = args[:artifact_output_uri] if args.key?(:artifact_output_uri)
  @image_output_uri = args[:image_output_uri] if args.key?(:image_output_uri)
end