Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportModelOperationMetadataOutputInfo
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportModelOperationMetadataOutputInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Further describes the output of the ExportModel. Supplements ExportModelRequest.OutputConfig.
Instance Attribute Summary collapse
-
#artifact_output_uri ⇒ String
Output only.
-
#image_output_uri ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExportModelOperationMetadataOutputInfo
constructor
A new instance of GoogleCloudAiplatformV1ExportModelOperationMetadataOutputInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExportModelOperationMetadataOutputInfo
Returns a new instance of GoogleCloudAiplatformV1ExportModelOperationMetadataOutputInfo.
9638 9639 9640 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9638 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_output_uri ⇒ String
Output only. If the Model artifact is being exported to Google Cloud Storage
this is the full path of the directory created, into which the Model files are
being written to.
Corresponds to the JSON property artifactOutputUri
9630 9631 9632 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9630 def artifact_output_uri @artifact_output_uri end |
#image_output_uri ⇒ String
Output only. If the Model image is being exported to Google Container Registry
or Artifact Registry this is the full path of the image created.
Corresponds to the JSON property imageOutputUri
9636 9637 9638 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9636 def image_output_uri @image_output_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9643 9644 9645 9646 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9643 def update!(**args) @artifact_output_uri = args[:artifact_output_uri] if args.key?(:artifact_output_uri) @image_output_uri = args[:image_output_uri] if args.key?(:image_output_uri) end |