Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportModelRequestOutputConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportModelRequestOutputConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Output configuration for the Model export.
Instance Attribute Summary collapse
-
#artifact_destination ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsDestination
The Google Cloud Storage location where the output is to be written to.
-
#export_format_id ⇒ String
The ID of the format in which the Model must be exported.
-
#image_destination ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ContainerRegistryDestination
The Container Registry location for the container image.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExportModelRequestOutputConfig
constructor
A new instance of GoogleCloudAiplatformV1ExportModelRequestOutputConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExportModelRequestOutputConfig
Returns a new instance of GoogleCloudAiplatformV1ExportModelRequestOutputConfig.
13214 13215 13216 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13214 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_destination ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsDestination
The Google Cloud Storage location where the output is to be written to.
Corresponds to the JSON property artifactDestination
13200 13201 13202 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13200 def artifact_destination @artifact_destination end |
#export_format_id ⇒ String
The ID of the format in which the Model must be exported. Each Model lists the
export formats it supports. If no value is provided here, then the first from
the list of the Model's supported formats is used by default.
Corresponds to the JSON property exportFormatId
13207 13208 13209 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13207 def export_format_id @export_format_id end |
#image_destination ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ContainerRegistryDestination
The Container Registry location for the container image.
Corresponds to the JSON property imageDestination
13212 13213 13214 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13212 def image_destination @image_destination end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13219 13220 13221 13222 13223 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13219 def update!(**args) @artifact_destination = args[:artifact_destination] if args.key?(:artifact_destination) @export_format_id = args[:export_format_id] if args.key?(:export_format_id) @image_destination = args[:image_destination] if args.key?(:image_destination) end |