Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportTensorboardTimeSeriesDataRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportTensorboardTimeSeriesDataRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Request message for TensorboardService.ExportTensorboardTimeSeriesData.
Instance Attribute Summary collapse
-
#filter ⇒ String
Exports the TensorboardTimeSeries' data that match the filter expression.
-
#order_by ⇒ String
Field to use to sort the TensorboardTimeSeries' data.
-
#page_size ⇒ Fixnum
The maximum number of data points to return per page.
-
#page_token ⇒ String
A page token, received from a previous ExportTensorboardTimeSeriesData call.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExportTensorboardTimeSeriesDataRequest
constructor
A new instance of GoogleCloudAiplatformV1ExportTensorboardTimeSeriesDataRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ExportTensorboardTimeSeriesDataRequest
Returns a new instance of GoogleCloudAiplatformV1ExportTensorboardTimeSeriesDataRequest.
14271 14272 14273 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14271 def initialize(**args) update!(**args) end |
Instance Attribute Details
#filter ⇒ String
Exports the TensorboardTimeSeries' data that match the filter expression.
Corresponds to the JSON property filter
14248 14249 14250 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14248 def filter @filter end |
#order_by ⇒ String
Field to use to sort the TensorboardTimeSeries' data. By default,
TensorboardTimeSeries' data is returned in a pseudo random order.
Corresponds to the JSON property orderBy
14254 14255 14256 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14254 def order_by @order_by end |
#page_size ⇒ Fixnum
The maximum number of data points to return per page. The default page_size is
- Values must be between 1 and 10000. Values above 10000 are coerced to
10000.
Corresponds to the JSON property
pageSize
14261 14262 14263 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14261 def page_size @page_size end |
#page_token ⇒ String
A page token, received from a previous ExportTensorboardTimeSeriesData call.
Provide this to retrieve the subsequent page. When paginating, all other
parameters provided to ExportTensorboardTimeSeriesData must match the call
that provided the page token.
Corresponds to the JSON property pageToken
14269 14270 14271 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14269 def page_token @page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14276 14277 14278 14279 14280 14281 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14276 def update!(**args) @filter = args[:filter] if args.key?(:filter) @order_by = args[:order_by] if args.key?(:order_by) @page_size = args[:page_size] if args.key?(:page_size) @page_token = args[:page_token] if args.key?(:page_token) end |