Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExportTensorboardTimeSeriesDataRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for TensorboardService.ExportTensorboardTimeSeriesData.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ExportTensorboardTimeSeriesDataRequest

Returns a new instance of GoogleCloudAiplatformV1ExportTensorboardTimeSeriesDataRequest.



8070
8071
8072
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8070

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#filterString

Exports the TensorboardTimeSeries' data that match the filter expression. Corresponds to the JSON property filter

Returns:

  • (String)


8047
8048
8049
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8047

def filter
  @filter
end

#order_byString

Field to use to sort the TensorboardTimeSeries' data. By default, TensorboardTimeSeries' data is returned in a pseudo random order. Corresponds to the JSON property orderBy

Returns:

  • (String)


8053
8054
8055
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8053

def order_by
  @order_by
end

#page_sizeFixnum

The maximum number of data points to return per page. The default page_size is

  1. Values must be between 1 and 10000. Values above 10000 are coerced to 10000. Corresponds to the JSON property pageSize

Returns:

  • (Fixnum)


8060
8061
8062
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8060

def page_size
  @page_size
end

#page_tokenString

A page token, received from a previous ExportTensorboardTimeSeriesData call. Provide this to retrieve the subsequent page. When paginating, all other parameters provided to ExportTensorboardTimeSeriesData must match the call that provided the page token. Corresponds to the JSON property pageToken

Returns:

  • (String)


8068
8069
8070
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8068

def page_token
  @page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8075
8076
8077
8078
8079
8080
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8075

def update!(**args)
  @filter = args[:filter] if args.key?(:filter)
  @order_by = args[:order_by] if args.key?(:order_by)
  @page_size = args[:page_size] if args.key?(:page_size)
  @page_token = args[:page_token] if args.key?(:page_token)
end