Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExternalApi

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Retrieve from data source powered by external API for grounding. The external API is not owned by Google, but need to follow the pre-defined API spec.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ExternalApi

Returns a new instance of GoogleCloudAiplatformV1ExternalApi.



9821
9822
9823
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9821

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_authGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ApiAuth

The generic reusable api auth config. Deprecated. Please use AuthConfig ( google/cloud/aiplatform/master/auth.proto) instead. Corresponds to the JSON property apiAuth



9792
9793
9794
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9792

def api_auth
  @api_auth
end

#api_specString

The API spec that the external API implements. Corresponds to the JSON property apiSpec

Returns:

  • (String)


9797
9798
9799
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9797

def api_spec
  @api_spec
end

#auth_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1AuthConfig

Auth configuration to run the extension. Corresponds to the JSON property authConfig



9802
9803
9804
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9802

def auth_config
  @auth_config
end

#elastic_search_paramsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ExternalApiElasticSearchParams

The search parameters to use for the ELASTIC_SEARCH spec. Corresponds to the JSON property elasticSearchParams



9807
9808
9809
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9807

def elastic_search_params
  @elastic_search_params
end

#endpointString

The endpoint of the external API. The system will call the API at this endpoint to retrieve the data for grounding. Example: https://acme.com:443/ search Corresponds to the JSON property endpoint

Returns:

  • (String)


9814
9815
9816
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9814

def endpoint
  @endpoint
end

#simple_search_paramsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ExternalApiSimpleSearchParams

The search parameters to use for SIMPLE_SEARCH spec. Corresponds to the JSON property simpleSearchParams



9819
9820
9821
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9819

def simple_search_params
  @simple_search_params
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9826
9827
9828
9829
9830
9831
9832
9833
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9826

def update!(**args)
  @api_auth = args[:api_auth] if args.key?(:api_auth)
  @api_spec = args[:api_spec] if args.key?(:api_spec)
  @auth_config = args[:auth_config] if args.key?(:auth_config)
  @elastic_search_params = args[:elastic_search_params] if args.key?(:elastic_search_params)
  @endpoint = args[:endpoint] if args.key?(:endpoint)
  @simple_search_params = args[:simple_search_params] if args.key?(:simple_search_params)
end