Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Fact
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Fact
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The fact used in grounding.
Instance Attribute Summary collapse
-
#chunk ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagChunk
A RagChunk includes the content of a chunk of a RagFile, and associated metadata.
-
#query ⇒ String
Query that is used to retrieve this fact.
-
#score ⇒ Float
If present, according to the underlying Vector DB and the selected metric type, the score can be either the distance or the similarity between the query and the fact and its range depends on the metric type.
-
#summary ⇒ String
If present, the summary/snippet of the fact.
-
#title ⇒ String
If present, it refers to the title of this fact.
-
#uri ⇒ String
If present, this uri links to the source of the fact.
-
#vector_distance ⇒ Float
If present, the distance between the query vector and this fact vector.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Fact
constructor
A new instance of GoogleCloudAiplatformV1Fact.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Fact
Returns a new instance of GoogleCloudAiplatformV1Fact.
14062 14063 14064 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14062 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chunk ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagChunk
A RagChunk includes the content of a chunk of a RagFile, and associated
metadata.
Corresponds to the JSON property chunk
14024 14025 14026 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14024 def chunk @chunk end |
#query ⇒ String
Query that is used to retrieve this fact.
Corresponds to the JSON property query
14029 14030 14031 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14029 def query @query end |
#score ⇒ Float
If present, according to the underlying Vector DB and the selected metric type,
the score can be either the distance or the similarity between the query and
the fact and its range depends on the metric type. For example, if the metric
type is COSINE_DISTANCE, it represents the distance between the query and the
fact. The larger the distance, the less relevant the fact is to the query. The
range is [0, 2], while 0 means the most relevant and 2 means the least
relevant.
Corresponds to the JSON property score
14040 14041 14042 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14040 def score @score end |
#summary ⇒ String
If present, the summary/snippet of the fact.
Corresponds to the JSON property summary
14045 14046 14047 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14045 def summary @summary end |
#title ⇒ String
If present, it refers to the title of this fact.
Corresponds to the JSON property title
14050 14051 14052 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14050 def title @title end |
#uri ⇒ String
If present, this uri links to the source of the fact.
Corresponds to the JSON property uri
14055 14056 14057 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14055 def uri @uri end |
#vector_distance ⇒ Float
If present, the distance between the query vector and this fact vector.
Corresponds to the JSON property vectorDistance
14060 14061 14062 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14060 def vector_distance @vector_distance end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14067 14068 14069 14070 14071 14072 14073 14074 14075 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14067 def update!(**args) @chunk = args[:chunk] if args.key?(:chunk) @query = args[:query] if args.key?(:query) @score = args[:score] if args.key?(:score) @summary = args[:summary] if args.key?(:summary) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) @vector_distance = args[:vector_distance] if args.key?(:vector_distance) end |