Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Fact
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Fact
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The fact used in grounding.
Instance Attribute Summary collapse
-
#chunk ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagChunk
A RagChunk includes the content of a chunk of a RagFile, and associated metadata.
-
#query ⇒ String
Query that is used to retrieve this fact.
-
#score ⇒ Float
If present, according to the underlying Vector DB and the selected metric type, the score can be either the distance or the similarity between the query and the fact and its range depends on the metric type.
-
#summary ⇒ String
If present, the summary/snippet of the fact.
-
#title ⇒ String
If present, it refers to the title of this fact.
-
#uri ⇒ String
If present, this uri links to the source of the fact.
-
#vector_distance ⇒ Float
If present, the distance between the query vector and this fact vector.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Fact
constructor
A new instance of GoogleCloudAiplatformV1Fact.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Fact
Returns a new instance of GoogleCloudAiplatformV1Fact.
9639 9640 9641 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9639 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chunk ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagChunk
A RagChunk includes the content of a chunk of a RagFile, and associated
metadata.
Corresponds to the JSON property chunk
9601 9602 9603 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9601 def chunk @chunk end |
#query ⇒ String
Query that is used to retrieve this fact.
Corresponds to the JSON property query
9606 9607 9608 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9606 def query @query end |
#score ⇒ Float
If present, according to the underlying Vector DB and the selected metric type,
the score can be either the distance or the similarity between the query and
the fact and its range depends on the metric type. For example, if the metric
type is COSINE_DISTANCE, it represents the distance between the query and the
fact. The larger the distance, the less relevant the fact is to the query. The
range is [0, 2], while 0 means the most relevant and 2 means the least
relevant.
Corresponds to the JSON property score
9617 9618 9619 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9617 def score @score end |
#summary ⇒ String
If present, the summary/snippet of the fact.
Corresponds to the JSON property summary
9622 9623 9624 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9622 def summary @summary end |
#title ⇒ String
If present, it refers to the title of this fact.
Corresponds to the JSON property title
9627 9628 9629 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9627 def title @title end |
#uri ⇒ String
If present, this uri links to the source of the fact.
Corresponds to the JSON property uri
9632 9633 9634 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9632 def uri @uri end |
#vector_distance ⇒ Float
If present, the distance between the query vector and this fact vector.
Corresponds to the JSON property vectorDistance
9637 9638 9639 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9637 def vector_distance @vector_distance end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9644 9645 9646 9647 9648 9649 9650 9651 9652 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9644 def update!(**args) @chunk = args[:chunk] if args.key?(:chunk) @query = args[:query] if args.key?(:query) @score = args[:score] if args.key?(:score) @summary = args[:summary] if args.key?(:summary) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) @vector_distance = args[:vector_distance] if args.key?(:vector_distance) end |