Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Fact

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The fact used in grounding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Fact

Returns a new instance of GoogleCloudAiplatformV1Fact.



9236
9237
9238
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9236

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#queryString

Query that is used to retrieve this fact. Corresponds to the JSON property query

Returns:

  • (String)


9203
9204
9205
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9203

def query
  @query
end

#scoreFloat

If present, according to the underlying Vector DB and the selected metric type, the score can be either the distance or the similarity between the query and the fact and its range depends on the metric type. For example, if the metric type is COSINE_DISTANCE, it represents the distance between the query and the fact. The larger the distance, the less relevant the fact is to the query. The range is [0, 2], while 0 means the most relevant and 2 means the least relevant. Corresponds to the JSON property score

Returns:

  • (Float)


9214
9215
9216
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9214

def score
  @score
end

#summaryString

If present, the summary/snippet of the fact. Corresponds to the JSON property summary

Returns:

  • (String)


9219
9220
9221
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9219

def summary
  @summary
end

#titleString

If present, it refers to the title of this fact. Corresponds to the JSON property title

Returns:

  • (String)


9224
9225
9226
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9224

def title
  @title
end

#uriString

If present, this uri links to the source of the fact. Corresponds to the JSON property uri

Returns:

  • (String)


9229
9230
9231
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9229

def uri
  @uri
end

#vector_distanceFloat

If present, the distance between the query vector and this fact vector. Corresponds to the JSON property vectorDistance

Returns:

  • (Float)


9234
9235
9236
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9234

def vector_distance
  @vector_distance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9241
9242
9243
9244
9245
9246
9247
9248
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9241

def update!(**args)
  @query = args[:query] if args.key?(:query)
  @score = args[:score] if args.key?(:score)
  @summary = args[:summary] if args.key?(:summary)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
  @vector_distance = args[:vector_distance] if args.key?(:vector_distance)
end