Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Fact
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Fact
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The fact used in grounding.
Instance Attribute Summary collapse
-
#query ⇒ String
Query that is used to retrieve this fact.
-
#score ⇒ Float
If present, according to the underlying Vector DB and the selected metric type, the score can be either the distance or the similarity between the query and the fact and its range depends on the metric type.
-
#summary ⇒ String
If present, the summary/snippet of the fact.
-
#title ⇒ String
If present, it refers to the title of this fact.
-
#uri ⇒ String
If present, this uri links to the source of the fact.
-
#vector_distance ⇒ Float
If present, the distance between the query vector and this fact vector.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Fact
constructor
A new instance of GoogleCloudAiplatformV1Fact.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Fact
Returns a new instance of GoogleCloudAiplatformV1Fact.
9087 9088 9089 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9087 def initialize(**args) update!(**args) end |
Instance Attribute Details
#query ⇒ String
Query that is used to retrieve this fact.
Corresponds to the JSON property query
9054 9055 9056 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9054 def query @query end |
#score ⇒ Float
If present, according to the underlying Vector DB and the selected metric type,
the score can be either the distance or the similarity between the query and
the fact and its range depends on the metric type. For example, if the metric
type is COSINE_DISTANCE, it represents the distance between the query and the
fact. The larger the distance, the less relevant the fact is to the query. The
range is [0, 2], while 0 means the most relevant and 2 means the least
relevant.
Corresponds to the JSON property score
9065 9066 9067 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9065 def score @score end |
#summary ⇒ String
If present, the summary/snippet of the fact.
Corresponds to the JSON property summary
9070 9071 9072 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9070 def summary @summary end |
#title ⇒ String
If present, it refers to the title of this fact.
Corresponds to the JSON property title
9075 9076 9077 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9075 def title @title end |
#uri ⇒ String
If present, this uri links to the source of the fact.
Corresponds to the JSON property uri
9080 9081 9082 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9080 def uri @uri end |
#vector_distance ⇒ Float
If present, the distance between the query vector and this fact vector.
Corresponds to the JSON property vectorDistance
9085 9086 9087 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9085 def vector_distance @vector_distance end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9092 9093 9094 9095 9096 9097 9098 9099 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9092 def update!(**args) @query = args[:query] if args.key?(:query) @score = args[:score] if args.key?(:score) @summary = args[:summary] if args.key?(:summary) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) @vector_distance = args[:vector_distance] if args.key?(:vector_distance) end |