Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Fact

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The fact used in grounding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Fact

Returns a new instance of GoogleCloudAiplatformV1Fact.



8893
8894
8895
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8893

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#queryString

Query that is used to retrieve this fact. Corresponds to the JSON property query

Returns:

  • (String)


8860
8861
8862
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8860

def query
  @query
end

#scoreFloat

If present, according to the underlying Vector DB and the selected metric type, the score can be either the distance or the similarity between the query and the fact and its range depends on the metric type. For example, if the metric type is COSINE_DISTANCE, it represents the distance between the query and the fact. The larger the distance, the less relevant the fact is to the query. The range is [0, 2], while 0 means the most relevant and 2 means the least relevant. Corresponds to the JSON property score

Returns:

  • (Float)


8871
8872
8873
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8871

def score
  @score
end

#summaryString

If present, the summary/snippet of the fact. Corresponds to the JSON property summary

Returns:

  • (String)


8876
8877
8878
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8876

def summary
  @summary
end

#titleString

If present, it refers to the title of this fact. Corresponds to the JSON property title

Returns:

  • (String)


8881
8882
8883
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8881

def title
  @title
end

#uriString

If present, this uri links to the source of the fact. Corresponds to the JSON property uri

Returns:

  • (String)


8886
8887
8888
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8886

def uri
  @uri
end

#vector_distanceFloat

If present, the distance between the query vector and this fact vector. Corresponds to the JSON property vectorDistance

Returns:

  • (Float)


8891
8892
8893
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8891

def vector_distance
  @vector_distance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8898
8899
8900
8901
8902
8903
8904
8905
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8898

def update!(**args)
  @query = args[:query] if args.key?(:query)
  @score = args[:score] if args.key?(:score)
  @summary = args[:summary] if args.key?(:summary)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
  @vector_distance = args[:vector_distance] if args.key?(:vector_distance)
end