Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Feature
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Feature
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Feature Metadata information. For example, color is a feature that describes an apple.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Description of the Feature.
-
#disable_monitoring ⇒ Boolean
(also: #disable_monitoring?)
Optional.
-
#etag ⇒ String
Used to perform a consistent read-modify-write updates.
-
#labels ⇒ Hash<String,String>
Optional.
-
#monitoring_stats_anomalies ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureMonitoringStatsAnomaly>
Output only.
-
#name ⇒ String
Immutable.
-
#point_of_contact ⇒ String
Entity responsible for maintaining this feature.
-
#update_time ⇒ String
Output only.
-
#value_type ⇒ String
Immutable.
-
#version_column_name ⇒ String
Only applicable for Vertex AI Feature Store.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Feature
constructor
A new instance of GoogleCloudAiplatformV1Feature.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Feature
Returns a new instance of GoogleCloudAiplatformV1Feature.
9265 9266 9267 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9265 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Only applicable for Vertex AI Feature Store (Legacy). Timestamp
when this EntityType was created.
Corresponds to the JSON property createTime
9189 9190 9191 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9189 def create_time @create_time end |
#description ⇒ String
Description of the Feature.
Corresponds to the JSON property description
9194 9195 9196 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9194 def description @description end |
#disable_monitoring ⇒ Boolean Also known as: disable_monitoring?
Optional. Only applicable for Vertex AI Feature Store (Legacy). If not set,
use the monitoring_config defined for the EntityType this Feature belongs to.
Only Features with type (Feature.ValueType) BOOL, STRING, DOUBLE or INT64 can
enable monitoring. If set to true, all types of data monitoring are disabled
despite the config on EntityType.
Corresponds to the JSON property disableMonitoring
9203 9204 9205 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9203 def disable_monitoring @disable_monitoring end |
#etag ⇒ String
Used to perform a consistent read-modify-write updates. If not set, a blind "
overwrite" update happens.
Corresponds to the JSON property etag
9210 9211 9212 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9210 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. The labels with user-defined metadata to organize your Features.
Label keys and values can be no longer than 64 characters (Unicode codepoints),
can only contain lowercase letters, numeric characters, underscores and
dashes. International characters are allowed. See https://goo.gl/xmQnxf for
more information on and examples of labels. No more than 64 user labels can be
associated with one Feature (System labels are excluded)." System reserved
label keys are prefixed with "aiplatform.googleapis.com/" and are immutable.
Corresponds to the JSON property labels
9221 9222 9223 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9221 def labels @labels end |
#monitoring_stats_anomalies ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureMonitoringStatsAnomaly>
Output only. Only applicable for Vertex AI Feature Store (Legacy). The list of
historical stats and anomalies with specified objectives.
Corresponds to the JSON property monitoringStatsAnomalies
9227 9228 9229 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9227 def monitoring_stats_anomalies @monitoring_stats_anomalies end |
#name ⇒ String
Immutable. Name of the Feature. Format: projects/project/locations/
location/featurestores/featurestore/entityTypes/entity_type/features/
feature`projects/`project`/locations/`location`/featureGroups/`
feature_group`/features/`feature The last part feature is assigned by the
client. The feature can be up to 64 characters long and can consist only of
ASCII Latin letters A-Z and a-z, underscore(_), and ASCII digits 0-9 starting
with a letter. The value will be unique given an entity type.
Corresponds to the JSON property name
9238 9239 9240 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9238 def name @name end |
#point_of_contact ⇒ String
Entity responsible for maintaining this feature. Can be comma separated list
of email addresses or URIs.
Corresponds to the JSON property pointOfContact
9244 9245 9246 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9244 def point_of_contact @point_of_contact end |
#update_time ⇒ String
Output only. Only applicable for Vertex AI Feature Store (Legacy). Timestamp
when this EntityType was most recently updated.
Corresponds to the JSON property updateTime
9250 9251 9252 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9250 def update_time @update_time end |
#value_type ⇒ String
Immutable. Only applicable for Vertex AI Feature Store (Legacy). Type of
Feature value.
Corresponds to the JSON property valueType
9256 9257 9258 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9256 def value_type @value_type end |
#version_column_name ⇒ String
Only applicable for Vertex AI Feature Store. The name of the BigQuery Table/
View column hosting data for this version. If no value is provided, will use
feature_id.
Corresponds to the JSON property versionColumnName
9263 9264 9265 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9263 def version_column_name @version_column_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9270 9271 9272 9273 9274 9275 9276 9277 9278 9279 9280 9281 9282 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9270 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @disable_monitoring = args[:disable_monitoring] if args.key?(:disable_monitoring) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @monitoring_stats_anomalies = args[:monitoring_stats_anomalies] if args.key?(:monitoring_stats_anomalies) @name = args[:name] if args.key?(:name) @point_of_contact = args[:point_of_contact] if args.key?(:point_of_contact) @update_time = args[:update_time] if args.key?(:update_time) @value_type = args[:value_type] if args.key?(:value_type) @version_column_name = args[:version_column_name] if args.key?(:version_column_name) end |