Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Feature

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Feature Metadata information. For example, color is a feature that describes an apple.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Feature

Returns a new instance of GoogleCloudAiplatformV1Feature.



8047
8048
8049
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8047

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Only applicable for Vertex AI Feature Store (Legacy). Timestamp when this EntityType was created. Corresponds to the JSON property createTime

Returns:

  • (String)


7971
7972
7973
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7971

def create_time
  @create_time
end

#descriptionString

Description of the Feature. Corresponds to the JSON property description

Returns:

  • (String)


7976
7977
7978
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7976

def description
  @description
end

#disable_monitoringBoolean Also known as: disable_monitoring?

Optional. Only applicable for Vertex AI Feature Store (Legacy). If not set, use the monitoring_config defined for the EntityType this Feature belongs to. Only Features with type (Feature.ValueType) BOOL, STRING, DOUBLE or INT64 can enable monitoring. If set to true, all types of data monitoring are disabled despite the config on EntityType. Corresponds to the JSON property disableMonitoring

Returns:

  • (Boolean)


7985
7986
7987
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7985

def disable_monitoring
  @disable_monitoring
end

#etagString

Used to perform a consistent read-modify-write updates. If not set, a blind " overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


7992
7993
7994
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7992

def etag
  @etag
end

#labelsHash<String,String>

Optional. The labels with user-defined metadata to organize your Features. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information on and examples of labels. No more than 64 user labels can be associated with one Feature (System labels are excluded)." System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


8003
8004
8005
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8003

def labels
  @labels
end

#monitoring_stats_anomaliesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureMonitoringStatsAnomaly>

Output only. Only applicable for Vertex AI Feature Store (Legacy). The list of historical stats and anomalies with specified objectives. Corresponds to the JSON property monitoringStatsAnomalies



8009
8010
8011
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8009

def monitoring_stats_anomalies
  @monitoring_stats_anomalies
end

#nameString

Immutable. Name of the Feature. Format: projects/project/locations/ location/featurestores/featurestore/entityTypes/entity_type/features/ feature`projects/`project`/locations/`location`/featureGroups/` feature_group`/features/`feature The last part feature is assigned by the client. The feature can be up to 64 characters long and can consist only of ASCII Latin letters A-Z and a-z, underscore(_), and ASCII digits 0-9 starting with a letter. The value will be unique given an entity type. Corresponds to the JSON property name

Returns:

  • (String)


8020
8021
8022
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8020

def name
  @name
end

#point_of_contactString

Entity responsible for maintaining this feature. Can be comma separated list of email addresses or URIs. Corresponds to the JSON property pointOfContact

Returns:

  • (String)


8026
8027
8028
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8026

def point_of_contact
  @point_of_contact
end

#update_timeString

Output only. Only applicable for Vertex AI Feature Store (Legacy). Timestamp when this EntityType was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


8032
8033
8034
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8032

def update_time
  @update_time
end

#value_typeString

Immutable. Only applicable for Vertex AI Feature Store (Legacy). Type of Feature value. Corresponds to the JSON property valueType

Returns:

  • (String)


8038
8039
8040
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8038

def value_type
  @value_type
end

#version_column_nameString

Only applicable for Vertex AI Feature Store. The name of the BigQuery Table/ View column hosting data for this version. If no value is provided, will use feature_id. Corresponds to the JSON property versionColumnName

Returns:

  • (String)


8045
8046
8047
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8045

def version_column_name
  @version_column_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8052
8053
8054
8055
8056
8057
8058
8059
8060
8061
8062
8063
8064
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8052

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @disable_monitoring = args[:disable_monitoring] if args.key?(:disable_monitoring)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @monitoring_stats_anomalies = args[:monitoring_stats_anomalies] if args.key?(:monitoring_stats_anomalies)
  @name = args[:name] if args.key?(:name)
  @point_of_contact = args[:point_of_contact] if args.key?(:point_of_contact)
  @update_time = args[:update_time] if args.key?(:update_time)
  @value_type = args[:value_type] if args.key?(:value_type)
  @version_column_name = args[:version_column_name] if args.key?(:version_column_name)
end