Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Vertex AI Feature Group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureGroup

Returns a new instance of GoogleCloudAiplatformV1FeatureGroup.



13177
13178
13179
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13177

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#big_queryGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureGroupBigQuery

Input source type for BigQuery Tables and Views. Corresponds to the JSON property bigQuery



13121
13122
13123
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13121

def big_query
  @big_query
end

#create_timeString

Output only. Timestamp when this FeatureGroup was created. Corresponds to the JSON property createTime

Returns:

  • (String)


13126
13127
13128
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13126

def create_time
  @create_time
end

#descriptionString

Optional. Description of the FeatureGroup. Corresponds to the JSON property description

Returns:

  • (String)


13131
13132
13133
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13131

def description
  @description
end

#etagString

Optional. Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


13137
13138
13139
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13137

def etag
  @etag
end

#labelsHash<String,String>

Optional. The labels with user-defined metadata to organize your FeatureGroup. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information on and examples of labels. No more than 64 user labels can be associated with one FeatureGroup(System labels are excluded)." System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


13148
13149
13150
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13148

def labels
  @labels
end

#nameString

Identifier. Name of the FeatureGroup. Format: projects/project/locations/ location/featureGroups/featureGroup` Corresponds to the JSON propertyname`

Returns:

  • (String)


13154
13155
13156
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13154

def name
  @name
end

#service_account_emailString

Output only. A Service Account unique to this FeatureGroup. The role bigquery. dataViewer should be granted to this service account to allow Vertex AI Feature Store to access source data while running jobs under this FeatureGroup. Corresponds to the JSON property serviceAccountEmail

Returns:

  • (String)


13161
13162
13163
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13161

def 
  @service_account_email
end

#service_agent_typeString

Optional. Service agent type used during jobs under a FeatureGroup. By default, the Vertex AI Service Agent is used. When using an IAM Policy to isolate this FeatureGroup within a project, a separate service account should be provisioned by setting this field to SERVICE_AGENT_TYPE_FEATURE_GROUP. This will generate a separate service account to access the BigQuery source table. Corresponds to the JSON property serviceAgentType

Returns:

  • (String)


13170
13171
13172
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13170

def service_agent_type
  @service_agent_type
end

#update_timeString

Output only. Timestamp when this FeatureGroup was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


13175
13176
13177
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13175

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13182
13183
13184
13185
13186
13187
13188
13189
13190
13191
13192
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13182

def update!(**args)
  @big_query = args[:big_query] if args.key?(:big_query)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @service_account_email = args[:service_account_email] if args.key?(:service_account_email)
  @service_agent_type = args[:service_agent_type] if args.key?(:service_agent_type)
  @update_time = args[:update_time] if args.key?(:update_time)
end