Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureGroup
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Vertex AI Feature Group.
Instance Attribute Summary collapse
-
#big_query ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureGroupBigQuery
Input source type for BigQuery Tables and Views.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#etag ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#service_account_email ⇒ String
Output only.
-
#service_agent_type ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureGroup
constructor
A new instance of GoogleCloudAiplatformV1FeatureGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureGroup
Returns a new instance of GoogleCloudAiplatformV1FeatureGroup.
10131 10132 10133 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10131 def initialize(**args) update!(**args) end |
Instance Attribute Details
#big_query ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureGroupBigQuery
Input source type for BigQuery Tables and Views.
Corresponds to the JSON property bigQuery
10075 10076 10077 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10075 def big_query @big_query end |
#create_time ⇒ String
Output only. Timestamp when this FeatureGroup was created.
Corresponds to the JSON property createTime
10080 10081 10082 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10080 def create_time @create_time end |
#description ⇒ String
Optional. Description of the FeatureGroup.
Corresponds to the JSON property description
10085 10086 10087 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10085 def description @description end |
#etag ⇒ String
Optional. Used to perform consistent read-modify-write updates. If not set, a
blind "overwrite" update happens.
Corresponds to the JSON property etag
10091 10092 10093 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10091 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. The labels with user-defined metadata to organize your FeatureGroup.
Label keys and values can be no longer than 64 characters (Unicode codepoints),
can only contain lowercase letters, numeric characters, underscores and
dashes. International characters are allowed. See https://goo.gl/xmQnxf for
more information on and examples of labels. No more than 64 user labels can be
associated with one FeatureGroup(System labels are excluded)." System reserved
label keys are prefixed with "aiplatform.googleapis.com/" and are immutable.
Corresponds to the JSON property labels
10102 10103 10104 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10102 def labels @labels end |
#name ⇒ String
Identifier. Name of the FeatureGroup. Format: projects/project/locations/
location/featureGroups/featureGroup`
Corresponds to the JSON propertyname`
10108 10109 10110 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10108 def name @name end |
#service_account_email ⇒ String
Output only. A Service Account unique to this FeatureGroup. The role bigquery.
dataViewer should be granted to this service account to allow Vertex AI
Feature Store to access source data while running jobs under this FeatureGroup.
Corresponds to the JSON property serviceAccountEmail
10115 10116 10117 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10115 def service_account_email @service_account_email end |
#service_agent_type ⇒ String
Optional. Service agent type used during jobs under a FeatureGroup. By default,
the Vertex AI Service Agent is used. When using an IAM Policy to isolate this
FeatureGroup within a project, a separate service account should be
provisioned by setting this field to SERVICE_AGENT_TYPE_FEATURE_GROUP. This
will generate a separate service account to access the BigQuery source table.
Corresponds to the JSON property serviceAgentType
10124 10125 10126 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10124 def service_agent_type @service_agent_type end |
#update_time ⇒ String
Output only. Timestamp when this FeatureGroup was last updated.
Corresponds to the JSON property updateTime
10129 10130 10131 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10129 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10136 10137 10138 10139 10140 10141 10142 10143 10144 10145 10146 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10136 def update!(**args) @big_query = args[:big_query] if args.key?(:big_query) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @service_account_email = args[:service_account_email] if args.key?(:service_account_email) @service_agent_type = args[:service_agent_type] if args.key?(:service_agent_type) @update_time = args[:update_time] if args.key?(:update_time) end |