Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureGroup
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Vertex AI Feature Group.
Instance Attribute Summary collapse
-
#big_query ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureGroupBigQuery
Input source type for BigQuery Tables and Views.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#etag ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#service_account_email ⇒ String
Output only.
-
#service_agent_type ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureGroup
constructor
A new instance of GoogleCloudAiplatformV1FeatureGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureGroup
Returns a new instance of GoogleCloudAiplatformV1FeatureGroup.
9439 9440 9441 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9439 def initialize(**args) update!(**args) end |
Instance Attribute Details
#big_query ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureGroupBigQuery
Input source type for BigQuery Tables and Views.
Corresponds to the JSON property bigQuery
9383 9384 9385 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9383 def big_query @big_query end |
#create_time ⇒ String
Output only. Timestamp when this FeatureGroup was created.
Corresponds to the JSON property createTime
9388 9389 9390 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9388 def create_time @create_time end |
#description ⇒ String
Optional. Description of the FeatureGroup.
Corresponds to the JSON property description
9393 9394 9395 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9393 def description @description end |
#etag ⇒ String
Optional. Used to perform consistent read-modify-write updates. If not set, a
blind "overwrite" update happens.
Corresponds to the JSON property etag
9399 9400 9401 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9399 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. The labels with user-defined metadata to organize your FeatureGroup.
Label keys and values can be no longer than 64 characters (Unicode codepoints),
can only contain lowercase letters, numeric characters, underscores and
dashes. International characters are allowed. See https://goo.gl/xmQnxf for
more information on and examples of labels. No more than 64 user labels can be
associated with one FeatureGroup(System labels are excluded)." System reserved
label keys are prefixed with "aiplatform.googleapis.com/" and are immutable.
Corresponds to the JSON property labels
9410 9411 9412 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9410 def labels @labels end |
#name ⇒ String
Identifier. Name of the FeatureGroup. Format: projects/project/locations/
location/featureGroups/featureGroup`
Corresponds to the JSON propertyname`
9416 9417 9418 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9416 def name @name end |
#service_account_email ⇒ String
Output only. A Service Account unique to this FeatureGroup. The role bigquery.
dataViewer should be granted to this service account to allow Vertex AI
Feature Store to access source data while running jobs under this FeatureGroup.
Corresponds to the JSON property serviceAccountEmail
9423 9424 9425 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9423 def service_account_email @service_account_email end |
#service_agent_type ⇒ String
Optional. Service agent type used during jobs under a FeatureGroup. By default,
the Vertex AI Service Agent is used. When using an IAM Policy to isolate this
FeatureGroup within a project, a separate service account should be
provisioned by setting this field to SERVICE_AGENT_TYPE_FEATURE_GROUP. This
will generate a separate service account to access the BigQuery source table.
Corresponds to the JSON property serviceAgentType
9432 9433 9434 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9432 def service_agent_type @service_agent_type end |
#update_time ⇒ String
Output only. Timestamp when this FeatureGroup was last updated.
Corresponds to the JSON property updateTime
9437 9438 9439 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9437 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9444 9445 9446 9447 9448 9449 9450 9451 9452 9453 9454 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9444 def update!(**args) @big_query = args[:big_query] if args.key?(:big_query) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @service_account_email = args[:service_account_email] if args.key?(:service_account_email) @service_agent_type = args[:service_agent_type] if args.key?(:service_agent_type) @update_time = args[:update_time] if args.key?(:update_time) end |