Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Vertex AI Feature Group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureGroup

Returns a new instance of GoogleCloudAiplatformV1FeatureGroup.



9274
9275
9276
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9274

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#big_queryGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureGroupBigQuery

Input source type for BigQuery Tables and Views. Corresponds to the JSON property bigQuery



9234
9235
9236
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9234

def big_query
  @big_query
end

#create_timeString

Output only. Timestamp when this FeatureGroup was created. Corresponds to the JSON property createTime

Returns:

  • (String)


9239
9240
9241
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9239

def create_time
  @create_time
end

#descriptionString

Optional. Description of the FeatureGroup. Corresponds to the JSON property description

Returns:

  • (String)


9244
9245
9246
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9244

def description
  @description
end

#etagString

Optional. Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


9250
9251
9252
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9250

def etag
  @etag
end

#labelsHash<String,String>

Optional. The labels with user-defined metadata to organize your FeatureGroup. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information on and examples of labels. No more than 64 user labels can be associated with one FeatureGroup(System labels are excluded)." System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


9261
9262
9263
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9261

def labels
  @labels
end

#nameString

Identifier. Name of the FeatureGroup. Format: projects/project/locations/ location/featureGroups/featureGroup` Corresponds to the JSON propertyname`

Returns:

  • (String)


9267
9268
9269
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9267

def name
  @name
end

#update_timeString

Output only. Timestamp when this FeatureGroup was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


9272
9273
9274
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9272

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9279
9280
9281
9282
9283
9284
9285
9286
9287
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9279

def update!(**args)
  @big_query = args[:big_query] if args.key?(:big_query)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end