Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureGroup
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Vertex AI Feature Group.
Instance Attribute Summary collapse
-
#big_query ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureGroupBigQuery
Input source type for BigQuery Tables and Views.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#etag ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureGroup
constructor
A new instance of GoogleCloudAiplatformV1FeatureGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureGroup
Returns a new instance of GoogleCloudAiplatformV1FeatureGroup.
8192 8193 8194 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8192 def initialize(**args) update!(**args) end |
Instance Attribute Details
#big_query ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureGroupBigQuery
Input source type for BigQuery Tables and Views.
Corresponds to the JSON property bigQuery
8152 8153 8154 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8152 def big_query @big_query end |
#create_time ⇒ String
Output only. Timestamp when this FeatureGroup was created.
Corresponds to the JSON property createTime
8157 8158 8159 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8157 def create_time @create_time end |
#description ⇒ String
Optional. Description of the FeatureGroup.
Corresponds to the JSON property description
8162 8163 8164 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8162 def description @description end |
#etag ⇒ String
Optional. Used to perform consistent read-modify-write updates. If not set, a
blind "overwrite" update happens.
Corresponds to the JSON property etag
8168 8169 8170 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8168 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. The labels with user-defined metadata to organize your FeatureGroup.
Label keys and values can be no longer than 64 characters (Unicode codepoints),
can only contain lowercase letters, numeric characters, underscores and
dashes. International characters are allowed. See https://goo.gl/xmQnxf for
more information on and examples of labels. No more than 64 user labels can be
associated with one FeatureGroup(System labels are excluded)." System reserved
label keys are prefixed with "aiplatform.googleapis.com/" and are immutable.
Corresponds to the JSON property labels
8179 8180 8181 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8179 def labels @labels end |
#name ⇒ String
Identifier. Name of the FeatureGroup. Format: projects/project/locations/
location/featureGroups/featureGroup`
Corresponds to the JSON propertyname`
8185 8186 8187 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8185 def name @name end |
#update_time ⇒ String
Output only. Timestamp when this FeatureGroup was last updated.
Corresponds to the JSON property updateTime
8190 8191 8192 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8190 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8197 8198 8199 8200 8201 8202 8203 8204 8205 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8197 def update!(**args) @big_query = args[:big_query] if args.key?(:big_query) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) end |