Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Vertex AI Feature Group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureGroup

Returns a new instance of GoogleCloudAiplatformV1FeatureGroup.



7896
7897
7898
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7896

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#big_queryGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureGroupBigQuery

Input source type for BigQuery Tables and Views. Corresponds to the JSON property bigQuery



7856
7857
7858
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7856

def big_query
  @big_query
end

#create_timeString

Output only. Timestamp when this FeatureGroup was created. Corresponds to the JSON property createTime

Returns:

  • (String)


7861
7862
7863
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7861

def create_time
  @create_time
end

#descriptionString

Optional. Description of the FeatureGroup. Corresponds to the JSON property description

Returns:

  • (String)


7866
7867
7868
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7866

def description
  @description
end

#etagString

Optional. Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


7872
7873
7874
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7872

def etag
  @etag
end

#labelsHash<String,String>

Optional. The labels with user-defined metadata to organize your FeatureGroup. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information on and examples of labels. No more than 64 user labels can be associated with one FeatureGroup(System labels are excluded)." System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


7883
7884
7885
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7883

def labels
  @labels
end

#nameString

Identifier. Name of the FeatureGroup. Format: projects/project/locations/ location/featureGroups/featureGroup` Corresponds to the JSON propertyname`

Returns:

  • (String)


7889
7890
7891
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7889

def name
  @name
end

#update_timeString

Output only. Timestamp when this FeatureGroup was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


7894
7895
7896
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7894

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7901
7902
7903
7904
7905
7906
7907
7908
7909
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7901

def update!(**args)
  @big_query = args[:big_query] if args.key?(:big_query)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end