Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureGroupBigQuery

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Input source type for BigQuery Tables and Views.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureGroupBigQuery

Returns a new instance of GoogleCloudAiplatformV1FeatureGroupBigQuery.



9867
9868
9869
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9867

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#big_query_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQuerySource

The BigQuery location for the input content. Corresponds to the JSON property bigQuerySource



9832
9833
9834
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9832

def big_query_source
  @big_query_source
end

#denseBoolean Also known as: dense?

Optional. If set, all feature values will be fetched from a single row per unique entityId including nulls. If not set, will collapse all rows for each unique entityId into a singe row with any non-null values if present, if no non-null values are present will sync null. ex: If source has schema ( entity_id, feature_timestamp, f0, f1) and the following rows: (e1, 2020-01- 01T10:00:00.123Z, 10, 15) (e1, 2020-02-01T10:00:00.123Z, 20, null) If dense is set, (e1, 20, null) is synced to online stores. If dense is not set, (e1, 20, 15) is synced to online stores. Corresponds to the JSON property dense

Returns:

  • (Boolean)


9844
9845
9846
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9844

def dense
  @dense
end

#entity_id_columnsArray<String>

Optional. Columns to construct entity_id / row keys. If not provided defaults to entity_id. Corresponds to the JSON property entityIdColumns

Returns:

  • (Array<String>)


9851
9852
9853
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9851

def entity_id_columns
  @entity_id_columns
end

#static_data_sourceBoolean Also known as: static_data_source?

Optional. Set if the data source is not a time-series. Corresponds to the JSON property staticDataSource

Returns:

  • (Boolean)


9856
9857
9858
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9856

def static_data_source
  @static_data_source
end

#time_seriesGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureGroupBigQueryTimeSeries

Optional. If the source is a time-series source, this can be set to control how downstream sources (ex: FeatureView ) will treat time-series sources. If not set, will treat the source as a time-series source with feature_timestamp as timestamp column and no scan boundary. Corresponds to the JSON property timeSeries



9865
9866
9867
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9865

def time_series
  @time_series
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9872
9873
9874
9875
9876
9877
9878
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9872

def update!(**args)
  @big_query_source = args[:big_query_source] if args.key?(:big_query_source)
  @dense = args[:dense] if args.key?(:dense)
  @entity_id_columns = args[:entity_id_columns] if args.key?(:entity_id_columns)
  @static_data_source = args[:static_data_source] if args.key?(:static_data_source)
  @time_series = args[:time_series] if args.key?(:time_series)
end