Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureMonitoringStatsAnomaly

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A list of historical SnapshotAnalysis or ImportFeaturesAnalysis stats requested by user, sorted by FeatureStatsAnomaly.start_time descending.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureMonitoringStatsAnomaly

Returns a new instance of GoogleCloudAiplatformV1FeatureMonitoringStatsAnomaly.



8308
8309
8310
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8308

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#feature_stats_anomalyGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureStatsAnomaly

Stats and Anomaly generated at specific timestamp for specific Feature. The start_time and end_time are used to define the time range of the dataset that current stats belongs to, e.g. prediction traffic is bucketed into prediction datasets by time window. If the Dataset is not defined by time window, start_time = end_time. Timestamp of the stats and anomalies always refers to end_time. Raw stats and anomalies are stored in stats_uri or anomaly_uri in the tensorflow defined protos. Field data_stats contains almost identical information with the raw stats in Vertex AI defined proto, for UI to display. Corresponds to the JSON property featureStatsAnomaly



8301
8302
8303
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8301

def feature_stats_anomaly
  @feature_stats_anomaly
end

#objectiveString

Output only. The objective for each stats. Corresponds to the JSON property objective

Returns:

  • (String)


8306
8307
8308
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8306

def objective
  @objective
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8313
8314
8315
8316
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8313

def update!(**args)
  @feature_stats_anomaly = args[:feature_stats_anomaly] if args.key?(:feature_stats_anomaly)
  @objective = args[:objective] if args.key?(:objective)
end