Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureNoiseSigma
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureNoiseSigma
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Noise sigma by features. Noise sigma represents the standard deviation of the gaussian kernel that will be used to add noise to interpolated inputs prior to computing gradients.
Instance Attribute Summary collapse
-
#noise_sigma ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureNoiseSigmaNoiseSigmaForFeature>
Noise sigma per feature.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureNoiseSigma
constructor
A new instance of GoogleCloudAiplatformV1FeatureNoiseSigma.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureNoiseSigma
Returns a new instance of GoogleCloudAiplatformV1FeatureNoiseSigma.
13270 13271 13272 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13270 def initialize(**args) update!(**args) end |
Instance Attribute Details
#noise_sigma ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureNoiseSigmaNoiseSigmaForFeature>
Noise sigma per feature. No noise is added to features that are not set.
Corresponds to the JSON property noiseSigma
13268 13269 13270 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13268 def noise_sigma @noise_sigma end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13275 13276 13277 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13275 def update!(**args) @noise_sigma = args[:noise_sigma] if args.key?(:noise_sigma) end |