Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureNoiseSigma

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Noise sigma by features. Noise sigma represents the standard deviation of the gaussian kernel that will be used to add noise to interpolated inputs prior to computing gradients.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureNoiseSigma

Returns a new instance of GoogleCloudAiplatformV1FeatureNoiseSigma.



10335
10336
10337
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10335

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#noise_sigmaArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureNoiseSigmaNoiseSigmaForFeature>

Noise sigma per feature. No noise is added to features that are not set. Corresponds to the JSON property noiseSigma



10333
10334
10335
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10333

def noise_sigma
  @noise_sigma
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10340
10341
10342
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10340

def update!(**args)
  @noise_sigma = args[:noise_sigma] if args.key?(:noise_sigma)
end