Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStore

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Vertex AI Feature Online Store provides a centralized repository for serving ML features and embedding indexes at low latency. The Feature Online Store is a top-level container.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureOnlineStore

Returns a new instance of GoogleCloudAiplatformV1FeatureOnlineStore.



14258
14259
14260
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14258

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bigtableGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStoreBigtable

Contains settings for the Cloud Bigtable instance that will be created to serve featureValues for all FeatureViews under this FeatureOnlineStore. Corresponds to the JSON property bigtable



14187
14188
14189
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14187

def bigtable
  @bigtable
end

#create_timeString

Output only. Timestamp when this FeatureOnlineStore was created. Corresponds to the JSON property createTime

Returns:

  • (String)


14192
14193
14194
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14192

def create_time
  @create_time
end

#dedicated_serving_endpointGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStoreDedicatedServingEndpoint

The dedicated serving endpoint for this FeatureOnlineStore. Only need to set when you choose Optimized storage type. Public endpoint is provisioned by default. Corresponds to the JSON property dedicatedServingEndpoint



14199
14200
14201
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14199

def dedicated_serving_endpoint
  @dedicated_serving_endpoint
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



14205
14206
14207
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14205

def encryption_spec
  @encryption_spec
end

#etagString

Optional. Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


14211
14212
14213
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14211

def etag
  @etag
end

#labelsHash<String,String>

Optional. The labels with user-defined metadata to organize your FeatureOnlineStore. Label keys and values can be no longer than 64 characters ( Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo. gl/xmQnxf for more information on and examples of labels. No more than 64 user labels can be associated with one FeatureOnlineStore(System labels are excluded)." System reserved label keys are prefixed with "aiplatform. googleapis.com/" and are immutable. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


14223
14224
14225
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14223

def labels
  @labels
end

#nameString

Identifier. Name of the FeatureOnlineStore. Format: projects/project/ locations/location/featureOnlineStores/featureOnlineStore` Corresponds to the JSON propertyname`

Returns:

  • (String)


14229
14230
14231
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14229

def name
  @name
end

#optimizedGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStoreOptimized

Optimized storage type Corresponds to the JSON property optimized



14234
14235
14236
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14234

def optimized
  @optimized
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


14239
14240
14241
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14239

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


14245
14246
14247
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14245

def satisfies_pzs
  @satisfies_pzs
end

#stateString

Output only. State of the featureOnlineStore. Corresponds to the JSON property state

Returns:

  • (String)


14251
14252
14253
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14251

def state
  @state
end

#update_timeString

Output only. Timestamp when this FeatureOnlineStore was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


14256
14257
14258
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14256

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14263
14264
14265
14266
14267
14268
14269
14270
14271
14272
14273
14274
14275
14276
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14263

def update!(**args)
  @bigtable = args[:bigtable] if args.key?(:bigtable)
  @create_time = args[:create_time] if args.key?(:create_time)
  @dedicated_serving_endpoint = args[:dedicated_serving_endpoint] if args.key?(:dedicated_serving_endpoint)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @optimized = args[:optimized] if args.key?(:optimized)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end