Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStore
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStore
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Vertex AI Feature Online Store provides a centralized repository for serving ML features and embedding indexes at low latency. The Feature Online Store is a top-level container.
Instance Attribute Summary collapse
-
#bigtable ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStoreBigtable
Contains settings for the Cloud Bigtable instance that will be created to serve featureValues for all FeatureViews under this FeatureOnlineStore.
-
#create_time ⇒ String
Output only.
-
#dedicated_serving_endpoint ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStoreDedicatedServingEndpoint
The dedicated serving endpoint for this FeatureOnlineStore.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.
-
#etag ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#optimized ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStoreOptimized
Optimized storage type Corresponds to the JSON property
optimized. -
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureOnlineStore
constructor
A new instance of GoogleCloudAiplatformV1FeatureOnlineStore.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureOnlineStore
Returns a new instance of GoogleCloudAiplatformV1FeatureOnlineStore.
13598 13599 13600 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13598 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bigtable ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStoreBigtable
Contains settings for the Cloud Bigtable instance that will be created to
serve featureValues for all FeatureViews under this FeatureOnlineStore.
Corresponds to the JSON property bigtable
13527 13528 13529 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13527 def bigtable @bigtable end |
#create_time ⇒ String
Output only. Timestamp when this FeatureOnlineStore was created.
Corresponds to the JSON property createTime
13532 13533 13534 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13532 def create_time @create_time end |
#dedicated_serving_endpoint ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStoreDedicatedServingEndpoint
The dedicated serving endpoint for this FeatureOnlineStore. Only need to set
when you choose Optimized storage type. Public endpoint is provisioned by
default.
Corresponds to the JSON property dedicatedServingEndpoint
13539 13540 13541 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13539 def dedicated_serving_endpoint @dedicated_serving_endpoint end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied
to a Vertex AI resource.
Corresponds to the JSON property encryptionSpec
13545 13546 13547 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13545 def encryption_spec @encryption_spec end |
#etag ⇒ String
Optional. Used to perform consistent read-modify-write updates. If not set, a
blind "overwrite" update happens.
Corresponds to the JSON property etag
13551 13552 13553 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13551 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. The labels with user-defined metadata to organize your
FeatureOnlineStore. Label keys and values can be no longer than 64 characters (
Unicode codepoints), can only contain lowercase letters, numeric characters,
underscores and dashes. International characters are allowed. See https://goo.
gl/xmQnxf for more information on and examples of labels. No more than 64 user
labels can be associated with one FeatureOnlineStore(System labels are
excluded)." System reserved label keys are prefixed with "aiplatform.
googleapis.com/" and are immutable.
Corresponds to the JSON property labels
13563 13564 13565 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13563 def labels @labels end |
#name ⇒ String
Identifier. Name of the FeatureOnlineStore. Format: projects/project/
locations/location/featureOnlineStores/featureOnlineStore`
Corresponds to the JSON propertyname`
13569 13570 13571 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13569 def name @name end |
#optimized ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStoreOptimized
Optimized storage type
Corresponds to the JSON property optimized
13574 13575 13576 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13574 def optimized @optimized end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
13579 13580 13581 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13579 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
13585 13586 13587 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13585 def satisfies_pzs @satisfies_pzs end |
#state ⇒ String
Output only. State of the featureOnlineStore.
Corresponds to the JSON property state
13591 13592 13593 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13591 def state @state end |
#update_time ⇒ String
Output only. Timestamp when this FeatureOnlineStore was last updated.
Corresponds to the JSON property updateTime
13596 13597 13598 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13596 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13603 13604 13605 13606 13607 13608 13609 13610 13611 13612 13613 13614 13615 13616 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13603 def update!(**args) @bigtable = args[:bigtable] if args.key?(:bigtable) @create_time = args[:create_time] if args.key?(:create_time) @dedicated_serving_endpoint = args[:dedicated_serving_endpoint] if args.key?(:dedicated_serving_endpoint) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @optimized = args[:optimized] if args.key?(:optimized) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |