Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStore
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStore
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Vertex AI Feature Online Store provides a centralized repository for serving ML features and embedding indexes at low latency. The Feature Online Store is a top-level container.
Instance Attribute Summary collapse
-
#bigtable ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStoreBigtable
Contains settings for the Cloud Bigtable instance that will be created to serve featureValues for all FeatureViews under this FeatureOnlineStore.
-
#create_time ⇒ String
Output only.
-
#dedicated_serving_endpoint ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStoreDedicatedServingEndpoint
The dedicated serving endpoint for this FeatureOnlineStore.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top- level resource.
-
#etag ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#optimized ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStoreOptimized
Optimized storage type Corresponds to the JSON property
optimized. -
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureOnlineStore
constructor
A new instance of GoogleCloudAiplatformV1FeatureOnlineStore.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureOnlineStore
Returns a new instance of GoogleCloudAiplatformV1FeatureOnlineStore.
10391 10392 10393 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10391 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bigtable ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStoreBigtable
Contains settings for the Cloud Bigtable instance that will be created to
serve featureValues for all FeatureViews under this FeatureOnlineStore.
Corresponds to the JSON property bigtable
10320 10321 10322 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10320 def bigtable @bigtable end |
#create_time ⇒ String
Output only. Timestamp when this FeatureOnlineStore was created.
Corresponds to the JSON property createTime
10325 10326 10327 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10325 def create_time @create_time end |
#dedicated_serving_endpoint ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStoreDedicatedServingEndpoint
The dedicated serving endpoint for this FeatureOnlineStore. Only need to set
when you choose Optimized storage type. Public endpoint is provisioned by
default.
Corresponds to the JSON property dedicatedServingEndpoint
10332 10333 10334 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10332 def dedicated_serving_endpoint @dedicated_serving_endpoint end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top-
level resource.
Corresponds to the JSON property encryptionSpec
10338 10339 10340 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10338 def encryption_spec @encryption_spec end |
#etag ⇒ String
Optional. Used to perform consistent read-modify-write updates. If not set, a
blind "overwrite" update happens.
Corresponds to the JSON property etag
10344 10345 10346 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10344 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. The labels with user-defined metadata to organize your
FeatureOnlineStore. Label keys and values can be no longer than 64 characters (
Unicode codepoints), can only contain lowercase letters, numeric characters,
underscores and dashes. International characters are allowed. See https://goo.
gl/xmQnxf for more information on and examples of labels. No more than 64 user
labels can be associated with one FeatureOnlineStore(System labels are
excluded)." System reserved label keys are prefixed with "aiplatform.
googleapis.com/" and are immutable.
Corresponds to the JSON property labels
10356 10357 10358 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10356 def labels @labels end |
#name ⇒ String
Identifier. Name of the FeatureOnlineStore. Format: projects/project/
locations/location/featureOnlineStores/featureOnlineStore`
Corresponds to the JSON propertyname`
10362 10363 10364 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10362 def name @name end |
#optimized ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStoreOptimized
Optimized storage type
Corresponds to the JSON property optimized
10367 10368 10369 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10367 def optimized @optimized end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
10372 10373 10374 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10372 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
10378 10379 10380 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10378 def satisfies_pzs @satisfies_pzs end |
#state ⇒ String
Output only. State of the featureOnlineStore.
Corresponds to the JSON property state
10384 10385 10386 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10384 def state @state end |
#update_time ⇒ String
Output only. Timestamp when this FeatureOnlineStore was last updated.
Corresponds to the JSON property updateTime
10389 10390 10391 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10389 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10396 10397 10398 10399 10400 10401 10402 10403 10404 10405 10406 10407 10408 10409 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10396 def update!(**args) @bigtable = args[:bigtable] if args.key?(:bigtable) @create_time = args[:create_time] if args.key?(:create_time) @dedicated_serving_endpoint = args[:dedicated_serving_endpoint] if args.key?(:dedicated_serving_endpoint) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @optimized = args[:optimized] if args.key?(:optimized) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |