Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStore
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStore
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Vertex AI Feature Online Store provides a centralized repository for serving ML features and embedding indexes at low latency. The Feature Online Store is a top-level container.
Instance Attribute Summary collapse
-
#bigtable ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStoreBigtable
Contains settings for the Cloud Bigtable instance that will be created to serve featureValues for all FeatureViews under this FeatureOnlineStore.
-
#create_time ⇒ String
Output only.
-
#dedicated_serving_endpoint ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStoreDedicatedServingEndpoint
The dedicated serving endpoint for this FeatureOnlineStore.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top- level resource.
-
#etag ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#optimized ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStoreOptimized
Optimized storage type Corresponds to the JSON property
optimized. -
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureOnlineStore
constructor
A new instance of GoogleCloudAiplatformV1FeatureOnlineStore.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureOnlineStore
Returns a new instance of GoogleCloudAiplatformV1FeatureOnlineStore.
9590 9591 9592 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9590 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bigtable ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStoreBigtable
Contains settings for the Cloud Bigtable instance that will be created to
serve featureValues for all FeatureViews under this FeatureOnlineStore.
Corresponds to the JSON property bigtable
9519 9520 9521 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9519 def bigtable @bigtable end |
#create_time ⇒ String
Output only. Timestamp when this FeatureOnlineStore was created.
Corresponds to the JSON property createTime
9524 9525 9526 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9524 def create_time @create_time end |
#dedicated_serving_endpoint ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStoreDedicatedServingEndpoint
The dedicated serving endpoint for this FeatureOnlineStore. Only need to set
when you choose Optimized storage type. Public endpoint is provisioned by
default.
Corresponds to the JSON property dedicatedServingEndpoint
9531 9532 9533 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9531 def dedicated_serving_endpoint @dedicated_serving_endpoint end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top-
level resource.
Corresponds to the JSON property encryptionSpec
9537 9538 9539 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9537 def encryption_spec @encryption_spec end |
#etag ⇒ String
Optional. Used to perform consistent read-modify-write updates. If not set, a
blind "overwrite" update happens.
Corresponds to the JSON property etag
9543 9544 9545 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9543 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. The labels with user-defined metadata to organize your
FeatureOnlineStore. Label keys and values can be no longer than 64 characters (
Unicode codepoints), can only contain lowercase letters, numeric characters,
underscores and dashes. International characters are allowed. See https://goo.
gl/xmQnxf for more information on and examples of labels. No more than 64 user
labels can be associated with one FeatureOnlineStore(System labels are
excluded)." System reserved label keys are prefixed with "aiplatform.
googleapis.com/" and are immutable.
Corresponds to the JSON property labels
9555 9556 9557 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9555 def labels @labels end |
#name ⇒ String
Identifier. Name of the FeatureOnlineStore. Format: projects/project/
locations/location/featureOnlineStores/featureOnlineStore`
Corresponds to the JSON propertyname`
9561 9562 9563 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9561 def name @name end |
#optimized ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStoreOptimized
Optimized storage type
Corresponds to the JSON property optimized
9566 9567 9568 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9566 def optimized @optimized end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
9571 9572 9573 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9571 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
9577 9578 9579 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9577 def satisfies_pzs @satisfies_pzs end |
#state ⇒ String
Output only. State of the featureOnlineStore.
Corresponds to the JSON property state
9583 9584 9585 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9583 def state @state end |
#update_time ⇒ String
Output only. Timestamp when this FeatureOnlineStore was last updated.
Corresponds to the JSON property updateTime
9588 9589 9590 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9588 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9595 9596 9597 9598 9599 9600 9601 9602 9603 9604 9605 9606 9607 9608 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9595 def update!(**args) @bigtable = args[:bigtable] if args.key?(:bigtable) @create_time = args[:create_time] if args.key?(:create_time) @dedicated_serving_endpoint = args[:dedicated_serving_endpoint] if args.key?(:dedicated_serving_endpoint) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @optimized = args[:optimized] if args.key?(:optimized) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |