Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStore
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStore
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Vertex AI Feature Online Store provides a centralized repository for serving ML features and embedding indexes at low latency. The Feature Online Store is a top-level container.
Instance Attribute Summary collapse
-
#bigtable ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStoreBigtable
Contains settings for the Cloud Bigtable instance that will be created to serve featureValues for all FeatureViews under this FeatureOnlineStore.
-
#create_time ⇒ String
Output only.
-
#etag ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureOnlineStore
constructor
A new instance of GoogleCloudAiplatformV1FeatureOnlineStore.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureOnlineStore
Returns a new instance of GoogleCloudAiplatformV1FeatureOnlineStore.
8202 8203 8204 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8202 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bigtable ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStoreBigtable
Contains settings for the Cloud Bigtable instance that will be created to
serve featureValues for all FeatureViews under this FeatureOnlineStore.
Corresponds to the JSON property bigtable
8161 8162 8163 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8161 def bigtable @bigtable end |
#create_time ⇒ String
Output only. Timestamp when this FeatureOnlineStore was created.
Corresponds to the JSON property createTime
8166 8167 8168 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8166 def create_time @create_time end |
#etag ⇒ String
Optional. Used to perform consistent read-modify-write updates. If not set, a
blind "overwrite" update happens.
Corresponds to the JSON property etag
8172 8173 8174 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8172 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. The labels with user-defined metadata to organize your
FeatureOnlineStore. Label keys and values can be no longer than 64 characters (
Unicode codepoints), can only contain lowercase letters, numeric characters,
underscores and dashes. International characters are allowed. See https://goo.
gl/xmQnxf for more information on and examples of labels. No more than 64 user
labels can be associated with one FeatureOnlineStore(System labels are
excluded)." System reserved label keys are prefixed with "aiplatform.
googleapis.com/" and are immutable.
Corresponds to the JSON property labels
8184 8185 8186 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8184 def labels @labels end |
#name ⇒ String
Identifier. Name of the FeatureOnlineStore. Format: projects/project/
locations/location/featureOnlineStores/featureOnlineStore`
Corresponds to the JSON propertyname`
8190 8191 8192 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8190 def name @name end |
#state ⇒ String
Output only. State of the featureOnlineStore.
Corresponds to the JSON property state
8195 8196 8197 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8195 def state @state end |
#update_time ⇒ String
Output only. Timestamp when this FeatureOnlineStore was last updated.
Corresponds to the JSON property updateTime
8200 8201 8202 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8200 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8207 8208 8209 8210 8211 8212 8213 8214 8215 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8207 def update!(**args) @bigtable = args[:bigtable] if args.key?(:bigtable) @create_time = args[:create_time] if args.key?(:create_time) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |