Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStoreBigtable
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStoreBigtable
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Instance Attribute Summary collapse
-
#auto_scaling ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStoreBigtableAutoScaling
Required.
-
#bigtable_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStoreBigtableBigtableMetadata
Metadata of the Bigtable instance.
-
#enable_direct_bigtable_access ⇒ Boolean
(also: #enable_direct_bigtable_access?)
Optional.
-
#zone ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureOnlineStoreBigtable
constructor
A new instance of GoogleCloudAiplatformV1FeatureOnlineStoreBigtable.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureOnlineStoreBigtable
Returns a new instance of GoogleCloudAiplatformV1FeatureOnlineStoreBigtable.
13439 13440 13441 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13439 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_scaling ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStoreBigtableAutoScaling
Required. Autoscaling config applied to Bigtable Instance.
Corresponds to the JSON property autoScaling
13418 13419 13420 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13418 def auto_scaling @auto_scaling end |
#bigtable_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStoreBigtableBigtableMetadata
Metadata of the Bigtable instance. This is used by direct read access to the
Bigtable in tenant project.
Corresponds to the JSON property bigtableMetadata
13424 13425 13426 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13424 def @bigtable_metadata end |
#enable_direct_bigtable_access ⇒ Boolean Also known as: enable_direct_bigtable_access?
Optional. It true, enable direct access to the Bigtable instance.
Corresponds to the JSON property enableDirectBigtableAccess
13429 13430 13431 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13429 def enable_direct_bigtable_access @enable_direct_bigtable_access end |
#zone ⇒ String
Optional. The zone where the underlying Bigtable cluster for the primary
Bigtable instance will be provisioned. Only the zone must be provided. For
example, only "us-central1-a" should be provided.
Corresponds to the JSON property zone
13437 13438 13439 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13437 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13444 13445 13446 13447 13448 13449 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13444 def update!(**args) @auto_scaling = args[:auto_scaling] if args.key?(:auto_scaling) @bigtable_metadata = args[:bigtable_metadata] if args.key?(:bigtable_metadata) @enable_direct_bigtable_access = args[:enable_direct_bigtable_access] if args.key?(:enable_direct_bigtable_access) @zone = args[:zone] if args.key?(:zone) end |