Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStoreBigtable

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureOnlineStoreBigtable

Returns a new instance of GoogleCloudAiplatformV1FeatureOnlineStoreBigtable.



12724
12725
12726
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12724

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_scalingGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStoreBigtableAutoScaling

Required. Autoscaling config applied to Bigtable Instance. Corresponds to the JSON property autoScaling



12703
12704
12705
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12703

def auto_scaling
  @auto_scaling
end

#bigtable_metadataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStoreBigtableBigtableMetadata

Metadata of the Bigtable instance. This is used by direct read access to the Bigtable in tenant project. Corresponds to the JSON property bigtableMetadata



12709
12710
12711
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12709

def 
  @bigtable_metadata
end

#enable_direct_bigtable_accessBoolean Also known as: enable_direct_bigtable_access?

Optional. It true, enable direct access to the Bigtable instance. Corresponds to the JSON property enableDirectBigtableAccess

Returns:

  • (Boolean)


12714
12715
12716
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12714

def enable_direct_bigtable_access
  @enable_direct_bigtable_access
end

#zoneString

Optional. The zone where the underlying Bigtable cluster for the primary Bigtable instance will be provisioned. Only the zone must be provided. For example, only "us-central1-a" should be provided. Corresponds to the JSON property zone

Returns:

  • (String)


12722
12723
12724
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12722

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12729
12730
12731
12732
12733
12734
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12729

def update!(**args)
  @auto_scaling = args[:auto_scaling] if args.key?(:auto_scaling)
  @bigtable_metadata = args[:bigtable_metadata] if args.key?(:bigtable_metadata)
  @enable_direct_bigtable_access = args[:enable_direct_bigtable_access] if args.key?(:enable_direct_bigtable_access)
  @zone = args[:zone] if args.key?(:zone)
end