Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStoreBigtableAutoScaling

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureOnlineStoreBigtableAutoScaling

Returns a new instance of GoogleCloudAiplatformV1FeatureOnlineStoreBigtableAutoScaling.



14614
14615
14616
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14614

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cpu_utilization_targetFixnum

Optional. A percentage of the cluster's CPU capacity. Can be from 10% to 80%. When a cluster's CPU utilization exceeds the target that you have set, Bigtable immediately adds nodes to the cluster. When CPU utilization is substantially lower than the target, Bigtable removes nodes. If not set will default to 50%. Corresponds to the JSON property cpuUtilizationTarget

Returns:

  • (Fixnum)


14599
14600
14601
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14599

def cpu_utilization_target
  @cpu_utilization_target
end

#max_node_countFixnum

Required. The maximum number of nodes to scale up to. Must be greater than or equal to min_node_count, and less than or equal to 10 times of 'min_node_count' . Corresponds to the JSON property maxNodeCount

Returns:

  • (Fixnum)


14606
14607
14608
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14606

def max_node_count
  @max_node_count
end

#min_node_countFixnum

Required. The minimum number of nodes to scale down to. Must be greater than or equal to 1. Corresponds to the JSON property minNodeCount

Returns:

  • (Fixnum)


14612
14613
14614
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14612

def min_node_count
  @min_node_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14619
14620
14621
14622
14623
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14619

def update!(**args)
  @cpu_utilization_target = args[:cpu_utilization_target] if args.key?(:cpu_utilization_target)
  @max_node_count = args[:max_node_count] if args.key?(:max_node_count)
  @min_node_count = args[:min_node_count] if args.key?(:min_node_count)
end