Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStoreBigtableAutoScaling
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStoreBigtableAutoScaling
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Instance Attribute Summary collapse
-
#cpu_utilization_target ⇒ Fixnum
Optional.
-
#max_node_count ⇒ Fixnum
Required.
-
#min_node_count ⇒ Fixnum
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureOnlineStoreBigtableAutoScaling
constructor
A new instance of GoogleCloudAiplatformV1FeatureOnlineStoreBigtableAutoScaling.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureOnlineStoreBigtableAutoScaling
Returns a new instance of GoogleCloudAiplatformV1FeatureOnlineStoreBigtableAutoScaling.
10169 10170 10171 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10169 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cpu_utilization_target ⇒ Fixnum
Optional. A percentage of the cluster's CPU capacity. Can be from 10% to 80%.
When a cluster's CPU utilization exceeds the target that you have set,
Bigtable immediately adds nodes to the cluster. When CPU utilization is
substantially lower than the target, Bigtable removes nodes. If not set will
default to 50%.
Corresponds to the JSON property cpuUtilizationTarget
10154 10155 10156 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10154 def cpu_utilization_target @cpu_utilization_target end |
#max_node_count ⇒ Fixnum
Required. The maximum number of nodes to scale up to. Must be greater than or
equal to min_node_count, and less than or equal to 10 times of 'min_node_count'
.
Corresponds to the JSON property maxNodeCount
10161 10162 10163 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10161 def max_node_count @max_node_count end |
#min_node_count ⇒ Fixnum
Required. The minimum number of nodes to scale down to. Must be greater than
or equal to 1.
Corresponds to the JSON property minNodeCount
10167 10168 10169 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10167 def min_node_count @min_node_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10174 10175 10176 10177 10178 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10174 def update!(**args) @cpu_utilization_target = args[:cpu_utilization_target] if args.key?(:cpu_utilization_target) @max_node_count = args[:max_node_count] if args.key?(:max_node_count) @min_node_count = args[:min_node_count] if args.key?(:min_node_count) end |