Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStoreDedicatedServingEndpoint
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStoreDedicatedServingEndpoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The dedicated serving endpoint for this FeatureOnlineStore. Only need to set when you choose Optimized storage type. Public endpoint is provisioned by default.
Instance Attribute Summary collapse
-
#private_service_connect_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PrivateServiceConnectConfig
Represents configuration for private service connect.
-
#public_endpoint_domain_name ⇒ String
Output only.
-
#service_attachment ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureOnlineStoreDedicatedServingEndpoint
constructor
A new instance of GoogleCloudAiplatformV1FeatureOnlineStoreDedicatedServingEndpoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureOnlineStoreDedicatedServingEndpoint
Returns a new instance of GoogleCloudAiplatformV1FeatureOnlineStoreDedicatedServingEndpoint.
15073 15074 15075 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15073 def initialize(**args) update!(**args) end |
Instance Attribute Details
#private_service_connect_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PrivateServiceConnectConfig
Represents configuration for private service connect.
Corresponds to the JSON property privateServiceConnectConfig
15059 15060 15061 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15059 def private_service_connect_config @private_service_connect_config end |
#public_endpoint_domain_name ⇒ String
Output only. This field will be populated with the domain name to use for this
FeatureOnlineStore
Corresponds to the JSON property publicEndpointDomainName
15065 15066 15067 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15065 def public_endpoint_domain_name @public_endpoint_domain_name end |
#service_attachment ⇒ String
Output only. The name of the service attachment resource. Populated if private
service connect is enabled and after FeatureViewSync is created.
Corresponds to the JSON property serviceAttachment
15071 15072 15073 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15071 def @service_attachment end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15078 15079 15080 15081 15082 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15078 def update!(**args) @private_service_connect_config = args[:private_service_connect_config] if args.key?(:private_service_connect_config) @public_endpoint_domain_name = args[:public_endpoint_domain_name] if args.key?(:public_endpoint_domain_name) @service_attachment = args[:service_attachment] if args.key?(:service_attachment) end |