Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStoreDedicatedServingEndpoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The dedicated serving endpoint for this FeatureOnlineStore. Only need to set when you choose Optimized storage type. Public endpoint is provisioned by default.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureOnlineStoreDedicatedServingEndpoint

Returns a new instance of GoogleCloudAiplatformV1FeatureOnlineStoreDedicatedServingEndpoint.



12629
12630
12631
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12629

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#private_service_connect_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PrivateServiceConnectConfig

Represents configuration for private service connect. Corresponds to the JSON property privateServiceConnectConfig



12615
12616
12617
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12615

def private_service_connect_config
  @private_service_connect_config
end

#public_endpoint_domain_nameString

Output only. This field will be populated with the domain name to use for this FeatureOnlineStore Corresponds to the JSON property publicEndpointDomainName

Returns:

  • (String)


12621
12622
12623
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12621

def public_endpoint_domain_name
  @public_endpoint_domain_name
end

#service_attachmentString

Output only. The name of the service attachment resource. Populated if private service connect is enabled and after FeatureViewSync is created. Corresponds to the JSON property serviceAttachment

Returns:

  • (String)


12627
12628
12629
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12627

def service_attachment
  @service_attachment
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12634
12635
12636
12637
12638
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12634

def update!(**args)
  @private_service_connect_config = args[:private_service_connect_config] if args.key?(:private_service_connect_config)
  @public_endpoint_domain_name = args[:public_endpoint_domain_name] if args.key?(:public_endpoint_domain_name)
  @service_attachment = args[:service_attachment] if args.key?(:service_attachment)
end