Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStoreDedicatedServingEndpoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The dedicated serving endpoint for this FeatureOnlineStore. Only need to set when you choose Optimized storage type. Public endpoint is provisioned by default.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureOnlineStoreDedicatedServingEndpoint

Returns a new instance of GoogleCloudAiplatformV1FeatureOnlineStoreDedicatedServingEndpoint.



8620
8621
8622
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8620

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#private_service_connect_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PrivateServiceConnectConfig

Represents configuration for private service connect. Corresponds to the JSON property privateServiceConnectConfig



8606
8607
8608
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8606

def private_service_connect_config
  @private_service_connect_config
end

#public_endpoint_domain_nameString

Output only. This field will be populated with the domain name to use for this FeatureOnlineStore Corresponds to the JSON property publicEndpointDomainName

Returns:

  • (String)


8612
8613
8614
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8612

def public_endpoint_domain_name
  @public_endpoint_domain_name
end

#service_attachmentString

Output only. The name of the service attachment resource. Populated if private service connect is enabled and after FeatureViewSync is created. Corresponds to the JSON property serviceAttachment

Returns:

  • (String)


8618
8619
8620
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8618

def service_attachment
  @service_attachment
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8625
8626
8627
8628
8629
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8625

def update!(**args)
  @private_service_connect_config = args[:private_service_connect_config] if args.key?(:private_service_connect_config)
  @public_endpoint_domain_name = args[:public_endpoint_domain_name] if args.key?(:public_endpoint_domain_name)
  @service_attachment = args[:service_attachment] if args.key?(:service_attachment)
end