Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureOnlineStoreDedicatedServingEndpoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The dedicated serving endpoint for this FeatureOnlineStore. Only need to set when you choose Optimized storage type. Public endpoint is provisioned by default.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureOnlineStoreDedicatedServingEndpoint

Returns a new instance of GoogleCloudAiplatformV1FeatureOnlineStoreDedicatedServingEndpoint.



7459
7460
7461
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7459

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#public_endpoint_domain_nameString

Output only. This field will be populated with the domain name to use for this FeatureOnlineStore Corresponds to the JSON property publicEndpointDomainName

Returns:

  • (String)


7457
7458
7459
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7457

def public_endpoint_domain_name
  @public_endpoint_domain_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7464
7465
7466
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 7464

def update!(**args)
  @public_endpoint_domain_name = args[:public_endpoint_domain_name] if args.key?(:public_endpoint_domain_name)
end