Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureValueMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureValueMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Metadata of feature value.
Instance Attribute Summary collapse
-
#generate_time ⇒ String
Feature generation timestamp.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureValueMetadata
constructor
A new instance of GoogleCloudAiplatformV1FeatureValueMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureValueMetadata
Returns a new instance of GoogleCloudAiplatformV1FeatureValueMetadata.
10827 10828 10829 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10827 def initialize(**args) update!(**args) end |
Instance Attribute Details
#generate_time ⇒ String
Feature generation timestamp. Typically, it is provided by user at feature
ingestion time. If not, feature store will use the system timestamp when the
data is ingested into feature store. Legacy Feature Store: For streaming
ingestion, the time, aligned by days, must be no older than five years (1825
days) and no later than one year (366 days) in the future.
Corresponds to the JSON property generateTime
10825 10826 10827 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10825 def generate_time @generate_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10832 10833 10834 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10832 def update!(**args) @generate_time = args[:generate_time] if args.key?(:generate_time) end |