Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureValueMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Metadata of feature value.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureValueMetadata

Returns a new instance of GoogleCloudAiplatformV1FeatureValueMetadata.



8664
8665
8666
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8664

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#generate_timeString

Feature generation timestamp. Typically, it is provided by user at feature ingestion time. If not, feature store will use the system timestamp when the data is ingested into feature store. For streaming ingestion, the time, aligned by days, must be no older than five years (1825 days) and no later than one year (366 days) in the future. Corresponds to the JSON property generateTime

Returns:

  • (String)


8662
8663
8664
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8662

def generate_time
  @generate_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8669
8670
8671
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8669

def update!(**args)
  @generate_time = args[:generate_time] if args.key?(:generate_time)
end