Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureView
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
FeatureView is representation of values that the FeatureOnlineStore will serve based on its syncConfig.
Instance Attribute Summary collapse
-
#big_query_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewBigQuerySource
Optional.
-
#bigtable_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewBigtableMetadata
Metadata for the Cloud Bigtable that supports directly interacting Bigtable instances.
-
#create_time ⇒ String
Output only.
-
#etag ⇒ String
Optional.
-
#feature_registry_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewFeatureRegistrySource
A Feature Registry source for features that need to be synced to Online Store.
-
#index_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewIndexConfig
Configuration for vector indexing.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#optimized_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewOptimizedConfig
Configuration for FeatureViews created in Optimized FeatureOnlineStore.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#service_account_email ⇒ String
Output only.
-
#service_agent_type ⇒ String
Optional.
-
#sync_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewSyncConfig
Configuration for Sync.
-
#update_time ⇒ String
Output only.
-
#vertex_rag_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewVertexRagSource
A Vertex Rag source for features that need to be synced to Online Store.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureView
constructor
A new instance of GoogleCloudAiplatformV1FeatureView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureView
Returns a new instance of GoogleCloudAiplatformV1FeatureView.
15067 15068 15069 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15067 def initialize(**args) update!(**args) end |
Instance Attribute Details
#big_query_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewBigQuerySource
Optional. Configures how data is supposed to be extracted from a BigQuery
source to be loaded onto the FeatureOnlineStore.
Corresponds to the JSON property bigQuerySource
14971 14972 14973 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14971 def big_query_source @big_query_source end |
#bigtable_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewBigtableMetadata
Metadata for the Cloud Bigtable that supports directly interacting Bigtable
instances.
Corresponds to the JSON property bigtableMetadata
14977 14978 14979 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14977 def @bigtable_metadata end |
#create_time ⇒ String
Output only. Timestamp when this FeatureView was created.
Corresponds to the JSON property createTime
14982 14983 14984 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14982 def create_time @create_time end |
#etag ⇒ String
Optional. Used to perform consistent read-modify-write updates. If not set, a
blind "overwrite" update happens.
Corresponds to the JSON property etag
14988 14989 14990 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14988 def etag @etag end |
#feature_registry_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewFeatureRegistrySource
A Feature Registry source for features that need to be synced to Online Store.
Corresponds to the JSON property featureRegistrySource
14993 14994 14995 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14993 def feature_registry_source @feature_registry_source end |
#index_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewIndexConfig
Configuration for vector indexing.
Corresponds to the JSON property indexConfig
14998 14999 15000 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14998 def index_config @index_config end |
#labels ⇒ Hash<String,String>
Optional. The labels with user-defined metadata to organize your FeatureViews.
Label keys and values can be no longer than 64 characters (Unicode codepoints),
can only contain lowercase letters, numeric characters, underscores and
dashes. International characters are allowed. See https://goo.gl/xmQnxf for
more information on and examples of labels. No more than 64 user labels can be
associated with one FeatureOnlineStore(System labels are excluded)." System
reserved label keys are prefixed with "aiplatform.googleapis.com/" and are
immutable.
Corresponds to the JSON property labels
15010 15011 15012 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15010 def labels @labels end |
#name ⇒ String
Identifier. Name of the FeatureView. Format: projects/project/locations/
location/featureOnlineStores/feature_online_store/featureViews/
feature_view`
Corresponds to the JSON propertyname`
15017 15018 15019 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15017 def name @name end |
#optimized_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewOptimizedConfig
Configuration for FeatureViews created in Optimized FeatureOnlineStore.
Corresponds to the JSON property optimizedConfig
15022 15023 15024 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15022 def optimized_config @optimized_config end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
15027 15028 15029 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15027 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
15033 15034 15035 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15033 def satisfies_pzs @satisfies_pzs end |
#service_account_email ⇒ String
Output only. A Service Account unique to this FeatureView. The role bigquery.
dataViewer should be granted to this service account to allow Vertex AI
Feature Store to sync data to the online store.
Corresponds to the JSON property serviceAccountEmail
15041 15042 15043 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15041 def service_account_email @service_account_email end |
#service_agent_type ⇒ String
Optional. Service agent type used during data sync. By default, the Vertex AI
Service Agent is used. When using an IAM Policy to isolate this FeatureView
within a project, a separate service account should be provisioned by setting
this field to SERVICE_AGENT_TYPE_FEATURE_VIEW. This will generate a separate
service account to access the BigQuery source table.
Corresponds to the JSON property serviceAgentType
15050 15051 15052 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15050 def service_agent_type @service_agent_type end |
#sync_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewSyncConfig
Configuration for Sync. Only one option is set.
Corresponds to the JSON property syncConfig
15055 15056 15057 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15055 def sync_config @sync_config end |
#update_time ⇒ String
Output only. Timestamp when this FeatureView was last updated.
Corresponds to the JSON property updateTime
15060 15061 15062 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15060 def update_time @update_time end |
#vertex_rag_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewVertexRagSource
A Vertex Rag source for features that need to be synced to Online Store.
Corresponds to the JSON property vertexRagSource
15065 15066 15067 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15065 def vertex_rag_source @vertex_rag_source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15072 15073 15074 15075 15076 15077 15078 15079 15080 15081 15082 15083 15084 15085 15086 15087 15088 15089 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15072 def update!(**args) @big_query_source = args[:big_query_source] if args.key?(:big_query_source) @bigtable_metadata = args[:bigtable_metadata] if args.key?(:bigtable_metadata) @create_time = args[:create_time] if args.key?(:create_time) @etag = args[:etag] if args.key?(:etag) @feature_registry_source = args[:feature_registry_source] if args.key?(:feature_registry_source) @index_config = args[:index_config] if args.key?(:index_config) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @optimized_config = args[:optimized_config] if args.key?(:optimized_config) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @service_account_email = args[:service_account_email] if args.key?(:service_account_email) @service_agent_type = args[:service_agent_type] if args.key?(:service_agent_type) @sync_config = args[:sync_config] if args.key?(:sync_config) @update_time = args[:update_time] if args.key?(:update_time) @vertex_rag_source = args[:vertex_rag_source] if args.key?(:vertex_rag_source) end |