Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureView
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
FeatureView is representation of values that the FeatureOnlineStore will serve based on its syncConfig.
Instance Attribute Summary collapse
-
#big_query_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewBigQuerySource
Optional.
-
#bigtable_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewBigtableMetadata
Metadata for the Cloud Bigtable that supports directly interacting Bigtable instances.
-
#create_time ⇒ String
Output only.
-
#etag ⇒ String
Optional.
-
#feature_registry_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewFeatureRegistrySource
A Feature Registry source for features that need to be synced to Online Store.
-
#index_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewIndexConfig
Configuration for vector indexing.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#optimized_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewOptimizedConfig
Configuration for FeatureViews created in Optimized FeatureOnlineStore.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#service_account_email ⇒ String
Output only.
-
#service_agent_type ⇒ String
Optional.
-
#sync_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewSyncConfig
Configuration for Sync.
-
#update_time ⇒ String
Output only.
-
#vertex_rag_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewVertexRagSource
A Vertex Rag source for features that need to be synced to Online Store.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureView
constructor
A new instance of GoogleCloudAiplatformV1FeatureView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureView
Returns a new instance of GoogleCloudAiplatformV1FeatureView.
13978 13979 13980 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13978 def initialize(**args) update!(**args) end |
Instance Attribute Details
#big_query_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewBigQuerySource
Optional. Configures how data is supposed to be extracted from a BigQuery
source to be loaded onto the FeatureOnlineStore.
Corresponds to the JSON property bigQuerySource
13882 13883 13884 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13882 def big_query_source @big_query_source end |
#bigtable_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewBigtableMetadata
Metadata for the Cloud Bigtable that supports directly interacting Bigtable
instances.
Corresponds to the JSON property bigtableMetadata
13888 13889 13890 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13888 def @bigtable_metadata end |
#create_time ⇒ String
Output only. Timestamp when this FeatureView was created.
Corresponds to the JSON property createTime
13893 13894 13895 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13893 def create_time @create_time end |
#etag ⇒ String
Optional. Used to perform consistent read-modify-write updates. If not set, a
blind "overwrite" update happens.
Corresponds to the JSON property etag
13899 13900 13901 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13899 def etag @etag end |
#feature_registry_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewFeatureRegistrySource
A Feature Registry source for features that need to be synced to Online Store.
Corresponds to the JSON property featureRegistrySource
13904 13905 13906 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13904 def feature_registry_source @feature_registry_source end |
#index_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewIndexConfig
Configuration for vector indexing.
Corresponds to the JSON property indexConfig
13909 13910 13911 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13909 def index_config @index_config end |
#labels ⇒ Hash<String,String>
Optional. The labels with user-defined metadata to organize your FeatureViews.
Label keys and values can be no longer than 64 characters (Unicode codepoints),
can only contain lowercase letters, numeric characters, underscores and
dashes. International characters are allowed. See https://goo.gl/xmQnxf for
more information on and examples of labels. No more than 64 user labels can be
associated with one FeatureOnlineStore(System labels are excluded)." System
reserved label keys are prefixed with "aiplatform.googleapis.com/" and are
immutable.
Corresponds to the JSON property labels
13921 13922 13923 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13921 def labels @labels end |
#name ⇒ String
Identifier. Name of the FeatureView. Format: projects/project/locations/
location/featureOnlineStores/feature_online_store/featureViews/
feature_view`
Corresponds to the JSON propertyname`
13928 13929 13930 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13928 def name @name end |
#optimized_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewOptimizedConfig
Configuration for FeatureViews created in Optimized FeatureOnlineStore.
Corresponds to the JSON property optimizedConfig
13933 13934 13935 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13933 def optimized_config @optimized_config end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
13938 13939 13940 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13938 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
13944 13945 13946 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13944 def satisfies_pzs @satisfies_pzs end |
#service_account_email ⇒ String
Output only. A Service Account unique to this FeatureView. The role bigquery.
dataViewer should be granted to this service account to allow Vertex AI
Feature Store to sync data to the online store.
Corresponds to the JSON property serviceAccountEmail
13952 13953 13954 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13952 def service_account_email @service_account_email end |
#service_agent_type ⇒ String
Optional. Service agent type used during data sync. By default, the Vertex AI
Service Agent is used. When using an IAM Policy to isolate this FeatureView
within a project, a separate service account should be provisioned by setting
this field to SERVICE_AGENT_TYPE_FEATURE_VIEW. This will generate a separate
service account to access the BigQuery source table.
Corresponds to the JSON property serviceAgentType
13961 13962 13963 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13961 def service_agent_type @service_agent_type end |
#sync_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewSyncConfig
Configuration for Sync. Only one option is set.
Corresponds to the JSON property syncConfig
13966 13967 13968 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13966 def sync_config @sync_config end |
#update_time ⇒ String
Output only. Timestamp when this FeatureView was last updated.
Corresponds to the JSON property updateTime
13971 13972 13973 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13971 def update_time @update_time end |
#vertex_rag_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewVertexRagSource
A Vertex Rag source for features that need to be synced to Online Store.
Corresponds to the JSON property vertexRagSource
13976 13977 13978 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13976 def vertex_rag_source @vertex_rag_source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13983 13984 13985 13986 13987 13988 13989 13990 13991 13992 13993 13994 13995 13996 13997 13998 13999 14000 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13983 def update!(**args) @big_query_source = args[:big_query_source] if args.key?(:big_query_source) @bigtable_metadata = args[:bigtable_metadata] if args.key?(:bigtable_metadata) @create_time = args[:create_time] if args.key?(:create_time) @etag = args[:etag] if args.key?(:etag) @feature_registry_source = args[:feature_registry_source] if args.key?(:feature_registry_source) @index_config = args[:index_config] if args.key?(:index_config) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @optimized_config = args[:optimized_config] if args.key?(:optimized_config) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @service_account_email = args[:service_account_email] if args.key?(:service_account_email) @service_agent_type = args[:service_agent_type] if args.key?(:service_agent_type) @sync_config = args[:sync_config] if args.key?(:sync_config) @update_time = args[:update_time] if args.key?(:update_time) @vertex_rag_source = args[:vertex_rag_source] if args.key?(:vertex_rag_source) end |