Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureView
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
FeatureView is representation of values that the FeatureOnlineStore will serve based on its syncConfig.
Instance Attribute Summary collapse
-
#big_query_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewBigQuerySource
Optional.
-
#create_time ⇒ String
Output only.
-
#etag ⇒ String
Optional.
-
#feature_registry_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewFeatureRegistrySource
A Feature Registry source for features that need to be synced to Online Store.
-
#index_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewIndexConfig
Configuration for vector indexing.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#optimized_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewOptimizedConfig
Configuration for FeatureViews created in Optimized FeatureOnlineStore.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#service_account_email ⇒ String
Output only.
-
#service_agent_type ⇒ String
Optional.
-
#sync_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewSyncConfig
Configuration for Sync.
-
#update_time ⇒ String
Output only.
-
#vertex_rag_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewVertexRagSource
A Vertex Rag source for features that need to be synced to Online Store.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureView
constructor
A new instance of GoogleCloudAiplatformV1FeatureView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureView
Returns a new instance of GoogleCloudAiplatformV1FeatureView.
10936 10937 10938 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10936 def initialize(**args) update!(**args) end |
Instance Attribute Details
#big_query_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewBigQuerySource
Optional. Configures how data is supposed to be extracted from a BigQuery
source to be loaded onto the FeatureOnlineStore.
Corresponds to the JSON property bigQuerySource
10846 10847 10848 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10846 def big_query_source @big_query_source end |
#create_time ⇒ String
Output only. Timestamp when this FeatureView was created.
Corresponds to the JSON property createTime
10851 10852 10853 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10851 def create_time @create_time end |
#etag ⇒ String
Optional. Used to perform consistent read-modify-write updates. If not set, a
blind "overwrite" update happens.
Corresponds to the JSON property etag
10857 10858 10859 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10857 def etag @etag end |
#feature_registry_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewFeatureRegistrySource
A Feature Registry source for features that need to be synced to Online Store.
Corresponds to the JSON property featureRegistrySource
10862 10863 10864 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10862 def feature_registry_source @feature_registry_source end |
#index_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewIndexConfig
Configuration for vector indexing.
Corresponds to the JSON property indexConfig
10867 10868 10869 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10867 def index_config @index_config end |
#labels ⇒ Hash<String,String>
Optional. The labels with user-defined metadata to organize your FeatureViews.
Label keys and values can be no longer than 64 characters (Unicode codepoints),
can only contain lowercase letters, numeric characters, underscores and
dashes. International characters are allowed. See https://goo.gl/xmQnxf for
more information on and examples of labels. No more than 64 user labels can be
associated with one FeatureOnlineStore(System labels are excluded)." System
reserved label keys are prefixed with "aiplatform.googleapis.com/" and are
immutable.
Corresponds to the JSON property labels
10879 10880 10881 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10879 def labels @labels end |
#name ⇒ String
Identifier. Name of the FeatureView. Format: projects/project/locations/
location/featureOnlineStores/feature_online_store/featureViews/
feature_view`
Corresponds to the JSON propertyname`
10886 10887 10888 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10886 def name @name end |
#optimized_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewOptimizedConfig
Configuration for FeatureViews created in Optimized FeatureOnlineStore.
Corresponds to the JSON property optimizedConfig
10891 10892 10893 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10891 def optimized_config @optimized_config end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
10896 10897 10898 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10896 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
10902 10903 10904 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10902 def satisfies_pzs @satisfies_pzs end |
#service_account_email ⇒ String
Output only. A Service Account unique to this FeatureView. The role bigquery.
dataViewer should be granted to this service account to allow Vertex AI
Feature Store to sync data to the online store.
Corresponds to the JSON property serviceAccountEmail
10910 10911 10912 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10910 def service_account_email @service_account_email end |
#service_agent_type ⇒ String
Optional. Service agent type used during data sync. By default, the Vertex AI
Service Agent is used. When using an IAM Policy to isolate this FeatureView
within a project, a separate service account should be provisioned by setting
this field to SERVICE_AGENT_TYPE_FEATURE_VIEW. This will generate a separate
service account to access the BigQuery source table.
Corresponds to the JSON property serviceAgentType
10919 10920 10921 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10919 def service_agent_type @service_agent_type end |
#sync_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewSyncConfig
Configuration for Sync. Only one option is set.
Corresponds to the JSON property syncConfig
10924 10925 10926 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10924 def sync_config @sync_config end |
#update_time ⇒ String
Output only. Timestamp when this FeatureView was last updated.
Corresponds to the JSON property updateTime
10929 10930 10931 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10929 def update_time @update_time end |
#vertex_rag_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewVertexRagSource
A Vertex Rag source for features that need to be synced to Online Store.
Corresponds to the JSON property vertexRagSource
10934 10935 10936 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10934 def vertex_rag_source @vertex_rag_source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10941 10942 10943 10944 10945 10946 10947 10948 10949 10950 10951 10952 10953 10954 10955 10956 10957 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10941 def update!(**args) @big_query_source = args[:big_query_source] if args.key?(:big_query_source) @create_time = args[:create_time] if args.key?(:create_time) @etag = args[:etag] if args.key?(:etag) @feature_registry_source = args[:feature_registry_source] if args.key?(:feature_registry_source) @index_config = args[:index_config] if args.key?(:index_config) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @optimized_config = args[:optimized_config] if args.key?(:optimized_config) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @service_account_email = args[:service_account_email] if args.key?(:service_account_email) @service_agent_type = args[:service_agent_type] if args.key?(:service_agent_type) @sync_config = args[:sync_config] if args.key?(:sync_config) @update_time = args[:update_time] if args.key?(:update_time) @vertex_rag_source = args[:vertex_rag_source] if args.key?(:vertex_rag_source) end |