Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

FeatureView is representation of values that the FeatureOnlineStore will serve based on its syncConfig.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureView

Returns a new instance of GoogleCloudAiplatformV1FeatureView.



10908
10909
10910
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10908

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#big_query_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewBigQuerySource

Optional. Configures how data is supposed to be extracted from a BigQuery source to be loaded onto the FeatureOnlineStore. Corresponds to the JSON property bigQuerySource



10818
10819
10820
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10818

def big_query_source
  @big_query_source
end

#create_timeString

Output only. Timestamp when this FeatureView was created. Corresponds to the JSON property createTime

Returns:

  • (String)


10823
10824
10825
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10823

def create_time
  @create_time
end

#etagString

Optional. Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


10829
10830
10831
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10829

def etag
  @etag
end

#feature_registry_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewFeatureRegistrySource

A Feature Registry source for features that need to be synced to Online Store. Corresponds to the JSON property featureRegistrySource



10834
10835
10836
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10834

def feature_registry_source
  @feature_registry_source
end

#index_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewIndexConfig

Configuration for vector indexing. Corresponds to the JSON property indexConfig



10839
10840
10841
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10839

def index_config
  @index_config
end

#labelsHash<String,String>

Optional. The labels with user-defined metadata to organize your FeatureViews. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information on and examples of labels. No more than 64 user labels can be associated with one FeatureOnlineStore(System labels are excluded)." System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


10851
10852
10853
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10851

def labels
  @labels
end

#nameString

Identifier. Name of the FeatureView. Format: projects/project/locations/ location/featureOnlineStores/feature_online_store/featureViews/ feature_view` Corresponds to the JSON propertyname`

Returns:

  • (String)


10858
10859
10860
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10858

def name
  @name
end

#optimized_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewOptimizedConfig

Configuration for FeatureViews created in Optimized FeatureOnlineStore. Corresponds to the JSON property optimizedConfig



10863
10864
10865
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10863

def optimized_config
  @optimized_config
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


10868
10869
10870
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10868

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


10874
10875
10876
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10874

def satisfies_pzs
  @satisfies_pzs
end

#service_account_emailString

Output only. A Service Account unique to this FeatureView. The role bigquery. dataViewer should be granted to this service account to allow Vertex AI Feature Store to sync data to the online store. Corresponds to the JSON property serviceAccountEmail

Returns:

  • (String)


10882
10883
10884
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10882

def 
  @service_account_email
end

#service_agent_typeString

Optional. Service agent type used during data sync. By default, the Vertex AI Service Agent is used. When using an IAM Policy to isolate this FeatureView within a project, a separate service account should be provisioned by setting this field to SERVICE_AGENT_TYPE_FEATURE_VIEW. This will generate a separate service account to access the BigQuery source table. Corresponds to the JSON property serviceAgentType

Returns:

  • (String)


10891
10892
10893
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10891

def service_agent_type
  @service_agent_type
end

#sync_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewSyncConfig

Configuration for Sync. Only one option is set. Corresponds to the JSON property syncConfig



10896
10897
10898
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10896

def sync_config
  @sync_config
end

#update_timeString

Output only. Timestamp when this FeatureView was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


10901
10902
10903
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10901

def update_time
  @update_time
end

#vertex_rag_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewVertexRagSource

A Vertex Rag source for features that need to be synced to Online Store. Corresponds to the JSON property vertexRagSource



10906
10907
10908
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10906

def vertex_rag_source
  @vertex_rag_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10913
10914
10915
10916
10917
10918
10919
10920
10921
10922
10923
10924
10925
10926
10927
10928
10929
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10913

def update!(**args)
  @big_query_source = args[:big_query_source] if args.key?(:big_query_source)
  @create_time = args[:create_time] if args.key?(:create_time)
  @etag = args[:etag] if args.key?(:etag)
  @feature_registry_source = args[:feature_registry_source] if args.key?(:feature_registry_source)
  @index_config = args[:index_config] if args.key?(:index_config)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @optimized_config = args[:optimized_config] if args.key?(:optimized_config)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @service_account_email = args[:service_account_email] if args.key?(:service_account_email)
  @service_agent_type = args[:service_agent_type] if args.key?(:service_agent_type)
  @sync_config = args[:sync_config] if args.key?(:sync_config)
  @update_time = args[:update_time] if args.key?(:update_time)
  @vertex_rag_source = args[:vertex_rag_source] if args.key?(:vertex_rag_source)
end