Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureView
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
FeatureView is representation of values that the FeatureOnlineStore will serve based on its syncConfig.
Instance Attribute Summary collapse
-
#big_query_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewBigQuerySource
Optional.
-
#create_time ⇒ String
Output only.
-
#etag ⇒ String
Optional.
-
#feature_registry_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewFeatureRegistrySource
A Feature Registry source for features that need to be synced to Online Store.
-
#index_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewIndexConfig
Configuration for vector indexing.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#optimized_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewOptimizedConfig
Configuration for FeatureViews created in Optimized FeatureOnlineStore.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#sync_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewSyncConfig
Configuration for Sync.
-
#update_time ⇒ String
Output only.
-
#vertex_rag_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewVertexRagSource
A Vertex Rag source for features that need to be synced to Online Store.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureView
constructor
A new instance of GoogleCloudAiplatformV1FeatureView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureView
Returns a new instance of GoogleCloudAiplatformV1FeatureView.
9803 9804 9805 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9803 def initialize(**args) update!(**args) end |
Instance Attribute Details
#big_query_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewBigQuerySource
Optional. Configures how data is supposed to be extracted from a BigQuery
source to be loaded onto the FeatureOnlineStore.
Corresponds to the JSON property bigQuerySource
9729 9730 9731 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9729 def big_query_source @big_query_source end |
#create_time ⇒ String
Output only. Timestamp when this FeatureView was created.
Corresponds to the JSON property createTime
9734 9735 9736 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9734 def create_time @create_time end |
#etag ⇒ String
Optional. Used to perform consistent read-modify-write updates. If not set, a
blind "overwrite" update happens.
Corresponds to the JSON property etag
9740 9741 9742 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9740 def etag @etag end |
#feature_registry_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewFeatureRegistrySource
A Feature Registry source for features that need to be synced to Online Store.
Corresponds to the JSON property featureRegistrySource
9745 9746 9747 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9745 def feature_registry_source @feature_registry_source end |
#index_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewIndexConfig
Configuration for vector indexing.
Corresponds to the JSON property indexConfig
9750 9751 9752 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9750 def index_config @index_config end |
#labels ⇒ Hash<String,String>
Optional. The labels with user-defined metadata to organize your FeatureViews.
Label keys and values can be no longer than 64 characters (Unicode codepoints),
can only contain lowercase letters, numeric characters, underscores and
dashes. International characters are allowed. See https://goo.gl/xmQnxf for
more information on and examples of labels. No more than 64 user labels can be
associated with one FeatureOnlineStore(System labels are excluded)." System
reserved label keys are prefixed with "aiplatform.googleapis.com/" and are
immutable.
Corresponds to the JSON property labels
9762 9763 9764 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9762 def labels @labels end |
#name ⇒ String
Identifier. Name of the FeatureView. Format: projects/project/locations/
location/featureOnlineStores/feature_online_store/featureViews/
feature_view`
Corresponds to the JSON propertyname`
9769 9770 9771 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9769 def name @name end |
#optimized_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewOptimizedConfig
Configuration for FeatureViews created in Optimized FeatureOnlineStore.
Corresponds to the JSON property optimizedConfig
9774 9775 9776 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9774 def optimized_config @optimized_config end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
9779 9780 9781 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9779 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
9785 9786 9787 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9785 def satisfies_pzs @satisfies_pzs end |
#sync_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewSyncConfig
Configuration for Sync. Only one option is set.
Corresponds to the JSON property syncConfig
9791 9792 9793 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9791 def sync_config @sync_config end |
#update_time ⇒ String
Output only. Timestamp when this FeatureView was last updated.
Corresponds to the JSON property updateTime
9796 9797 9798 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9796 def update_time @update_time end |
#vertex_rag_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewVertexRagSource
A Vertex Rag source for features that need to be synced to Online Store.
Corresponds to the JSON property vertexRagSource
9801 9802 9803 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9801 def vertex_rag_source @vertex_rag_source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9808 9809 9810 9811 9812 9813 9814 9815 9816 9817 9818 9819 9820 9821 9822 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9808 def update!(**args) @big_query_source = args[:big_query_source] if args.key?(:big_query_source) @create_time = args[:create_time] if args.key?(:create_time) @etag = args[:etag] if args.key?(:etag) @feature_registry_source = args[:feature_registry_source] if args.key?(:feature_registry_source) @index_config = args[:index_config] if args.key?(:index_config) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @optimized_config = args[:optimized_config] if args.key?(:optimized_config) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @sync_config = args[:sync_config] if args.key?(:sync_config) @update_time = args[:update_time] if args.key?(:update_time) @vertex_rag_source = args[:vertex_rag_source] if args.key?(:vertex_rag_source) end |