Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

FeatureView is representation of values that the FeatureOnlineStore will serve based on its syncConfig.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureView

Returns a new instance of GoogleCloudAiplatformV1FeatureView.



8910
8911
8912
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8910

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#big_query_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewBigQuerySource

Optional. Configures how data is supposed to be extracted from a BigQuery source to be loaded onto the FeatureOnlineStore. Corresponds to the JSON property bigQuerySource



8841
8842
8843
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8841

def big_query_source
  @big_query_source
end

#create_timeString

Output only. Timestamp when this FeatureView was created. Corresponds to the JSON property createTime

Returns:

  • (String)


8846
8847
8848
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8846

def create_time
  @create_time
end

#etagString

Optional. Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


8852
8853
8854
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8852

def etag
  @etag
end

#feature_registry_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewFeatureRegistrySource

A Feature Registry source for features that need to be synced to Online Store. Corresponds to the JSON property featureRegistrySource



8857
8858
8859
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8857

def feature_registry_source
  @feature_registry_source
end

#index_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewIndexConfig

Configuration for vector indexing. Corresponds to the JSON property indexConfig



8862
8863
8864
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8862

def index_config
  @index_config
end

#labelsHash<String,String>

Optional. The labels with user-defined metadata to organize your FeatureViews. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information on and examples of labels. No more than 64 user labels can be associated with one FeatureOnlineStore(System labels are excluded)." System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


8874
8875
8876
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8874

def labels
  @labels
end

#nameString

Identifier. Name of the FeatureView. Format: projects/project/locations/ location/featureOnlineStores/feature_online_store/featureViews/ feature_view` Corresponds to the JSON propertyname`

Returns:

  • (String)


8881
8882
8883
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8881

def name
  @name
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


8886
8887
8888
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8886

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


8892
8893
8894
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8892

def satisfies_pzs
  @satisfies_pzs
end

#sync_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewSyncConfig

Configuration for Sync. Only one option is set. Corresponds to the JSON property syncConfig



8898
8899
8900
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8898

def sync_config
  @sync_config
end

#update_timeString

Output only. Timestamp when this FeatureView was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


8903
8904
8905
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8903

def update_time
  @update_time
end

#vertex_rag_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewVertexRagSource

A Vertex Rag source for features that need to be synced to Online Store. Corresponds to the JSON property vertexRagSource



8908
8909
8910
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8908

def vertex_rag_source
  @vertex_rag_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8915
8916
8917
8918
8919
8920
8921
8922
8923
8924
8925
8926
8927
8928
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8915

def update!(**args)
  @big_query_source = args[:big_query_source] if args.key?(:big_query_source)
  @create_time = args[:create_time] if args.key?(:create_time)
  @etag = args[:etag] if args.key?(:etag)
  @feature_registry_source = args[:feature_registry_source] if args.key?(:feature_registry_source)
  @index_config = args[:index_config] if args.key?(:index_config)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @sync_config = args[:sync_config] if args.key?(:sync_config)
  @update_time = args[:update_time] if args.key?(:update_time)
  @vertex_rag_source = args[:vertex_rag_source] if args.key?(:vertex_rag_source)
end