Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

FeatureView is representation of values that the FeatureOnlineStore will serve based on its syncConfig.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureView

Returns a new instance of GoogleCloudAiplatformV1FeatureView.



8373
8374
8375
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8373

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#big_query_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewBigQuerySource

Optional. Configures how data is supposed to be extracted from a BigQuery source to be loaded onto the FeatureOnlineStore. Corresponds to the JSON property bigQuerySource



8326
8327
8328
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8326

def big_query_source
  @big_query_source
end

#create_timeString

Output only. Timestamp when this FeatureView was created. Corresponds to the JSON property createTime

Returns:

  • (String)


8331
8332
8333
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8331

def create_time
  @create_time
end

#etagString

Optional. Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


8337
8338
8339
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8337

def etag
  @etag
end

#feature_registry_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewFeatureRegistrySource

A Feature Registry source for features that need to be synced to Online Store. Corresponds to the JSON property featureRegistrySource



8342
8343
8344
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8342

def feature_registry_source
  @feature_registry_source
end

#labelsHash<String,String>

Optional. The labels with user-defined metadata to organize your FeatureViews. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information on and examples of labels. No more than 64 user labels can be associated with one FeatureOnlineStore(System labels are excluded)." System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


8354
8355
8356
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8354

def labels
  @labels
end

#nameString

Identifier. Name of the FeatureView. Format: projects/project/locations/ location/featureOnlineStores/feature_online_store/featureViews/ feature_view` Corresponds to the JSON propertyname`

Returns:

  • (String)


8361
8362
8363
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8361

def name
  @name
end

#sync_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewSyncConfig

Configuration for Sync. Only one option is set. Corresponds to the JSON property syncConfig



8366
8367
8368
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8366

def sync_config
  @sync_config
end

#update_timeString

Output only. Timestamp when this FeatureView was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


8371
8372
8373
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8371

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8378
8379
8380
8381
8382
8383
8384
8385
8386
8387
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8378

def update!(**args)
  @big_query_source = args[:big_query_source] if args.key?(:big_query_source)
  @create_time = args[:create_time] if args.key?(:create_time)
  @etag = args[:etag] if args.key?(:etag)
  @feature_registry_source = args[:feature_registry_source] if args.key?(:feature_registry_source)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @sync_config = args[:sync_config] if args.key?(:sync_config)
  @update_time = args[:update_time] if args.key?(:update_time)
end