Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewBigtableMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Metadata for the Cloud Bigtable that supports directly interacting Bigtable instances.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureViewBigtableMetadata

Returns a new instance of GoogleCloudAiplatformV1FeatureViewBigtableMetadata.



13277
13278
13279
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13277

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#read_app_profileString

Output only. The Bigtable App Profile to use for reading from Bigtable. Corresponds to the JSON property readAppProfile

Returns:

  • (String)


13275
13276
13277
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13275

def read_app_profile
  @read_app_profile
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13282
13283
13284
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13282

def update!(**args)
  @read_app_profile = args[:read_app_profile] if args.key?(:read_app_profile)
end