Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewDirectWriteResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewDirectWriteResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Response message for FeatureOnlineStoreService.FeatureViewDirectWrite.
Instance Attribute Summary collapse
-
#status ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#write_responses ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewDirectWriteResponseWriteResponse>
Details about write for each key.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureViewDirectWriteResponse
constructor
A new instance of GoogleCloudAiplatformV1FeatureViewDirectWriteResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureViewDirectWriteResponse
Returns a new instance of GoogleCloudAiplatformV1FeatureViewDirectWriteResponse.
15650 15651 15652 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15650 def initialize(**args) update!(**args) end |
Instance Attribute Details
#status ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property status
15641 15642 15643 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15641 def status @status end |
#write_responses ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewDirectWriteResponseWriteResponse>
Details about write for each key. If status is not OK, WriteResponse.data_key
will have the key with error, but WriteResponse.online_store_write_time will
not be present.
Corresponds to the JSON property writeResponses
15648 15649 15650 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15648 def write_responses @write_responses end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15655 15656 15657 15658 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15655 def update!(**args) @status = args[:status] if args.key?(:status) @write_responses = args[:write_responses] if args.key?(:write_responses) end |