Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewDirectWriteResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Response message for FeatureOnlineStoreService.FeatureViewDirectWrite.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureViewDirectWriteResponse

Returns a new instance of GoogleCloudAiplatformV1FeatureViewDirectWriteResponse.



14345
14346
14347
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14345

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#statusGoogle::Apis::AiplatformV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property status



14336
14337
14338
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14336

def status
  @status
end

#write_responsesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewDirectWriteResponseWriteResponse>

Details about write for each key. If status is not OK, WriteResponse.data_key will have the key with error, but WriteResponse.online_store_write_time will not be present. Corresponds to the JSON property writeResponses



14343
14344
14345
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14343

def write_responses
  @write_responses
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14350
14351
14352
14353
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14350

def update!(**args)
  @status = args[:status] if args.key?(:status)
  @write_responses = args[:write_responses] if args.key?(:write_responses)
end