Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewDirectWriteResponseWriteResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewDirectWriteResponseWriteResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Details about the write for each key.
Instance Attribute Summary collapse
-
#data_key ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewDataKey
Lookup key for a feature view.
-
#online_store_write_time ⇒ String
When the feature values were written to the online store.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureViewDirectWriteResponseWriteResponse
constructor
A new instance of GoogleCloudAiplatformV1FeatureViewDirectWriteResponseWriteResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureViewDirectWriteResponseWriteResponse
Returns a new instance of GoogleCloudAiplatformV1FeatureViewDirectWriteResponseWriteResponse.
11132 11133 11134 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11132 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_key ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewDataKey
Lookup key for a feature view.
Corresponds to the JSON property dataKey
11124 11125 11126 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11124 def data_key @data_key end |
#online_store_write_time ⇒ String
When the feature values were written to the online store. If
FeatureViewDirectWriteResponse.status is not OK, this field is not populated.
Corresponds to the JSON property onlineStoreWriteTime
11130 11131 11132 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11130 def online_store_write_time @online_store_write_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11137 11138 11139 11140 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11137 def update!(**args) @data_key = args[:data_key] if args.key?(:data_key) @online_store_write_time = args[:online_store_write_time] if args.key?(:online_store_write_time) end |