Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewFeatureRegistrySource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A Feature Registry source for features that need to be synced to Online Store.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureViewFeatureRegistrySource

Returns a new instance of GoogleCloudAiplatformV1FeatureViewFeatureRegistrySource.



9085
9086
9087
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9085

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#feature_groupsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewFeatureRegistrySourceFeatureGroup>

Required. List of features that need to be synced to Online Store. Corresponds to the JSON property featureGroups



9078
9079
9080
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9078

def feature_groups
  @feature_groups
end

#project_numberFixnum

Optional. The project number of the parent project of the Feature Groups. Corresponds to the JSON property projectNumber

Returns:

  • (Fixnum)


9083
9084
9085
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9083

def project_number
  @project_number
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9090
9091
9092
9093
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9090

def update!(**args)
  @feature_groups = args[:feature_groups] if args.key?(:feature_groups)
  @project_number = args[:project_number] if args.key?(:project_number)
end