Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewOptimizedConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewOptimizedConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Configuration for FeatureViews created in Optimized FeatureOnlineStore.
Instance Attribute Summary collapse
-
#automatic_resources ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AutomaticResources
A description of resources that to large degree are decided by Agent Platform, and require only a modest additional configuration.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureViewOptimizedConfig
constructor
A new instance of GoogleCloudAiplatformV1FeatureViewOptimizedConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureViewOptimizedConfig
Returns a new instance of GoogleCloudAiplatformV1FeatureViewOptimizedConfig.
14856 14857 14858 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14856 def initialize(**args) update!(**args) end |
Instance Attribute Details
#automatic_resources ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AutomaticResources
A description of resources that to large degree are decided by Agent Platform,
and require only a modest additional configuration. Each Model supporting
these resources documents its specific guidelines.
Corresponds to the JSON property automaticResources
14854 14855 14856 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14854 def automatic_resources @automatic_resources end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14861 14862 14863 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14861 def update!(**args) @automatic_resources = args[:automatic_resources] if args.key?(:automatic_resources) end |