Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewOptimizedConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Configuration for FeatureViews created in Optimized FeatureOnlineStore.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureViewOptimizedConfig

Returns a new instance of GoogleCloudAiplatformV1FeatureViewOptimizedConfig.



14538
14539
14540
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14538

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#automatic_resourcesGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1AutomaticResources

A description of resources that to large degree are decided by Agent Platform, and require only a modest additional configuration. Each Model supporting these resources documents its specific guidelines. Corresponds to the JSON property automaticResources



14536
14537
14538
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14536

def automatic_resources
  @automatic_resources
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14543
14544
14545
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14543

def update!(**args)
  @automatic_resources = args[:automatic_resources] if args.key?(:automatic_resources)
end