Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewSync
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewSync
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
FeatureViewSync is a representation of sync operation which copies data from data source to Feature View in Online Store.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#final_status ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#name ⇒ String
Identifier.
-
#run_time ⇒ Google::Apis::AiplatformV1::GoogleTypeInterval
Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive).
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#sync_summary ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewSyncSyncSummary
Summary from the Sync job.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureViewSync
constructor
A new instance of GoogleCloudAiplatformV1FeatureViewSync.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureViewSync
Returns a new instance of GoogleCloudAiplatformV1FeatureViewSync.
14603 14604 14605 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14603 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Time when this FeatureViewSync is created. Creation of a
FeatureViewSync means that the job is pending / waiting for sufficient
resources but may not have started the actual data transfer yet.
Corresponds to the JSON property createTime
14558 14559 14560 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14558 def create_time @create_time end |
#final_status ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property finalStatus
14568 14569 14570 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14568 def final_status @final_status end |
#name ⇒ String
Identifier. Name of the FeatureViewSync. Format: projects/project/locations/
location/featureOnlineStores/feature_online_store/featureViews/
feature_view/featureViewSyncs/feature_view_sync`
Corresponds to the JSON propertyname`
14575 14576 14577 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14575 def name @name end |
#run_time ⇒ Google::Apis::AiplatformV1::GoogleTypeInterval
Represents a time interval, encoded as a Timestamp start (inclusive) and a
Timestamp end (exclusive). The start must be less than or equal to the end.
When the start equals the end, the interval is empty (matches no time). When
both start and end are unspecified, the interval matches any time.
Corresponds to the JSON property runTime
14583 14584 14585 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14583 def run_time @run_time end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
14588 14589 14590 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14588 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
14594 14595 14596 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14594 def satisfies_pzs @satisfies_pzs end |
#sync_summary ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewSyncSyncSummary
Summary from the Sync job. For continuous syncs, the summary is updated
periodically. For batch syncs, it gets updated on completion of the sync.
Corresponds to the JSON property syncSummary
14601 14602 14603 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14601 def sync_summary @sync_summary end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14608 14609 14610 14611 14612 14613 14614 14615 14616 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14608 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @final_status = args[:final_status] if args.key?(:final_status) @name = args[:name] if args.key?(:name) @run_time = args[:run_time] if args.key?(:run_time) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @sync_summary = args[:sync_summary] if args.key?(:sync_summary) end |