Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewSync

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

FeatureViewSync is a representation of sync operation which copies data from data source to Feature View in Online Store.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureViewSync

Returns a new instance of GoogleCloudAiplatformV1FeatureViewSync.



10503
10504
10505
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10503

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Time when this FeatureViewSync is created. Creation of a FeatureViewSync means that the job is pending / waiting for sufficient resources but may not have started the actual data transfer yet. Corresponds to the JSON property createTime

Returns:

  • (String)


10458
10459
10460
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10458

def create_time
  @create_time
end

#final_statusGoogle::Apis::AiplatformV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property finalStatus



10468
10469
10470
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10468

def final_status
  @final_status
end

#nameString

Identifier. Name of the FeatureViewSync. Format: projects/project/locations/ location/featureOnlineStores/feature_online_store/featureViews/ feature_view/featureViewSyncs/feature_view_sync` Corresponds to the JSON propertyname`

Returns:

  • (String)


10475
10476
10477
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10475

def name
  @name
end

#run_timeGoogle::Apis::AiplatformV1::GoogleTypeInterval

Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive). The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time. Corresponds to the JSON property runTime



10483
10484
10485
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10483

def run_time
  @run_time
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


10488
10489
10490
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10488

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


10494
10495
10496
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10494

def satisfies_pzs
  @satisfies_pzs
end

#sync_summaryGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewSyncSyncSummary

Summary from the Sync job. For continuous syncs, the summary is updated periodically. For batch syncs, it gets updated on completion of the sync. Corresponds to the JSON property syncSummary



10501
10502
10503
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10501

def sync_summary
  @sync_summary
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10508
10509
10510
10511
10512
10513
10514
10515
10516
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10508

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @final_status = args[:final_status] if args.key?(:final_status)
  @name = args[:name] if args.key?(:name)
  @run_time = args[:run_time] if args.key?(:run_time)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @sync_summary = args[:sync_summary] if args.key?(:sync_summary)
end