Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewSync

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

FeatureViewSync is a representation of sync operation which copies data from data source to Feature View in Online Store.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureViewSync

Returns a new instance of GoogleCloudAiplatformV1FeatureViewSync.



9271
9272
9273
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9271

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Time when this FeatureViewSync is created. Creation of a FeatureViewSync means that the job is pending / waiting for sufficient resources but may not have started the actual data transfer yet. Corresponds to the JSON property createTime

Returns:

  • (String)


9226
9227
9228
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9226

def create_time
  @create_time
end

#final_statusGoogle::Apis::AiplatformV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property finalStatus



9236
9237
9238
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9236

def final_status
  @final_status
end

#nameString

Identifier. Name of the FeatureViewSync. Format: projects/project/locations/ location/featureOnlineStores/feature_online_store/featureViews/ feature_view/featureViewSyncs/feature_view_sync` Corresponds to the JSON propertyname`

Returns:

  • (String)


9243
9244
9245
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9243

def name
  @name
end

#run_timeGoogle::Apis::AiplatformV1::GoogleTypeInterval

Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive). The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time. Corresponds to the JSON property runTime



9251
9252
9253
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9251

def run_time
  @run_time
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


9256
9257
9258
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9256

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


9262
9263
9264
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9262

def satisfies_pzs
  @satisfies_pzs
end

#sync_summaryGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewSyncSyncSummary

Summary from the Sync job. For continuous syncs, the summary is updated periodically. For batch syncs, it gets updated on completion of the sync. Corresponds to the JSON property syncSummary



9269
9270
9271
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9269

def sync_summary
  @sync_summary
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9276
9277
9278
9279
9280
9281
9282
9283
9284
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9276

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @final_status = args[:final_status] if args.key?(:final_status)
  @name = args[:name] if args.key?(:name)
  @run_time = args[:run_time] if args.key?(:run_time)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @sync_summary = args[:sync_summary] if args.key?(:sync_summary)
end