Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureViewSync

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

FeatureViewSync is a representation of sync operation which copies data from data source to Feature View in Online Store.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FeatureViewSync

Returns a new instance of GoogleCloudAiplatformV1FeatureViewSync.



8518
8519
8520
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8518

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Time when this FeatureViewSync is created. Creation of a FeatureViewSync means that the job is pending / waiting for sufficient resources but may not have started the actual data transfer yet. Corresponds to the JSON property createTime

Returns:

  • (String)


8491
8492
8493
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8491

def create_time
  @create_time
end

#final_statusGoogle::Apis::AiplatformV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property finalStatus



8501
8502
8503
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8501

def final_status
  @final_status
end

#nameString

Identifier. Name of the FeatureViewSync. Format: projects/project/locations/ location/featureOnlineStores/feature_online_store/featureViews/ feature_view/featureViewSyncs/feature_view_sync` Corresponds to the JSON propertyname`

Returns:

  • (String)


8508
8509
8510
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8508

def name
  @name
end

#run_timeGoogle::Apis::AiplatformV1::GoogleTypeInterval

Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive). The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time. Corresponds to the JSON property runTime



8516
8517
8518
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8516

def run_time
  @run_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8523
8524
8525
8526
8527
8528
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8523

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @final_status = args[:final_status] if args.key?(:final_status)
  @name = args[:name] if args.key?(:name)
  @run_time = args[:run_time] if args.key?(:run_time)
end