Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Featurestore

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Vertex AI Feature Store provides a centralized repository for organizing, storing, and serving ML features. The Featurestore is a top-level container for your features and their values.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Featurestore

Returns a new instance of GoogleCloudAiplatformV1Featurestore.



13868
13869
13870
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13868

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this Featurestore was created. Corresponds to the JSON property createTime

Returns:

  • (String)


13799
13800
13801
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13799

def create_time
  @create_time
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



13805
13806
13807
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13805

def encryption_spec
  @encryption_spec
end

#etagString

Optional. Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


13811
13812
13813
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13811

def etag
  @etag
end

#labelsHash<String,String>

Optional. The labels with user-defined metadata to organize your Featurestore. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information on and examples of labels. No more than 64 user labels can be associated with one Featurestore(System labels are excluded)." System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


13822
13823
13824
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13822

def labels
  @labels
end

#nameString

Output only. Name of the Featurestore. Format: projects/project/locations/ location/featurestores/featurestore` Corresponds to the JSON propertyname`

Returns:

  • (String)


13828
13829
13830
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13828

def name
  @name
end

#online_serving_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FeaturestoreOnlineServingConfig

OnlineServingConfig specifies the details for provisioning online serving resources. Corresponds to the JSON property onlineServingConfig



13834
13835
13836
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13834

def online_serving_config
  @online_serving_config
end

#online_storage_ttl_daysFixnum

Optional. TTL in days for feature values that will be stored in online serving storage. The Feature Store online storage periodically removes obsolete feature values older than online_storage_ttl_days since the feature generation time. Note that online_storage_ttl_days should be less than or equal to offline_storage_ttl_days for each EntityType under a featurestore. If not set, default to 4000 days Corresponds to the JSON property onlineStorageTtlDays

Returns:

  • (Fixnum)


13844
13845
13846
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13844

def online_storage_ttl_days
  @online_storage_ttl_days
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


13849
13850
13851
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13849

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


13855
13856
13857
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13855

def satisfies_pzs
  @satisfies_pzs
end

#stateString

Output only. State of the featurestore. Corresponds to the JSON property state

Returns:

  • (String)


13861
13862
13863
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13861

def state
  @state
end

#update_timeString

Output only. Timestamp when this Featurestore was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


13866
13867
13868
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13866

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13873
13874
13875
13876
13877
13878
13879
13880
13881
13882
13883
13884
13885
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13873

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @online_serving_config = args[:online_serving_config] if args.key?(:online_serving_config)
  @online_storage_ttl_days = args[:online_storage_ttl_days] if args.key?(:online_storage_ttl_days)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end