Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Featurestore
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Featurestore
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Vertex AI Feature Store provides a centralized repository for organizing, storing, and serving ML features. The Featurestore is a top-level container for your features and their values.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top- level resource.
-
#etag ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Output only.
-
#online_serving_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeaturestoreOnlineServingConfig
OnlineServingConfig specifies the details for provisioning online serving resources.
-
#online_storage_ttl_days ⇒ Fixnum
Optional.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Featurestore
constructor
A new instance of GoogleCloudAiplatformV1Featurestore.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Featurestore
Returns a new instance of GoogleCloudAiplatformV1Featurestore.
11552 11553 11554 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11552 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this Featurestore was created.
Corresponds to the JSON property createTime
11483 11484 11485 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11483 def create_time @create_time end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top-
level resource.
Corresponds to the JSON property encryptionSpec
11489 11490 11491 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11489 def encryption_spec @encryption_spec end |
#etag ⇒ String
Optional. Used to perform consistent read-modify-write updates. If not set, a
blind "overwrite" update happens.
Corresponds to the JSON property etag
11495 11496 11497 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11495 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. The labels with user-defined metadata to organize your Featurestore.
Label keys and values can be no longer than 64 characters (Unicode codepoints),
can only contain lowercase letters, numeric characters, underscores and
dashes. International characters are allowed. See https://goo.gl/xmQnxf for
more information on and examples of labels. No more than 64 user labels can be
associated with one Featurestore(System labels are excluded)." System reserved
label keys are prefixed with "aiplatform.googleapis.com/" and are immutable.
Corresponds to the JSON property labels
11506 11507 11508 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11506 def labels @labels end |
#name ⇒ String
Output only. Name of the Featurestore. Format: projects/project/locations/
location/featurestores/featurestore`
Corresponds to the JSON propertyname`
11512 11513 11514 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11512 def name @name end |
#online_serving_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeaturestoreOnlineServingConfig
OnlineServingConfig specifies the details for provisioning online serving
resources.
Corresponds to the JSON property onlineServingConfig
11518 11519 11520 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11518 def online_serving_config @online_serving_config end |
#online_storage_ttl_days ⇒ Fixnum
Optional. TTL in days for feature values that will be stored in online serving
storage. The Feature Store online storage periodically removes obsolete
feature values older than online_storage_ttl_days since the feature
generation time. Note that online_storage_ttl_days should be less than or
equal to offline_storage_ttl_days for each EntityType under a featurestore.
If not set, default to 4000 days
Corresponds to the JSON property onlineStorageTtlDays
11528 11529 11530 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11528 def online_storage_ttl_days @online_storage_ttl_days end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
11533 11534 11535 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11533 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
11539 11540 11541 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11539 def satisfies_pzs @satisfies_pzs end |
#state ⇒ String
Output only. State of the featurestore.
Corresponds to the JSON property state
11545 11546 11547 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11545 def state @state end |
#update_time ⇒ String
Output only. Timestamp when this Featurestore was last updated.
Corresponds to the JSON property updateTime
11550 11551 11552 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11550 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11557 11558 11559 11560 11561 11562 11563 11564 11565 11566 11567 11568 11569 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11557 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @online_serving_config = args[:online_serving_config] if args.key?(:online_serving_config) @online_storage_ttl_days = args[:online_storage_ttl_days] if args.key?(:online_storage_ttl_days) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |