Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Featurestore
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Featurestore
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Vertex AI Feature Store provides a centralized repository for organizing, storing, and serving ML features. The Featurestore is a top-level container for your features and their values.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top- level resource.
-
#etag ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Output only.
-
#online_serving_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeaturestoreOnlineServingConfig
OnlineServingConfig specifies the details for provisioning online serving resources.
-
#online_storage_ttl_days ⇒ Fixnum
Optional.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Featurestore
constructor
A new instance of GoogleCloudAiplatformV1Featurestore.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Featurestore
Returns a new instance of GoogleCloudAiplatformV1Featurestore.
11412 11413 11414 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11412 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this Featurestore was created.
Corresponds to the JSON property createTime
11343 11344 11345 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11343 def create_time @create_time end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top-
level resource.
Corresponds to the JSON property encryptionSpec
11349 11350 11351 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11349 def encryption_spec @encryption_spec end |
#etag ⇒ String
Optional. Used to perform consistent read-modify-write updates. If not set, a
blind "overwrite" update happens.
Corresponds to the JSON property etag
11355 11356 11357 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11355 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. The labels with user-defined metadata to organize your Featurestore.
Label keys and values can be no longer than 64 characters (Unicode codepoints),
can only contain lowercase letters, numeric characters, underscores and
dashes. International characters are allowed. See https://goo.gl/xmQnxf for
more information on and examples of labels. No more than 64 user labels can be
associated with one Featurestore(System labels are excluded)." System reserved
label keys are prefixed with "aiplatform.googleapis.com/" and are immutable.
Corresponds to the JSON property labels
11366 11367 11368 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11366 def labels @labels end |
#name ⇒ String
Output only. Name of the Featurestore. Format: projects/project/locations/
location/featurestores/featurestore`
Corresponds to the JSON propertyname`
11372 11373 11374 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11372 def name @name end |
#online_serving_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeaturestoreOnlineServingConfig
OnlineServingConfig specifies the details for provisioning online serving
resources.
Corresponds to the JSON property onlineServingConfig
11378 11379 11380 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11378 def online_serving_config @online_serving_config end |
#online_storage_ttl_days ⇒ Fixnum
Optional. TTL in days for feature values that will be stored in online serving
storage. The Feature Store online storage periodically removes obsolete
feature values older than online_storage_ttl_days since the feature
generation time. Note that online_storage_ttl_days should be less than or
equal to offline_storage_ttl_days for each EntityType under a featurestore.
If not set, default to 4000 days
Corresponds to the JSON property onlineStorageTtlDays
11388 11389 11390 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11388 def online_storage_ttl_days @online_storage_ttl_days end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
11393 11394 11395 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11393 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
11399 11400 11401 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11399 def satisfies_pzs @satisfies_pzs end |
#state ⇒ String
Output only. State of the featurestore.
Corresponds to the JSON property state
11405 11406 11407 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11405 def state @state end |
#update_time ⇒ String
Output only. Timestamp when this Featurestore was last updated.
Corresponds to the JSON property updateTime
11410 11411 11412 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11410 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11417 11418 11419 11420 11421 11422 11423 11424 11425 11426 11427 11428 11429 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11417 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @online_serving_config = args[:online_serving_config] if args.key?(:online_serving_config) @online_storage_ttl_days = args[:online_storage_ttl_days] if args.key?(:online_storage_ttl_days) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |