Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Featurestore

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Vertex AI Feature Store provides a centralized repository for organizing, storing, and serving ML features. The Featurestore is a top-level container for your features and their values.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Featurestore

Returns a new instance of GoogleCloudAiplatformV1Featurestore.



8199
8200
8201
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8199

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this Featurestore was created. Corresponds to the JSON property createTime

Returns:

  • (String)


8142
8143
8144
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8142

def create_time
  @create_time
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key spec that can be applied to a top- level resource. Corresponds to the JSON property encryptionSpec



8148
8149
8150
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8148

def encryption_spec
  @encryption_spec
end

#etagString

Optional. Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


8154
8155
8156
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8154

def etag
  @etag
end

#labelsHash<String,String>

Optional. The labels with user-defined metadata to organize your Featurestore. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information on and examples of labels. No more than 64 user labels can be associated with one Featurestore(System labels are excluded)." System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


8165
8166
8167
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8165

def labels
  @labels
end

#nameString

Output only. Name of the Featurestore. Format: projects/project/locations/ location/featurestores/featurestore` Corresponds to the JSON propertyname`

Returns:

  • (String)


8171
8172
8173
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8171

def name
  @name
end

#online_serving_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FeaturestoreOnlineServingConfig

OnlineServingConfig specifies the details for provisioning online serving resources. Corresponds to the JSON property onlineServingConfig



8177
8178
8179
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8177

def online_serving_config
  @online_serving_config
end

#online_storage_ttl_daysFixnum

Optional. TTL in days for feature values that will be stored in online serving storage. The Feature Store online storage periodically removes obsolete feature values older than online_storage_ttl_days since the feature generation time. Note that online_storage_ttl_days should be less than or equal to offline_storage_ttl_days for each EntityType under a featurestore. If not set, default to 4000 days Corresponds to the JSON property onlineStorageTtlDays

Returns:

  • (Fixnum)


8187
8188
8189
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8187

def online_storage_ttl_days
  @online_storage_ttl_days
end

#stateString

Output only. State of the featurestore. Corresponds to the JSON property state

Returns:

  • (String)


8192
8193
8194
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8192

def state
  @state
end

#update_timeString

Output only. Timestamp when this Featurestore was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


8197
8198
8199
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8197

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8204
8205
8206
8207
8208
8209
8210
8211
8212
8213
8214
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 8204

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @online_serving_config = args[:online_serving_config] if args.key?(:online_serving_config)
  @online_storage_ttl_days = args[:online_storage_ttl_days] if args.key?(:online_storage_ttl_days)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end