Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeaturestoreMonitoringConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeaturestoreMonitoringConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Configuration of how features in Featurestore are monitored.
Instance Attribute Summary collapse
-
#categorical_threshold_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeaturestoreMonitoringConfigThresholdConfig
The config for Featurestore Monitoring threshold.
-
#import_features_analysis ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeaturestoreMonitoringConfigImportFeaturesAnalysis
Configuration of the Featurestore's ImportFeature Analysis Based Monitoring.
-
#numerical_threshold_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeaturestoreMonitoringConfigThresholdConfig
The config for Featurestore Monitoring threshold.
-
#snapshot_analysis ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeaturestoreMonitoringConfigSnapshotAnalysis
Configuration of the Featurestore's Snapshot Analysis Based Monitoring.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeaturestoreMonitoringConfig
constructor
A new instance of GoogleCloudAiplatformV1FeaturestoreMonitoringConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeaturestoreMonitoringConfig
Returns a new instance of GoogleCloudAiplatformV1FeaturestoreMonitoringConfig.
15499 15500 15501 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15499 def initialize(**args) update!(**args) end |
Instance Attribute Details
#categorical_threshold_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeaturestoreMonitoringConfigThresholdConfig
The config for Featurestore Monitoring threshold.
Corresponds to the JSON property categoricalThresholdConfig
15478 15479 15480 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15478 def categorical_threshold_config @categorical_threshold_config end |
#import_features_analysis ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeaturestoreMonitoringConfigImportFeaturesAnalysis
Configuration of the Featurestore's ImportFeature Analysis Based Monitoring.
This type of analysis generates statistics for values of each Feature imported
by every ImportFeatureValues operation.
Corresponds to the JSON property importFeaturesAnalysis
15485 15486 15487 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15485 def import_features_analysis @import_features_analysis end |
#numerical_threshold_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeaturestoreMonitoringConfigThresholdConfig
The config for Featurestore Monitoring threshold.
Corresponds to the JSON property numericalThresholdConfig
15490 15491 15492 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15490 def numerical_threshold_config @numerical_threshold_config end |
#snapshot_analysis ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeaturestoreMonitoringConfigSnapshotAnalysis
Configuration of the Featurestore's Snapshot Analysis Based Monitoring. This
type of analysis generates statistics for each Feature based on a snapshot of
the latest feature value of each entities every monitoring_interval.
Corresponds to the JSON property snapshotAnalysis
15497 15498 15499 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15497 def snapshot_analysis @snapshot_analysis end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15504 15505 15506 15507 15508 15509 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15504 def update!(**args) @categorical_threshold_config = args[:categorical_threshold_config] if args.key?(:categorical_threshold_config) @import_features_analysis = args[:import_features_analysis] if args.key?(:import_features_analysis) @numerical_threshold_config = args[:numerical_threshold_config] if args.key?(:numerical_threshold_config) @snapshot_analysis = args[:snapshot_analysis] if args.key?(:snapshot_analysis) end |