Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeaturestoreMonitoringConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Configuration of how features in Featurestore are monitored.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FeaturestoreMonitoringConfig

Returns a new instance of GoogleCloudAiplatformV1FeaturestoreMonitoringConfig.



14839
14840
14841
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14839

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#categorical_threshold_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FeaturestoreMonitoringConfigThresholdConfig

The config for Featurestore Monitoring threshold. Corresponds to the JSON property categoricalThresholdConfig



14818
14819
14820
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14818

def categorical_threshold_config
  @categorical_threshold_config
end

#import_features_analysisGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FeaturestoreMonitoringConfigImportFeaturesAnalysis

Configuration of the Featurestore's ImportFeature Analysis Based Monitoring. This type of analysis generates statistics for values of each Feature imported by every ImportFeatureValues operation. Corresponds to the JSON property importFeaturesAnalysis



14825
14826
14827
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14825

def import_features_analysis
  @import_features_analysis
end

#numerical_threshold_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FeaturestoreMonitoringConfigThresholdConfig

The config for Featurestore Monitoring threshold. Corresponds to the JSON property numericalThresholdConfig



14830
14831
14832
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14830

def numerical_threshold_config
  @numerical_threshold_config
end

#snapshot_analysisGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FeaturestoreMonitoringConfigSnapshotAnalysis

Configuration of the Featurestore's Snapshot Analysis Based Monitoring. This type of analysis generates statistics for each Feature based on a snapshot of the latest feature value of each entities every monitoring_interval. Corresponds to the JSON property snapshotAnalysis



14837
14838
14839
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14837

def snapshot_analysis
  @snapshot_analysis
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14844
14845
14846
14847
14848
14849
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14844

def update!(**args)
  @categorical_threshold_config = args[:categorical_threshold_config] if args.key?(:categorical_threshold_config)
  @import_features_analysis = args[:import_features_analysis] if args.key?(:import_features_analysis)
  @numerical_threshold_config = args[:numerical_threshold_config] if args.key?(:numerical_threshold_config)
  @snapshot_analysis = args[:snapshot_analysis] if args.key?(:snapshot_analysis)
end