Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeaturestoreMonitoringConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Configuration of how features in Featurestore are monitored.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FeaturestoreMonitoringConfig

Returns a new instance of GoogleCloudAiplatformV1FeaturestoreMonitoringConfig.



10622
10623
10624
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10622

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#categorical_threshold_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FeaturestoreMonitoringConfigThresholdConfig

The config for Featurestore Monitoring threshold. Corresponds to the JSON property categoricalThresholdConfig



10601
10602
10603
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10601

def categorical_threshold_config
  @categorical_threshold_config
end

#import_features_analysisGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FeaturestoreMonitoringConfigImportFeaturesAnalysis

Configuration of the Featurestore's ImportFeature Analysis Based Monitoring. This type of analysis generates statistics for values of each Feature imported by every ImportFeatureValues operation. Corresponds to the JSON property importFeaturesAnalysis



10608
10609
10610
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10608

def import_features_analysis
  @import_features_analysis
end

#numerical_threshold_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FeaturestoreMonitoringConfigThresholdConfig

The config for Featurestore Monitoring threshold. Corresponds to the JSON property numericalThresholdConfig



10613
10614
10615
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10613

def numerical_threshold_config
  @numerical_threshold_config
end

#snapshot_analysisGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FeaturestoreMonitoringConfigSnapshotAnalysis

Configuration of the Featurestore's Snapshot Analysis Based Monitoring. This type of analysis generates statistics for each Feature based on a snapshot of the latest feature value of each entities every monitoring_interval. Corresponds to the JSON property snapshotAnalysis



10620
10621
10622
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10620

def snapshot_analysis
  @snapshot_analysis
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10627
10628
10629
10630
10631
10632
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10627

def update!(**args)
  @categorical_threshold_config = args[:categorical_threshold_config] if args.key?(:categorical_threshold_config)
  @import_features_analysis = args[:import_features_analysis] if args.key?(:import_features_analysis)
  @numerical_threshold_config = args[:numerical_threshold_config] if args.key?(:numerical_threshold_config)
  @snapshot_analysis = args[:snapshot_analysis] if args.key?(:snapshot_analysis)
end