Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeaturestoreMonitoringConfigImportFeaturesAnalysis

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Configuration of the Featurestore's ImportFeature Analysis Based Monitoring. This type of analysis generates statistics for values of each Feature imported by every ImportFeatureValues operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FeaturestoreMonitoringConfigImportFeaturesAnalysis

Returns a new instance of GoogleCloudAiplatformV1FeaturestoreMonitoringConfigImportFeaturesAnalysis.



14662
14663
14664
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14662

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#anomaly_detection_baselineString

The baseline used to do anomaly detection for the statistics generated by import features analysis. Corresponds to the JSON property anomalyDetectionBaseline

Returns:

  • (String)


14654
14655
14656
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14654

def anomaly_detection_baseline
  @anomaly_detection_baseline
end

#stateString

Whether to enable / disable / inherite default hebavior for import features analysis. Corresponds to the JSON property state

Returns:

  • (String)


14660
14661
14662
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14660

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14667
14668
14669
14670
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14667

def update!(**args)
  @anomaly_detection_baseline = args[:anomaly_detection_baseline] if args.key?(:anomaly_detection_baseline)
  @state = args[:state] if args.key?(:state)
end