Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeaturestoreOnlineServingConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

OnlineServingConfig specifies the details for provisioning online serving resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FeaturestoreOnlineServingConfig

Returns a new instance of GoogleCloudAiplatformV1FeaturestoreOnlineServingConfig.



10920
10921
10922
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10920

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fixed_node_countFixnum

The number of nodes for the online store. The number of nodes doesn't scale automatically, but you can manually update the number of nodes. If set to 0, the featurestore will not have an online store and cannot be used for online serving. Corresponds to the JSON property fixedNodeCount

Returns:

  • (Fixnum)


10911
10912
10913
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10911

def fixed_node_count
  @fixed_node_count
end

#scalingGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FeaturestoreOnlineServingConfigScaling

Online serving scaling configuration. If min_node_count and max_node_count are set to the same value, the cluster will be configured with the fixed number of node (no auto-scaling). Corresponds to the JSON property scaling



10918
10919
10920
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10918

def scaling
  @scaling
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10925
10926
10927
10928
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10925

def update!(**args)
  @fixed_node_count = args[:fixed_node_count] if args.key?(:fixed_node_count)
  @scaling = args[:scaling] if args.key?(:scaling)
end