Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeaturestoreOnlineServingConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeaturestoreOnlineServingConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
OnlineServingConfig specifies the details for provisioning online serving resources.
Instance Attribute Summary collapse
-
#fixed_node_count ⇒ Fixnum
The number of nodes for the online store.
-
#scaling ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeaturestoreOnlineServingConfigScaling
Online serving scaling configuration.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeaturestoreOnlineServingConfig
constructor
A new instance of GoogleCloudAiplatformV1FeaturestoreOnlineServingConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1FeaturestoreOnlineServingConfig
Returns a new instance of GoogleCloudAiplatformV1FeaturestoreOnlineServingConfig.
10751 10752 10753 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10751 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fixed_node_count ⇒ Fixnum
The number of nodes for the online store. The number of nodes doesn't scale
automatically, but you can manually update the number of nodes. If set to 0,
the featurestore will not have an online store and cannot be used for online
serving.
Corresponds to the JSON property fixedNodeCount
10742 10743 10744 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10742 def fixed_node_count @fixed_node_count end |
#scaling ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeaturestoreOnlineServingConfigScaling
Online serving scaling configuration. If min_node_count and max_node_count are
set to the same value, the cluster will be configured with the fixed number of
node (no auto-scaling).
Corresponds to the JSON property scaling
10749 10750 10751 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10749 def scaling @scaling end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10756 10757 10758 10759 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10756 def update!(**args) @fixed_node_count = args[:fixed_node_count] if args.key?(:fixed_node_count) @scaling = args[:scaling] if args.key?(:scaling) end |