Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeaturestoreOnlineServingConfigScaling

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Online serving scaling configuration. If min_node_count and max_node_count are set to the same value, the cluster will be configured with the fixed number of node (no auto-scaling).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FeaturestoreOnlineServingConfigScaling

Returns a new instance of GoogleCloudAiplatformV1FeaturestoreOnlineServingConfigScaling.



9235
9236
9237
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9235

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cpu_utilization_targetFixnum

Optional. The cpu utilization that the Autoscaler should be trying to achieve. This number is on a scale from 0 (no utilization) to 100 (total utilization), and is limited between 10 and 80. When a cluster's CPU utilization exceeds the target that you have set, Bigtable immediately adds nodes to the cluster. When CPU utilization is substantially lower than the target, Bigtable removes nodes. If not set or set to 0, default to 50. Corresponds to the JSON property cpuUtilizationTarget

Returns:

  • (Fixnum)


9221
9222
9223
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9221

def cpu_utilization_target
  @cpu_utilization_target
end

#max_node_countFixnum

The maximum number of nodes to scale up to. Must be greater than min_node_count, and less than or equal to 10 times of 'min_node_count'. Corresponds to the JSON property maxNodeCount

Returns:

  • (Fixnum)


9227
9228
9229
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9227

def max_node_count
  @max_node_count
end

#min_node_countFixnum

Required. The minimum number of nodes to scale down to. Must be greater than or equal to 1. Corresponds to the JSON property minNodeCount

Returns:

  • (Fixnum)


9233
9234
9235
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9233

def min_node_count
  @min_node_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9240
9241
9242
9243
9244
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9240

def update!(**args)
  @cpu_utilization_target = args[:cpu_utilization_target] if args.key?(:cpu_utilization_target)
  @max_node_count = args[:max_node_count] if args.key?(:max_node_count)
  @min_node_count = args[:min_node_count] if args.key?(:min_node_count)
end