Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FileData

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

URI based data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FileData

Returns a new instance of GoogleCloudAiplatformV1FileData.



10966
10967
10968
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10966

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Optional. Display name of the file data. Used to provide a label or filename to distinguish file datas. This field is only returned in PromptMessage for prompt management. It is not currently used in the Gemini GenerateContent calls. Corresponds to the JSON property displayName

Returns:

  • (String)


10954
10955
10956
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10954

def display_name
  @display_name
end

#file_uriString

Required. URI. Corresponds to the JSON property fileUri

Returns:

  • (String)


10959
10960
10961
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10959

def file_uri
  @file_uri
end

#mime_typeString

Required. The IANA standard MIME type of the source data. Corresponds to the JSON property mimeType

Returns:

  • (String)


10964
10965
10966
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10964

def mime_type
  @mime_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10971
10972
10973
10974
10975
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10971

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @file_uri = args[:file_uri] if args.key?(:file_uri)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
end