Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FileData

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

URI based data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FileData

Returns a new instance of GoogleCloudAiplatformV1FileData.



10890
10891
10892
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10890

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Optional. Display name of the file data. Used to provide a label or filename to distinguish file datas. This field is only returned in PromptMessage for prompt management. It is not currently used in the Gemini GenerateContent calls. Corresponds to the JSON property displayName

Returns:

  • (String)


10878
10879
10880
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10878

def display_name
  @display_name
end

#file_uriString

Required. URI. Corresponds to the JSON property fileUri

Returns:

  • (String)


10883
10884
10885
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10883

def file_uri
  @file_uri
end

#mime_typeString

Required. The IANA standard MIME type of the source data. Corresponds to the JSON property mimeType

Returns:

  • (String)


10888
10889
10890
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10888

def mime_type
  @mime_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10895
10896
10897
10898
10899
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10895

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @file_uri = args[:file_uri] if args.key?(:file_uri)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
end