Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FindNeighborsRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FindNeighborsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The request message for MatchService.FindNeighbors.
Instance Attribute Summary collapse
-
#deployed_index_id ⇒ String
The ID of the DeployedIndex that will serve the request.
-
#queries ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FindNeighborsRequestQuery>
The list of queries.
-
#return_full_datapoint ⇒ Boolean
(also: #return_full_datapoint?)
If set to true, the full datapoints (including all vector values and restricts) of the nearest neighbors are returned.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1FindNeighborsRequest
constructor
A new instance of GoogleCloudAiplatformV1FindNeighborsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1FindNeighborsRequest
Returns a new instance of GoogleCloudAiplatformV1FindNeighborsRequest.
15595 15596 15597 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15595 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deployed_index_id ⇒ String
The ID of the DeployedIndex that will serve the request. This request is sent
to a specific IndexEndpoint, as per the IndexEndpoint.network. That
IndexEndpoint also has IndexEndpoint.deployed_indexes, and each such index has
a DeployedIndex.id field. The value of the field below must equal one of the
DeployedIndex.id fields of the IndexEndpoint that is being called for this
request.
Corresponds to the JSON property deployedIndexId
15580 15581 15582 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15580 def deployed_index_id @deployed_index_id end |
#queries ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FindNeighborsRequestQuery>
The list of queries.
Corresponds to the JSON property queries
15585 15586 15587 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15585 def queries @queries end |
#return_full_datapoint ⇒ Boolean Also known as: return_full_datapoint?
If set to true, the full datapoints (including all vector values and restricts)
of the nearest neighbors are returned. Note that returning full datapoint
will significantly increase the latency and cost of the query.
Corresponds to the JSON property returnFullDatapoint
15592 15593 15594 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15592 def return_full_datapoint @return_full_datapoint end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15600 15601 15602 15603 15604 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15600 def update!(**args) @deployed_index_id = args[:deployed_index_id] if args.key?(:deployed_index_id) @queries = args[:queries] if args.key?(:queries) @return_full_datapoint = args[:return_full_datapoint] if args.key?(:return_full_datapoint) end |