Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FindNeighborsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The request message for MatchService.FindNeighbors.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FindNeighborsRequest

Returns a new instance of GoogleCloudAiplatformV1FindNeighborsRequest.



11001
11002
11003
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11001

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deployed_index_idString

The ID of the DeployedIndex that will serve the request. This request is sent to a specific IndexEndpoint, as per the IndexEndpoint.network. That IndexEndpoint also has IndexEndpoint.deployed_indexes, and each such index has a DeployedIndex.id field. The value of the field below must equal one of the DeployedIndex.id fields of the IndexEndpoint that is being called for this request. Corresponds to the JSON property deployedIndexId

Returns:

  • (String)


10986
10987
10988
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10986

def deployed_index_id
  @deployed_index_id
end

#queriesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FindNeighborsRequestQuery>

The list of queries. Corresponds to the JSON property queries



10991
10992
10993
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10991

def queries
  @queries
end

#return_full_datapointBoolean Also known as: return_full_datapoint?

If set to true, the full datapoints (including all vector values and restricts) of the nearest neighbors are returned. Note that returning full datapoint will significantly increase the latency and cost of the query. Corresponds to the JSON property returnFullDatapoint

Returns:

  • (Boolean)


10998
10999
11000
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10998

def return_full_datapoint
  @return_full_datapoint
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11006
11007
11008
11009
11010
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11006

def update!(**args)
  @deployed_index_id = args[:deployed_index_id] if args.key?(:deployed_index_id)
  @queries = args[:queries] if args.key?(:queries)
  @return_full_datapoint = args[:return_full_datapoint] if args.key?(:return_full_datapoint)
end