Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FindNeighborsRequestQuery

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A query to find a number of the nearest neighbors (most similar vectors) of a vector.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FindNeighborsRequestQuery

Returns a new instance of GoogleCloudAiplatformV1FindNeighborsRequestQuery.



14414
14415
14416
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14414

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#approximate_neighbor_countFixnum

The number of neighbors to find via approximate search before exact reordering is performed. If not set, the default value from scam config is used; if set, this value must be > 0. Corresponds to the JSON property approximateNeighborCount

Returns:

  • (Fixnum)


14376
14377
14378
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14376

def approximate_neighbor_count
  @approximate_neighbor_count
end

#datapointGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapoint

A datapoint of Index. Corresponds to the JSON property datapoint



14381
14382
14383
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14381

def datapoint
  @datapoint
end

#fraction_leaf_nodes_to_search_overrideFloat

The fraction of the number of leaves to search, set at query time allows user to tune search performance. This value increase result in both search accuracy and latency increase. The value should be between 0.0 and 1.0. If not set or set to 0.0, query uses the default value specified in NearestNeighborSearchConfig.TreeAHConfig.fraction_leaf_nodes_to_search. Corresponds to the JSON property fractionLeafNodesToSearchOverride

Returns:

  • (Float)


14390
14391
14392
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14390

def fraction_leaf_nodes_to_search_override
  @fraction_leaf_nodes_to_search_override
end

#neighbor_countFixnum

The number of nearest neighbors to be retrieved from database for each query. If not set, will use the default from the service configuration (https://cloud. google.com/vertex-ai/docs/matching-engine/configuring-indexes#nearest-neighbor- search-config). Corresponds to the JSON property neighborCount

Returns:

  • (Fixnum)


14398
14399
14400
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14398

def neighbor_count
  @neighbor_count
end

#per_crowding_attribute_neighbor_countFixnum

Crowding is a constraint on a neighbor list produced by nearest neighbor search requiring that no more than some value k' of the k neighbors returned have the same value of crowding_attribute. It's used for improving result diversity. This field is the maximum number of matches with the same crowding tag. Corresponds to the JSON property perCrowdingAttributeNeighborCount

Returns:

  • (Fixnum)


14407
14408
14409
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14407

def per_crowding_attribute_neighbor_count
  @per_crowding_attribute_neighbor_count
end

#rrfGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FindNeighborsRequestQueryRrf

Parameters for RRF algorithm that combines search results. Corresponds to the JSON property rrf



14412
14413
14414
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14412

def rrf
  @rrf
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14419
14420
14421
14422
14423
14424
14425
14426
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14419

def update!(**args)
  @approximate_neighbor_count = args[:approximate_neighbor_count] if args.key?(:approximate_neighbor_count)
  @datapoint = args[:datapoint] if args.key?(:datapoint)
  @fraction_leaf_nodes_to_search_override = args[:fraction_leaf_nodes_to_search_override] if args.key?(:fraction_leaf_nodes_to_search_override)
  @neighbor_count = args[:neighbor_count] if args.key?(:neighbor_count)
  @per_crowding_attribute_neighbor_count = args[:per_crowding_attribute_neighbor_count] if args.key?(:per_crowding_attribute_neighbor_count)
  @rrf = args[:rrf] if args.key?(:rrf)
end