Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FindNeighborsRequestQuery

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A query to find a number of the nearest neighbors (most similar vectors) of a vector.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FindNeighborsRequestQuery

Returns a new instance of GoogleCloudAiplatformV1FindNeighborsRequestQuery.



9625
9626
9627
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9625

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#approximate_neighbor_countFixnum

The number of neighbors to find via approximate search before exact reordering is performed. If not set, the default value from scam config is used; if set, this value must be > 0. Corresponds to the JSON property approximateNeighborCount

Returns:

  • (Fixnum)


9592
9593
9594
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9592

def approximate_neighbor_count
  @approximate_neighbor_count
end

#datapointGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapoint

A datapoint of Index. Corresponds to the JSON property datapoint



9597
9598
9599
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9597

def datapoint
  @datapoint
end

#fraction_leaf_nodes_to_search_overrideFloat

The fraction of the number of leaves to search, set at query time allows user to tune search performance. This value increase result in both search accuracy and latency increase. The value should be between 0.0 and 1.0. If not set or set to 0.0, query uses the default value specified in NearestNeighborSearchConfig.TreeAHConfig.fraction_leaf_nodes_to_search. Corresponds to the JSON property fractionLeafNodesToSearchOverride

Returns:

  • (Float)


9606
9607
9608
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9606

def fraction_leaf_nodes_to_search_override
  @fraction_leaf_nodes_to_search_override
end

#neighbor_countFixnum

The number of nearest neighbors to be retrieved from database for each query. If not set, will use the default from the service configuration (https://cloud. google.com/vertex-ai/docs/matching-engine/configuring-indexes#nearest-neighbor- search-config). Corresponds to the JSON property neighborCount

Returns:

  • (Fixnum)


9614
9615
9616
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9614

def neighbor_count
  @neighbor_count
end

#per_crowding_attribute_neighbor_countFixnum

Crowding is a constraint on a neighbor list produced by nearest neighbor search requiring that no more than some value k' of the k neighbors returned have the same value of crowding_attribute. It's used for improving result diversity. This field is the maximum number of matches with the same crowding tag. Corresponds to the JSON property perCrowdingAttributeNeighborCount

Returns:

  • (Fixnum)


9623
9624
9625
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9623

def per_crowding_attribute_neighbor_count
  @per_crowding_attribute_neighbor_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9630
9631
9632
9633
9634
9635
9636
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9630

def update!(**args)
  @approximate_neighbor_count = args[:approximate_neighbor_count] if args.key?(:approximate_neighbor_count)
  @datapoint = args[:datapoint] if args.key?(:datapoint)
  @fraction_leaf_nodes_to_search_override = args[:fraction_leaf_nodes_to_search_override] if args.key?(:fraction_leaf_nodes_to_search_override)
  @neighbor_count = args[:neighbor_count] if args.key?(:neighbor_count)
  @per_crowding_attribute_neighbor_count = args[:per_crowding_attribute_neighbor_count] if args.key?(:per_crowding_attribute_neighbor_count)
end