Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FindNeighborsRequestQueryRrf

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Parameters for RRF algorithm that combines search results.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FindNeighborsRequestQueryRrf

Returns a new instance of GoogleCloudAiplatformV1FindNeighborsRequestQueryRrf.



15155
15156
15157
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15155

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#alphaFloat

Required. Users can provide an alpha value to give more weight to dense vs sparse results. For example, if the alpha is 0, we only return sparse and if the alpha is 1, we only return dense. Corresponds to the JSON property alpha

Returns:

  • (Float)


15153
15154
15155
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15153

def alpha
  @alpha
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15160
15161
15162
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15160

def update!(**args)
  @alpha = args[:alpha] if args.key?(:alpha)
end