Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FindNeighborsResponseNeighbor

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A neighbor of the query vector.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FindNeighborsResponseNeighbor

Returns a new instance of GoogleCloudAiplatformV1FindNeighborsResponseNeighbor.



12196
12197
12198
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12196

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#datapointGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapoint

A datapoint of Index. Corresponds to the JSON property datapoint



12184
12185
12186
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12184

def datapoint
  @datapoint
end

#distanceFloat

The distance between the neighbor and the dense embedding query. Corresponds to the JSON property distance

Returns:

  • (Float)


12189
12190
12191
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12189

def distance
  @distance
end

#sparse_distanceFloat

The distance between the neighbor and the query sparse_embedding. Corresponds to the JSON property sparseDistance

Returns:

  • (Float)


12194
12195
12196
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12194

def sparse_distance
  @sparse_distance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12201
12202
12203
12204
12205
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12201

def update!(**args)
  @datapoint = args[:datapoint] if args.key?(:datapoint)
  @distance = args[:distance] if args.key?(:distance)
  @sparse_distance = args[:sparse_distance] if args.key?(:sparse_distance)
end