Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FindNeighborsResponseNeighbor
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FindNeighborsResponseNeighbor
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A neighbor of the query vector.
Instance Attribute Summary collapse
-
#datapoint ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapoint
A datapoint of Index.
-
#distance ⇒ Float
The distance between the neighbor and the dense embedding query.
-
#sparse_distance ⇒ Float
The distance between the neighbor and the query sparse_embedding.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1FindNeighborsResponseNeighbor
constructor
A new instance of GoogleCloudAiplatformV1FindNeighborsResponseNeighbor.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1FindNeighborsResponseNeighbor
Returns a new instance of GoogleCloudAiplatformV1FindNeighborsResponseNeighbor.
12021 12022 12023 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12021 def initialize(**args) update!(**args) end |
Instance Attribute Details
#datapoint ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapoint
A datapoint of Index.
Corresponds to the JSON property datapoint
12009 12010 12011 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12009 def datapoint @datapoint end |
#distance ⇒ Float
The distance between the neighbor and the dense embedding query.
Corresponds to the JSON property distance
12014 12015 12016 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12014 def distance @distance end |
#sparse_distance ⇒ Float
The distance between the neighbor and the query sparse_embedding.
Corresponds to the JSON property sparseDistance
12019 12020 12021 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12019 def sparse_distance @sparse_distance end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12026 12027 12028 12029 12030 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12026 def update!(**args) @datapoint = args[:datapoint] if args.key?(:datapoint) @distance = args[:distance] if args.key?(:distance) @sparse_distance = args[:sparse_distance] if args.key?(:sparse_distance) end |