Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FindNeighborsResponseNeighbor

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A neighbor of the query vector.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FindNeighborsResponseNeighbor

Returns a new instance of GoogleCloudAiplatformV1FindNeighborsResponseNeighbor.



11725
11726
11727
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11725

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#datapointGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapoint

A datapoint of Index. Corresponds to the JSON property datapoint



11713
11714
11715
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11713

def datapoint
  @datapoint
end

#distanceFloat

The distance between the neighbor and the dense embedding query. Corresponds to the JSON property distance

Returns:

  • (Float)


11718
11719
11720
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11718

def distance
  @distance
end

#sparse_distanceFloat

The distance between the neighbor and the query sparse_embedding. Corresponds to the JSON property sparseDistance

Returns:

  • (Float)


11723
11724
11725
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11723

def sparse_distance
  @sparse_distance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11730
11731
11732
11733
11734
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11730

def update!(**args)
  @datapoint = args[:datapoint] if args.key?(:datapoint)
  @distance = args[:distance] if args.key?(:distance)
  @sparse_distance = args[:sparse_distance] if args.key?(:sparse_distance)
end