Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FractionSplit

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Assigns the input data to training, validation, and test sets as per the given fractions. Any of training_fraction, validation_fraction and test_fraction may optionally be provided, they must sum to up to 1. If the provided ones sum to less than 1, the remainder is assigned to sets as decided by Vertex AI. If none of the fractions are set, by default roughly 80% of data is used for training, 10% for validation, and 10% for test.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FractionSplit

Returns a new instance of GoogleCloudAiplatformV1FractionSplit.



9477
9478
9479
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9477

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#test_fractionFloat

The fraction of the input data that is to be used to evaluate the Model. Corresponds to the JSON property testFraction

Returns:

  • (Float)


9465
9466
9467
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9465

def test_fraction
  @test_fraction
end

#training_fractionFloat

The fraction of the input data that is to be used to train the Model. Corresponds to the JSON property trainingFraction

Returns:

  • (Float)


9470
9471
9472
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9470

def training_fraction
  @training_fraction
end

#validation_fractionFloat

The fraction of the input data that is to be used to validate the Model. Corresponds to the JSON property validationFraction

Returns:

  • (Float)


9475
9476
9477
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9475

def validation_fraction
  @validation_fraction
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9482
9483
9484
9485
9486
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9482

def update!(**args)
  @test_fraction = args[:test_fraction] if args.key?(:test_fraction)
  @training_fraction = args[:training_fraction] if args.key?(:training_fraction)
  @validation_fraction = args[:validation_fraction] if args.key?(:validation_fraction)
end