Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FunctionCall

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A predicted FunctionCall returned from the model that contains a string representing the FunctionDeclaration.name and a structured JSON object containing the parameters and their values.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FunctionCall

Returns a new instance of GoogleCloudAiplatformV1FunctionCall.



17019
17020
17021
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17019

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#argsHash<String,Object>

Optional. The function parameters and values in JSON object format. See FunctionDeclaration.parameters for parameter details. Corresponds to the JSON property args

Returns:

  • (Hash<String,Object>)


16993
16994
16995
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16993

def args
  @args
end

#idString

Optional. The unique id of the function call. If populated, the client to execute the function_call and return the response with the matching id. Corresponds to the JSON property id

Returns:

  • (String)


16999
17000
17001
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16999

def id
  @id
end

#nameString

Optional. The name of the function to call. Matches FunctionDeclaration.name. Corresponds to the JSON property name

Returns:

  • (String)


17004
17005
17006
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17004

def name
  @name
end

#partial_argsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PartialArg>

Optional. The partial argument value of the function call. If provided, represents the arguments/fields that are streamed incrementally. Corresponds to the JSON property partialArgs



17010
17011
17012
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17010

def partial_args
  @partial_args
end

#will_continueBoolean Also known as: will_continue?

Optional. Whether this is the last part of the FunctionCall. If true, another partial message for the current FunctionCall is expected to follow. Corresponds to the JSON property willContinue

Returns:

  • (Boolean)


17016
17017
17018
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17016

def will_continue
  @will_continue
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17024
17025
17026
17027
17028
17029
17030
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17024

def update!(**args)
  @args = args[:args] if args.key?(:args)
  @id = args[:id] if args.key?(:id)
  @name = args[:name] if args.key?(:name)
  @partial_args = args[:partial_args] if args.key?(:partial_args)
  @will_continue = args[:will_continue] if args.key?(:will_continue)
end