Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FunctionCall

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A predicted FunctionCall returned from the model that contains a string representing the FunctionDeclaration.name and a structured JSON object containing the parameters and their values.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FunctionCall

Returns a new instance of GoogleCloudAiplatformV1FunctionCall.



15547
15548
15549
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15547

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#argsHash<String,Object>

Optional. The function parameters and values in JSON object format. See FunctionDeclaration.parameters for parameter details. Corresponds to the JSON property args

Returns:

  • (Hash<String,Object>)


15527
15528
15529
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15527

def args
  @args
end

#nameString

Optional. The name of the function to call. Matches FunctionDeclaration.name. Corresponds to the JSON property name

Returns:

  • (String)


15532
15533
15534
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15532

def name
  @name
end

#partial_argsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PartialArg>

Optional. The partial argument value of the function call. If provided, represents the arguments/fields that are streamed incrementally. Corresponds to the JSON property partialArgs



15538
15539
15540
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15538

def partial_args
  @partial_args
end

#will_continueBoolean Also known as: will_continue?

Optional. Whether this is the last part of the FunctionCall. If true, another partial message for the current FunctionCall is expected to follow. Corresponds to the JSON property willContinue

Returns:

  • (Boolean)


15544
15545
15546
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15544

def will_continue
  @will_continue
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15552
15553
15554
15555
15556
15557
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15552

def update!(**args)
  @args = args[:args] if args.key?(:args)
  @name = args[:name] if args.key?(:name)
  @partial_args = args[:partial_args] if args.key?(:partial_args)
  @will_continue = args[:will_continue] if args.key?(:will_continue)
end