Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FunctionCall

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A predicted [FunctionCall] returned from the model that contains a string representing the [FunctionDeclaration.name] and a structured JSON object containing the parameters and their values.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FunctionCall

Returns a new instance of GoogleCloudAiplatformV1FunctionCall.



14584
14585
14586
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14584

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#argsHash<String,Object>

Optional. The function parameters and values in JSON object format. See [ FunctionDeclaration.parameters] for parameter details. Corresponds to the JSON property args

Returns:

  • (Hash<String,Object>)


14564
14565
14566
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14564

def args
  @args
end

#nameString

Optional. The name of the function to call. Matches [FunctionDeclaration.name]. Corresponds to the JSON property name

Returns:

  • (String)


14569
14570
14571
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14569

def name
  @name
end

#partial_argsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PartialArg>

Optional. The partial argument value of the function call. If provided, represents the arguments/fields that are streamed incrementally. Corresponds to the JSON property partialArgs



14575
14576
14577
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14575

def partial_args
  @partial_args
end

#will_continueBoolean Also known as: will_continue?

Optional. Whether this is the last part of the FunctionCall. If true, another partial message for the current FunctionCall is expected to follow. Corresponds to the JSON property willContinue

Returns:

  • (Boolean)


14581
14582
14583
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14581

def will_continue
  @will_continue
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14589
14590
14591
14592
14593
14594
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14589

def update!(**args)
  @args = args[:args] if args.key?(:args)
  @name = args[:name] if args.key?(:name)
  @partial_args = args[:partial_args] if args.key?(:partial_args)
  @will_continue = args[:will_continue] if args.key?(:will_continue)
end