Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FunctionCallingConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Function calling config.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FunctionCallingConfig

Returns a new instance of GoogleCloudAiplatformV1FunctionCallingConfig.



15537
15538
15539
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15537

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowed_function_namesArray<String>

Optional. Function names to call. Only set when the Mode is ANY. Function names should match FunctionDeclaration.name. With mode set to ANY, model will predict a function call from the set of function names provided. Corresponds to the JSON property allowedFunctionNames

Returns:

  • (Array<String>)


15522
15523
15524
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15522

def allowed_function_names
  @allowed_function_names
end

#modeString

Optional. Function calling mode. Corresponds to the JSON property mode

Returns:

  • (String)


15527
15528
15529
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15527

def mode
  @mode
end

#stream_function_call_argumentsBoolean Also known as: stream_function_call_arguments?

Optional. When set to true, arguments of a single function call will be streamed out in multiple parts/contents/responses. Partial parameter results will be returned in the FunctionCall.partial_args field. Corresponds to the JSON property streamFunctionCallArguments

Returns:

  • (Boolean)


15534
15535
15536
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15534

def stream_function_call_arguments
  @stream_function_call_arguments
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15542
15543
15544
15545
15546
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15542

def update!(**args)
  @allowed_function_names = args[:allowed_function_names] if args.key?(:allowed_function_names)
  @mode = args[:mode] if args.key?(:mode)
  @stream_function_call_arguments = args[:stream_function_call_arguments] if args.key?(:stream_function_call_arguments)
end