Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FunctionCallingConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FunctionCallingConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Function calling config.
Instance Attribute Summary collapse
-
#allowed_function_names ⇒ Array<String>
Optional.
-
#mode ⇒ String
Optional.
-
#stream_function_call_arguments ⇒ Boolean
(also: #stream_function_call_arguments?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1FunctionCallingConfig
constructor
A new instance of GoogleCloudAiplatformV1FunctionCallingConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1FunctionCallingConfig
Returns a new instance of GoogleCloudAiplatformV1FunctionCallingConfig.
14822 14823 14824 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14822 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowed_function_names ⇒ Array<String>
Optional. Function names to call. Only set when the Mode is ANY. Function
names should match [FunctionDeclaration.name]. With mode set to ANY, model
will predict a function call from the set of function names provided.
Corresponds to the JSON property allowedFunctionNames
14807 14808 14809 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14807 def allowed_function_names @allowed_function_names end |
#mode ⇒ String
Optional. Function calling mode.
Corresponds to the JSON property mode
14812 14813 14814 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14812 def mode @mode end |
#stream_function_call_arguments ⇒ Boolean Also known as: stream_function_call_arguments?
Optional. When set to true, arguments of a single function call will be
streamed out in multiple parts/contents/responses. Partial parameter results
will be returned in the [FunctionCall.partial_args] field.
Corresponds to the JSON property streamFunctionCallArguments
14819 14820 14821 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14819 def stream_function_call_arguments @stream_function_call_arguments end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14827 14828 14829 14830 14831 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14827 def update!(**args) @allowed_function_names = args[:allowed_function_names] if args.key?(:allowed_function_names) @mode = args[:mode] if args.key?(:mode) @stream_function_call_arguments = args[:stream_function_call_arguments] if args.key?(:stream_function_call_arguments) end |