Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FunctionDeclaration
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FunctionDeclaration
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Structured representation of a function declaration as defined by the OpenAPI
3.0 specification. Included in this
declaration are the function name, description, parameters and response type.
This FunctionDeclaration is a representation of a block of code that can be
used as a Tool by the model and executed by the client.
Instance Attribute Summary collapse
-
#behavior ⇒ String
Optional.
-
#description ⇒ String
Optional.
-
#name ⇒ String
Required.
-
#parameters ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema
Defines the schema of input and output data.
-
#parameters_json_schema ⇒ Object
Optional.
-
#response ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema
Defines the schema of input and output data.
-
#response_json_schema ⇒ Object
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1FunctionDeclaration
constructor
A new instance of GoogleCloudAiplatformV1FunctionDeclaration.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1FunctionDeclaration
Returns a new instance of GoogleCloudAiplatformV1FunctionDeclaration.
17126 17127 17128 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17126 def initialize(**args) update!(**args) end |
Instance Attribute Details
#behavior ⇒ String
Optional. Specifies the function Behavior. If not specified, the system keeps
the current function call behavior. This field is currently only supported by
the BidiGenerateContent method.
Corresponds to the JSON property behavior
17082 17083 17084 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17082 def behavior @behavior end |
#description ⇒ String
Optional. Description and purpose of the function. Model uses it to decide how
and whether to call the function.
Corresponds to the JSON property description
17088 17089 17090 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17088 def description @description end |
#name ⇒ String
Required. The name of the function to call. Must start with a letter or an
underscore. Must be a-z, A-Z, 0-9, or contain underscores, dots, colons and
dashes, with a maximum length of 128.
Corresponds to the JSON property name
17095 17096 17097 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17095 def name @name end |
#parameters ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema
Defines the schema of input and output data. This is a subset of the OpenAPI
3.0 Schema Object.
Corresponds to the JSON property parameters
17101 17102 17103 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17101 def parameters @parameters end |
#parameters_json_schema ⇒ Object
Optional. Describes the parameters to the function in JSON Schema format. The
schema must describe an object where the properties are the parameters to the
function. For example: ` "type": "object", "properties": ` "name": ` "type"
: "string" `, "age": ` "type": "integer" ` `, "additionalProperties": false, "
required": ["name", "age"], "propertyOrdering": ["name", "age"] ` This
field is mutually exclusive with parameters.
Corresponds to the JSON property parametersJsonSchema
17111 17112 17113 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17111 def parameters_json_schema @parameters_json_schema end |
#response ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema
Defines the schema of input and output data. This is a subset of the OpenAPI
3.0 Schema Object.
Corresponds to the JSON property response
17117 17118 17119 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17117 def response @response end |
#response_json_schema ⇒ Object
Optional. Describes the output from this function in JSON Schema format. The
value specified by the schema is the response value of the function. This
field is mutually exclusive with response.
Corresponds to the JSON property responseJsonSchema
17124 17125 17126 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17124 def response_json_schema @response_json_schema end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17131 17132 17133 17134 17135 17136 17137 17138 17139 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17131 def update!(**args) @behavior = args[:behavior] if args.key?(:behavior) @description = args[:description] if args.key?(:description) @name = args[:name] if args.key?(:name) @parameters = args[:parameters] if args.key?(:parameters) @parameters_json_schema = args[:parameters_json_schema] if args.key?(:parameters_json_schema) @response = args[:response] if args.key?(:response) @response_json_schema = args[:response_json_schema] if args.key?(:response_json_schema) end |