Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FunctionDeclaration

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Structured representation of a function declaration as defined by the OpenAPI 3.0 specification. Included in this declaration are the function name, description, parameters and response type. This FunctionDeclaration is a representation of a block of code that can be used as a Tool by the model and executed by the client.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FunctionDeclaration

Returns a new instance of GoogleCloudAiplatformV1FunctionDeclaration.



16474
16475
16476
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16474

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#behaviorString

Optional. Specifies the function Behavior. If not specified, the system keeps the current function call behavior. This field is currently only supported by the BidiGenerateContent method. Corresponds to the JSON property behavior

Returns:

  • (String)


16430
16431
16432
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16430

def behavior
  @behavior
end

#descriptionString

Optional. Description and purpose of the function. Model uses it to decide how and whether to call the function. Corresponds to the JSON property description

Returns:

  • (String)


16436
16437
16438
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16436

def description
  @description
end

#nameString

Required. The name of the function to call. Must start with a letter or an underscore. Must be a-z, A-Z, 0-9, or contain underscores, dots, colons and dashes, with a maximum length of 128. Corresponds to the JSON property name

Returns:

  • (String)


16443
16444
16445
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16443

def name
  @name
end

#parametersGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema

Defines the schema of input and output data. This is a subset of the OpenAPI 3.0 Schema Object. Corresponds to the JSON property parameters



16449
16450
16451
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16449

def parameters
  @parameters
end

#parameters_json_schemaObject

Optional. Describes the parameters to the function in JSON Schema format. The schema must describe an object where the properties are the parameters to the function. For example: ` "type": "object", "properties": ` "name": ` "type" : "string" `, "age": ` "type": "integer" ` `, "additionalProperties": false, " required": ["name", "age"], "propertyOrdering": ["name", "age"] ` This field is mutually exclusive with parameters. Corresponds to the JSON property parametersJsonSchema

Returns:

  • (Object)


16459
16460
16461
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16459

def parameters_json_schema
  @parameters_json_schema
end

#responseGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema

Defines the schema of input and output data. This is a subset of the OpenAPI 3.0 Schema Object. Corresponds to the JSON property response



16465
16466
16467
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16465

def response
  @response
end

#response_json_schemaObject

Optional. Describes the output from this function in JSON Schema format. The value specified by the schema is the response value of the function. This field is mutually exclusive with response. Corresponds to the JSON property responseJsonSchema

Returns:

  • (Object)


16472
16473
16474
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16472

def response_json_schema
  @response_json_schema
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16479
16480
16481
16482
16483
16484
16485
16486
16487
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16479

def update!(**args)
  @behavior = args[:behavior] if args.key?(:behavior)
  @description = args[:description] if args.key?(:description)
  @name = args[:name] if args.key?(:name)
  @parameters = args[:parameters] if args.key?(:parameters)
  @parameters_json_schema = args[:parameters_json_schema] if args.key?(:parameters_json_schema)
  @response = args[:response] if args.key?(:response)
  @response_json_schema = args[:response_json_schema] if args.key?(:response_json_schema)
end