Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FunctionDeclaration

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Structured representation of a function declaration as defined by the OpenAPI 3.0 specification. Included in this declaration are the function name, description, parameters and response type. This FunctionDeclaration is a representation of a block of code that can be used as a Tool by the model and executed by the client.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FunctionDeclaration

Returns a new instance of GoogleCloudAiplatformV1FunctionDeclaration.



15599
15600
15601
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15599

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Optional. Description and purpose of the function. Model uses it to decide how and whether to call the function. Corresponds to the JSON property description

Returns:

  • (String)


15561
15562
15563
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15561

def description
  @description
end

#nameString

Required. The name of the function to call. Must start with a letter or an underscore. Must be a-z, A-Z, 0-9, or contain underscores, dots, colons and dashes, with a maximum length of 128. Corresponds to the JSON property name

Returns:

  • (String)


15568
15569
15570
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15568

def name
  @name
end

#parametersGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema

Defines the schema of input and output data. This is a subset of the OpenAPI 3.0 Schema Object. Corresponds to the JSON property parameters



15574
15575
15576
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15574

def parameters
  @parameters
end

#parameters_json_schemaObject

Optional. Describes the parameters to the function in JSON Schema format. The schema must describe an object where the properties are the parameters to the function. For example: ` "type": "object", "properties": ` "name": ` "type" : "string" `, "age": ` "type": "integer" ` `, "additionalProperties": false, " required": ["name", "age"], "propertyOrdering": ["name", "age"] ` This field is mutually exclusive with parameters. Corresponds to the JSON property parametersJsonSchema

Returns:

  • (Object)


15584
15585
15586
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15584

def parameters_json_schema
  @parameters_json_schema
end

#responseGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema

Defines the schema of input and output data. This is a subset of the OpenAPI 3.0 Schema Object. Corresponds to the JSON property response



15590
15591
15592
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15590

def response
  @response
end

#response_json_schemaObject

Optional. Describes the output from this function in JSON Schema format. The value specified by the schema is the response value of the function. This field is mutually exclusive with response. Corresponds to the JSON property responseJsonSchema

Returns:

  • (Object)


15597
15598
15599
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15597

def response_json_schema
  @response_json_schema
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15604
15605
15606
15607
15608
15609
15610
15611
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15604

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @name = args[:name] if args.key?(:name)
  @parameters = args[:parameters] if args.key?(:parameters)
  @parameters_json_schema = args[:parameters_json_schema] if args.key?(:parameters_json_schema)
  @response = args[:response] if args.key?(:response)
  @response_json_schema = args[:response_json_schema] if args.key?(:response_json_schema)
end