Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FunctionDeclaration

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Structured representation of a function declaration as defined by the OpenAPI 3.0 specification. Included in this declaration are the function name, description, parameters and response type. This FunctionDeclaration is a representation of a block of code that can be used as a Tool by the model and executed by the client.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FunctionDeclaration

Returns a new instance of GoogleCloudAiplatformV1FunctionDeclaration.



11568
11569
11570
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11568

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Optional. Description and purpose of the function. Model uses it to decide how and whether to call the function. Corresponds to the JSON property description

Returns:

  • (String)


11545
11546
11547
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11545

def description
  @description
end

#nameString

Required. The name of the function to call. Must start with a letter or an underscore. Must be a-z, A-Z, 0-9, or contain underscores, dots and dashes, with a maximum length of 64. Corresponds to the JSON property name

Returns:

  • (String)


11552
11553
11554
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11552

def name
  @name
end

#parametersGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema

Schema is used to define the format of input/output data. Represents a select subset of an OpenAPI 3.0 schema object. More fields may be added in the future as needed. Corresponds to the JSON property parameters



11559
11560
11561
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11559

def parameters
  @parameters
end

#responseGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema

Schema is used to define the format of input/output data. Represents a select subset of an OpenAPI 3.0 schema object. More fields may be added in the future as needed. Corresponds to the JSON property response



11566
11567
11568
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11566

def response
  @response
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11573
11574
11575
11576
11577
11578
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11573

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @name = args[:name] if args.key?(:name)
  @parameters = args[:parameters] if args.key?(:parameters)
  @response = args[:response] if args.key?(:response)
end