Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FunctionResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The result output from a FunctionCall that contains a string representing the FunctionDeclaration.name and a structured JSON object containing any output from the function is used as context to the model. This should contain the result of a FunctionCall made based on model prediction.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FunctionResponse

Returns a new instance of GoogleCloudAiplatformV1FunctionResponse.



15648
15649
15650
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15648

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Required. The name of the function to call. Matches FunctionDeclaration.name and FunctionCall.name. Corresponds to the JSON property name

Returns:

  • (String)


15625
15626
15627
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15625

def name
  @name
end

#partsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FunctionResponsePart>

Optional. Ordered Parts that constitute a function response. Parts may have different IANA MIME types. Corresponds to the JSON property parts



15631
15632
15633
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15631

def parts
  @parts
end

#responseHash<String,Object>

Required. The function response in JSON object format. Use "output" key to specify function output and "error" key to specify error details (if any). If " output" and "error" keys are not specified, then whole "response" is treated as function output. Corresponds to the JSON property response

Returns:

  • (Hash<String,Object>)


15639
15640
15641
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15639

def response
  @response
end

#schedulingString

Optional. Specifies how the response should be scheduled in the conversation. Only applicable to NON_BLOCKING function calls, is ignored otherwise. Defaults to WHEN_IDLE. Corresponds to the JSON property scheduling

Returns:

  • (String)


15646
15647
15648
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15646

def scheduling
  @scheduling
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15653
15654
15655
15656
15657
15658
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15653

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @parts = args[:parts] if args.key?(:parts)
  @response = args[:response] if args.key?(:response)
  @scheduling = args[:scheduling] if args.key?(:scheduling)
end