Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FunctionResponseBlob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Raw media bytes for function response. Text should not be sent as raw bytes, use the 'text' field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FunctionResponseBlob

Returns a new instance of GoogleCloudAiplatformV1FunctionResponseBlob.



16561
16562
16563
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16561

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dataString

Required. Raw bytes. Corresponds to the JSON property data NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


16546
16547
16548
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16546

def data
  @data
end

#display_nameString

Optional. Display name of the blob. Used to provide a label or filename to distinguish blobs. This field is only returned in PromptMessage for prompt management. It is currently used in the Gemini GenerateContent calls only when server side tools (code_execution, google_search, and url_context) are enabled. Corresponds to the JSON property displayName

Returns:

  • (String)


16554
16555
16556
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16554

def display_name
  @display_name
end

#mime_typeString

Required. The IANA standard MIME type of the source data. Corresponds to the JSON property mimeType

Returns:

  • (String)


16559
16560
16561
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16559

def mime_type
  @mime_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16566
16567
16568
16569
16570
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16566

def update!(**args)
  @data = args[:data] if args.key?(:data)
  @display_name = args[:display_name] if args.key?(:display_name)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
end