Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FunctionResponsePart

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A datatype containing media that is part of a FunctionResponse message. A FunctionResponsePart consists of data which has an associated datatype. A FunctionResponsePart can only contain one of the accepted types in FunctionResponsePart.data. A FunctionResponsePart must have a fixed IANA MIME type identifying the type and subtype of the media if the inline_data field is filled with raw bytes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1FunctionResponsePart

Returns a new instance of GoogleCloudAiplatformV1FunctionResponsePart.



16628
16629
16630
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16628

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#file_dataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FunctionResponseFileData

URI based data for function response. Corresponds to the JSON property fileData



16620
16621
16622
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16620

def file_data
  @file_data
end

#inline_dataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FunctionResponseBlob

Raw media bytes for function response. Text should not be sent as raw bytes, use the 'text' field. Corresponds to the JSON property inlineData



16626
16627
16628
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16626

def inline_data
  @inline_data
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16633
16634
16635
16636
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16633

def update!(**args)
  @file_data = args[:file_data] if args.key?(:file_data)
  @inline_data = args[:inline_data] if args.key?(:inline_data)
end