Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GatewayConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GatewayConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Configuration for a single gateway.
Instance Attribute Summary collapse
-
#allowed_projects ⇒ Array<String>
Optional.
-
#dns_record ⇒ String
Output only.
-
#dns_zone_name ⇒ String
Optional.
-
#ip_address ⇒ String
Output only.
-
#network ⇒ String
Optional.
-
#psc_endpoint ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#subnetwork ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GatewayConfig
constructor
A new instance of GoogleCloudAiplatformV1GatewayConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GatewayConfig
Returns a new instance of GoogleCloudAiplatformV1GatewayConfig.
17375 17376 17377 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17375 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowed_projects ⇒ Array<String>
Optional. Additional consumer projects permitted to attach their own PSC
endpoint to this gateway's ServiceAttachment. This is the "decoupled" mode,
where the customer creates the PSC endpoint in a project other than this
gateway's network project. Each listed project is VPC-SC enforced: it must
be within the caller's service perimeter. The owning
SemanticGovernancePolicyEngine's own project is always permitted implicitly
and need not be listed. Format: projects/project`(ID or number).
Corresponds to the JSON propertyallowedProjects`
17326 17327 17328 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17326 def allowed_projects @allowed_projects end |
#dns_record ⇒ String
Output only. The fully qualified record name of the created A-record in Cloud
DNS.
Corresponds to the JSON property dnsRecord
17332 17333 17334 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17332 def dns_record @dns_record end |
#dns_zone_name ⇒ String
Optional. Name of the private Cloud DNS managed zone in which to create the
gateway's A-record. This is the managed zone's own name, not its DNS name: for
a zone serving example.internal., this field takes the zone name, such as
my-private-zone. The zone's DNS name is combined with a generated per-gateway
label to form the record's fully qualified name, which must stay within the
255-octet DNS limit. If the full name is too long, gateway provisioning fails
when it attempts to create the DNS record.
Corresponds to the JSON property dnsZoneName
17343 17344 17345 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17343 def dns_zone_name @dns_zone_name end |
#ip_address ⇒ String
Output only. The private IP address of the PSC endpoint.
Corresponds to the JSON property ipAddress
17348 17349 17350 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17348 def ip_address @ip_address end |
#network ⇒ String
Optional. The URI of the network resource where PSC-E will be provisioned. if
not provided default network will be used. Format: projects/project/global/
networks/network
Corresponds to the JSON property network
17355 17356 17357 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17355 def network @network end |
#psc_endpoint ⇒ String
Output only. The self-link or name of the Private Service Connect endpoint
forwarding rule.
Corresponds to the JSON property pscEndpoint
17361 17362 17363 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17361 def psc_endpoint @psc_endpoint end |
#state ⇒ String
Output only. The state of the Gateway configuration.
Corresponds to the JSON property state
17366 17367 17368 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17366 def state @state end |
#subnetwork ⇒ String
Optional. The URI of the subnetwork resource where PSC-E will be provisioned.
if not provided default subnet will be used from the same location Format:
projects/project/regions/region/subnetworks/subnetwork
Corresponds to the JSON property subnetwork
17373 17374 17375 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17373 def subnetwork @subnetwork end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17380 17381 17382 17383 17384 17385 17386 17387 17388 17389 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17380 def update!(**args) @allowed_projects = args[:allowed_projects] if args.key?(:allowed_projects) @dns_record = args[:dns_record] if args.key?(:dns_record) @dns_zone_name = args[:dns_zone_name] if args.key?(:dns_zone_name) @ip_address = args[:ip_address] if args.key?(:ip_address) @network = args[:network] if args.key?(:network) @psc_endpoint = args[:psc_endpoint] if args.key?(:psc_endpoint) @state = args[:state] if args.key?(:state) @subnetwork = args[:subnetwork] if args.key?(:subnetwork) end |