Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GatewayConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GatewayConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Configuration for a single gateway.
Instance Attribute Summary collapse
-
#allowed_projects ⇒ Array<String>
Optional.
-
#dns_record ⇒ String
Output only.
-
#dns_zone_name ⇒ String
Optional.
-
#ip_address ⇒ String
Output only.
-
#network ⇒ String
Optional.
-
#psc_endpoint ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#subnetwork ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GatewayConfig
constructor
A new instance of GoogleCloudAiplatformV1GatewayConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GatewayConfig
Returns a new instance of GoogleCloudAiplatformV1GatewayConfig.
16978 16979 16980 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16978 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowed_projects ⇒ Array<String>
Optional. Additional consumer projects permitted to attach their own PSC
endpoint to this gateway's ServiceAttachment. This is the "decoupled" mode,
where the customer creates the PSC endpoint in a project other than this
gateway's network project. Each listed project is VPC-SC enforced: it must
be within the caller's service perimeter. The owning
SemanticGovernancePolicyEngine's own project is always permitted implicitly
and need not be listed. Format: project ID or number.
Corresponds to the JSON property allowedProjects
16934 16935 16936 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16934 def allowed_projects @allowed_projects end |
#dns_record ⇒ String
Output only. The fully qualified record name of the created A-record in Cloud
DNS.
Corresponds to the JSON property dnsRecord
16940 16941 16942 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16940 def dns_record @dns_record end |
#dns_zone_name ⇒ String
Optional. FQDN of the private DNS zone to create DNS record set for PSC
endpoint.
Corresponds to the JSON property dnsZoneName
16946 16947 16948 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16946 def dns_zone_name @dns_zone_name end |
#ip_address ⇒ String
Output only. The private IP address of the PSC endpoint.
Corresponds to the JSON property ipAddress
16951 16952 16953 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16951 def ip_address @ip_address end |
#network ⇒ String
Optional. The URI of the network resource where PSC-E will be provisioned. if
not provided default network will be used. Format: projects/project/global/
networks/network
Corresponds to the JSON property network
16958 16959 16960 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16958 def network @network end |
#psc_endpoint ⇒ String
Output only. The self-link or name of the Private Service Connect endpoint
forwarding rule.
Corresponds to the JSON property pscEndpoint
16964 16965 16966 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16964 def psc_endpoint @psc_endpoint end |
#state ⇒ String
Output only. The state of the Gateway configuration.
Corresponds to the JSON property state
16969 16970 16971 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16969 def state @state end |
#subnetwork ⇒ String
Optional. The URI of the subnetwork resource where PSC-E will be provisioned.
if not provided default subnet will be used from the same location Format:
projects/project/regions/region/subnetworks/subnetwork
Corresponds to the JSON property subnetwork
16976 16977 16978 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16976 def subnetwork @subnetwork end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16983 16984 16985 16986 16987 16988 16989 16990 16991 16992 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16983 def update!(**args) @allowed_projects = args[:allowed_projects] if args.key?(:allowed_projects) @dns_record = args[:dns_record] if args.key?(:dns_record) @dns_zone_name = args[:dns_zone_name] if args.key?(:dns_zone_name) @ip_address = args[:ip_address] if args.key?(:ip_address) @network = args[:network] if args.key?(:network) @psc_endpoint = args[:psc_endpoint] if args.key?(:psc_endpoint) @state = args[:state] if args.key?(:state) @subnetwork = args[:subnetwork] if args.key?(:subnetwork) end |