Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GatewayConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Configuration for a single gateway.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GatewayConfig

Returns a new instance of GoogleCloudAiplatformV1GatewayConfig.



16672
16673
16674
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16672

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dns_recordString

Output only. The fully qualified record name of the created A-record in Cloud DNS. Corresponds to the JSON property dnsRecord

Returns:

  • (String)


16634
16635
16636
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16634

def dns_record
  @dns_record
end

#dns_zone_nameString

Optional. FQDN of the private DNS zone to create DNS record set for PSC endpoint. Corresponds to the JSON property dnsZoneName

Returns:

  • (String)


16640
16641
16642
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16640

def dns_zone_name
  @dns_zone_name
end

#ip_addressString

Output only. The private IP address of the PSC endpoint. Corresponds to the JSON property ipAddress

Returns:

  • (String)


16645
16646
16647
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16645

def ip_address
  @ip_address
end

#networkString

Optional. The URI of the network resource where PSC-E will be provisioned. if not provided default network will be used. Format: projects/project/global/ networks/network Corresponds to the JSON property network

Returns:

  • (String)


16652
16653
16654
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16652

def network
  @network
end

#psc_endpointString

Output only. The self-link or name of the Private Service Connect endpoint forwarding rule. Corresponds to the JSON property pscEndpoint

Returns:

  • (String)


16658
16659
16660
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16658

def psc_endpoint
  @psc_endpoint
end

#stateString

Output only. The state of the Gateway configuration. Corresponds to the JSON property state

Returns:

  • (String)


16663
16664
16665
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16663

def state
  @state
end

#subnetworkString

Optional. The URI of the subnetwork resource where PSC-E will be provisioned. if not provided default subnet will be used from the same location Format: projects/project/regions/region/subnetworks/subnetwork Corresponds to the JSON property subnetwork

Returns:

  • (String)


16670
16671
16672
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16670

def subnetwork
  @subnetwork
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16677
16678
16679
16680
16681
16682
16683
16684
16685
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16677

def update!(**args)
  @dns_record = args[:dns_record] if args.key?(:dns_record)
  @dns_zone_name = args[:dns_zone_name] if args.key?(:dns_zone_name)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @network = args[:network] if args.key?(:network)
  @psc_endpoint = args[:psc_endpoint] if args.key?(:psc_endpoint)
  @state = args[:state] if args.key?(:state)
  @subnetwork = args[:subnetwork] if args.key?(:subnetwork)
end