Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GatewayConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GatewayConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Configuration for a single gateway.
Instance Attribute Summary collapse
-
#dns_record ⇒ String
Output only.
-
#dns_zone_name ⇒ String
Optional.
-
#ip_address ⇒ String
Output only.
-
#network ⇒ String
Optional.
-
#psc_endpoint ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#subnetwork ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GatewayConfig
constructor
A new instance of GoogleCloudAiplatformV1GatewayConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GatewayConfig
Returns a new instance of GoogleCloudAiplatformV1GatewayConfig.
16343 16344 16345 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16343 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dns_record ⇒ String
Output only. The fully qualified record name of the created A-record in Cloud
DNS.
Corresponds to the JSON property dnsRecord
16305 16306 16307 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16305 def dns_record @dns_record end |
#dns_zone_name ⇒ String
Optional. FQDN of the private DNS zone to create DNS record set for PSC
endpoint.
Corresponds to the JSON property dnsZoneName
16311 16312 16313 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16311 def dns_zone_name @dns_zone_name end |
#ip_address ⇒ String
Output only. The private IP address of the PSC endpoint.
Corresponds to the JSON property ipAddress
16316 16317 16318 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16316 def ip_address @ip_address end |
#network ⇒ String
Optional. The URI of the network resource where PSC-E will be provisioned. if
not provided default network will be used. Format: projects/project/global/
networks/network
Corresponds to the JSON property network
16323 16324 16325 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16323 def network @network end |
#psc_endpoint ⇒ String
Output only. The self-link or name of the Private Service Connect endpoint
forwarding rule.
Corresponds to the JSON property pscEndpoint
16329 16330 16331 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16329 def psc_endpoint @psc_endpoint end |
#state ⇒ String
Output only. The state of the Gateway configuration.
Corresponds to the JSON property state
16334 16335 16336 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16334 def state @state end |
#subnetwork ⇒ String
Optional. The URI of the subnetwork resource where PSC-E will be provisioned.
if not provided default subnet will be used from the same location Format:
projects/project/regions/region/subnetworks/subnetwork
Corresponds to the JSON property subnetwork
16341 16342 16343 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16341 def subnetwork @subnetwork end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16348 16349 16350 16351 16352 16353 16354 16355 16356 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16348 def update!(**args) @dns_record = args[:dns_record] if args.key?(:dns_record) @dns_zone_name = args[:dns_zone_name] if args.key?(:dns_zone_name) @ip_address = args[:ip_address] if args.key?(:ip_address) @network = args[:network] if args.key?(:network) @psc_endpoint = args[:psc_endpoint] if args.key?(:psc_endpoint) @state = args[:state] if args.key?(:state) @subnetwork = args[:subnetwork] if args.key?(:subnetwork) end |