Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for [PredictionService.GenerateContent].

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateContentRequest

Returns a new instance of GoogleCloudAiplatformV1GenerateContentRequest.



11855
11856
11857
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11855

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cached_contentString

Optional. The name of the cached content used as context to serve the prediction. Note: only used in explicit caching, where users can have control over caching (e.g. what content to cache) and enjoy guaranteed cost savings. Format: projects/project/locations/location/cachedContents/cachedContent Corresponds to the JSON property cachedContent

Returns:

  • (String)


11805
11806
11807
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11805

def cached_content
  @cached_content
end

#contentsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content>

Required. The content of the current conversation with the model. For single- turn queries, this is a single instance. For multi-turn queries, this is a repeated field that contains conversation history + latest request. Corresponds to the JSON property contents



11812
11813
11814
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11812

def contents
  @contents
end

#generation_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfig

Generation config. Corresponds to the JSON property generationConfig



11817
11818
11819
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11817

def generation_config
  @generation_config
end

#labelsHash<String,String>

Optional. The labels with user-defined metadata for the request. It is used for billing and reporting only. Label keys and values can be no longer than 63 characters (Unicode codepoints) and can only contain lowercase letters, numeric characters, underscores, and dashes. International characters are allowed. Label values are optional. Label keys must start with a letter. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


11826
11827
11828
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11826

def labels
  @labels
end

#safety_settingsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetySetting>

Optional. Per request settings for blocking unsafe content. Enforced on GenerateContentResponse.candidates. Corresponds to the JSON property safetySettings



11832
11833
11834
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11832

def safety_settings
  @safety_settings
end

#system_instructionGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Content

The base structured datatype containing multi-part content of a message. A Content includes a role field designating the producer of the Content and a parts field containing multi-part data that contains the content of the message turn. Corresponds to the JSON property systemInstruction



11840
11841
11842
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11840

def system_instruction
  @system_instruction
end

#tool_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolConfig

Tool config. This config is shared for all tools provided in the request. Corresponds to the JSON property toolConfig



11845
11846
11847
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11845

def tool_config
  @tool_config
end

#toolsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tool>

Optional. A list of Tools the model may use to generate the next response. A Tool is a piece of code that enables the system to interact with external systems to perform an action, or set of actions, outside of knowledge and scope of the model. Corresponds to the JSON property tools



11853
11854
11855
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11853

def tools
  @tools
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11860
11861
11862
11863
11864
11865
11866
11867
11868
11869
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11860

def update!(**args)
  @cached_content = args[:cached_content] if args.key?(:cached_content)
  @contents = args[:contents] if args.key?(:contents)
  @generation_config = args[:generation_config] if args.key?(:generation_config)
  @labels = args[:labels] if args.key?(:labels)
  @safety_settings = args[:safety_settings] if args.key?(:safety_settings)
  @system_instruction = args[:system_instruction] if args.key?(:system_instruction)
  @tool_config = args[:tool_config] if args.key?(:tool_config)
  @tools = args[:tools] if args.key?(:tools)
end