Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Request message for [PredictionService.GenerateContent].
Instance Attribute Summary collapse
-
#cached_content ⇒ String
Optional.
-
#contents ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content>
Required.
-
#generation_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfig
Generation config.
-
#labels ⇒ Hash<String,String>
Optional.
-
#safety_settings ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetySetting>
Optional.
-
#system_instruction ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content
The base structured datatype containing multi-part content of a message.
-
#tool_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolConfig
Tool config.
-
#tools ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tool>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateContentRequest
constructor
A new instance of GoogleCloudAiplatformV1GenerateContentRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateContentRequest
Returns a new instance of GoogleCloudAiplatformV1GenerateContentRequest.
11757 11758 11759 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11757 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cached_content ⇒ String
Optional. The name of the cached content used as context to serve the
prediction. Note: only used in explicit caching, where users can have control
over caching (e.g. what content to cache) and enjoy guaranteed cost savings.
Format: projects/project/locations/location/cachedContents/cachedContent
Corresponds to the JSON property cachedContent
11707 11708 11709 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11707 def cached_content @cached_content end |
#contents ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content>
Required. The content of the current conversation with the model. For single-
turn queries, this is a single instance. For multi-turn queries, this is a
repeated field that contains conversation history + latest request.
Corresponds to the JSON property contents
11714 11715 11716 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11714 def contents @contents end |
#generation_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfig
Generation config.
Corresponds to the JSON property generationConfig
11719 11720 11721 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11719 def generation_config @generation_config end |
#labels ⇒ Hash<String,String>
Optional. The labels with user-defined metadata for the request. It is used
for billing and reporting only. Label keys and values can be no longer than 63
characters (Unicode codepoints) and can only contain lowercase letters,
numeric characters, underscores, and dashes. International characters are
allowed. Label values are optional. Label keys must start with a letter.
Corresponds to the JSON property labels
11728 11729 11730 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11728 def labels @labels end |
#safety_settings ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetySetting>
Optional. Per request settings for blocking unsafe content. Enforced on
GenerateContentResponse.candidates.
Corresponds to the JSON property safetySettings
11734 11735 11736 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11734 def safety_settings @safety_settings end |
#system_instruction ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content
The base structured datatype containing multi-part content of a message. A
Content includes a role field designating the producer of the Content and
a parts field containing multi-part data that contains the content of the
message turn.
Corresponds to the JSON property systemInstruction
11742 11743 11744 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11742 def system_instruction @system_instruction end |
#tool_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolConfig
Tool config. This config is shared for all tools provided in the request.
Corresponds to the JSON property toolConfig
11747 11748 11749 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11747 def tool_config @tool_config end |
#tools ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tool>
Optional. A list of Tools the model may use to generate the next response. A
Tool is a piece of code that enables the system to interact with external
systems to perform an action, or set of actions, outside of knowledge and
scope of the model.
Corresponds to the JSON property tools
11755 11756 11757 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11755 def tools @tools end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11762 11763 11764 11765 11766 11767 11768 11769 11770 11771 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11762 def update!(**args) @cached_content = args[:cached_content] if args.key?(:cached_content) @contents = args[:contents] if args.key?(:contents) @generation_config = args[:generation_config] if args.key?(:generation_config) @labels = args[:labels] if args.key?(:labels) @safety_settings = args[:safety_settings] if args.key?(:safety_settings) @system_instruction = args[:system_instruction] if args.key?(:system_instruction) @tool_config = args[:tool_config] if args.key?(:tool_config) @tools = args[:tools] if args.key?(:tools) end |