Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Request message for [PredictionService.GenerateContent].
Instance Attribute Summary collapse
-
#contents ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content>
Required.
-
#generation_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfig
Generation config.
-
#safety_settings ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetySetting>
Optional.
-
#system_instruction ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content
The base structured datatype containing multi-part content of a message.
-
#tool_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolConfig
Tool config.
-
#tools ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tool>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateContentRequest
constructor
A new instance of GoogleCloudAiplatformV1GenerateContentRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateContentRequest
Returns a new instance of GoogleCloudAiplatformV1GenerateContentRequest.
10298 10299 10300 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10298 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contents ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content>
Required. The content of the current conversation with the model. For single-
turn queries, this is a single instance. For multi-turn queries, this is a
repeated field that contains conversation history + latest request.
Corresponds to the JSON property contents
10264 10265 10266 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10264 def contents @contents end |
#generation_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfig
Generation config.
Corresponds to the JSON property generationConfig
10269 10270 10271 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10269 def generation_config @generation_config end |
#safety_settings ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetySetting>
Optional. Per request settings for blocking unsafe content. Enforced on
GenerateContentResponse.candidates.
Corresponds to the JSON property safetySettings
10275 10276 10277 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10275 def safety_settings @safety_settings end |
#system_instruction ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content
The base structured datatype containing multi-part content of a message. A
Content includes a role field designating the producer of the Content and
a parts field containing multi-part data that contains the content of the
message turn.
Corresponds to the JSON property systemInstruction
10283 10284 10285 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10283 def system_instruction @system_instruction end |
#tool_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolConfig
Tool config. This config is shared for all tools provided in the request.
Corresponds to the JSON property toolConfig
10288 10289 10290 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10288 def tool_config @tool_config end |
#tools ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tool>
Optional. A list of Tools the model may use to generate the next response. A
Tool is a piece of code that enables the system to interact with external
systems to perform an action, or set of actions, outside of knowledge and
scope of the model.
Corresponds to the JSON property tools
10296 10297 10298 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10296 def tools @tools end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10303 10304 10305 10306 10307 10308 10309 10310 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10303 def update!(**args) @contents = args[:contents] if args.key?(:contents) @generation_config = args[:generation_config] if args.key?(:generation_config) @safety_settings = args[:safety_settings] if args.key?(:safety_settings) @system_instruction = args[:system_instruction] if args.key?(:system_instruction) @tool_config = args[:tool_config] if args.key?(:tool_config) @tools = args[:tools] if args.key?(:tools) end |