Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Request message for [PredictionService.GenerateContent].
Instance Attribute Summary collapse
-
#contents ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content>
Required.
-
#generation_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfig
Generation config.
-
#safety_settings ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetySetting>
Optional.
-
#system_instruction ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content
The base structured datatype containing multi-part content of a message.
-
#tools ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tool>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateContentRequest
constructor
A new instance of GoogleCloudAiplatformV1GenerateContentRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateContentRequest
Returns a new instance of GoogleCloudAiplatformV1GenerateContentRequest.
9921 9922 9923 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9921 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contents ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content>
Required. The content of the current conversation with the model. For single-
turn queries, this is a single instance. For multi-turn queries, this is a
repeated field that contains conversation history + latest request.
Corresponds to the JSON property contents
9892 9893 9894 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9892 def contents @contents end |
#generation_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfig
Generation config.
Corresponds to the JSON property generationConfig
9897 9898 9899 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9897 def generation_config @generation_config end |
#safety_settings ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetySetting>
Optional. Per request settings for blocking unsafe content. Enforced on
GenerateContentResponse.candidates.
Corresponds to the JSON property safetySettings
9903 9904 9905 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9903 def safety_settings @safety_settings end |
#system_instruction ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content
The base structured datatype containing multi-part content of a message. A
Content includes a role field designating the producer of the Content and
a parts field containing multi-part data that contains the content of the
message turn.
Corresponds to the JSON property systemInstruction
9911 9912 9913 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9911 def system_instruction @system_instruction end |
#tools ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tool>
Optional. A list of Tools the model may use to generate the next response. A
Tool is a piece of code that enables the system to interact with external
systems to perform an action, or set of actions, outside of knowledge and
scope of the model.
Corresponds to the JSON property tools
9919 9920 9921 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9919 def tools @tools end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9926 9927 9928 9929 9930 9931 9932 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9926 def update!(**args) @contents = args[:contents] if args.key?(:contents) @generation_config = args[:generation_config] if args.key?(:generation_config) @safety_settings = args[:safety_settings] if args.key?(:safety_settings) @system_instruction = args[:system_instruction] if args.key?(:system_instruction) @tools = args[:tools] if args.key?(:tools) end |