Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for [PredictionService.GenerateContent].

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateContentRequest

Returns a new instance of GoogleCloudAiplatformV1GenerateContentRequest.



9909
9910
9911
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9909

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content>

Required. The content of the current conversation with the model. For single- turn queries, this is a single instance. For multi-turn queries, this is a repeated field that contains conversation history + latest request. Corresponds to the JSON property contents



9880
9881
9882
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9880

def contents
  @contents
end

#generation_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfig

Generation config. Corresponds to the JSON property generationConfig



9885
9886
9887
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9885

def generation_config
  @generation_config
end

#safety_settingsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetySetting>

Optional. Per request settings for blocking unsafe content. Enforced on GenerateContentResponse.candidates. Corresponds to the JSON property safetySettings



9891
9892
9893
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9891

def safety_settings
  @safety_settings
end

#system_instructionGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Content

The base structured datatype containing multi-part content of a message. A Content includes a role field designating the producer of the Content and a parts field containing multi-part data that contains the content of the message turn. Corresponds to the JSON property systemInstruction



9899
9900
9901
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9899

def system_instruction
  @system_instruction
end

#toolsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tool>

Optional. A list of Tools the model may use to generate the next response. A Tool is a piece of code that enables the system to interact with external systems to perform an action, or set of actions, outside of knowledge and scope of the model. Corresponds to the JSON property tools



9907
9908
9909
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9907

def tools
  @tools
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9914
9915
9916
9917
9918
9919
9920
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9914

def update!(**args)
  @contents = args[:contents] if args.key?(:contents)
  @generation_config = args[:generation_config] if args.key?(:generation_config)
  @safety_settings = args[:safety_settings] if args.key?(:safety_settings)
  @system_instruction = args[:system_instruction] if args.key?(:system_instruction)
  @tools = args[:tools] if args.key?(:tools)
end