Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for [PredictionService.GenerateContent].

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateContentRequest

Returns a new instance of GoogleCloudAiplatformV1GenerateContentRequest.



9658
9659
9660
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9658

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content>

Required. The content of the current conversation with the model. For single- turn queries, this is a single instance. For multi-turn queries, this is a repeated field that contains conversation history + latest request. Corresponds to the JSON property contents



9637
9638
9639
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9637

def contents
  @contents
end

#generation_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfig

Generation config. Corresponds to the JSON property generationConfig



9642
9643
9644
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9642

def generation_config
  @generation_config
end

#safety_settingsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetySetting>

Optional. Per request settings for blocking unsafe content. Enforced on GenerateContentResponse.candidates. Corresponds to the JSON property safetySettings



9648
9649
9650
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9648

def safety_settings
  @safety_settings
end

#toolsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tool>

Optional. A list of Tools the model may use to generate the next response. A Tool is a piece of code that enables the system to interact with external systems to perform an action, or set of actions, outside of knowledge and scope of the model. Corresponds to the JSON property tools



9656
9657
9658
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9656

def tools
  @tools
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9663
9664
9665
9666
9667
9668
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9663

def update!(**args)
  @contents = args[:contents] if args.key?(:contents)
  @generation_config = args[:generation_config] if args.key?(:generation_config)
  @safety_settings = args[:safety_settings] if args.key?(:safety_settings)
  @tools = args[:tools] if args.key?(:tools)
end