Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Response message for [PredictionService.GenerateContent].

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateContentResponse

Returns a new instance of GoogleCloudAiplatformV1GenerateContentResponse.



16968
16969
16970
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16968

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#candidatesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Candidate>

Output only. Generated candidates. Corresponds to the JSON property candidates



16937
16938
16939
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16937

def candidates
  @candidates
end

#create_timeString

Output only. Timestamp when the request is made to the server. Corresponds to the JSON property createTime

Returns:

  • (String)


16942
16943
16944
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16942

def create_time
  @create_time
end

#model_versionString

Output only. The model version used to generate the response. Corresponds to the JSON property modelVersion

Returns:

  • (String)


16947
16948
16949
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16947

def model_version
  @model_version
end

#prompt_feedbackGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentResponsePromptFeedback

Content filter results for a prompt sent in the request. Note: This is sent only in the first stream chunk and only if no candidates were generated due to content violations. Corresponds to the JSON property promptFeedback



16954
16955
16956
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16954

def prompt_feedback
  @prompt_feedback
end

#response_idString

Output only. response_id is used to identify each response. It is the encoding of the event_id. Corresponds to the JSON property responseId

Returns:

  • (String)


16960
16961
16962
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16960

def response_id
  @response_id
end

#usage_metadataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentResponseUsageMetadata

Usage metadata about the content generation request and response. This message provides a detailed breakdown of token usage and other relevant metrics. Corresponds to the JSON property usageMetadata



16966
16967
16968
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16966

def 
  @usage_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16973
16974
16975
16976
16977
16978
16979
16980
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16973

def update!(**args)
  @candidates = args[:candidates] if args.key?(:candidates)
  @create_time = args[:create_time] if args.key?(:create_time)
  @model_version = args[:model_version] if args.key?(:model_version)
  @prompt_feedback = args[:prompt_feedback] if args.key?(:prompt_feedback)
  @response_id = args[:response_id] if args.key?(:response_id)
  @usage_metadata = args[:usage_metadata] if args.key?(:usage_metadata)
end