Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Response message for [PredictionService.GenerateContent].
Instance Attribute Summary collapse
-
#candidates ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Candidate>
Output only.
-
#create_time ⇒ String
Output only.
-
#model_version ⇒ String
Output only.
-
#prompt_feedback ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentResponsePromptFeedback
Content filter results for a prompt sent in the request.
-
#response_id ⇒ String
Output only.
-
#usage_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentResponseUsageMetadata
Usage metadata about the content generation request and response.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateContentResponse
constructor
A new instance of GoogleCloudAiplatformV1GenerateContentResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateContentResponse
Returns a new instance of GoogleCloudAiplatformV1GenerateContentResponse.
16090 16091 16092 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16090 def initialize(**args) update!(**args) end |
Instance Attribute Details
#candidates ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Candidate>
Output only. Generated candidates.
Corresponds to the JSON property candidates
16059 16060 16061 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16059 def candidates @candidates end |
#create_time ⇒ String
Output only. Timestamp when the request is made to the server.
Corresponds to the JSON property createTime
16064 16065 16066 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16064 def create_time @create_time end |
#model_version ⇒ String
Output only. The model version used to generate the response.
Corresponds to the JSON property modelVersion
16069 16070 16071 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16069 def model_version @model_version end |
#prompt_feedback ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentResponsePromptFeedback
Content filter results for a prompt sent in the request. Note: This is sent
only in the first stream chunk and only if no candidates were generated due to
content violations.
Corresponds to the JSON property promptFeedback
16076 16077 16078 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16076 def prompt_feedback @prompt_feedback end |
#response_id ⇒ String
Output only. response_id is used to identify each response. It is the encoding
of the event_id.
Corresponds to the JSON property responseId
16082 16083 16084 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16082 def response_id @response_id end |
#usage_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentResponseUsageMetadata
Usage metadata about the content generation request and response. This message
provides a detailed breakdown of token usage and other relevant metrics.
Corresponds to the JSON property usageMetadata
16088 16089 16090 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16088 def @usage_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16095 16096 16097 16098 16099 16100 16101 16102 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16095 def update!(**args) @candidates = args[:candidates] if args.key?(:candidates) @create_time = args[:create_time] if args.key?(:create_time) @model_version = args[:model_version] if args.key?(:model_version) @prompt_feedback = args[:prompt_feedback] if args.key?(:prompt_feedback) @response_id = args[:response_id] if args.key?(:response_id) @usage_metadata = args[:usage_metadata] if args.key?(:usage_metadata) end |