Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Response message for [PredictionService.GenerateContent].
Instance Attribute Summary collapse
-
#candidates ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Candidate>
Output only.
-
#create_time ⇒ String
Output only.
-
#model_version ⇒ String
Output only.
-
#prompt_feedback ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentResponsePromptFeedback
Content filter results for a prompt sent in the request.
-
#response_id ⇒ String
Output only.
-
#usage_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentResponseUsageMetadata
Usage metadata about response(s).
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateContentResponse
constructor
A new instance of GoogleCloudAiplatformV1GenerateContentResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateContentResponse
Returns a new instance of GoogleCloudAiplatformV1GenerateContentResponse.
12807 12808 12809 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12807 def initialize(**args) update!(**args) end |
Instance Attribute Details
#candidates ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Candidate>
Output only. Generated candidates.
Corresponds to the JSON property candidates
12779 12780 12781 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12779 def candidates @candidates end |
#create_time ⇒ String
Output only. Timestamp when the request is made to the server.
Corresponds to the JSON property createTime
12784 12785 12786 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12784 def create_time @create_time end |
#model_version ⇒ String
Output only. The model version used to generate the response.
Corresponds to the JSON property modelVersion
12789 12790 12791 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12789 def model_version @model_version end |
#prompt_feedback ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentResponsePromptFeedback
Content filter results for a prompt sent in the request.
Corresponds to the JSON property promptFeedback
12794 12795 12796 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12794 def prompt_feedback @prompt_feedback end |
#response_id ⇒ String
Output only. response_id is used to identify each response. It is the encoding
of the event_id.
Corresponds to the JSON property responseId
12800 12801 12802 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12800 def response_id @response_id end |
#usage_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentResponseUsageMetadata
Usage metadata about response(s).
Corresponds to the JSON property usageMetadata
12805 12806 12807 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12805 def @usage_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12812 12813 12814 12815 12816 12817 12818 12819 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12812 def update!(**args) @candidates = args[:candidates] if args.key?(:candidates) @create_time = args[:create_time] if args.key?(:create_time) @model_version = args[:model_version] if args.key?(:model_version) @prompt_feedback = args[:prompt_feedback] if args.key?(:prompt_feedback) @response_id = args[:response_id] if args.key?(:response_id) @usage_metadata = args[:usage_metadata] if args.key?(:usage_metadata) end |