Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Response message for [PredictionService.GenerateContent].

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateContentResponse

Returns a new instance of GoogleCloudAiplatformV1GenerateContentResponse.



12611
12612
12613
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12611

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#candidatesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Candidate>

Output only. Generated candidates. Corresponds to the JSON property candidates



12583
12584
12585
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12583

def candidates
  @candidates
end

#create_timeString

Output only. Timestamp when the request is made to the server. Corresponds to the JSON property createTime

Returns:

  • (String)


12588
12589
12590
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12588

def create_time
  @create_time
end

#model_versionString

Output only. The model version used to generate the response. Corresponds to the JSON property modelVersion

Returns:

  • (String)


12593
12594
12595
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12593

def model_version
  @model_version
end

#prompt_feedbackGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentResponsePromptFeedback

Content filter results for a prompt sent in the request. Corresponds to the JSON property promptFeedback



12598
12599
12600
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12598

def prompt_feedback
  @prompt_feedback
end

#response_idString

Output only. response_id is used to identify each response. It is the encoding of the event_id. Corresponds to the JSON property responseId

Returns:

  • (String)


12604
12605
12606
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12604

def response_id
  @response_id
end

#usage_metadataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentResponseUsageMetadata

Usage metadata about response(s). Corresponds to the JSON property usageMetadata



12609
12610
12611
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12609

def 
  @usage_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12616
12617
12618
12619
12620
12621
12622
12623
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12616

def update!(**args)
  @candidates = args[:candidates] if args.key?(:candidates)
  @create_time = args[:create_time] if args.key?(:create_time)
  @model_version = args[:model_version] if args.key?(:model_version)
  @prompt_feedback = args[:prompt_feedback] if args.key?(:prompt_feedback)
  @response_id = args[:response_id] if args.key?(:response_id)
  @usage_metadata = args[:usage_metadata] if args.key?(:usage_metadata)
end