Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Response message for [PredictionService.GenerateContent].

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateContentResponse

Returns a new instance of GoogleCloudAiplatformV1GenerateContentResponse.



12323
12324
12325
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12323

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#candidatesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Candidate>

Output only. Generated candidates. Corresponds to the JSON property candidates



12295
12296
12297
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12295

def candidates
  @candidates
end

#create_timeString

Output only. Timestamp when the request is made to the server. Corresponds to the JSON property createTime

Returns:

  • (String)


12300
12301
12302
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12300

def create_time
  @create_time
end

#model_versionString

Output only. The model version used to generate the response. Corresponds to the JSON property modelVersion

Returns:

  • (String)


12305
12306
12307
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12305

def model_version
  @model_version
end

#prompt_feedbackGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentResponsePromptFeedback

Content filter results for a prompt sent in the request. Corresponds to the JSON property promptFeedback



12310
12311
12312
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12310

def prompt_feedback
  @prompt_feedback
end

#response_idString

Output only. response_id is used to identify each response. It is the encoding of the event_id. Corresponds to the JSON property responseId

Returns:

  • (String)


12316
12317
12318
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12316

def response_id
  @response_id
end

#usage_metadataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentResponseUsageMetadata

Usage metadata about response(s). Corresponds to the JSON property usageMetadata



12321
12322
12323
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12321

def 
  @usage_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12328
12329
12330
12331
12332
12333
12334
12335
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12328

def update!(**args)
  @candidates = args[:candidates] if args.key?(:candidates)
  @create_time = args[:create_time] if args.key?(:create_time)
  @model_version = args[:model_version] if args.key?(:model_version)
  @prompt_feedback = args[:prompt_feedback] if args.key?(:prompt_feedback)
  @response_id = args[:response_id] if args.key?(:response_id)
  @usage_metadata = args[:usage_metadata] if args.key?(:usage_metadata)
end