Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Response message for [PredictionService.GenerateContent].
Instance Attribute Summary collapse
-
#candidates ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Candidate>
Output only.
-
#create_time ⇒ String
Output only.
-
#model_version ⇒ String
Output only.
-
#prompt_feedback ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentResponsePromptFeedback
Content filter results for a prompt sent in the request.
-
#response_id ⇒ String
Output only.
-
#usage_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentResponseUsageMetadata
Usage metadata about response(s).
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateContentResponse
constructor
A new instance of GoogleCloudAiplatformV1GenerateContentResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateContentResponse
Returns a new instance of GoogleCloudAiplatformV1GenerateContentResponse.
11907 11908 11909 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11907 def initialize(**args) update!(**args) end |
Instance Attribute Details
#candidates ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Candidate>
Output only. Generated candidates.
Corresponds to the JSON property candidates
11879 11880 11881 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11879 def candidates @candidates end |
#create_time ⇒ String
Output only. Timestamp when the request is made to the server.
Corresponds to the JSON property createTime
11884 11885 11886 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11884 def create_time @create_time end |
#model_version ⇒ String
Output only. The model version used to generate the response.
Corresponds to the JSON property modelVersion
11889 11890 11891 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11889 def model_version @model_version end |
#prompt_feedback ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentResponsePromptFeedback
Content filter results for a prompt sent in the request.
Corresponds to the JSON property promptFeedback
11894 11895 11896 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11894 def prompt_feedback @prompt_feedback end |
#response_id ⇒ String
Output only. response_id is used to identify each response. It is the encoding
of the event_id.
Corresponds to the JSON property responseId
11900 11901 11902 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11900 def response_id @response_id end |
#usage_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentResponseUsageMetadata
Usage metadata about response(s).
Corresponds to the JSON property usageMetadata
11905 11906 11907 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11905 def @usage_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11912 11913 11914 11915 11916 11917 11918 11919 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11912 def update!(**args) @candidates = args[:candidates] if args.key?(:candidates) @create_time = args[:create_time] if args.key?(:create_time) @model_version = args[:model_version] if args.key?(:model_version) @prompt_feedback = args[:prompt_feedback] if args.key?(:prompt_feedback) @response_id = args[:response_id] if args.key?(:response_id) @usage_metadata = args[:usage_metadata] if args.key?(:usage_metadata) end |