Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Response message for [PredictionService.GenerateContent].
Instance Attribute Summary collapse
-
#candidates ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Candidate>
Output only.
-
#model_version ⇒ String
Output only.
-
#prompt_feedback ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentResponsePromptFeedback
Content filter results for a prompt sent in the request.
-
#usage_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentResponseUsageMetadata
Usage metadata about response(s).
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateContentResponse
constructor
A new instance of GoogleCloudAiplatformV1GenerateContentResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateContentResponse
Returns a new instance of GoogleCloudAiplatformV1GenerateContentResponse.
11460 11461 11462 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11460 def initialize(**args) update!(**args) end |
Instance Attribute Details
#candidates ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Candidate>
Output only. Generated candidates.
Corresponds to the JSON property candidates
11443 11444 11445 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11443 def candidates @candidates end |
#model_version ⇒ String
Output only. The model version used to generate the response.
Corresponds to the JSON property modelVersion
11448 11449 11450 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11448 def model_version @model_version end |
#prompt_feedback ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentResponsePromptFeedback
Content filter results for a prompt sent in the request.
Corresponds to the JSON property promptFeedback
11453 11454 11455 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11453 def prompt_feedback @prompt_feedback end |
#usage_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentResponseUsageMetadata
Usage metadata about response(s).
Corresponds to the JSON property usageMetadata
11458 11459 11460 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11458 def @usage_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11465 11466 11467 11468 11469 11470 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11465 def update!(**args) @candidates = args[:candidates] if args.key?(:candidates) @model_version = args[:model_version] if args.key?(:model_version) @prompt_feedback = args[:prompt_feedback] if args.key?(:prompt_feedback) @usage_metadata = args[:usage_metadata] if args.key?(:usage_metadata) end |