Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentResponsePromptFeedback

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Content filter results for a prompt sent in the request. Note: This is sent only in the first stream chunk and only if no candidates were generated due to content violations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateContentResponsePromptFeedback

Returns a new instance of GoogleCloudAiplatformV1GenerateContentResponsePromptFeedback.



17313
17314
17315
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17313

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#block_reasonString

Output only. The reason why the prompt was blocked. Corresponds to the JSON property blockReason

Returns:

  • (String)


17299
17300
17301
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17299

def block_reason
  @block_reason
end

#block_reason_messageString

Output only. A readable message that explains the reason why the prompt was blocked. Corresponds to the JSON property blockReasonMessage

Returns:

  • (String)


17305
17306
17307
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17305

def block_reason_message
  @block_reason_message
end

#safety_ratingsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetyRating>

Output only. A list of safety ratings for the prompt. There is one rating per category. Corresponds to the JSON property safetyRatings



17311
17312
17313
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17311

def safety_ratings
  @safety_ratings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17318
17319
17320
17321
17322
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17318

def update!(**args)
  @block_reason = args[:block_reason] if args.key?(:block_reason)
  @block_reason_message = args[:block_reason_message] if args.key?(:block_reason_message)
  @safety_ratings = args[:safety_ratings] if args.key?(:safety_ratings)
end