Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentResponsePromptFeedback
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentResponsePromptFeedback
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Content filter results for a prompt sent in the request. Note: This is sent only in the first stream chunk and only if no candidates were generated due to content violations.
Instance Attribute Summary collapse
-
#block_reason ⇒ String
Output only.
-
#block_reason_message ⇒ String
Output only.
-
#safety_ratings ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetyRating>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateContentResponsePromptFeedback
constructor
A new instance of GoogleCloudAiplatformV1GenerateContentResponsePromptFeedback.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateContentResponsePromptFeedback
Returns a new instance of GoogleCloudAiplatformV1GenerateContentResponsePromptFeedback.
16081 16082 16083 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16081 def initialize(**args) update!(**args) end |
Instance Attribute Details
#block_reason ⇒ String
Output only. The reason why the prompt was blocked.
Corresponds to the JSON property blockReason
16067 16068 16069 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16067 def block_reason @block_reason end |
#block_reason_message ⇒ String
Output only. A readable message that explains the reason why the prompt was
blocked.
Corresponds to the JSON property blockReasonMessage
16073 16074 16075 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16073 def @block_reason_message end |
#safety_ratings ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetyRating>
Output only. A list of safety ratings for the prompt. There is one rating per
category.
Corresponds to the JSON property safetyRatings
16079 16080 16081 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16079 def @safety_ratings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16086 16087 16088 16089 16090 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16086 def update!(**args) @block_reason = args[:block_reason] if args.key?(:block_reason) @block_reason_message = args[:block_reason_message] if args.key?(:block_reason_message) @safety_ratings = args[:safety_ratings] if args.key?(:safety_ratings) end |