Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentResponsePromptFeedback
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentResponsePromptFeedback
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Content filter results for a prompt sent in the request. Note: This is sent only in the first stream chunk and only if no candidates were generated due to content violations.
Instance Attribute Summary collapse
-
#block_reason ⇒ String
Output only.
-
#block_reason_message ⇒ String
Output only.
-
#safety_ratings ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetyRating>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateContentResponsePromptFeedback
constructor
A new instance of GoogleCloudAiplatformV1GenerateContentResponsePromptFeedback.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateContentResponsePromptFeedback
Returns a new instance of GoogleCloudAiplatformV1GenerateContentResponsePromptFeedback.
15157 15158 15159 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15157 def initialize(**args) update!(**args) end |
Instance Attribute Details
#block_reason ⇒ String
Output only. The reason why the prompt was blocked.
Corresponds to the JSON property blockReason
15143 15144 15145 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15143 def block_reason @block_reason end |
#block_reason_message ⇒ String
Output only. A readable message that explains the reason why the prompt was
blocked.
Corresponds to the JSON property blockReasonMessage
15149 15150 15151 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15149 def @block_reason_message end |
#safety_ratings ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetyRating>
Output only. A list of safety ratings for the prompt. There is one rating per
category.
Corresponds to the JSON property safetyRatings
15155 15156 15157 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15155 def @safety_ratings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15162 15163 15164 15165 15166 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15162 def update!(**args) @block_reason = args[:block_reason] if args.key?(:block_reason) @block_reason_message = args[:block_reason_message] if args.key?(:block_reason_message) @safety_ratings = args[:safety_ratings] if args.key?(:safety_ratings) end |