Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentResponseUsageMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentResponseUsageMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Usage metadata about the content generation request and response. This message provides a detailed breakdown of token usage and other relevant metrics.
Instance Attribute Summary collapse
-
#cache_tokens_details ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModalityTokenCount>
Output only.
-
#cached_content_token_count ⇒ Fixnum
Output only.
-
#candidates_token_count ⇒ Fixnum
The total number of tokens in the generated candidates.
-
#candidates_tokens_details ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModalityTokenCount>
Output only.
-
#prompt_token_count ⇒ Fixnum
The total number of tokens in the prompt.
-
#prompt_tokens_details ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModalityTokenCount>
Output only.
-
#thoughts_token_count ⇒ Fixnum
Output only.
-
#tool_use_prompt_token_count ⇒ Fixnum
Output only.
-
#tool_use_prompt_tokens_details ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModalityTokenCount>
Output only.
-
#total_token_count ⇒ Fixnum
The total number of tokens for the entire request.
-
#traffic_type ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateContentResponseUsageMetadata
constructor
A new instance of GoogleCloudAiplatformV1GenerateContentResponseUsageMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateContentResponseUsageMetadata
Returns a new instance of GoogleCloudAiplatformV1GenerateContentResponseUsageMetadata.
16268 16269 16270 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16268 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cache_tokens_details ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModalityTokenCount>
Output only. A detailed breakdown of the token count for each modality in the
cached content.
Corresponds to the JSON property cacheTokensDetails
16206 16207 16208 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16206 def cache_tokens_details @cache_tokens_details end |
#cached_content_token_count ⇒ Fixnum
Output only. The number of tokens in the cached content that was used for this
request.
Corresponds to the JSON property cachedContentTokenCount
16212 16213 16214 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16212 def cached_content_token_count @cached_content_token_count end |
#candidates_token_count ⇒ Fixnum
The total number of tokens in the generated candidates.
Corresponds to the JSON property candidatesTokenCount
16217 16218 16219 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16217 def candidates_token_count @candidates_token_count end |
#candidates_tokens_details ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModalityTokenCount>
Output only. A detailed breakdown of the token count for each modality in the
generated candidates.
Corresponds to the JSON property candidatesTokensDetails
16223 16224 16225 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16223 def candidates_tokens_details @candidates_tokens_details end |
#prompt_token_count ⇒ Fixnum
The total number of tokens in the prompt. This includes any text, images, or
other media provided in the request. When cached_content is set, this also
includes the number of tokens in the cached content.
Corresponds to the JSON property promptTokenCount
16230 16231 16232 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16230 def prompt_token_count @prompt_token_count end |
#prompt_tokens_details ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModalityTokenCount>
Output only. A detailed breakdown of the token count for each modality in the
prompt.
Corresponds to the JSON property promptTokensDetails
16236 16237 16238 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16236 def prompt_tokens_details @prompt_tokens_details end |
#thoughts_token_count ⇒ Fixnum
Output only. The number of tokens that were part of the model's generated "
thoughts" output, if applicable.
Corresponds to the JSON property thoughtsTokenCount
16242 16243 16244 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16242 def thoughts_token_count @thoughts_token_count end |
#tool_use_prompt_token_count ⇒ Fixnum
Output only. The number of tokens in the results from tool executions, which
are provided back to the model as input, if applicable.
Corresponds to the JSON property toolUsePromptTokenCount
16248 16249 16250 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16248 def tool_use_prompt_token_count @tool_use_prompt_token_count end |
#tool_use_prompt_tokens_details ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModalityTokenCount>
Output only. A detailed breakdown by modality of the token counts from the
results of tool executions, which are provided back to the model as input.
Corresponds to the JSON property toolUsePromptTokensDetails
16254 16255 16256 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16254 def tool_use_prompt_tokens_details @tool_use_prompt_tokens_details end |
#total_token_count ⇒ Fixnum
The total number of tokens for the entire request. This is the sum of
prompt_token_count, candidates_token_count, tool_use_prompt_token_count,
and thoughts_token_count.
Corresponds to the JSON property totalTokenCount
16261 16262 16263 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16261 def total_token_count @total_token_count end |
#traffic_type ⇒ String
Output only. The traffic type for this request.
Corresponds to the JSON property trafficType
16266 16267 16268 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16266 def traffic_type @traffic_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16273 16274 16275 16276 16277 16278 16279 16280 16281 16282 16283 16284 16285 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16273 def update!(**args) @cache_tokens_details = args[:cache_tokens_details] if args.key?(:cache_tokens_details) @cached_content_token_count = args[:cached_content_token_count] if args.key?(:cached_content_token_count) @candidates_token_count = args[:candidates_token_count] if args.key?(:candidates_token_count) @candidates_tokens_details = args[:candidates_tokens_details] if args.key?(:candidates_tokens_details) @prompt_token_count = args[:prompt_token_count] if args.key?(:prompt_token_count) @prompt_tokens_details = args[:prompt_tokens_details] if args.key?(:prompt_tokens_details) @thoughts_token_count = args[:thoughts_token_count] if args.key?(:thoughts_token_count) @tool_use_prompt_token_count = args[:tool_use_prompt_token_count] if args.key?(:tool_use_prompt_token_count) @tool_use_prompt_tokens_details = args[:tool_use_prompt_tokens_details] if args.key?(:tool_use_prompt_tokens_details) @total_token_count = args[:total_token_count] if args.key?(:total_token_count) @traffic_type = args[:traffic_type] if args.key?(:traffic_type) end |