Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentResponseUsageMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Usage metadata about response(s).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateContentResponseUsageMetadata

Returns a new instance of GoogleCloudAiplatformV1GenerateContentResponseUsageMetadata.



12918
12919
12920
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12918

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cache_tokens_detailsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModalityTokenCount>

Output only. List of modalities of the cached content in the request input. Corresponds to the JSON property cacheTokensDetails



12860
12861
12862
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12860

def cache_tokens_details
  @cache_tokens_details
end

#cached_content_token_countFixnum

Output only. Number of tokens in the cached part in the input (the cached content). Corresponds to the JSON property cachedContentTokenCount

Returns:

  • (Fixnum)


12866
12867
12868
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12866

def cached_content_token_count
  @cached_content_token_count
end

#candidates_token_countFixnum

Number of tokens in the response(s). Corresponds to the JSON property candidatesTokenCount

Returns:

  • (Fixnum)


12871
12872
12873
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12871

def candidates_token_count
  @candidates_token_count
end

#candidates_tokens_detailsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModalityTokenCount>

Output only. List of modalities that were returned in the response. Corresponds to the JSON property candidatesTokensDetails



12876
12877
12878
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12876

def candidates_tokens_details
  @candidates_tokens_details
end

#prompt_token_countFixnum

Number of tokens in the request. When cached_content is set, this is still the total effective prompt size meaning this includes the number of tokens in the cached content. Corresponds to the JSON property promptTokenCount

Returns:

  • (Fixnum)


12883
12884
12885
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12883

def prompt_token_count
  @prompt_token_count
end

#prompt_tokens_detailsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModalityTokenCount>

Output only. List of modalities that were processed in the request input. Corresponds to the JSON property promptTokensDetails



12888
12889
12890
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12888

def prompt_tokens_details
  @prompt_tokens_details
end

#thoughts_token_countFixnum

Output only. Number of tokens present in thoughts output. Corresponds to the JSON property thoughtsTokenCount

Returns:

  • (Fixnum)


12893
12894
12895
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12893

def thoughts_token_count
  @thoughts_token_count
end

#tool_use_prompt_token_countFixnum

Output only. Number of tokens present in tool-use prompt(s). Corresponds to the JSON property toolUsePromptTokenCount

Returns:

  • (Fixnum)


12898
12899
12900
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12898

def tool_use_prompt_token_count
  @tool_use_prompt_token_count
end

#tool_use_prompt_tokens_detailsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModalityTokenCount>

Output only. List of modalities that were processed for tool-use request inputs. Corresponds to the JSON property toolUsePromptTokensDetails



12904
12905
12906
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12904

def tool_use_prompt_tokens_details
  @tool_use_prompt_tokens_details
end

#total_token_countFixnum

Total token count for prompt, response candidates, and tool-use prompts (if present). Corresponds to the JSON property totalTokenCount

Returns:

  • (Fixnum)


12910
12911
12912
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12910

def total_token_count
  @total_token_count
end

#traffic_typeString

Output only. Traffic type. This shows whether a request consumes Pay-As-You-Go or Provisioned Throughput quota. Corresponds to the JSON property trafficType

Returns:

  • (String)


12916
12917
12918
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12916

def traffic_type
  @traffic_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12923
12924
12925
12926
12927
12928
12929
12930
12931
12932
12933
12934
12935
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12923

def update!(**args)
  @cache_tokens_details = args[:cache_tokens_details] if args.key?(:cache_tokens_details)
  @cached_content_token_count = args[:cached_content_token_count] if args.key?(:cached_content_token_count)
  @candidates_token_count = args[:candidates_token_count] if args.key?(:candidates_token_count)
  @candidates_tokens_details = args[:candidates_tokens_details] if args.key?(:candidates_tokens_details)
  @prompt_token_count = args[:prompt_token_count] if args.key?(:prompt_token_count)
  @prompt_tokens_details = args[:prompt_tokens_details] if args.key?(:prompt_tokens_details)
  @thoughts_token_count = args[:thoughts_token_count] if args.key?(:thoughts_token_count)
  @tool_use_prompt_token_count = args[:tool_use_prompt_token_count] if args.key?(:tool_use_prompt_token_count)
  @tool_use_prompt_tokens_details = args[:tool_use_prompt_tokens_details] if args.key?(:tool_use_prompt_tokens_details)
  @total_token_count = args[:total_token_count] if args.key?(:total_token_count)
  @traffic_type = args[:traffic_type] if args.key?(:traffic_type)
end