Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentResponseUsageMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentResponseUsageMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Usage metadata about response(s).
Instance Attribute Summary collapse
-
#cache_tokens_details ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModalityTokenCount>
Output only.
-
#cached_content_token_count ⇒ Fixnum
Output only.
-
#candidates_token_count ⇒ Fixnum
Number of tokens in the response(s).
-
#candidates_tokens_details ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModalityTokenCount>
Output only.
-
#prompt_token_count ⇒ Fixnum
Number of tokens in the request.
-
#prompt_tokens_details ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModalityTokenCount>
Output only.
-
#thoughts_token_count ⇒ Fixnum
Output only.
-
#tool_use_prompt_token_count ⇒ Fixnum
Output only.
-
#tool_use_prompt_tokens_details ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModalityTokenCount>
Output only.
-
#total_token_count ⇒ Fixnum
Total token count for prompt, response candidates, and tool-use prompts (if present).
-
#traffic_type ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateContentResponseUsageMetadata
constructor
A new instance of GoogleCloudAiplatformV1GenerateContentResponseUsageMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateContentResponseUsageMetadata
Returns a new instance of GoogleCloudAiplatformV1GenerateContentResponseUsageMetadata.
12057 12058 12059 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12057 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cache_tokens_details ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModalityTokenCount>
Output only. List of modalities of the cached content in the request input.
Corresponds to the JSON property cacheTokensDetails
11999 12000 12001 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11999 def cache_tokens_details @cache_tokens_details end |
#cached_content_token_count ⇒ Fixnum
Output only. Number of tokens in the cached part in the input (the cached
content).
Corresponds to the JSON property cachedContentTokenCount
12005 12006 12007 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12005 def cached_content_token_count @cached_content_token_count end |
#candidates_token_count ⇒ Fixnum
Number of tokens in the response(s).
Corresponds to the JSON property candidatesTokenCount
12010 12011 12012 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12010 def candidates_token_count @candidates_token_count end |
#candidates_tokens_details ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModalityTokenCount>
Output only. List of modalities that were returned in the response.
Corresponds to the JSON property candidatesTokensDetails
12015 12016 12017 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12015 def candidates_tokens_details @candidates_tokens_details end |
#prompt_token_count ⇒ Fixnum
Number of tokens in the request. When cached_content is set, this is still
the total effective prompt size meaning this includes the number of tokens in
the cached content.
Corresponds to the JSON property promptTokenCount
12022 12023 12024 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12022 def prompt_token_count @prompt_token_count end |
#prompt_tokens_details ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModalityTokenCount>
Output only. List of modalities that were processed in the request input.
Corresponds to the JSON property promptTokensDetails
12027 12028 12029 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12027 def prompt_tokens_details @prompt_tokens_details end |
#thoughts_token_count ⇒ Fixnum
Output only. Number of tokens present in thoughts output.
Corresponds to the JSON property thoughtsTokenCount
12032 12033 12034 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12032 def thoughts_token_count @thoughts_token_count end |
#tool_use_prompt_token_count ⇒ Fixnum
Output only. Number of tokens present in tool-use prompt(s).
Corresponds to the JSON property toolUsePromptTokenCount
12037 12038 12039 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12037 def tool_use_prompt_token_count @tool_use_prompt_token_count end |
#tool_use_prompt_tokens_details ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModalityTokenCount>
Output only. List of modalities that were processed for tool-use request
inputs.
Corresponds to the JSON property toolUsePromptTokensDetails
12043 12044 12045 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12043 def tool_use_prompt_tokens_details @tool_use_prompt_tokens_details end |
#total_token_count ⇒ Fixnum
Total token count for prompt, response candidates, and tool-use prompts (if
present).
Corresponds to the JSON property totalTokenCount
12049 12050 12051 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12049 def total_token_count @total_token_count end |
#traffic_type ⇒ String
Output only. Traffic type. This shows whether a request consumes Pay-As-You-Go
or Provisioned Throughput quota.
Corresponds to the JSON property trafficType
12055 12056 12057 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12055 def traffic_type @traffic_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12062 12063 12064 12065 12066 12067 12068 12069 12070 12071 12072 12073 12074 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12062 def update!(**args) @cache_tokens_details = args[:cache_tokens_details] if args.key?(:cache_tokens_details) @cached_content_token_count = args[:cached_content_token_count] if args.key?(:cached_content_token_count) @candidates_token_count = args[:candidates_token_count] if args.key?(:candidates_token_count) @candidates_tokens_details = args[:candidates_tokens_details] if args.key?(:candidates_tokens_details) @prompt_token_count = args[:prompt_token_count] if args.key?(:prompt_token_count) @prompt_tokens_details = args[:prompt_tokens_details] if args.key?(:prompt_tokens_details) @thoughts_token_count = args[:thoughts_token_count] if args.key?(:thoughts_token_count) @tool_use_prompt_token_count = args[:tool_use_prompt_token_count] if args.key?(:tool_use_prompt_token_count) @tool_use_prompt_tokens_details = args[:tool_use_prompt_tokens_details] if args.key?(:tool_use_prompt_tokens_details) @total_token_count = args[:total_token_count] if args.key?(:total_token_count) @traffic_type = args[:traffic_type] if args.key?(:traffic_type) end |