Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentResponseUsageMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Usage metadata about response(s).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateContentResponseUsageMetadata

Returns a new instance of GoogleCloudAiplatformV1GenerateContentResponseUsageMetadata.



12018
12019
12020
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12018

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cache_tokens_detailsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModalityTokenCount>

Output only. List of modalities of the cached content in the request input. Corresponds to the JSON property cacheTokensDetails



11960
11961
11962
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11960

def cache_tokens_details
  @cache_tokens_details
end

#cached_content_token_countFixnum

Output only. Number of tokens in the cached part in the input (the cached content). Corresponds to the JSON property cachedContentTokenCount

Returns:

  • (Fixnum)


11966
11967
11968
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11966

def cached_content_token_count
  @cached_content_token_count
end

#candidates_token_countFixnum

Number of tokens in the response(s). Corresponds to the JSON property candidatesTokenCount

Returns:

  • (Fixnum)


11971
11972
11973
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11971

def candidates_token_count
  @candidates_token_count
end

#candidates_tokens_detailsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModalityTokenCount>

Output only. List of modalities that were returned in the response. Corresponds to the JSON property candidatesTokensDetails



11976
11977
11978
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11976

def candidates_tokens_details
  @candidates_tokens_details
end

#prompt_token_countFixnum

Number of tokens in the request. When cached_content is set, this is still the total effective prompt size meaning this includes the number of tokens in the cached content. Corresponds to the JSON property promptTokenCount

Returns:

  • (Fixnum)


11983
11984
11985
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11983

def prompt_token_count
  @prompt_token_count
end

#prompt_tokens_detailsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModalityTokenCount>

Output only. List of modalities that were processed in the request input. Corresponds to the JSON property promptTokensDetails



11988
11989
11990
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11988

def prompt_tokens_details
  @prompt_tokens_details
end

#thoughts_token_countFixnum

Output only. Number of tokens present in thoughts output. Corresponds to the JSON property thoughtsTokenCount

Returns:

  • (Fixnum)


11993
11994
11995
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11993

def thoughts_token_count
  @thoughts_token_count
end

#tool_use_prompt_token_countFixnum

Output only. Number of tokens present in tool-use prompt(s). Corresponds to the JSON property toolUsePromptTokenCount

Returns:

  • (Fixnum)


11998
11999
12000
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11998

def tool_use_prompt_token_count
  @tool_use_prompt_token_count
end

#tool_use_prompt_tokens_detailsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModalityTokenCount>

Output only. List of modalities that were processed for tool-use request inputs. Corresponds to the JSON property toolUsePromptTokensDetails



12004
12005
12006
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12004

def tool_use_prompt_tokens_details
  @tool_use_prompt_tokens_details
end

#total_token_countFixnum

Total token count for prompt, response candidates, and tool-use prompts (if present). Corresponds to the JSON property totalTokenCount

Returns:

  • (Fixnum)


12010
12011
12012
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12010

def total_token_count
  @total_token_count
end

#traffic_typeString

Output only. Traffic type. This shows whether a request consumes Pay-As-You-Go or Provisioned Throughput quota. Corresponds to the JSON property trafficType

Returns:

  • (String)


12016
12017
12018
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12016

def traffic_type
  @traffic_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12023
12024
12025
12026
12027
12028
12029
12030
12031
12032
12033
12034
12035
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12023

def update!(**args)
  @cache_tokens_details = args[:cache_tokens_details] if args.key?(:cache_tokens_details)
  @cached_content_token_count = args[:cached_content_token_count] if args.key?(:cached_content_token_count)
  @candidates_token_count = args[:candidates_token_count] if args.key?(:candidates_token_count)
  @candidates_tokens_details = args[:candidates_tokens_details] if args.key?(:candidates_tokens_details)
  @prompt_token_count = args[:prompt_token_count] if args.key?(:prompt_token_count)
  @prompt_tokens_details = args[:prompt_tokens_details] if args.key?(:prompt_tokens_details)
  @thoughts_token_count = args[:thoughts_token_count] if args.key?(:thoughts_token_count)
  @tool_use_prompt_token_count = args[:tool_use_prompt_token_count] if args.key?(:tool_use_prompt_token_count)
  @tool_use_prompt_tokens_details = args[:tool_use_prompt_tokens_details] if args.key?(:tool_use_prompt_tokens_details)
  @total_token_count = args[:total_token_count] if args.key?(:total_token_count)
  @traffic_type = args[:traffic_type] if args.key?(:traffic_type)
end