Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentResponseUsageMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Usage metadata about response(s).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateContentResponseUsageMetadata

Returns a new instance of GoogleCloudAiplatformV1GenerateContentResponseUsageMetadata.



11914
11915
11916
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11914

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cache_tokens_detailsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModalityTokenCount>

Output only. List of modalities of the cached content in the request input. Corresponds to the JSON property cacheTokensDetails



11862
11863
11864
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11862

def cache_tokens_details
  @cache_tokens_details
end

#cached_content_token_countFixnum

Output only. Number of tokens in the cached part in the input (the cached content). Corresponds to the JSON property cachedContentTokenCount

Returns:

  • (Fixnum)


11868
11869
11870
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11868

def cached_content_token_count
  @cached_content_token_count
end

#candidates_token_countFixnum

Number of tokens in the response(s). Corresponds to the JSON property candidatesTokenCount

Returns:

  • (Fixnum)


11873
11874
11875
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11873

def candidates_token_count
  @candidates_token_count
end

#candidates_tokens_detailsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModalityTokenCount>

Output only. List of modalities that were returned in the response. Corresponds to the JSON property candidatesTokensDetails



11878
11879
11880
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11878

def candidates_tokens_details
  @candidates_tokens_details
end

#prompt_token_countFixnum

Number of tokens in the request. When cached_content is set, this is still the total effective prompt size meaning this includes the number of tokens in the cached content. Corresponds to the JSON property promptTokenCount

Returns:

  • (Fixnum)


11885
11886
11887
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11885

def prompt_token_count
  @prompt_token_count
end

#prompt_tokens_detailsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModalityTokenCount>

Output only. List of modalities that were processed in the request input. Corresponds to the JSON property promptTokensDetails



11890
11891
11892
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11890

def prompt_tokens_details
  @prompt_tokens_details
end

#thoughts_token_countFixnum

Output only. Number of tokens present in thoughts output. Corresponds to the JSON property thoughtsTokenCount

Returns:

  • (Fixnum)


11895
11896
11897
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11895

def thoughts_token_count
  @thoughts_token_count
end

#tool_use_prompt_token_countFixnum

Output only. Number of tokens present in tool-use prompt(s). Corresponds to the JSON property toolUsePromptTokenCount

Returns:

  • (Fixnum)


11900
11901
11902
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11900

def tool_use_prompt_token_count
  @tool_use_prompt_token_count
end

#tool_use_prompt_tokens_detailsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModalityTokenCount>

Output only. List of modalities that were processed for tool-use request inputs. Corresponds to the JSON property toolUsePromptTokensDetails



11906
11907
11908
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11906

def tool_use_prompt_tokens_details
  @tool_use_prompt_tokens_details
end

#total_token_countFixnum

Total token count for prompt, response candidates, and tool-use prompts (if present). Corresponds to the JSON property totalTokenCount

Returns:

  • (Fixnum)


11912
11913
11914
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11912

def total_token_count
  @total_token_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11919
11920
11921
11922
11923
11924
11925
11926
11927
11928
11929
11930
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11919

def update!(**args)
  @cache_tokens_details = args[:cache_tokens_details] if args.key?(:cache_tokens_details)
  @cached_content_token_count = args[:cached_content_token_count] if args.key?(:cached_content_token_count)
  @candidates_token_count = args[:candidates_token_count] if args.key?(:candidates_token_count)
  @candidates_tokens_details = args[:candidates_tokens_details] if args.key?(:candidates_tokens_details)
  @prompt_token_count = args[:prompt_token_count] if args.key?(:prompt_token_count)
  @prompt_tokens_details = args[:prompt_tokens_details] if args.key?(:prompt_tokens_details)
  @thoughts_token_count = args[:thoughts_token_count] if args.key?(:thoughts_token_count)
  @tool_use_prompt_token_count = args[:tool_use_prompt_token_count] if args.key?(:tool_use_prompt_token_count)
  @tool_use_prompt_tokens_details = args[:tool_use_prompt_tokens_details] if args.key?(:tool_use_prompt_tokens_details)
  @total_token_count = args[:total_token_count] if args.key?(:total_token_count)
end