Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentResponseUsageMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentResponseUsageMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Usage metadata about response(s).
Instance Attribute Summary collapse
-
#cache_tokens_details ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModalityTokenCount>
Output only.
-
#cached_content_token_count ⇒ Fixnum
Output only.
-
#candidates_token_count ⇒ Fixnum
Number of tokens in the response(s).
-
#candidates_tokens_details ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModalityTokenCount>
Output only.
-
#prompt_token_count ⇒ Fixnum
Number of tokens in the request.
-
#prompt_tokens_details ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModalityTokenCount>
Output only.
-
#tool_use_prompt_token_count ⇒ Fixnum
Output only.
-
#tool_use_prompt_tokens_details ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModalityTokenCount>
Output only.
-
#total_token_count ⇒ Fixnum
Total token count for prompt, response candidates, and tool-use prompts (if present).
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateContentResponseUsageMetadata
constructor
A new instance of GoogleCloudAiplatformV1GenerateContentResponseUsageMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateContentResponseUsageMetadata
Returns a new instance of GoogleCloudAiplatformV1GenerateContentResponseUsageMetadata.
11890 11891 11892 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11890 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cache_tokens_details ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModalityTokenCount>
Output only. List of modalities of the cached content in the request input.
Corresponds to the JSON property cacheTokensDetails
11843 11844 11845 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11843 def cache_tokens_details @cache_tokens_details end |
#cached_content_token_count ⇒ Fixnum
Output only. Number of tokens in the cached part in the input (the cached
content).
Corresponds to the JSON property cachedContentTokenCount
11849 11850 11851 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11849 def cached_content_token_count @cached_content_token_count end |
#candidates_token_count ⇒ Fixnum
Number of tokens in the response(s).
Corresponds to the JSON property candidatesTokenCount
11854 11855 11856 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11854 def candidates_token_count @candidates_token_count end |
#candidates_tokens_details ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModalityTokenCount>
Output only. List of modalities that were returned in the response.
Corresponds to the JSON property candidatesTokensDetails
11859 11860 11861 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11859 def candidates_tokens_details @candidates_tokens_details end |
#prompt_token_count ⇒ Fixnum
Number of tokens in the request. When cached_content is set, this is still
the total effective prompt size meaning this includes the number of tokens in
the cached content.
Corresponds to the JSON property promptTokenCount
11866 11867 11868 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11866 def prompt_token_count @prompt_token_count end |
#prompt_tokens_details ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModalityTokenCount>
Output only. List of modalities that were processed in the request input.
Corresponds to the JSON property promptTokensDetails
11871 11872 11873 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11871 def prompt_tokens_details @prompt_tokens_details end |
#tool_use_prompt_token_count ⇒ Fixnum
Output only. Number of tokens present in tool-use prompt(s).
Corresponds to the JSON property toolUsePromptTokenCount
11876 11877 11878 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11876 def tool_use_prompt_token_count @tool_use_prompt_token_count end |
#tool_use_prompt_tokens_details ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModalityTokenCount>
Output only. List of modalities that were processed for tool-use request
inputs.
Corresponds to the JSON property toolUsePromptTokensDetails
11882 11883 11884 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11882 def tool_use_prompt_tokens_details @tool_use_prompt_tokens_details end |
#total_token_count ⇒ Fixnum
Total token count for prompt, response candidates, and tool-use prompts (if
present).
Corresponds to the JSON property totalTokenCount
11888 11889 11890 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11888 def total_token_count @total_token_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11895 11896 11897 11898 11899 11900 11901 11902 11903 11904 11905 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11895 def update!(**args) @cache_tokens_details = args[:cache_tokens_details] if args.key?(:cache_tokens_details) @cached_content_token_count = args[:cached_content_token_count] if args.key?(:cached_content_token_count) @candidates_token_count = args[:candidates_token_count] if args.key?(:candidates_token_count) @candidates_tokens_details = args[:candidates_tokens_details] if args.key?(:candidates_tokens_details) @prompt_token_count = args[:prompt_token_count] if args.key?(:prompt_token_count) @prompt_tokens_details = args[:prompt_tokens_details] if args.key?(:prompt_tokens_details) @tool_use_prompt_token_count = args[:tool_use_prompt_token_count] if args.key?(:tool_use_prompt_token_count) @tool_use_prompt_tokens_details = args[:tool_use_prompt_tokens_details] if args.key?(:tool_use_prompt_tokens_details) @total_token_count = args[:total_token_count] if args.key?(:total_token_count) end |