Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentResponseUsageMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateContentResponseUsageMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Usage metadata about response(s).
Instance Attribute Summary collapse
-
#cached_content_token_count ⇒ Fixnum
Output only.
-
#candidates_token_count ⇒ Fixnum
Number of tokens in the response(s).
-
#prompt_token_count ⇒ Fixnum
Number of tokens in the request.
-
#total_token_count ⇒ Fixnum
Total token count for prompt and response candidates.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateContentResponseUsageMetadata
constructor
A new instance of GoogleCloudAiplatformV1GenerateContentResponseUsageMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateContentResponseUsageMetadata
Returns a new instance of GoogleCloudAiplatformV1GenerateContentResponseUsageMetadata.
11531 11532 11533 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11531 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cached_content_token_count ⇒ Fixnum
Output only. Number of tokens in the cached part in the input (the cached
content).
Corresponds to the JSON property cachedContentTokenCount
11512 11513 11514 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11512 def cached_content_token_count @cached_content_token_count end |
#candidates_token_count ⇒ Fixnum
Number of tokens in the response(s).
Corresponds to the JSON property candidatesTokenCount
11517 11518 11519 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11517 def candidates_token_count @candidates_token_count end |
#prompt_token_count ⇒ Fixnum
Number of tokens in the request. When cached_content is set, this is still
the total effective prompt size meaning this includes the number of tokens in
the cached content.
Corresponds to the JSON property promptTokenCount
11524 11525 11526 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11524 def prompt_token_count @prompt_token_count end |
#total_token_count ⇒ Fixnum
Total token count for prompt and response candidates.
Corresponds to the JSON property totalTokenCount
11529 11530 11531 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11529 def total_token_count @total_token_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11536 11537 11538 11539 11540 11541 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11536 def update!(**args) @cached_content_token_count = args[:cached_content_token_count] if args.key?(:cached_content_token_count) @candidates_token_count = args[:candidates_token_count] if args.key?(:candidates_token_count) @prompt_token_count = args[:prompt_token_count] if args.key?(:prompt_token_count) @total_token_count = args[:total_token_count] if args.key?(:total_token_count) end |