Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateInstanceRubricsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for EvaluationService.GenerateInstanceRubrics.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateInstanceRubricsRequest

Returns a new instance of GoogleCloudAiplatformV1GenerateInstanceRubricsRequest.



16368
16369
16370
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16368

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentConfig

Deprecated: Use google.cloud.aiplatform.master.AgentConfig in agent_eval_data instead. Configuration for an Agent. Corresponds to the JSON property agentConfig



16334
16335
16336
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16334

def agent_config
  @agent_config
end

#contentsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content>

Required. The prompt to generate rubrics from. For single-turn queries, this is a single instance. For multi-turn queries, this is a repeated field that contains conversation history + latest request. Corresponds to the JSON property contents



16341
16342
16343
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16341

def contents
  @contents
end

#locationString

Required. The resource name of the Location to generate rubrics from. Format: projects/project/locations/location` Corresponds to the JSON propertylocation`

Returns:

  • (String)


16347
16348
16349
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16347

def location
  @location
end

#metric_resource_nameString

Optional. The resource name of a registered metric. Rubric generation using predefined metric spec or LLMBasedMetricSpec is supported. If this field is set, the configuration provided in this field is used for rubric generation. The predefined_rubric_generation_spec and rubric_generation_spec fields will be ignored. Corresponds to the JSON property metricResourceName

Returns:

  • (String)


16356
16357
16358
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16356

def metric_resource_name
  @metric_resource_name
end

#predefined_rubric_generation_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PredefinedMetricSpec

The spec for a pre-defined metric. Corresponds to the JSON property predefinedRubricGenerationSpec



16361
16362
16363
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16361

def predefined_rubric_generation_spec
  @predefined_rubric_generation_spec
end

#rubric_generation_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricGenerationSpec

Specification for how rubrics should be generated. Corresponds to the JSON property rubricGenerationSpec



16366
16367
16368
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16366

def rubric_generation_spec
  @rubric_generation_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16373
16374
16375
16376
16377
16378
16379
16380
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16373

def update!(**args)
  @agent_config = args[:agent_config] if args.key?(:agent_config)
  @contents = args[:contents] if args.key?(:contents)
  @location = args[:location] if args.key?(:location)
  @metric_resource_name = args[:metric_resource_name] if args.key?(:metric_resource_name)
  @predefined_rubric_generation_spec = args[:predefined_rubric_generation_spec] if args.key?(:predefined_rubric_generation_spec)
  @rubric_generation_spec = args[:rubric_generation_spec] if args.key?(:rubric_generation_spec)
end