Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateInstanceRubricsRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateInstanceRubricsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Request message for EvaluationService.GenerateInstanceRubrics.
Instance Attribute Summary collapse
-
#agent_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentConfig
Deprecated: Use
google.cloud.aiplatform.master.AgentConfiginagent_eval_datainstead. -
#contents ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content>
Required.
-
#location ⇒ String
Required.
-
#metric_resource_name ⇒ String
Optional.
-
#predefined_rubric_generation_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PredefinedMetricSpec
The spec for a pre-defined metric.
-
#rubric_generation_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricGenerationSpec
Specification for how rubrics should be generated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateInstanceRubricsRequest
constructor
A new instance of GoogleCloudAiplatformV1GenerateInstanceRubricsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateInstanceRubricsRequest
Returns a new instance of GoogleCloudAiplatformV1GenerateInstanceRubricsRequest.
16264 16265 16266 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16264 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceDeprecatedAgentConfig
Deprecated: Use google.cloud.aiplatform.master.AgentConfig in
agent_eval_data instead. Configuration for an Agent.
Corresponds to the JSON property agentConfig
16230 16231 16232 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16230 def agent_config @agent_config end |
#contents ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content>
Required. The prompt to generate rubrics from. For single-turn queries, this
is a single instance. For multi-turn queries, this is a repeated field that
contains conversation history + latest request.
Corresponds to the JSON property contents
16237 16238 16239 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16237 def contents @contents end |
#location ⇒ String
Required. The resource name of the Location to generate rubrics from. Format:
projects/project/locations/location`
Corresponds to the JSON propertylocation`
16243 16244 16245 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16243 def location @location end |
#metric_resource_name ⇒ String
Optional. The resource name of a registered metric. Rubric generation using
predefined metric spec or LLMBasedMetricSpec is supported. If this field is
set, the configuration provided in this field is used for rubric generation.
The predefined_rubric_generation_spec and rubric_generation_spec fields
will be ignored.
Corresponds to the JSON property metricResourceName
16252 16253 16254 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16252 def metric_resource_name @metric_resource_name end |
#predefined_rubric_generation_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PredefinedMetricSpec
The spec for a pre-defined metric.
Corresponds to the JSON property predefinedRubricGenerationSpec
16257 16258 16259 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16257 def predefined_rubric_generation_spec @predefined_rubric_generation_spec end |
#rubric_generation_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricGenerationSpec
Specification for how rubrics should be generated.
Corresponds to the JSON property rubricGenerationSpec
16262 16263 16264 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16262 def rubric_generation_spec @rubric_generation_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16269 16270 16271 16272 16273 16274 16275 16276 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16269 def update!(**args) @agent_config = args[:agent_config] if args.key?(:agent_config) @contents = args[:contents] if args.key?(:contents) @location = args[:location] if args.key?(:location) @metric_resource_name = args[:metric_resource_name] if args.key?(:metric_resource_name) @predefined_rubric_generation_spec = args[:predefined_rubric_generation_spec] if args.key?(:predefined_rubric_generation_spec) @rubric_generation_spec = args[:rubric_generation_spec] if args.key?(:rubric_generation_spec) end |