Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateInstanceRubricsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for EvaluationService.GenerateInstanceRubrics.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateInstanceRubricsRequest

Returns a new instance of GoogleCloudAiplatformV1GenerateInstanceRubricsRequest.



15531
15532
15533
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15531

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationInstanceAgentConfig

Configuration for an Agent. Corresponds to the JSON property agentConfig



15506
15507
15508
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15506

def agent_config
  @agent_config
end

#contentsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content>

Required. The prompt to generate rubrics from. For single-turn queries, this is a single instance. For multi-turn queries, this is a repeated field that contains conversation history + latest request. Corresponds to the JSON property contents



15513
15514
15515
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15513

def contents
  @contents
end

#locationString

Required. The resource name of the Location to generate rubrics from. Format: projects/project/locations/location` Corresponds to the JSON propertylocation`

Returns:

  • (String)


15519
15520
15521
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15519

def location
  @location
end

#predefined_rubric_generation_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PredefinedMetricSpec

The spec for a pre-defined metric. Corresponds to the JSON property predefinedRubricGenerationSpec



15524
15525
15526
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15524

def predefined_rubric_generation_spec
  @predefined_rubric_generation_spec
end

#rubric_generation_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricGenerationSpec

Specification for how rubrics should be generated. Corresponds to the JSON property rubricGenerationSpec



15529
15530
15531
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15529

def rubric_generation_spec
  @rubric_generation_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15536
15537
15538
15539
15540
15541
15542
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15536

def update!(**args)
  @agent_config = args[:agent_config] if args.key?(:agent_config)
  @contents = args[:contents] if args.key?(:contents)
  @location = args[:location] if args.key?(:location)
  @predefined_rubric_generation_spec = args[:predefined_rubric_generation_spec] if args.key?(:predefined_rubric_generation_spec)
  @rubric_generation_spec = args[:rubric_generation_spec] if args.key?(:rubric_generation_spec)
end