Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateLossClustersRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateLossClustersRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Request message for EvaluationAnalyticsService.GenerateLossClusters.
Instance Attribute Summary collapse
-
#configs ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1LossAnalysisConfig>
Required.
-
#evaluation_set ⇒ String
Reference to a persisted EvaluationSet.
-
#inline_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateLossClustersRequestEvaluationResultList
A wrapper to allow providing a list of items inline.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateLossClustersRequest
constructor
A new instance of GoogleCloudAiplatformV1GenerateLossClustersRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateLossClustersRequest
Returns a new instance of GoogleCloudAiplatformV1GenerateLossClustersRequest.
17950 17951 17952 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17950 def initialize(**args) update!(**args) end |
Instance Attribute Details
#configs ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1LossAnalysisConfig>
Required. Configuration for the analysis algorithm. Analysis for multiple
metrics and multiple candidates could be specified.
Corresponds to the JSON property configs
17937 17938 17939 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17937 def configs @configs end |
#evaluation_set ⇒ String
Reference to a persisted EvaluationSet. The service will read items from this
set.
Corresponds to the JSON property evaluationSet
17943 17944 17945 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17943 def evaluation_set @evaluation_set end |
#inline_results ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateLossClustersRequestEvaluationResultList
A wrapper to allow providing a list of items inline.
Corresponds to the JSON property inlineResults
17948 17949 17950 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17948 def inline_results @inline_results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17955 17956 17957 17958 17959 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17955 def update!(**args) @configs = args[:configs] if args.key?(:configs) @evaluation_set = args[:evaluation_set] if args.key?(:evaluation_set) @inline_results = args[:inline_results] if args.key?(:inline_results) end |