Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateLossClustersRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for EvaluationAnalyticsService.GenerateLossClusters.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateLossClustersRequest

Returns a new instance of GoogleCloudAiplatformV1GenerateLossClustersRequest.



17551
17552
17553
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17551

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#configsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1LossAnalysisConfig>

Required. Configuration for the analysis algorithm. Analysis for multiple metrics and multiple candidates could be specified. Corresponds to the JSON property configs



17538
17539
17540
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17538

def configs
  @configs
end

#evaluation_setString

Reference to a persisted EvaluationSet. The service will read items from this set. Corresponds to the JSON property evaluationSet

Returns:

  • (String)


17544
17545
17546
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17544

def evaluation_set
  @evaluation_set
end

#inline_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateLossClustersRequestEvaluationResultList

A wrapper to allow providing a list of items inline. Corresponds to the JSON property inlineResults



17549
17550
17551
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17549

def inline_results
  @inline_results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17556
17557
17558
17559
17560
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17556

def update!(**args)
  @configs = args[:configs] if args.key?(:configs)
  @evaluation_set = args[:evaluation_set] if args.key?(:evaluation_set)
  @inline_results = args[:inline_results] if args.key?(:inline_results)
end