Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateLossClustersRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for EvaluationAnalyticsService.GenerateLossClusters.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateLossClustersRequest

Returns a new instance of GoogleCloudAiplatformV1GenerateLossClustersRequest.



17257
17258
17259
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17257

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#configsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1LossAnalysisConfig>

Required. Configuration for the analysis algorithm. Analysis for multiple metrics and multiple candidates could be specified. Corresponds to the JSON property configs



17244
17245
17246
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17244

def configs
  @configs
end

#evaluation_setString

Reference to a persisted EvaluationSet. The service will read items from this set. Corresponds to the JSON property evaluationSet

Returns:

  • (String)


17250
17251
17252
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17250

def evaluation_set
  @evaluation_set
end

#inline_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateLossClustersRequestEvaluationResultList

A wrapper to allow providing a list of items inline. Corresponds to the JSON property inlineResults



17255
17256
17257
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17255

def inline_results
  @inline_results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17262
17263
17264
17265
17266
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17262

def update!(**args)
  @configs = args[:configs] if args.key?(:configs)
  @evaluation_set = args[:evaluation_set] if args.key?(:evaluation_set)
  @inline_results = args[:inline_results] if args.key?(:inline_results)
end