Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateLossClustersRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for EvaluationAnalyticsService.GenerateLossClusters.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateLossClustersRequest

Returns a new instance of GoogleCloudAiplatformV1GenerateLossClustersRequest.



16915
16916
16917
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16915

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#configsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1LossAnalysisConfig>

Required. Configuration for the analysis algorithm. Analysis for multiple metrics and multiple candidates could be specified. Corresponds to the JSON property configs



16902
16903
16904
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16902

def configs
  @configs
end

#evaluation_setString

Reference to a persisted EvaluationSet. The service will read items from this set. Corresponds to the JSON property evaluationSet

Returns:

  • (String)


16908
16909
16910
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16908

def evaluation_set
  @evaluation_set
end

#inline_resultsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateLossClustersRequestEvaluationResultList

A wrapper to allow providing a list of items inline. Corresponds to the JSON property inlineResults



16913
16914
16915
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16913

def inline_results
  @inline_results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16920
16921
16922
16923
16924
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16920

def update!(**args)
  @configs = args[:configs] if args.key?(:configs)
  @evaluation_set = args[:evaluation_set] if args.key?(:evaluation_set)
  @inline_results = args[:inline_results] if args.key?(:inline_results)
end