Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateMemoriesRequestDirectContentsSourceEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A single piece of conversation from which to generate memories.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateMemoriesRequestDirectContentsSourceEvent

Returns a new instance of GoogleCloudAiplatformV1GenerateMemoriesRequestDirectContentsSourceEvent.



15688
15689
15690
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15688

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Content

The structured data content of a message. A Content message contains a role field, which indicates the producer of the content, and a parts field, which contains the multi-part data of the message. Corresponds to the JSON property content



15686
15687
15688
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15686

def content
  @content
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15693
15694
15695
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15693

def update!(**args)
  @content = args[:content] if args.key?(:content)
end