Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateMemoriesRequestVertexSessionSource
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateMemoriesRequestVertexSessionSource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Defines an Agent Engine Session from which to generate the memories. If scope
is not provided, the scope will be extracted from the Session (i.e. "user_id"
: sesison.user_id).
Instance Attribute Summary collapse
-
#end_time ⇒ String
Optional.
-
#session ⇒ String
Required.
-
#start_time ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateMemoriesRequestVertexSessionSource
constructor
A new instance of GoogleCloudAiplatformV1GenerateMemoriesRequestVertexSessionSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateMemoriesRequestVertexSessionSource
Returns a new instance of GoogleCloudAiplatformV1GenerateMemoriesRequestVertexSessionSource.
18213 18214 18215 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18213 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time ⇒ String
Optional. End time (exclusive) of the time range. If not set, the end time is
unbounded.
Corresponds to the JSON property endTime
18197 18198 18199 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18197 def end_time @end_time end |
#session ⇒ String
Required. The resource name of the Session to generate memories for. Format:
projects/project/locations/location/reasoningEngines/reasoning_engine/
sessions/session`
Corresponds to the JSON propertysession`
18204 18205 18206 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18204 def session @session end |
#start_time ⇒ String
Optional. Time range to define which session events should be used to generate
memories. Start time (inclusive) of the time range. If not set, the start time
is unbounded.
Corresponds to the JSON property startTime
18211 18212 18213 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18211 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18218 18219 18220 18221 18222 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18218 def update!(**args) @end_time = args[:end_time] if args.key?(:end_time) @session = args[:session] if args.key?(:session) @start_time = args[:start_time] if args.key?(:start_time) end |