Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateMemoriesRequestVertexSessionSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Defines an Agent Engine Session from which to generate the memories. If scope is not provided, the scope will be extracted from the Session (i.e. "user_id" : sesison.user_id).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateMemoriesRequestVertexSessionSource

Returns a new instance of GoogleCloudAiplatformV1GenerateMemoriesRequestVertexSessionSource.



17158
17159
17160
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17158

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_timeString

Optional. End time (exclusive) of the time range. If not set, the end time is unbounded. Corresponds to the JSON property endTime

Returns:

  • (String)


17142
17143
17144
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17142

def end_time
  @end_time
end

#sessionString

Required. The resource name of the Session to generate memories for. Format: projects/project/locations/location/reasoningEngines/reasoning_engine/ sessions/session` Corresponds to the JSON propertysession`

Returns:

  • (String)


17149
17150
17151
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17149

def session
  @session
end

#start_timeString

Optional. Time range to define which session events should be used to generate memories. Start time (inclusive) of the time range. If not set, the start time is unbounded. Corresponds to the JSON property startTime

Returns:

  • (String)


17156
17157
17158
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17156

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17163
17164
17165
17166
17167
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17163

def update!(**args)
  @end_time = args[:end_time] if args.key?(:end_time)
  @session = args[:session] if args.key?(:session)
  @start_time = args[:start_time] if args.key?(:start_time)
end