Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateSyntheticDataRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateSyntheticDataRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Request message for DataFoundryService.GenerateSyntheticData. It contains the settings and information needed to generate synthetic data.
Instance Attribute Summary collapse
-
#count ⇒ Fixnum
Required.
-
#examples ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SyntheticExample>
Optional.
-
#output_field_specs ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1OutputFieldSpec>
Required.
-
#task_description ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TaskDescriptionStrategy
Defines a generation strategy based on a general task description.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateSyntheticDataRequest
constructor
A new instance of GoogleCloudAiplatformV1GenerateSyntheticDataRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateSyntheticDataRequest
Returns a new instance of GoogleCloudAiplatformV1GenerateSyntheticDataRequest.
17200 17201 17202 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17200 def initialize(**args) update!(**args) end |
Instance Attribute Details
#count ⇒ Fixnum
Required. The number of synthetic examples to generate. For this stateless API,
you can generate up to 50 examples in a single request.
Corresponds to the JSON property count
17179 17180 17181 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17179 def count @count end |
#examples ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SyntheticExample>
Optional. A list of few-shot examples that help the model understand the
desired style, tone, and format of the generated synthetic data. Providing
these few-shot examples can significantly improve the quality and relevance of
the output.
Corresponds to the JSON property examples
17187 17188 17189 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17187 def examples @examples end |
#output_field_specs ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1OutputFieldSpec>
Required. Defines the schema of each synthetic example to be generated,
defined by a list of fields.
Corresponds to the JSON property outputFieldSpecs
17193 17194 17195 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17193 def output_field_specs @output_field_specs end |
#task_description ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TaskDescriptionStrategy
Defines a generation strategy based on a general task description.
Corresponds to the JSON property taskDescription
17198 17199 17200 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17198 def task_description @task_description end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17205 17206 17207 17208 17209 17210 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17205 def update!(**args) @count = args[:count] if args.key?(:count) @examples = args[:examples] if args.key?(:examples) @output_field_specs = args[:output_field_specs] if args.key?(:output_field_specs) @task_description = args[:task_description] if args.key?(:task_description) end |