Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateSyntheticDataRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for DataFoundryService.GenerateSyntheticData.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateSyntheticDataRequest

Returns a new instance of GoogleCloudAiplatformV1GenerateSyntheticDataRequest.



15808
15809
15810
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15808

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countFixnum

Required. The number of synthetic examples to generate. For this stateless API, the count is limited to a small number. Corresponds to the JSON property count

Returns:

  • (Fixnum)


15790
15791
15792
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15790

def count
  @count
end

#examplesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SyntheticExample>

Optional. A list of few-shot examples to guide the model's output style and format. Corresponds to the JSON property examples



15796
15797
15798
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15796

def examples
  @examples
end

#output_field_specsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1OutputFieldSpec>

Required. The schema of the desired output, defined by a list of fields. Corresponds to the JSON property outputFieldSpecs



15801
15802
15803
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15801

def output_field_specs
  @output_field_specs
end

#task_descriptionGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TaskDescriptionStrategy

Defines a generation strategy based on a high-level task description. Corresponds to the JSON property taskDescription



15806
15807
15808
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15806

def task_description
  @task_description
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15813
15814
15815
15816
15817
15818
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15813

def update!(**args)
  @count = args[:count] if args.key?(:count)
  @examples = args[:examples] if args.key?(:examples)
  @output_field_specs = args[:output_field_specs] if args.key?(:output_field_specs)
  @task_description = args[:task_description] if args.key?(:task_description)
end