Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateSyntheticDataResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateSyntheticDataResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The response message for the GenerateSyntheticData method, containing the
synthetic examples generated by the Gen AI evaluation service.
Instance Attribute Summary collapse
-
#synthetic_examples ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SyntheticExample>
A list of generated synthetic examples, each containing a complete synthetic data instance generated based on your request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateSyntheticDataResponse
constructor
A new instance of GoogleCloudAiplatformV1GenerateSyntheticDataResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateSyntheticDataResponse
Returns a new instance of GoogleCloudAiplatformV1GenerateSyntheticDataResponse.
16576 16577 16578 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16576 def initialize(**args) update!(**args) end |
Instance Attribute Details
#synthetic_examples ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SyntheticExample>
A list of generated synthetic examples, each containing a complete synthetic
data instance generated based on your request.
Corresponds to the JSON property syntheticExamples
16574 16575 16576 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16574 def synthetic_examples @synthetic_examples end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16581 16582 16583 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16581 def update!(**args) @synthetic_examples = args[:synthetic_examples] if args.key?(:synthetic_examples) end |