Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateUserScenariosRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateUserScenariosRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Request message for DataFoundryService.GenerateUserScenarios.
Instance Attribute Summary collapse
-
#agents ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AgentConfig>
Optional.
-
#allow_cross_region_model ⇒ Boolean
(also: #allow_cross_region_model?)
Optional.
-
#gemini_agent_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GeminiAgentConfig
Config for scraping a Gemini Agent (a Vertex AI Agent resource scraped via the Vertex Interactions API).
-
#root_agent_id ⇒ String
Optional.
-
#user_scenario_generation_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1UserScenarioGenerationConfig
User scenario generation configuration.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateUserScenariosRequest
constructor
A new instance of GoogleCloudAiplatformV1GenerateUserScenariosRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateUserScenariosRequest
Returns a new instance of GoogleCloudAiplatformV1GenerateUserScenariosRequest.
18311 18312 18313 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18311 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agents ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AgentConfig>
Optional. A map containing the static configurations for each agent in the
system. Key: agent_id (matches the author field in events). Value: The
static configuration of the agent. Required unless gemini_agent_config is
set, in which case the agents map and root_agent_id are derived from the
referenced Gemini Agent.
Corresponds to the JSON property agents
18280 18281 18282 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18280 def agents @agents end |
#allow_cross_region_model ⇒ Boolean Also known as: allow_cross_region_model?
Optional. Allows the scenario generation to use cross region models. When this
flag is set, the service may route traffic to other regions if a model is
unavailable in the current region (e.g., to a global endpoint). If a fully-
qualified model endpoint resource name with a different region than the
request location is provided elsewhere in the request, this flag must be set
to true or the request will fail.
Corresponds to the JSON property allowCrossRegionModel
18290 18291 18292 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18290 def allow_cross_region_model @allow_cross_region_model end |
#gemini_agent_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GeminiAgentConfig
Config for scraping a Gemini Agent (a Vertex AI Agent resource scraped via the
Vertex Interactions API).
Corresponds to the JSON property geminiAgentConfig
18297 18298 18299 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18297 def gemini_agent_config @gemini_agent_config end |
#root_agent_id ⇒ String
Optional. The agent id to identify the root agent. Required unless
gemini_agent_config is set, in which case it is derived from the referenced
Gemini Agent.
Corresponds to the JSON property rootAgentId
18304 18305 18306 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18304 def root_agent_id @root_agent_id end |
#user_scenario_generation_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1UserScenarioGenerationConfig
User scenario generation configuration.
Corresponds to the JSON property userScenarioGenerationConfig
18309 18310 18311 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18309 def user_scenario_generation_config @user_scenario_generation_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18316 18317 18318 18319 18320 18321 18322 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18316 def update!(**args) @agents = args[:agents] if args.key?(:agents) @allow_cross_region_model = args[:allow_cross_region_model] if args.key?(:allow_cross_region_model) @gemini_agent_config = args[:gemini_agent_config] if args.key?(:gemini_agent_config) @root_agent_id = args[:root_agent_id] if args.key?(:root_agent_id) @user_scenario_generation_config = args[:user_scenario_generation_config] if args.key?(:user_scenario_generation_config) end |