Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateUserScenariosRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for DataFoundryService.GenerateUserScenarios.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateUserScenariosRequest

Returns a new instance of GoogleCloudAiplatformV1GenerateUserScenariosRequest.



17906
17907
17908
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17906

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agentsHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AgentConfig>

Optional. A map containing the static configurations for each agent in the system. Key: agent_id (matches the author field in events). Value: The static configuration of the agent. Required unless gemini_agent_config is set, in which case the agents map and root_agent_id are derived from the referenced Gemini Agent. Corresponds to the JSON property agents



17881
17882
17883
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17881

def agents
  @agents
end

#allow_cross_region_modelBoolean Also known as: allow_cross_region_model?

Optional. Allows the scenario generation to use cross region models. When this flag is set, the service may route traffic to other regions if a model is unavailable in the current region (e.g., to a global endpoint). If a fully- qualified model endpoint resource name with a different region than the request location is provided elsewhere in the request, this flag must be set to true or the request will fail. Corresponds to the JSON property allowCrossRegionModel

Returns:

  • (Boolean)


17891
17892
17893
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17891

def allow_cross_region_model
  @allow_cross_region_model
end

#root_agent_idString

Optional. The agent id to identify the root agent. Required unless gemini_agent_config is set, in which case it is derived from the referenced Gemini Agent. Corresponds to the JSON property rootAgentId

Returns:

  • (String)


17899
17900
17901
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17899

def root_agent_id
  @root_agent_id
end

#user_scenario_generation_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1UserScenarioGenerationConfig

User scenario generation configuration. Corresponds to the JSON property userScenarioGenerationConfig



17904
17905
17906
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17904

def user_scenario_generation_config
  @user_scenario_generation_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17911
17912
17913
17914
17915
17916
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17911

def update!(**args)
  @agents = args[:agents] if args.key?(:agents)
  @allow_cross_region_model = args[:allow_cross_region_model] if args.key?(:allow_cross_region_model)
  @root_agent_id = args[:root_agent_id] if args.key?(:root_agent_id)
  @user_scenario_generation_config = args[:user_scenario_generation_config] if args.key?(:user_scenario_generation_config)
end