Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateUserScenariosRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for DataFoundryService.GenerateUserScenarios.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateUserScenariosRequest

Returns a new instance of GoogleCloudAiplatformV1GenerateUserScenariosRequest.



17266
17267
17268
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17266

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agentsHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AgentConfig>

Required. A map containing the static configurations for each agent in the system. Key: agent_id (matches the author field in events). Value: The static configuration of the agent. Corresponds to the JSON property agents



17243
17244
17245
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17243

def agents
  @agents
end

#allow_cross_region_modelBoolean Also known as: allow_cross_region_model?

Optional. Allows the scenario generation to use cross region models. When this flag is set, the service may route traffic to other regions if a model is unavailable in the current region (e.g., to a global endpoint). If a fully- qualified model endpoint resource name with a different region than the request location is provided elsewhere in the request, this flag must be set to true or the request will fail. Corresponds to the JSON property allowCrossRegionModel

Returns:

  • (Boolean)


17253
17254
17255
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17253

def allow_cross_region_model
  @allow_cross_region_model
end

#root_agent_idString

Required. The agent id to identify the root agent. Corresponds to the JSON property rootAgentId

Returns:

  • (String)


17259
17260
17261
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17259

def root_agent_id
  @root_agent_id
end

#user_scenario_generation_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1UserScenarioGenerationConfig

User scenario generation configuration. Corresponds to the JSON property userScenarioGenerationConfig



17264
17265
17266
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17264

def user_scenario_generation_config
  @user_scenario_generation_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17271
17272
17273
17274
17275
17276
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17271

def update!(**args)
  @agents = args[:agents] if args.key?(:agents)
  @allow_cross_region_model = args[:allow_cross_region_model] if args.key?(:allow_cross_region_model)
  @root_agent_id = args[:root_agent_id] if args.key?(:root_agent_id)
  @user_scenario_generation_config = args[:user_scenario_generation_config] if args.key?(:user_scenario_generation_config)
end