Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateVideoResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateVideoResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Generate video response.
Instance Attribute Summary collapse
-
#generated_samples ⇒ Array<String>
The cloud storage uris of the generated videos.
-
#rai_media_filtered_count ⇒ Fixnum
Returns if any videos were filtered due to RAI policies.
-
#rai_media_filtered_reasons ⇒ Array<String>
Returns rai failure reasons if any.
-
#videos ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateVideoResponseVideo>
List of video bytes or Cloud Storage URIs of the generated videos.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateVideoResponse
constructor
A new instance of GoogleCloudAiplatformV1GenerateVideoResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerateVideoResponse
Returns a new instance of GoogleCloudAiplatformV1GenerateVideoResponse.
12768 12769 12770 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12768 def initialize(**args) update!(**args) end |
Instance Attribute Details
#generated_samples ⇒ Array<String>
The cloud storage uris of the generated videos.
Corresponds to the JSON property generatedSamples
12751 12752 12753 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12751 def generated_samples @generated_samples end |
#rai_media_filtered_count ⇒ Fixnum
Returns if any videos were filtered due to RAI policies.
Corresponds to the JSON property raiMediaFilteredCount
12756 12757 12758 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12756 def rai_media_filtered_count @rai_media_filtered_count end |
#rai_media_filtered_reasons ⇒ Array<String>
Returns rai failure reasons if any.
Corresponds to the JSON property raiMediaFilteredReasons
12761 12762 12763 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12761 def rai_media_filtered_reasons @rai_media_filtered_reasons end |
#videos ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerateVideoResponseVideo>
List of video bytes or Cloud Storage URIs of the generated videos.
Corresponds to the JSON property videos
12766 12767 12768 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12766 def videos @videos end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12773 12774 12775 12776 12777 12778 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12773 def update!(**args) @generated_samples = args[:generated_samples] if args.key?(:generated_samples) @rai_media_filtered_count = args[:rai_media_filtered_count] if args.key?(:rai_media_filtered_count) @rai_media_filtered_reasons = args[:rai_media_filtered_reasons] if args.key?(:rai_media_filtered_reasons) @videos = args[:videos] if args.key?(:videos) end |