Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Configuration for content generation. This message contains all the parameters that control how the model generates content. It allows you to influence the randomness, length, and structure of the output.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerationConfig

Returns a new instance of GoogleCloudAiplatformV1GenerationConfig.



18606
18607
18608
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18606

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audio_timestampBoolean Also known as: audio_timestamp?

Optional. If enabled, audio timestamps will be included in the request to the model. This can be useful for synchronizing audio with other modalities in the response. Corresponds to the JSON property audioTimestamp

Returns:

  • (Boolean)


18424
18425
18426
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18424

def audio_timestamp
  @audio_timestamp
end

#audio_transcription_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1AudioTranscriptionConfig

Configuration for speech recognition (transcription). Corresponds to the JSON property audioTranscriptionConfig



18430
18431
18432
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18430

def audio_transcription_config
  @audio_transcription_config
end

#candidate_countFixnum

Optional. The number of candidate responses to generate. A higher candidate_count can provide more options to choose from, but it also consumes more resources. This can be useful for generating a variety of responses and selecting the best one. Corresponds to the JSON property candidateCount

Returns:

  • (Fixnum)


18438
18439
18440
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18438

def candidate_count
  @candidate_count
end

#enable_affective_dialogBoolean Also known as: enable_affective_dialog?

Optional. If enabled, the model will detect emotions and adapt its responses accordingly. For example, if the model detects that the user is frustrated, it may provide a more empathetic response. Corresponds to the JSON property enableAffectiveDialog

Returns:

  • (Boolean)


18445
18446
18447
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18445

def enable_affective_dialog
  @enable_affective_dialog
end

#frequency_penaltyFloat

Optional. Penalizes tokens based on their frequency in the generated text. A positive value helps to reduce the repetition of words and phrases. Valid values can range from [-2.0, 2.0]. Corresponds to the JSON property frequencyPenalty

Returns:

  • (Float)


18453
18454
18455
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18453

def frequency_penalty
  @frequency_penalty
end

#image_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ImageConfig

Configuration for image generation. This message allows you to control various aspects of image generation, such as the output format, aspect ratio, and whether the model can generate images of people. Corresponds to the JSON property imageConfig



18460
18461
18462
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18460

def image_config
  @image_config
end

#logprobsFixnum

Optional. The number of top log probabilities to return for each token. This can be used to see which other tokens were considered likely candidates for a given position. A higher value will return more options, but it will also increase the size of the response. Corresponds to the JSON property logprobs

Returns:

  • (Fixnum)


18468
18469
18470
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18468

def logprobs
  @logprobs
end

#max_output_tokensFixnum

Optional. The maximum number of tokens to generate in the response. A token is approximately four characters. The default value varies by model. This parameter can be used to control the length of the generated text and prevent overly long responses. Corresponds to the JSON property maxOutputTokens

Returns:

  • (Fixnum)


18476
18477
18478
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18476

def max_output_tokens
  @max_output_tokens
end

#media_resolutionString

Optional. The token resolution at which input media content is sampled. This is used to control the trade-off between the quality of the response and the number of tokens used to represent the media. A higher resolution allows the model to perceive more detail, which can lead to a more nuanced response, but it will also use more tokens. This does not affect the image dimensions sent to the model. Corresponds to the JSON property mediaResolution

Returns:

  • (String)


18486
18487
18488
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18486

def media_resolution
  @media_resolution
end

#presence_penaltyFloat

Optional. Penalizes tokens that have already appeared in the generated text. A positive value encourages the model to generate more diverse and less repetitive text. Valid values can range from [-2.0, 2.0]. Corresponds to the JSON property presencePenalty

Returns:

  • (Float)


18493
18494
18495
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18493

def presence_penalty
  @presence_penalty
end

#response_formatArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ResponseFormat>

Optional. New response format field for the model to configure output formatting and delivery. Corresponds to the JSON property responseFormat



18499
18500
18501
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18499

def response_format
  @response_format
end

#response_json_schemaObject

Optional. When this field is set, response_schema must be omitted and response_mime_type must be set to application/json. Deprecated: Use response_format instead. Corresponds to the JSON property responseJsonSchema

Returns:

  • (Object)


18506
18507
18508
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18506

def response_json_schema
  @response_json_schema
end

#response_logprobsBoolean Also known as: response_logprobs?

Optional. If set to true, the log probabilities of the output tokens are returned. Log probabilities are the logarithm of the probability of a token appearing in the output. A higher log probability means the token is more likely to be generated. This can be useful for analyzing the model's confidence in its own output and for debugging. Corresponds to the JSON property responseLogprobs

Returns:

  • (Boolean)


18515
18516
18517
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18515

def response_logprobs
  @response_logprobs
end

#response_mime_typeString

Optional. The IANA standard MIME type of the response. The model will generate output that conforms to this MIME type. Supported values include 'text/plain' ( default) and 'application/json'. The model needs to be prompted to output the appropriate response type, otherwise the behavior is undefined. Deprecated: Use response_format instead. Corresponds to the JSON property responseMimeType

Returns:

  • (String)


18525
18526
18527
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18525

def response_mime_type
  @response_mime_type
end

#response_modalitiesArray<String>

Optional. The modalities of the response. The model will generate a response that includes all the specified modalities. For example, if this is set to [ TEXT, IMAGE], the response will include both text and an image. Corresponds to the JSON property responseModalities

Returns:

  • (Array<String>)


18532
18533
18534
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18532

def response_modalities
  @response_modalities
end

#response_schemaGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema

Defines the schema of input and output data. This is a subset of the OpenAPI 3.0 Schema Object. Corresponds to the JSON property responseSchema



18538
18539
18540
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18538

def response_schema
  @response_schema
end

#routing_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfigRoutingConfig

The configuration for routing the request to a specific model. This can be used to control which model is used for the generation, either automatically or by specifying a model name. Corresponds to the JSON property routingConfig



18545
18546
18547
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18545

def routing_config
  @routing_config
end

#seedFixnum

Optional. A seed for the random number generator. By setting a seed, you can make the model's output mostly deterministic. For a given prompt and parameters (like temperature, top_p, etc.), the model will produce the same response every time. However, it's not a guaranteed absolute deterministic behavior. This is different from parameters like temperature, which control the level of randomness. seed ensures that the "random" choices the model makes are the same on every run, making it essential for testing and ensuring reproducible results. Corresponds to the JSON property seed

Returns:

  • (Fixnum)


18557
18558
18559
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18557

def seed
  @seed
end

#speech_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SpeechConfig

Configuration for speech generation. Corresponds to the JSON property speechConfig



18562
18563
18564
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18562

def speech_config
  @speech_config
end

#stop_sequencesArray<String>

Optional. A list of character sequences that will stop the model from generating further tokens. If a stop sequence is generated, the output will end at that point. This is useful for controlling the length and structure of the output. For example, you can use ["\n", "###"] to stop generation at a new line or a specific marker. Corresponds to the JSON property stopSequences

Returns:

  • (Array<String>)


18571
18572
18573
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18571

def stop_sequences
  @stop_sequences
end

#temperatureFloat

Optional. Controls the randomness of the output. A higher temperature results in more creative and diverse responses, while a lower temperature makes the output more predictable and focused. The valid range is (0.0, 2.0]. Corresponds to the JSON property temperature

Returns:

  • (Float)


18578
18579
18580
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18578

def temperature
  @temperature
end

#thinking_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfigThinkingConfig

Configuration for the model's thinking features. "Thinking" is a process where the model breaks down a complex task into smaller, manageable steps. This allows the model to reason about the task, plan its approach, and execute the plan to generate a high-quality response. Corresponds to the JSON property thinkingConfig



18586
18587
18588
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18586

def thinking_config
  @thinking_config
end

#top_kFloat

Optional. Specifies the top-k sampling threshold. The model considers only the top k most probable tokens for the next token. This can be useful for generating more coherent and less random text. For example, a top_k of 40 means the model will choose the next word from the 40 most likely words. Corresponds to the JSON property topK

Returns:

  • (Float)


18594
18595
18596
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18594

def top_k
  @top_k
end

#top_pFloat

Optional. Specifies the nucleus sampling threshold. The model considers only the smallest set of tokens whose cumulative probability is at least top_p. This helps generate more diverse and less repetitive responses. For example, a top_p of 0.9 means the model considers tokens until the cumulative probability of the tokens to select from reaches 0.9. It's recommended to adjust either temperature or top_p, but not both. Corresponds to the JSON property topP

Returns:

  • (Float)


18604
18605
18606
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18604

def top_p
  @top_p
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18611
18612
18613
18614
18615
18616
18617
18618
18619
18620
18621
18622
18623
18624
18625
18626
18627
18628
18629
18630
18631
18632
18633
18634
18635
18636
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18611

def update!(**args)
  @audio_timestamp = args[:audio_timestamp] if args.key?(:audio_timestamp)
  @audio_transcription_config = args[:audio_transcription_config] if args.key?(:audio_transcription_config)
  @candidate_count = args[:candidate_count] if args.key?(:candidate_count)
  @enable_affective_dialog = args[:enable_affective_dialog] if args.key?(:enable_affective_dialog)
  @frequency_penalty = args[:frequency_penalty] if args.key?(:frequency_penalty)
  @image_config = args[:image_config] if args.key?(:image_config)
  @logprobs = args[:logprobs] if args.key?(:logprobs)
  @max_output_tokens = args[:max_output_tokens] if args.key?(:max_output_tokens)
  @media_resolution = args[:media_resolution] if args.key?(:media_resolution)
  @presence_penalty = args[:presence_penalty] if args.key?(:presence_penalty)
  @response_format = args[:response_format] if args.key?(:response_format)
  @response_json_schema = args[:response_json_schema] if args.key?(:response_json_schema)
  @response_logprobs = args[:response_logprobs] if args.key?(:response_logprobs)
  @response_mime_type = args[:response_mime_type] if args.key?(:response_mime_type)
  @response_modalities = args[:response_modalities] if args.key?(:response_modalities)
  @response_schema = args[:response_schema] if args.key?(:response_schema)
  @routing_config = args[:routing_config] if args.key?(:routing_config)
  @seed = args[:seed] if args.key?(:seed)
  @speech_config = args[:speech_config] if args.key?(:speech_config)
  @stop_sequences = args[:stop_sequences] if args.key?(:stop_sequences)
  @temperature = args[:temperature] if args.key?(:temperature)
  @thinking_config = args[:thinking_config] if args.key?(:thinking_config)
  @top_k = args[:top_k] if args.key?(:top_k)
  @top_p = args[:top_p] if args.key?(:top_p)
end