Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Generation config.
Instance Attribute Summary collapse
-
#audio_timestamp ⇒ Boolean
(also: #audio_timestamp?)
Optional.
-
#candidate_count ⇒ Fixnum
Optional.
-
#enable_affective_dialog ⇒ Boolean
(also: #enable_affective_dialog?)
Optional.
-
#frequency_penalty ⇒ Float
Optional.
-
#logprobs ⇒ Fixnum
Optional.
-
#max_output_tokens ⇒ Fixnum
Optional.
-
#media_resolution ⇒ String
Optional.
-
#presence_penalty ⇒ Float
Optional.
-
#response_json_schema ⇒ Object
Optional.
-
#response_logprobs ⇒ Boolean
(also: #response_logprobs?)
Optional.
-
#response_mime_type ⇒ String
Optional.
-
#response_modalities ⇒ Array<String>
Optional.
-
#response_schema ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema
Schema is used to define the format of input/output data.
-
#routing_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfigRoutingConfig
The configuration for routing the request to a specific model.
-
#seed ⇒ Fixnum
Optional.
-
#speech_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SpeechConfig
The speech generation config.
-
#stop_sequences ⇒ Array<String>
Optional.
-
#temperature ⇒ Float
Optional.
-
#thinking_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfigThinkingConfig
Config for thinking features.
-
#top_k ⇒ Float
Optional.
-
#top_p ⇒ Float
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerationConfig
constructor
A new instance of GoogleCloudAiplatformV1GenerationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerationConfig
Returns a new instance of GoogleCloudAiplatformV1GenerationConfig.
12998 12999 13000 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12998 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audio_timestamp ⇒ Boolean Also known as: audio_timestamp?
Optional. If enabled, audio timestamp will be included in the request to the
model.
Corresponds to the JSON property audioTimestamp
12874 12875 12876 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12874 def @audio_timestamp end |
#candidate_count ⇒ Fixnum
Optional. Number of candidates to generate.
Corresponds to the JSON property candidateCount
12880 12881 12882 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12880 def candidate_count @candidate_count end |
#enable_affective_dialog ⇒ Boolean Also known as: enable_affective_dialog?
Optional. If enabled, the model will detect emotions and adapt its responses
accordingly.
Corresponds to the JSON property enableAffectiveDialog
12886 12887 12888 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12886 def enable_affective_dialog @enable_affective_dialog end |
#frequency_penalty ⇒ Float
Optional. Frequency penalties.
Corresponds to the JSON property frequencyPenalty
12892 12893 12894 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12892 def frequency_penalty @frequency_penalty end |
#logprobs ⇒ Fixnum
Optional. Logit probabilities.
Corresponds to the JSON property logprobs
12897 12898 12899 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12897 def logprobs @logprobs end |
#max_output_tokens ⇒ Fixnum
Optional. The maximum number of output tokens to generate per message.
Corresponds to the JSON property maxOutputTokens
12902 12903 12904 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12902 def max_output_tokens @max_output_tokens end |
#media_resolution ⇒ String
Optional. If specified, the media resolution specified will be used.
Corresponds to the JSON property mediaResolution
12907 12908 12909 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12907 def media_resolution @media_resolution end |
#presence_penalty ⇒ Float
Optional. Positive penalties.
Corresponds to the JSON property presencePenalty
12912 12913 12914 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12912 def presence_penalty @presence_penalty end |
#response_json_schema ⇒ Object
Optional. Output schema of the generated response. This is an alternative to
response_schema that accepts JSON Schema. If set,
response_schema must be omitted, but response_mime_type is required. While
the full JSON Schema may be sent, not all features are supported. Specifically,
only the following properties are supported: - $id - $defs - $ref - $
anchor - type - format - title - description - enum (for strings
and numbers) - items - prefixItems - minItems - maxItems - minimum -
maximum - anyOf - oneOf (interpreted the same as anyOf) - properties
additionalProperties-requiredThe non-standardpropertyOrderingproperty may also be set. Cyclic references are unrolled to a limited degree and, as such, may only be used within non-required properties. (Nullable properties are not sufficient.) If$refis set on a sub-schema, no other properties, except for than those starting as a$, may be set. Corresponds to the JSON propertyresponseJsonSchema
12929 12930 12931 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12929 def response_json_schema @response_json_schema end |
#response_logprobs ⇒ Boolean Also known as: response_logprobs?
Optional. If true, export the logprobs results in response.
Corresponds to the JSON property responseLogprobs
12934 12935 12936 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12934 def response_logprobs @response_logprobs end |
#response_mime_type ⇒ String
Optional. Output response mimetype of the generated candidate text. Supported
mimetype: - text/plain: (default) Text output. - application/json: JSON
response in the candidates. The model needs to be prompted to output the
appropriate response type, otherwise the behavior is undefined. This is a
preview feature.
Corresponds to the JSON property responseMimeType
12944 12945 12946 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12944 def response_mime_type @response_mime_type end |
#response_modalities ⇒ Array<String>
Optional. The modalities of the response.
Corresponds to the JSON property responseModalities
12949 12950 12951 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12949 def response_modalities @response_modalities end |
#response_schema ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema
Schema is used to define the format of input/output data. Represents a select
subset of an OpenAPI 3.0 schema object. More fields may be added in the future as needed.
Corresponds to the JSON property responseSchema
12956 12957 12958 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12956 def response_schema @response_schema end |
#routing_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfigRoutingConfig
The configuration for routing the request to a specific model.
Corresponds to the JSON property routingConfig
12961 12962 12963 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12961 def routing_config @routing_config end |
#seed ⇒ Fixnum
Optional. Seed.
Corresponds to the JSON property seed
12966 12967 12968 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12966 def seed @seed end |
#speech_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SpeechConfig
The speech generation config.
Corresponds to the JSON property speechConfig
12971 12972 12973 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12971 def speech_config @speech_config end |
#stop_sequences ⇒ Array<String>
Optional. Stop sequences.
Corresponds to the JSON property stopSequences
12976 12977 12978 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12976 def stop_sequences @stop_sequences end |
#temperature ⇒ Float
Optional. Controls the randomness of predictions.
Corresponds to the JSON property temperature
12981 12982 12983 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12981 def temperature @temperature end |
#thinking_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfigThinkingConfig
Config for thinking features.
Corresponds to the JSON property thinkingConfig
12986 12987 12988 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12986 def thinking_config @thinking_config end |
#top_k ⇒ Float
Optional. If specified, top-k sampling will be used.
Corresponds to the JSON property topK
12991 12992 12993 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12991 def top_k @top_k end |
#top_p ⇒ Float
Optional. If specified, nucleus sampling will be used.
Corresponds to the JSON property topP
12996 12997 12998 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12996 def top_p @top_p end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13003 13004 13005 13006 13007 13008 13009 13010 13011 13012 13013 13014 13015 13016 13017 13018 13019 13020 13021 13022 13023 13024 13025 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13003 def update!(**args) @audio_timestamp = args[:audio_timestamp] if args.key?(:audio_timestamp) @candidate_count = args[:candidate_count] if args.key?(:candidate_count) @enable_affective_dialog = args[:enable_affective_dialog] if args.key?(:enable_affective_dialog) @frequency_penalty = args[:frequency_penalty] if args.key?(:frequency_penalty) @logprobs = args[:logprobs] if args.key?(:logprobs) @max_output_tokens = args[:max_output_tokens] if args.key?(:max_output_tokens) @media_resolution = args[:media_resolution] if args.key?(:media_resolution) @presence_penalty = args[:presence_penalty] if args.key?(:presence_penalty) @response_json_schema = args[:response_json_schema] if args.key?(:response_json_schema) @response_logprobs = args[:response_logprobs] if args.key?(:response_logprobs) @response_mime_type = args[:response_mime_type] if args.key?(:response_mime_type) @response_modalities = args[:response_modalities] if args.key?(:response_modalities) @response_schema = args[:response_schema] if args.key?(:response_schema) @routing_config = args[:routing_config] if args.key?(:routing_config) @seed = args[:seed] if args.key?(:seed) @speech_config = args[:speech_config] if args.key?(:speech_config) @stop_sequences = args[:stop_sequences] if args.key?(:stop_sequences) @temperature = args[:temperature] if args.key?(:temperature) @thinking_config = args[:thinking_config] if args.key?(:thinking_config) @top_k = args[:top_k] if args.key?(:top_k) @top_p = args[:top_p] if args.key?(:top_p) end |