Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Generation config.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerationConfig

Returns a new instance of GoogleCloudAiplatformV1GenerationConfig.



12942
12943
12944
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12942

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audio_timestampBoolean Also known as: audio_timestamp?

Optional. If enabled, audio timestamp will be included in the request to the model. Corresponds to the JSON property audioTimestamp

Returns:

  • (Boolean)


12818
12819
12820
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12818

def audio_timestamp
  @audio_timestamp
end

#candidate_countFixnum

Optional. Number of candidates to generate. Corresponds to the JSON property candidateCount

Returns:

  • (Fixnum)


12824
12825
12826
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12824

def candidate_count
  @candidate_count
end

#enable_affective_dialogBoolean Also known as: enable_affective_dialog?

Optional. If enabled, the model will detect emotions and adapt its responses accordingly. Corresponds to the JSON property enableAffectiveDialog

Returns:

  • (Boolean)


12830
12831
12832
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12830

def enable_affective_dialog
  @enable_affective_dialog
end

#frequency_penaltyFloat

Optional. Frequency penalties. Corresponds to the JSON property frequencyPenalty

Returns:

  • (Float)


12836
12837
12838
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12836

def frequency_penalty
  @frequency_penalty
end

#logprobsFixnum

Optional. Logit probabilities. Corresponds to the JSON property logprobs

Returns:

  • (Fixnum)


12841
12842
12843
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12841

def logprobs
  @logprobs
end

#max_output_tokensFixnum

Optional. The maximum number of output tokens to generate per message. Corresponds to the JSON property maxOutputTokens

Returns:

  • (Fixnum)


12846
12847
12848
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12846

def max_output_tokens
  @max_output_tokens
end

#media_resolutionString

Optional. If specified, the media resolution specified will be used. Corresponds to the JSON property mediaResolution

Returns:

  • (String)


12851
12852
12853
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12851

def media_resolution
  @media_resolution
end

#presence_penaltyFloat

Optional. Positive penalties. Corresponds to the JSON property presencePenalty

Returns:

  • (Float)


12856
12857
12858
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12856

def presence_penalty
  @presence_penalty
end

#response_json_schemaObject

Optional. Output schema of the generated response. This is an alternative to response_schema that accepts JSON Schema. If set, response_schema must be omitted, but response_mime_type is required. While the full JSON Schema may be sent, not all features are supported. Specifically, only the following properties are supported: - $id - $defs - $ref - $ anchor - type - format - title - description - enum (for strings and numbers) - items - prefixItems - minItems - maxItems - minimum - maximum - anyOf - oneOf (interpreted the same as anyOf) - properties

  • additionalProperties - required The non-standard propertyOrdering property may also be set. Cyclic references are unrolled to a limited degree and, as such, may only be used within non-required properties. (Nullable properties are not sufficient.) If $ref is set on a sub-schema, no other properties, except for than those starting as a $, may be set. Corresponds to the JSON property responseJsonSchema

Returns:

  • (Object)


12873
12874
12875
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12873

def response_json_schema
  @response_json_schema
end

#response_logprobsBoolean Also known as: response_logprobs?

Optional. If true, export the logprobs results in response. Corresponds to the JSON property responseLogprobs

Returns:

  • (Boolean)


12878
12879
12880
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12878

def response_logprobs
  @response_logprobs
end

#response_mime_typeString

Optional. Output response mimetype of the generated candidate text. Supported mimetype: - text/plain: (default) Text output. - application/json: JSON response in the candidates. The model needs to be prompted to output the appropriate response type, otherwise the behavior is undefined. This is a preview feature. Corresponds to the JSON property responseMimeType

Returns:

  • (String)


12888
12889
12890
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12888

def response_mime_type
  @response_mime_type
end

#response_modalitiesArray<String>

Optional. The modalities of the response. Corresponds to the JSON property responseModalities

Returns:

  • (Array<String>)


12893
12894
12895
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12893

def response_modalities
  @response_modalities
end

#response_schemaGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema

Schema is used to define the format of input/output data. Represents a select subset of an OpenAPI 3.0 schema object. More fields may be added in the future as needed. Corresponds to the JSON property responseSchema



12900
12901
12902
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12900

def response_schema
  @response_schema
end

#routing_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfigRoutingConfig

The configuration for routing the request to a specific model. Corresponds to the JSON property routingConfig



12905
12906
12907
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12905

def routing_config
  @routing_config
end

#seedFixnum

Optional. Seed. Corresponds to the JSON property seed

Returns:

  • (Fixnum)


12910
12911
12912
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12910

def seed
  @seed
end

#speech_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SpeechConfig

The speech generation config. Corresponds to the JSON property speechConfig



12915
12916
12917
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12915

def speech_config
  @speech_config
end

#stop_sequencesArray<String>

Optional. Stop sequences. Corresponds to the JSON property stopSequences

Returns:

  • (Array<String>)


12920
12921
12922
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12920

def stop_sequences
  @stop_sequences
end

#temperatureFloat

Optional. Controls the randomness of predictions. Corresponds to the JSON property temperature

Returns:

  • (Float)


12925
12926
12927
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12925

def temperature
  @temperature
end

#thinking_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfigThinkingConfig

Config for thinking features. Corresponds to the JSON property thinkingConfig



12930
12931
12932
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12930

def thinking_config
  @thinking_config
end

#top_kFloat

Optional. If specified, top-k sampling will be used. Corresponds to the JSON property topK

Returns:

  • (Float)


12935
12936
12937
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12935

def top_k
  @top_k
end

#top_pFloat

Optional. If specified, nucleus sampling will be used. Corresponds to the JSON property topP

Returns:

  • (Float)


12940
12941
12942
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12940

def top_p
  @top_p
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12947
12948
12949
12950
12951
12952
12953
12954
12955
12956
12957
12958
12959
12960
12961
12962
12963
12964
12965
12966
12967
12968
12969
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12947

def update!(**args)
  @audio_timestamp = args[:audio_timestamp] if args.key?(:audio_timestamp)
  @candidate_count = args[:candidate_count] if args.key?(:candidate_count)
  @enable_affective_dialog = args[:enable_affective_dialog] if args.key?(:enable_affective_dialog)
  @frequency_penalty = args[:frequency_penalty] if args.key?(:frequency_penalty)
  @logprobs = args[:logprobs] if args.key?(:logprobs)
  @max_output_tokens = args[:max_output_tokens] if args.key?(:max_output_tokens)
  @media_resolution = args[:media_resolution] if args.key?(:media_resolution)
  @presence_penalty = args[:presence_penalty] if args.key?(:presence_penalty)
  @response_json_schema = args[:response_json_schema] if args.key?(:response_json_schema)
  @response_logprobs = args[:response_logprobs] if args.key?(:response_logprobs)
  @response_mime_type = args[:response_mime_type] if args.key?(:response_mime_type)
  @response_modalities = args[:response_modalities] if args.key?(:response_modalities)
  @response_schema = args[:response_schema] if args.key?(:response_schema)
  @routing_config = args[:routing_config] if args.key?(:routing_config)
  @seed = args[:seed] if args.key?(:seed)
  @speech_config = args[:speech_config] if args.key?(:speech_config)
  @stop_sequences = args[:stop_sequences] if args.key?(:stop_sequences)
  @temperature = args[:temperature] if args.key?(:temperature)
  @thinking_config = args[:thinking_config] if args.key?(:thinking_config)
  @top_k = args[:top_k] if args.key?(:top_k)
  @top_p = args[:top_p] if args.key?(:top_p)
end