Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Generation config.
Instance Attribute Summary collapse
-
#audio_timestamp ⇒ Boolean
(also: #audio_timestamp?)
Optional.
-
#candidate_count ⇒ Fixnum
Optional.
-
#frequency_penalty ⇒ Float
Optional.
-
#logprobs ⇒ Fixnum
Optional.
-
#max_output_tokens ⇒ Fixnum
Optional.
-
#media_resolution ⇒ String
Optional.
-
#presence_penalty ⇒ Float
Optional.
-
#response_logprobs ⇒ Boolean
(also: #response_logprobs?)
Optional.
-
#response_mime_type ⇒ String
Optional.
-
#response_modalities ⇒ Array<String>
Optional.
-
#response_schema ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema
Schema is used to define the format of input/output data.
-
#routing_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfigRoutingConfig
The configuration for routing the request to a specific model.
-
#seed ⇒ Fixnum
Optional.
-
#speech_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SpeechConfig
The speech generation config.
-
#stop_sequences ⇒ Array<String>
Optional.
-
#temperature ⇒ Float
Optional.
-
#thinking_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfigThinkingConfig
Config for thinking features.
-
#top_k ⇒ Float
Optional.
-
#top_p ⇒ Float
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerationConfig
constructor
A new instance of GoogleCloudAiplatformV1GenerationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerationConfig
Returns a new instance of GoogleCloudAiplatformV1GenerationConfig.
12575 12576 12577 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12575 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audio_timestamp ⇒ Boolean Also known as: audio_timestamp?
Optional. If enabled, audio timestamp will be included in the request to the
model.
Corresponds to the JSON property audioTimestamp
12475 12476 12477 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12475 def @audio_timestamp end |
#candidate_count ⇒ Fixnum
Optional. Number of candidates to generate.
Corresponds to the JSON property candidateCount
12481 12482 12483 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12481 def candidate_count @candidate_count end |
#frequency_penalty ⇒ Float
Optional. Frequency penalties.
Corresponds to the JSON property frequencyPenalty
12486 12487 12488 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12486 def frequency_penalty @frequency_penalty end |
#logprobs ⇒ Fixnum
Optional. Logit probabilities.
Corresponds to the JSON property logprobs
12491 12492 12493 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12491 def logprobs @logprobs end |
#max_output_tokens ⇒ Fixnum
Optional. The maximum number of output tokens to generate per message.
Corresponds to the JSON property maxOutputTokens
12496 12497 12498 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12496 def max_output_tokens @max_output_tokens end |
#media_resolution ⇒ String
Optional. If specified, the media resolution specified will be used.
Corresponds to the JSON property mediaResolution
12501 12502 12503 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12501 def media_resolution @media_resolution end |
#presence_penalty ⇒ Float
Optional. Positive penalties.
Corresponds to the JSON property presencePenalty
12506 12507 12508 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12506 def presence_penalty @presence_penalty end |
#response_logprobs ⇒ Boolean Also known as: response_logprobs?
Optional. If true, export the logprobs results in response.
Corresponds to the JSON property responseLogprobs
12511 12512 12513 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12511 def response_logprobs @response_logprobs end |
#response_mime_type ⇒ String
Optional. Output response mimetype of the generated candidate text. Supported
mimetype: - text/plain: (default) Text output. - application/json: JSON
response in the candidates. The model needs to be prompted to output the
appropriate response type, otherwise the behavior is undefined. This is a
preview feature.
Corresponds to the JSON property responseMimeType
12521 12522 12523 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12521 def response_mime_type @response_mime_type end |
#response_modalities ⇒ Array<String>
Optional. The modalities of the response.
Corresponds to the JSON property responseModalities
12526 12527 12528 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12526 def response_modalities @response_modalities end |
#response_schema ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema
Schema is used to define the format of input/output data. Represents a select
subset of an OpenAPI 3.0 schema object. More fields may be added in the future as needed.
Corresponds to the JSON property responseSchema
12533 12534 12535 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12533 def response_schema @response_schema end |
#routing_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfigRoutingConfig
The configuration for routing the request to a specific model.
Corresponds to the JSON property routingConfig
12538 12539 12540 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12538 def routing_config @routing_config end |
#seed ⇒ Fixnum
Optional. Seed.
Corresponds to the JSON property seed
12543 12544 12545 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12543 def seed @seed end |
#speech_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SpeechConfig
The speech generation config.
Corresponds to the JSON property speechConfig
12548 12549 12550 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12548 def speech_config @speech_config end |
#stop_sequences ⇒ Array<String>
Optional. Stop sequences.
Corresponds to the JSON property stopSequences
12553 12554 12555 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12553 def stop_sequences @stop_sequences end |
#temperature ⇒ Float
Optional. Controls the randomness of predictions.
Corresponds to the JSON property temperature
12558 12559 12560 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12558 def temperature @temperature end |
#thinking_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfigThinkingConfig
Config for thinking features.
Corresponds to the JSON property thinkingConfig
12563 12564 12565 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12563 def thinking_config @thinking_config end |
#top_k ⇒ Float
Optional. If specified, top-k sampling will be used.
Corresponds to the JSON property topK
12568 12569 12570 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12568 def top_k @top_k end |
#top_p ⇒ Float
Optional. If specified, nucleus sampling will be used.
Corresponds to the JSON property topP
12573 12574 12575 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12573 def top_p @top_p end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12580 12581 12582 12583 12584 12585 12586 12587 12588 12589 12590 12591 12592 12593 12594 12595 12596 12597 12598 12599 12600 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12580 def update!(**args) @audio_timestamp = args[:audio_timestamp] if args.key?(:audio_timestamp) @candidate_count = args[:candidate_count] if args.key?(:candidate_count) @frequency_penalty = args[:frequency_penalty] if args.key?(:frequency_penalty) @logprobs = args[:logprobs] if args.key?(:logprobs) @max_output_tokens = args[:max_output_tokens] if args.key?(:max_output_tokens) @media_resolution = args[:media_resolution] if args.key?(:media_resolution) @presence_penalty = args[:presence_penalty] if args.key?(:presence_penalty) @response_logprobs = args[:response_logprobs] if args.key?(:response_logprobs) @response_mime_type = args[:response_mime_type] if args.key?(:response_mime_type) @response_modalities = args[:response_modalities] if args.key?(:response_modalities) @response_schema = args[:response_schema] if args.key?(:response_schema) @routing_config = args[:routing_config] if args.key?(:routing_config) @seed = args[:seed] if args.key?(:seed) @speech_config = args[:speech_config] if args.key?(:speech_config) @stop_sequences = args[:stop_sequences] if args.key?(:stop_sequences) @temperature = args[:temperature] if args.key?(:temperature) @thinking_config = args[:thinking_config] if args.key?(:thinking_config) @top_k = args[:top_k] if args.key?(:top_k) @top_p = args[:top_p] if args.key?(:top_p) end |