Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Generation config.
Instance Attribute Summary collapse
-
#audio_timestamp ⇒ Boolean
(also: #audio_timestamp?)
Optional.
-
#candidate_count ⇒ Fixnum
Optional.
-
#frequency_penalty ⇒ Float
Optional.
-
#logprobs ⇒ Fixnum
Optional.
-
#max_output_tokens ⇒ Fixnum
Optional.
-
#media_resolution ⇒ String
Optional.
-
#presence_penalty ⇒ Float
Optional.
-
#response_logprobs ⇒ Boolean
(also: #response_logprobs?)
Optional.
-
#response_mime_type ⇒ String
Optional.
-
#response_modalities ⇒ Array<String>
Optional.
-
#response_schema ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema
Schema is used to define the format of input/output data.
-
#routing_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfigRoutingConfig
The configuration for routing the request to a specific model.
-
#seed ⇒ Fixnum
Optional.
-
#speech_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SpeechConfig
The speech generation config.
-
#stop_sequences ⇒ Array<String>
Optional.
-
#temperature ⇒ Float
Optional.
-
#thinking_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfigThinkingConfig
Config for thinking features.
-
#top_k ⇒ Float
Optional.
-
#top_p ⇒ Float
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerationConfig
constructor
A new instance of GoogleCloudAiplatformV1GenerationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerationConfig
Returns a new instance of GoogleCloudAiplatformV1GenerationConfig.
12253 12254 12255 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12253 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audio_timestamp ⇒ Boolean Also known as: audio_timestamp?
Optional. If enabled, audio timestamp will be included in the request to the
model.
Corresponds to the JSON property audioTimestamp
12153 12154 12155 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12153 def @audio_timestamp end |
#candidate_count ⇒ Fixnum
Optional. Number of candidates to generate.
Corresponds to the JSON property candidateCount
12159 12160 12161 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12159 def candidate_count @candidate_count end |
#frequency_penalty ⇒ Float
Optional. Frequency penalties.
Corresponds to the JSON property frequencyPenalty
12164 12165 12166 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12164 def frequency_penalty @frequency_penalty end |
#logprobs ⇒ Fixnum
Optional. Logit probabilities.
Corresponds to the JSON property logprobs
12169 12170 12171 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12169 def logprobs @logprobs end |
#max_output_tokens ⇒ Fixnum
Optional. The maximum number of output tokens to generate per message.
Corresponds to the JSON property maxOutputTokens
12174 12175 12176 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12174 def max_output_tokens @max_output_tokens end |
#media_resolution ⇒ String
Optional. If specified, the media resolution specified will be used.
Corresponds to the JSON property mediaResolution
12179 12180 12181 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12179 def media_resolution @media_resolution end |
#presence_penalty ⇒ Float
Optional. Positive penalties.
Corresponds to the JSON property presencePenalty
12184 12185 12186 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12184 def presence_penalty @presence_penalty end |
#response_logprobs ⇒ Boolean Also known as: response_logprobs?
Optional. If true, export the logprobs results in response.
Corresponds to the JSON property responseLogprobs
12189 12190 12191 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12189 def response_logprobs @response_logprobs end |
#response_mime_type ⇒ String
Optional. Output response mimetype of the generated candidate text. Supported
mimetype: - text/plain: (default) Text output. - application/json: JSON
response in the candidates. The model needs to be prompted to output the
appropriate response type, otherwise the behavior is undefined. This is a
preview feature.
Corresponds to the JSON property responseMimeType
12199 12200 12201 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12199 def response_mime_type @response_mime_type end |
#response_modalities ⇒ Array<String>
Optional. The modalities of the response.
Corresponds to the JSON property responseModalities
12204 12205 12206 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12204 def response_modalities @response_modalities end |
#response_schema ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema
Schema is used to define the format of input/output data. Represents a select
subset of an OpenAPI 3.0 schema object. More fields may be added in the future as needed.
Corresponds to the JSON property responseSchema
12211 12212 12213 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12211 def response_schema @response_schema end |
#routing_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfigRoutingConfig
The configuration for routing the request to a specific model.
Corresponds to the JSON property routingConfig
12216 12217 12218 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12216 def routing_config @routing_config end |
#seed ⇒ Fixnum
Optional. Seed.
Corresponds to the JSON property seed
12221 12222 12223 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12221 def seed @seed end |
#speech_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SpeechConfig
The speech generation config.
Corresponds to the JSON property speechConfig
12226 12227 12228 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12226 def speech_config @speech_config end |
#stop_sequences ⇒ Array<String>
Optional. Stop sequences.
Corresponds to the JSON property stopSequences
12231 12232 12233 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12231 def stop_sequences @stop_sequences end |
#temperature ⇒ Float
Optional. Controls the randomness of predictions.
Corresponds to the JSON property temperature
12236 12237 12238 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12236 def temperature @temperature end |
#thinking_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfigThinkingConfig
Config for thinking features.
Corresponds to the JSON property thinkingConfig
12241 12242 12243 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12241 def thinking_config @thinking_config end |
#top_k ⇒ Float
Optional. If specified, top-k sampling will be used.
Corresponds to the JSON property topK
12246 12247 12248 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12246 def top_k @top_k end |
#top_p ⇒ Float
Optional. If specified, nucleus sampling will be used.
Corresponds to the JSON property topP
12251 12252 12253 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12251 def top_p @top_p end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12258 12259 12260 12261 12262 12263 12264 12265 12266 12267 12268 12269 12270 12271 12272 12273 12274 12275 12276 12277 12278 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12258 def update!(**args) @audio_timestamp = args[:audio_timestamp] if args.key?(:audio_timestamp) @candidate_count = args[:candidate_count] if args.key?(:candidate_count) @frequency_penalty = args[:frequency_penalty] if args.key?(:frequency_penalty) @logprobs = args[:logprobs] if args.key?(:logprobs) @max_output_tokens = args[:max_output_tokens] if args.key?(:max_output_tokens) @media_resolution = args[:media_resolution] if args.key?(:media_resolution) @presence_penalty = args[:presence_penalty] if args.key?(:presence_penalty) @response_logprobs = args[:response_logprobs] if args.key?(:response_logprobs) @response_mime_type = args[:response_mime_type] if args.key?(:response_mime_type) @response_modalities = args[:response_modalities] if args.key?(:response_modalities) @response_schema = args[:response_schema] if args.key?(:response_schema) @routing_config = args[:routing_config] if args.key?(:routing_config) @seed = args[:seed] if args.key?(:seed) @speech_config = args[:speech_config] if args.key?(:speech_config) @stop_sequences = args[:stop_sequences] if args.key?(:stop_sequences) @temperature = args[:temperature] if args.key?(:temperature) @thinking_config = args[:thinking_config] if args.key?(:thinking_config) @top_k = args[:top_k] if args.key?(:top_k) @top_p = args[:top_p] if args.key?(:top_p) end |