Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Generation config.
Instance Attribute Summary collapse
-
#audio_timestamp ⇒ Boolean
(also: #audio_timestamp?)
Optional.
-
#candidate_count ⇒ Fixnum
Optional.
-
#frequency_penalty ⇒ Float
Optional.
-
#logprobs ⇒ Fixnum
Optional.
-
#max_output_tokens ⇒ Fixnum
Optional.
-
#media_resolution ⇒ String
Optional.
-
#presence_penalty ⇒ Float
Optional.
-
#response_logprobs ⇒ Boolean
(also: #response_logprobs?)
Optional.
-
#response_mime_type ⇒ String
Optional.
-
#response_modalities ⇒ Array<String>
Optional.
-
#response_schema ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema
Schema is used to define the format of input/output data.
-
#routing_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfigRoutingConfig
The configuration for routing the request to a specific model.
-
#seed ⇒ Fixnum
Optional.
-
#speech_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SpeechConfig
The speech generation config.
-
#stop_sequences ⇒ Array<String>
Optional.
-
#temperature ⇒ Float
Optional.
-
#top_k ⇒ Float
Optional.
-
#top_p ⇒ Float
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerationConfig
constructor
A new instance of GoogleCloudAiplatformV1GenerationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerationConfig
Returns a new instance of GoogleCloudAiplatformV1GenerationConfig.
12079 12080 12081 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12079 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audio_timestamp ⇒ Boolean Also known as: audio_timestamp?
Optional. If enabled, audio timestamp will be included in the request to the
model.
Corresponds to the JSON property audioTimestamp
11984 11985 11986 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11984 def @audio_timestamp end |
#candidate_count ⇒ Fixnum
Optional. Number of candidates to generate.
Corresponds to the JSON property candidateCount
11990 11991 11992 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11990 def candidate_count @candidate_count end |
#frequency_penalty ⇒ Float
Optional. Frequency penalties.
Corresponds to the JSON property frequencyPenalty
11995 11996 11997 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11995 def frequency_penalty @frequency_penalty end |
#logprobs ⇒ Fixnum
Optional. Logit probabilities.
Corresponds to the JSON property logprobs
12000 12001 12002 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12000 def logprobs @logprobs end |
#max_output_tokens ⇒ Fixnum
Optional. The maximum number of output tokens to generate per message.
Corresponds to the JSON property maxOutputTokens
12005 12006 12007 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12005 def max_output_tokens @max_output_tokens end |
#media_resolution ⇒ String
Optional. If specified, the media resolution specified will be used.
Corresponds to the JSON property mediaResolution
12010 12011 12012 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12010 def media_resolution @media_resolution end |
#presence_penalty ⇒ Float
Optional. Positive penalties.
Corresponds to the JSON property presencePenalty
12015 12016 12017 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12015 def presence_penalty @presence_penalty end |
#response_logprobs ⇒ Boolean Also known as: response_logprobs?
Optional. If true, export the logprobs results in response.
Corresponds to the JSON property responseLogprobs
12020 12021 12022 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12020 def response_logprobs @response_logprobs end |
#response_mime_type ⇒ String
Optional. Output response mimetype of the generated candidate text. Supported
mimetype: - text/plain: (default) Text output. - application/json: JSON
response in the candidates. The model needs to be prompted to output the
appropriate response type, otherwise the behavior is undefined. This is a
preview feature.
Corresponds to the JSON property responseMimeType
12030 12031 12032 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12030 def response_mime_type @response_mime_type end |
#response_modalities ⇒ Array<String>
Optional. The modalities of the response.
Corresponds to the JSON property responseModalities
12035 12036 12037 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12035 def response_modalities @response_modalities end |
#response_schema ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema
Schema is used to define the format of input/output data. Represents a select
subset of an OpenAPI 3.0 schema object. More fields may be added in the future as needed.
Corresponds to the JSON property responseSchema
12042 12043 12044 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12042 def response_schema @response_schema end |
#routing_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfigRoutingConfig
The configuration for routing the request to a specific model.
Corresponds to the JSON property routingConfig
12047 12048 12049 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12047 def routing_config @routing_config end |
#seed ⇒ Fixnum
Optional. Seed.
Corresponds to the JSON property seed
12052 12053 12054 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12052 def seed @seed end |
#speech_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SpeechConfig
The speech generation config.
Corresponds to the JSON property speechConfig
12057 12058 12059 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12057 def speech_config @speech_config end |
#stop_sequences ⇒ Array<String>
Optional. Stop sequences.
Corresponds to the JSON property stopSequences
12062 12063 12064 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12062 def stop_sequences @stop_sequences end |
#temperature ⇒ Float
Optional. Controls the randomness of predictions.
Corresponds to the JSON property temperature
12067 12068 12069 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12067 def temperature @temperature end |
#top_k ⇒ Float
Optional. If specified, top-k sampling will be used.
Corresponds to the JSON property topK
12072 12073 12074 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12072 def top_k @top_k end |
#top_p ⇒ Float
Optional. If specified, nucleus sampling will be used.
Corresponds to the JSON property topP
12077 12078 12079 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12077 def top_p @top_p end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12084 12085 12086 12087 12088 12089 12090 12091 12092 12093 12094 12095 12096 12097 12098 12099 12100 12101 12102 12103 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12084 def update!(**args) @audio_timestamp = args[:audio_timestamp] if args.key?(:audio_timestamp) @candidate_count = args[:candidate_count] if args.key?(:candidate_count) @frequency_penalty = args[:frequency_penalty] if args.key?(:frequency_penalty) @logprobs = args[:logprobs] if args.key?(:logprobs) @max_output_tokens = args[:max_output_tokens] if args.key?(:max_output_tokens) @media_resolution = args[:media_resolution] if args.key?(:media_resolution) @presence_penalty = args[:presence_penalty] if args.key?(:presence_penalty) @response_logprobs = args[:response_logprobs] if args.key?(:response_logprobs) @response_mime_type = args[:response_mime_type] if args.key?(:response_mime_type) @response_modalities = args[:response_modalities] if args.key?(:response_modalities) @response_schema = args[:response_schema] if args.key?(:response_schema) @routing_config = args[:routing_config] if args.key?(:routing_config) @seed = args[:seed] if args.key?(:seed) @speech_config = args[:speech_config] if args.key?(:speech_config) @stop_sequences = args[:stop_sequences] if args.key?(:stop_sequences) @temperature = args[:temperature] if args.key?(:temperature) @top_k = args[:top_k] if args.key?(:top_k) @top_p = args[:top_p] if args.key?(:top_p) end |