Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Generation config.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerationConfig

Returns a new instance of GoogleCloudAiplatformV1GenerationConfig.



11940
11941
11942
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11940

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audio_timestampBoolean Also known as: audio_timestamp?

Optional. If enabled, audio timestamp will be included in the request to the model. Corresponds to the JSON property audioTimestamp

Returns:

  • (Boolean)


11845
11846
11847
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11845

def audio_timestamp
  @audio_timestamp
end

#candidate_countFixnum

Optional. Number of candidates to generate. Corresponds to the JSON property candidateCount

Returns:

  • (Fixnum)


11851
11852
11853
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11851

def candidate_count
  @candidate_count
end

#frequency_penaltyFloat

Optional. Frequency penalties. Corresponds to the JSON property frequencyPenalty

Returns:

  • (Float)


11856
11857
11858
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11856

def frequency_penalty
  @frequency_penalty
end

#logprobsFixnum

Optional. Logit probabilities. Corresponds to the JSON property logprobs

Returns:

  • (Fixnum)


11861
11862
11863
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11861

def logprobs
  @logprobs
end

#max_output_tokensFixnum

Optional. The maximum number of output tokens to generate per message. Corresponds to the JSON property maxOutputTokens

Returns:

  • (Fixnum)


11866
11867
11868
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11866

def max_output_tokens
  @max_output_tokens
end

#media_resolutionString

Optional. If specified, the media resolution specified will be used. Corresponds to the JSON property mediaResolution

Returns:

  • (String)


11871
11872
11873
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11871

def media_resolution
  @media_resolution
end

#presence_penaltyFloat

Optional. Positive penalties. Corresponds to the JSON property presencePenalty

Returns:

  • (Float)


11876
11877
11878
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11876

def presence_penalty
  @presence_penalty
end

#response_logprobsBoolean Also known as: response_logprobs?

Optional. If true, export the logprobs results in response. Corresponds to the JSON property responseLogprobs

Returns:

  • (Boolean)


11881
11882
11883
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11881

def response_logprobs
  @response_logprobs
end

#response_mime_typeString

Optional. Output response mimetype of the generated candidate text. Supported mimetype: - text/plain: (default) Text output. - application/json: JSON response in the candidates. The model needs to be prompted to output the appropriate response type, otherwise the behavior is undefined. This is a preview feature. Corresponds to the JSON property responseMimeType

Returns:

  • (String)


11891
11892
11893
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11891

def response_mime_type
  @response_mime_type
end

#response_modalitiesArray<String>

Optional. The modalities of the response. Corresponds to the JSON property responseModalities

Returns:

  • (Array<String>)


11896
11897
11898
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11896

def response_modalities
  @response_modalities
end

#response_schemaGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema

Schema is used to define the format of input/output data. Represents a select subset of an OpenAPI 3.0 schema object. More fields may be added in the future as needed. Corresponds to the JSON property responseSchema



11903
11904
11905
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11903

def response_schema
  @response_schema
end

#routing_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfigRoutingConfig

The configuration for routing the request to a specific model. Corresponds to the JSON property routingConfig



11908
11909
11910
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11908

def routing_config
  @routing_config
end

#seedFixnum

Optional. Seed. Corresponds to the JSON property seed

Returns:

  • (Fixnum)


11913
11914
11915
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11913

def seed
  @seed
end

#speech_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SpeechConfig

The speech generation config. Corresponds to the JSON property speechConfig



11918
11919
11920
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11918

def speech_config
  @speech_config
end

#stop_sequencesArray<String>

Optional. Stop sequences. Corresponds to the JSON property stopSequences

Returns:

  • (Array<String>)


11923
11924
11925
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11923

def stop_sequences
  @stop_sequences
end

#temperatureFloat

Optional. Controls the randomness of predictions. Corresponds to the JSON property temperature

Returns:

  • (Float)


11928
11929
11930
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11928

def temperature
  @temperature
end

#top_kFloat

Optional. If specified, top-k sampling will be used. Corresponds to the JSON property topK

Returns:

  • (Float)


11933
11934
11935
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11933

def top_k
  @top_k
end

#top_pFloat

Optional. If specified, nucleus sampling will be used. Corresponds to the JSON property topP

Returns:

  • (Float)


11938
11939
11940
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11938

def top_p
  @top_p
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11945
11946
11947
11948
11949
11950
11951
11952
11953
11954
11955
11956
11957
11958
11959
11960
11961
11962
11963
11964
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11945

def update!(**args)
  @audio_timestamp = args[:audio_timestamp] if args.key?(:audio_timestamp)
  @candidate_count = args[:candidate_count] if args.key?(:candidate_count)
  @frequency_penalty = args[:frequency_penalty] if args.key?(:frequency_penalty)
  @logprobs = args[:logprobs] if args.key?(:logprobs)
  @max_output_tokens = args[:max_output_tokens] if args.key?(:max_output_tokens)
  @media_resolution = args[:media_resolution] if args.key?(:media_resolution)
  @presence_penalty = args[:presence_penalty] if args.key?(:presence_penalty)
  @response_logprobs = args[:response_logprobs] if args.key?(:response_logprobs)
  @response_mime_type = args[:response_mime_type] if args.key?(:response_mime_type)
  @response_modalities = args[:response_modalities] if args.key?(:response_modalities)
  @response_schema = args[:response_schema] if args.key?(:response_schema)
  @routing_config = args[:routing_config] if args.key?(:routing_config)
  @seed = args[:seed] if args.key?(:seed)
  @speech_config = args[:speech_config] if args.key?(:speech_config)
  @stop_sequences = args[:stop_sequences] if args.key?(:stop_sequences)
  @temperature = args[:temperature] if args.key?(:temperature)
  @top_k = args[:top_k] if args.key?(:top_k)
  @top_p = args[:top_p] if args.key?(:top_p)
end