Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Generation config.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerationConfig

Returns a new instance of GoogleCloudAiplatformV1GenerationConfig.



10641
10642
10643
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10641

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#candidate_countFixnum

Optional. Number of candidates to generate. Corresponds to the JSON property candidateCount

Returns:

  • (Fixnum)


10567
10568
10569
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10567

def candidate_count
  @candidate_count
end

#frequency_penaltyFloat

Optional. Frequency penalties. Corresponds to the JSON property frequencyPenalty

Returns:

  • (Float)


10572
10573
10574
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10572

def frequency_penalty
  @frequency_penalty
end

#logprobsFixnum

Optional. Logit probabilities. Corresponds to the JSON property logprobs

Returns:

  • (Fixnum)


10577
10578
10579
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10577

def logprobs
  @logprobs
end

#max_output_tokensFixnum

Optional. The maximum number of output tokens to generate per message. Corresponds to the JSON property maxOutputTokens

Returns:

  • (Fixnum)


10582
10583
10584
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10582

def max_output_tokens
  @max_output_tokens
end

#presence_penaltyFloat

Optional. Positive penalties. Corresponds to the JSON property presencePenalty

Returns:

  • (Float)


10587
10588
10589
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10587

def presence_penalty
  @presence_penalty
end

#response_logprobsBoolean Also known as: response_logprobs?

Optional. If true, export the logprobs results in response. Corresponds to the JSON property responseLogprobs

Returns:

  • (Boolean)


10592
10593
10594
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10592

def response_logprobs
  @response_logprobs
end

#response_mime_typeString

Optional. Output response mimetype of the generated candidate text. Supported mimetype: - text/plain: (default) Text output. - application/json: JSON response in the candidates. The model needs to be prompted to output the appropriate response type, otherwise the behavior is undefined. This is a preview feature. Corresponds to the JSON property responseMimeType

Returns:

  • (String)


10602
10603
10604
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10602

def response_mime_type
  @response_mime_type
end

#response_schemaGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema

Schema is used to define the format of input/output data. Represents a select subset of an OpenAPI 3.0 schema object. More fields may be added in the future as needed. Corresponds to the JSON property responseSchema



10609
10610
10611
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10609

def response_schema
  @response_schema
end

#routing_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfigRoutingConfig

The configuration for routing the request to a specific model. Corresponds to the JSON property routingConfig



10614
10615
10616
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10614

def routing_config
  @routing_config
end

#seedFixnum

Optional. Seed. Corresponds to the JSON property seed

Returns:

  • (Fixnum)


10619
10620
10621
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10619

def seed
  @seed
end

#stop_sequencesArray<String>

Optional. Stop sequences. Corresponds to the JSON property stopSequences

Returns:

  • (Array<String>)


10624
10625
10626
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10624

def stop_sequences
  @stop_sequences
end

#temperatureFloat

Optional. Controls the randomness of predictions. Corresponds to the JSON property temperature

Returns:

  • (Float)


10629
10630
10631
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10629

def temperature
  @temperature
end

#top_kFloat

Optional. If specified, top-k sampling will be used. Corresponds to the JSON property topK

Returns:

  • (Float)


10634
10635
10636
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10634

def top_k
  @top_k
end

#top_pFloat

Optional. If specified, nucleus sampling will be used. Corresponds to the JSON property topP

Returns:

  • (Float)


10639
10640
10641
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10639

def top_p
  @top_p
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10646
10647
10648
10649
10650
10651
10652
10653
10654
10655
10656
10657
10658
10659
10660
10661
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10646

def update!(**args)
  @candidate_count = args[:candidate_count] if args.key?(:candidate_count)
  @frequency_penalty = args[:frequency_penalty] if args.key?(:frequency_penalty)
  @logprobs = args[:logprobs] if args.key?(:logprobs)
  @max_output_tokens = args[:max_output_tokens] if args.key?(:max_output_tokens)
  @presence_penalty = args[:presence_penalty] if args.key?(:presence_penalty)
  @response_logprobs = args[:response_logprobs] if args.key?(:response_logprobs)
  @response_mime_type = args[:response_mime_type] if args.key?(:response_mime_type)
  @response_schema = args[:response_schema] if args.key?(:response_schema)
  @routing_config = args[:routing_config] if args.key?(:routing_config)
  @seed = args[:seed] if args.key?(:seed)
  @stop_sequences = args[:stop_sequences] if args.key?(:stop_sequences)
  @temperature = args[:temperature] if args.key?(:temperature)
  @top_k = args[:top_k] if args.key?(:top_k)
  @top_p = args[:top_p] if args.key?(:top_p)
end