Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Generation config.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerationConfig

Returns a new instance of GoogleCloudAiplatformV1GenerationConfig.



10228
10229
10230
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10228

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#candidate_countFixnum

Optional. Number of candidates to generate. Corresponds to the JSON property candidateCount

Returns:

  • (Fixnum)


10175
10176
10177
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10175

def candidate_count
  @candidate_count
end

#frequency_penaltyFloat

Optional. Frequency penalties. Corresponds to the JSON property frequencyPenalty

Returns:

  • (Float)


10180
10181
10182
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10180

def frequency_penalty
  @frequency_penalty
end

#max_output_tokensFixnum

Optional. The maximum number of output tokens to generate per message. Corresponds to the JSON property maxOutputTokens

Returns:

  • (Fixnum)


10185
10186
10187
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10185

def max_output_tokens
  @max_output_tokens
end

#presence_penaltyFloat

Optional. Positive penalties. Corresponds to the JSON property presencePenalty

Returns:

  • (Float)


10190
10191
10192
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10190

def presence_penalty
  @presence_penalty
end

#response_mime_typeString

Optional. Output response mimetype of the generated candidate text. Supported mimetype: - text/plain: (default) Text output. - application/json: JSON response in the candidates. The model needs to be prompted to output the appropriate response type, otherwise the behavior is undefined. This is a preview feature. Corresponds to the JSON property responseMimeType

Returns:

  • (String)


10199
10200
10201
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10199

def response_mime_type
  @response_mime_type
end

#response_schemaGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema

Schema is used to define the format of input/output data. Represents a select subset of an OpenAPI 3.0 schema object. More fields may be added in the future as needed. Corresponds to the JSON property responseSchema



10206
10207
10208
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10206

def response_schema
  @response_schema
end

#stop_sequencesArray<String>

Optional. Stop sequences. Corresponds to the JSON property stopSequences

Returns:

  • (Array<String>)


10211
10212
10213
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10211

def stop_sequences
  @stop_sequences
end

#temperatureFloat

Optional. Controls the randomness of predictions. Corresponds to the JSON property temperature

Returns:

  • (Float)


10216
10217
10218
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10216

def temperature
  @temperature
end

#top_kFloat

Optional. If specified, top-k sampling will be used. Corresponds to the JSON property topK

Returns:

  • (Float)


10221
10222
10223
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10221

def top_k
  @top_k
end

#top_pFloat

Optional. If specified, nucleus sampling will be used. Corresponds to the JSON property topP

Returns:

  • (Float)


10226
10227
10228
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10226

def top_p
  @top_p
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10233
10234
10235
10236
10237
10238
10239
10240
10241
10242
10243
10244
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10233

def update!(**args)
  @candidate_count = args[:candidate_count] if args.key?(:candidate_count)
  @frequency_penalty = args[:frequency_penalty] if args.key?(:frequency_penalty)
  @max_output_tokens = args[:max_output_tokens] if args.key?(:max_output_tokens)
  @presence_penalty = args[:presence_penalty] if args.key?(:presence_penalty)
  @response_mime_type = args[:response_mime_type] if args.key?(:response_mime_type)
  @response_schema = args[:response_schema] if args.key?(:response_schema)
  @stop_sequences = args[:stop_sequences] if args.key?(:stop_sequences)
  @temperature = args[:temperature] if args.key?(:temperature)
  @top_k = args[:top_k] if args.key?(:top_k)
  @top_p = args[:top_p] if args.key?(:top_p)
end