Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Generation config.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerationConfig

Returns a new instance of GoogleCloudAiplatformV1GenerationConfig.



9178
9179
9180
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9178

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#candidate_countFixnum

Optional. Number of candidates to generate. Corresponds to the JSON property candidateCount

Returns:

  • (Fixnum)


9126
9127
9128
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9126

def candidate_count
  @candidate_count
end

#frequency_penaltyFloat

Optional. Frequency penalties. Corresponds to the JSON property frequencyPenalty

Returns:

  • (Float)


9131
9132
9133
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9131

def frequency_penalty
  @frequency_penalty
end

#max_output_tokensFixnum

Optional. The maximum number of output tokens to generate per message. Corresponds to the JSON property maxOutputTokens

Returns:

  • (Fixnum)


9136
9137
9138
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9136

def max_output_tokens
  @max_output_tokens
end

#presence_penaltyFloat

Optional. Positive penalties. Corresponds to the JSON property presencePenalty

Returns:

  • (Float)


9141
9142
9143
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9141

def presence_penalty
  @presence_penalty
end

#response_mime_typeString

Optional. Output response mimetype of the generated candidate text. Supported mimetype: - text/plain: (default) Text output. - application/json: JSON response in the candidates. The model needs to be prompted to output the appropriate response type, otherwise the behavior is undefined. This is a preview feature. Corresponds to the JSON property responseMimeType

Returns:

  • (String)


9150
9151
9152
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9150

def response_mime_type
  @response_mime_type
end

#response_styleString

Optional. Control Three levels of creativity in the model output. Default: RESPONSE_STYLE_BALANCED Corresponds to the JSON property responseStyle

Returns:

  • (String)


9156
9157
9158
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9156

def response_style
  @response_style
end

#stop_sequencesArray<String>

Optional. Stop sequences. Corresponds to the JSON property stopSequences

Returns:

  • (Array<String>)


9161
9162
9163
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9161

def stop_sequences
  @stop_sequences
end

#temperatureFloat

Optional. Controls the randomness of predictions. Corresponds to the JSON property temperature

Returns:

  • (Float)


9166
9167
9168
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9166

def temperature
  @temperature
end

#top_kFloat

Optional. If specified, top-k sampling will be used. Corresponds to the JSON property topK

Returns:

  • (Float)


9171
9172
9173
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9171

def top_k
  @top_k
end

#top_pFloat

Optional. If specified, nucleus sampling will be used. Corresponds to the JSON property topP

Returns:

  • (Float)


9176
9177
9178
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9176

def top_p
  @top_p
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9183
9184
9185
9186
9187
9188
9189
9190
9191
9192
9193
9194
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9183

def update!(**args)
  @candidate_count = args[:candidate_count] if args.key?(:candidate_count)
  @frequency_penalty = args[:frequency_penalty] if args.key?(:frequency_penalty)
  @max_output_tokens = args[:max_output_tokens] if args.key?(:max_output_tokens)
  @presence_penalty = args[:presence_penalty] if args.key?(:presence_penalty)
  @response_mime_type = args[:response_mime_type] if args.key?(:response_mime_type)
  @response_style = args[:response_style] if args.key?(:response_style)
  @stop_sequences = args[:stop_sequences] if args.key?(:stop_sequences)
  @temperature = args[:temperature] if args.key?(:temperature)
  @top_k = args[:top_k] if args.key?(:top_k)
  @top_p = args[:top_p] if args.key?(:top_p)
end