Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Generation config.
Instance Attribute Summary collapse
-
#candidate_count ⇒ Fixnum
Optional.
-
#frequency_penalty ⇒ Float
Optional.
-
#max_output_tokens ⇒ Fixnum
Optional.
-
#presence_penalty ⇒ Float
Optional.
-
#response_mime_type ⇒ String
Optional.
-
#stop_sequences ⇒ Array<String>
Optional.
-
#temperature ⇒ Float
Optional.
-
#top_k ⇒ Float
Optional.
-
#top_p ⇒ Float
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerationConfig
constructor
A new instance of GoogleCloudAiplatformV1GenerationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerationConfig
Returns a new instance of GoogleCloudAiplatformV1GenerationConfig.
10081 10082 10083 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10081 def initialize(**args) update!(**args) end |
Instance Attribute Details
#candidate_count ⇒ Fixnum
Optional. Number of candidates to generate.
Corresponds to the JSON property candidateCount
10035 10036 10037 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10035 def candidate_count @candidate_count end |
#frequency_penalty ⇒ Float
Optional. Frequency penalties.
Corresponds to the JSON property frequencyPenalty
10040 10041 10042 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10040 def frequency_penalty @frequency_penalty end |
#max_output_tokens ⇒ Fixnum
Optional. The maximum number of output tokens to generate per message.
Corresponds to the JSON property maxOutputTokens
10045 10046 10047 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10045 def max_output_tokens @max_output_tokens end |
#presence_penalty ⇒ Float
Optional. Positive penalties.
Corresponds to the JSON property presencePenalty
10050 10051 10052 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10050 def presence_penalty @presence_penalty end |
#response_mime_type ⇒ String
Optional. Output response mimetype of the generated candidate text. Supported
mimetype: - text/plain: (default) Text output. - application/json: JSON
response in the candidates. The model needs to be prompted to output the
appropriate response type, otherwise the behavior is undefined. This is a
preview feature.
Corresponds to the JSON property responseMimeType
10059 10060 10061 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10059 def response_mime_type @response_mime_type end |
#stop_sequences ⇒ Array<String>
Optional. Stop sequences.
Corresponds to the JSON property stopSequences
10064 10065 10066 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10064 def stop_sequences @stop_sequences end |
#temperature ⇒ Float
Optional. Controls the randomness of predictions.
Corresponds to the JSON property temperature
10069 10070 10071 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10069 def temperature @temperature end |
#top_k ⇒ Float
Optional. If specified, top-k sampling will be used.
Corresponds to the JSON property topK
10074 10075 10076 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10074 def top_k @top_k end |
#top_p ⇒ Float
Optional. If specified, nucleus sampling will be used.
Corresponds to the JSON property topP
10079 10080 10081 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10079 def top_p @top_p end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10086 10087 10088 10089 10090 10091 10092 10093 10094 10095 10096 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10086 def update!(**args) @candidate_count = args[:candidate_count] if args.key?(:candidate_count) @frequency_penalty = args[:frequency_penalty] if args.key?(:frequency_penalty) @max_output_tokens = args[:max_output_tokens] if args.key?(:max_output_tokens) @presence_penalty = args[:presence_penalty] if args.key?(:presence_penalty) @response_mime_type = args[:response_mime_type] if args.key?(:response_mime_type) @stop_sequences = args[:stop_sequences] if args.key?(:stop_sequences) @temperature = args[:temperature] if args.key?(:temperature) @top_k = args[:top_k] if args.key?(:top_k) @top_p = args[:top_p] if args.key?(:top_p) end |