Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfigRoutingConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfigRoutingConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The configuration for routing the request to a specific model. This can be used to control which model is used for the generation, either automatically or by specifying a model name.
Instance Attribute Summary collapse
-
#auto_mode ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfigRoutingConfigAutoRoutingMode
The configuration for automated routing.
-
#manual_mode ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfigRoutingConfigManualRoutingMode
The configuration for manual routing.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerationConfigRoutingConfig
constructor
A new instance of GoogleCloudAiplatformV1GenerationConfigRoutingConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerationConfigRoutingConfig
Returns a new instance of GoogleCloudAiplatformV1GenerationConfigRoutingConfig.
18252 18253 18254 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18252 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_mode ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfigRoutingConfigAutoRoutingMode
The configuration for automated routing. When automated routing is specified,
the routing will be determined by the pretrained routing model and customer
provided model routing preference.
Corresponds to the JSON property autoMode
18244 18245 18246 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18244 def auto_mode @auto_mode end |
#manual_mode ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfigRoutingConfigManualRoutingMode
The configuration for manual routing. When manual routing is specified, the
model will be selected based on the model name provided.
Corresponds to the JSON property manualMode
18250 18251 18252 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18250 def manual_mode @manual_mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18257 18258 18259 18260 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18257 def update!(**args) @auto_mode = args[:auto_mode] if args.key?(:auto_mode) @manual_mode = args[:manual_mode] if args.key?(:manual_mode) end |