Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfigRoutingConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The configuration for routing the request to a specific model. This can be used to control which model is used for the generation, either automatically or by specifying a model name.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerationConfigRoutingConfig

Returns a new instance of GoogleCloudAiplatformV1GenerationConfigRoutingConfig.



15938
15939
15940
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15938

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_modeGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfigRoutingConfigAutoRoutingMode

The configuration for automated routing. When automated routing is specified, the routing will be determined by the pretrained routing model and customer provided model routing preference. Corresponds to the JSON property autoMode



15930
15931
15932
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15930

def auto_mode
  @auto_mode
end

#manual_modeGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfigRoutingConfigManualRoutingMode

The configuration for manual routing. When manual routing is specified, the model will be selected based on the model name provided. Corresponds to the JSON property manualMode



15936
15937
15938
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15936

def manual_mode
  @manual_mode
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15943
15944
15945
15946
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15943

def update!(**args)
  @auto_mode = args[:auto_mode] if args.key?(:auto_mode)
  @manual_mode = args[:manual_mode] if args.key?(:manual_mode)
end