Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfigRoutingConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The configuration for routing the request to a specific model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerationConfigRoutingConfig

Returns a new instance of GoogleCloudAiplatformV1GenerationConfigRoutingConfig.



13043
13044
13045
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13043

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_modeGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfigRoutingConfigAutoRoutingMode

When automated routing is specified, the routing will be determined by the pretrained routing model and customer provided model routing preference. Corresponds to the JSON property autoMode



13036
13037
13038
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13036

def auto_mode
  @auto_mode
end

#manual_modeGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfigRoutingConfigManualRoutingMode

When manual routing is set, the specified model will be used directly. Corresponds to the JSON property manualMode



13041
13042
13043
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13041

def manual_mode
  @manual_mode
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13048
13049
13050
13051
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13048

def update!(**args)
  @auto_mode = args[:auto_mode] if args.key?(:auto_mode)
  @manual_mode = args[:manual_mode] if args.key?(:manual_mode)
end