Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfigRoutingConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The configuration for routing the request to a specific model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerationConfigRoutingConfig

Returns a new instance of GoogleCloudAiplatformV1GenerationConfigRoutingConfig.



12257
12258
12259
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12257

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_modeGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfigRoutingConfigAutoRoutingMode

When automated routing is specified, the routing will be determined by the pretrained routing model and customer provided model routing preference. Corresponds to the JSON property autoMode



12250
12251
12252
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12250

def auto_mode
  @auto_mode
end

#manual_modeGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfigRoutingConfigManualRoutingMode

When manual routing is set, the specified model will be used directly. Corresponds to the JSON property manualMode



12255
12256
12257
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12255

def manual_mode
  @manual_mode
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12262
12263
12264
12265
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12262

def update!(**args)
  @auto_mode = args[:auto_mode] if args.key?(:auto_mode)
  @manual_mode = args[:manual_mode] if args.key?(:manual_mode)
end