Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfigRoutingConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfigRoutingConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The configuration for routing the request to a specific model.
Instance Attribute Summary collapse
-
#auto_mode ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfigRoutingConfigAutoRoutingMode
When automated routing is specified, the routing will be determined by the pretrained routing model and customer provided model routing preference.
-
#manual_mode ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfigRoutingConfigManualRoutingMode
When manual routing is set, the specified model will be used directly.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerationConfigRoutingConfig
constructor
A new instance of GoogleCloudAiplatformV1GenerationConfigRoutingConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerationConfigRoutingConfig
Returns a new instance of GoogleCloudAiplatformV1GenerationConfigRoutingConfig.
12121 12122 12123 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12121 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_mode ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfigRoutingConfigAutoRoutingMode
When automated routing is specified, the routing will be determined by the
pretrained routing model and customer provided model routing preference.
Corresponds to the JSON property autoMode
12114 12115 12116 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12114 def auto_mode @auto_mode end |
#manual_mode ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfigRoutingConfigManualRoutingMode
When manual routing is set, the specified model will be used directly.
Corresponds to the JSON property manualMode
12119 12120 12121 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12119 def manual_mode @manual_mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12126 12127 12128 12129 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12126 def update!(**args) @auto_mode = args[:auto_mode] if args.key?(:auto_mode) @manual_mode = args[:manual_mode] if args.key?(:manual_mode) end |