Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfigRoutingConfigAutoRoutingMode

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The configuration for automated routing. When automated routing is specified, the routing will be determined by the pretrained routing model and customer provided model routing preference.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerationConfigRoutingConfigAutoRoutingMode

Returns a new instance of GoogleCloudAiplatformV1GenerationConfigRoutingConfigAutoRoutingMode.



15960
15961
15962
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15960

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#model_routing_preferenceString

The model routing preference. Corresponds to the JSON property modelRoutingPreference

Returns:

  • (String)


15958
15959
15960
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15958

def model_routing_preference
  @model_routing_preference
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15965
15966
15967
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15965

def update!(**args)
  @model_routing_preference = args[:model_routing_preference] if args.key?(:model_routing_preference)
end