Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfigThinkingConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfigThinkingConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Configuration for the model's thinking features. "Thinking" is a process where the model breaks down a complex task into smaller, manageable steps. This allows the model to reason about the task, plan its approach, and execute the plan to generate a high-quality response.
Instance Attribute Summary collapse
-
#include_thoughts ⇒ Boolean
(also: #include_thoughts?)
Optional.
-
#thinking_budget ⇒ Fixnum
Optional.
-
#thinking_level ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerationConfigThinkingConfig
constructor
A new instance of GoogleCloudAiplatformV1GenerationConfigThinkingConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GenerationConfigThinkingConfig
Returns a new instance of GoogleCloudAiplatformV1GenerationConfigThinkingConfig.
17069 17070 17071 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17069 def initialize(**args) update!(**args) end |
Instance Attribute Details
#include_thoughts ⇒ Boolean Also known as: include_thoughts?
Optional. If true, the model will include its thoughts in the response. "
Thoughts" are the intermediate steps the model takes to arrive at the final
response. They can provide insights into the model's reasoning process and
help with debugging. If this is true, thoughts are returned only when
available.
Corresponds to the JSON property includeThoughts
17054 17055 17056 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17054 def include_thoughts @include_thoughts end |
#thinking_budget ⇒ Fixnum
Optional. The token budget for the model's thinking process. The model will
make a best effort to stay within this budget. This can be used to control the
trade-off between response quality and latency.
Corresponds to the JSON property thinkingBudget
17062 17063 17064 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17062 def thinking_budget @thinking_budget end |
#thinking_level ⇒ String
Optional. The number of thoughts tokens that the model should generate.
Corresponds to the JSON property thinkingLevel
17067 17068 17069 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17067 def thinking_level @thinking_level end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17074 17075 17076 17077 17078 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17074 def update!(**args) @include_thoughts = args[:include_thoughts] if args.key?(:include_thoughts) @thinking_budget = args[:thinking_budget] if args.key?(:thinking_budget) @thinking_level = args[:thinking_level] if args.key?(:thinking_level) end |