Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenericOperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Generic Metadata shared by all operations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GenericOperationMetadata

Returns a new instance of GoogleCloudAiplatformV1GenericOperationMetadata.



18367
18368
18369
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18367

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Time when the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


18352
18353
18354
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18352

def create_time
  @create_time
end

#partial_failuresArray<Google::Apis::AiplatformV1::GoogleRpcStatus>

Output only. Partial failures encountered. E.g. single files that couldn't be read. This field should never exceed 20 entries. Status details field will contain standard Google Cloud error details. Corresponds to the JSON property partialFailures



18359
18360
18361
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18359

def partial_failures
  @partial_failures
end

#update_timeString

Output only. Time when the operation was updated for the last time. If the operation has finished (successfully or not), this is the finish time. Corresponds to the JSON property updateTime

Returns:

  • (String)


18365
18366
18367
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18365

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18372
18373
18374
18375
18376
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18372

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @partial_failures = args[:partial_failures] if args.key?(:partial_failures)
  @update_time = args[:update_time] if args.key?(:update_time)
end