Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenericOperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Generic Metadata shared by all operations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GenericOperationMetadata

Returns a new instance of GoogleCloudAiplatformV1GenericOperationMetadata.



16254
16255
16256
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16254

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Time when the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


16239
16240
16241
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16239

def create_time
  @create_time
end

#partial_failuresArray<Google::Apis::AiplatformV1::GoogleRpcStatus>

Output only. Partial failures encountered. E.g. single files that couldn't be read. This field should never exceed 20 entries. Status details field will contain standard Google Cloud error details. Corresponds to the JSON property partialFailures



16246
16247
16248
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16246

def partial_failures
  @partial_failures
end

#update_timeString

Output only. Time when the operation was updated for the last time. If the operation has finished (successfully or not), this is the finish time. Corresponds to the JSON property updateTime

Returns:

  • (String)


16252
16253
16254
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16252

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16259
16260
16261
16262
16263
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16259

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @partial_failures = args[:partial_failures] if args.key?(:partial_failures)
  @update_time = args[:update_time] if args.key?(:update_time)
end