Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenericOperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Generic Metadata shared by all operations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GenericOperationMetadata

Returns a new instance of GoogleCloudAiplatformV1GenericOperationMetadata.



12055
12056
12057
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12055

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Time when the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


12040
12041
12042
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12040

def create_time
  @create_time
end

#partial_failuresArray<Google::Apis::AiplatformV1::GoogleRpcStatus>

Output only. Partial failures encountered. E.g. single files that couldn't be read. This field should never exceed 20 entries. Status details field will contain standard Google Cloud error details. Corresponds to the JSON property partialFailures



12047
12048
12049
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12047

def partial_failures
  @partial_failures
end

#update_timeString

Output only. Time when the operation was updated for the last time. If the operation has finished (successfully or not), this is the finish time. Corresponds to the JSON property updateTime

Returns:

  • (String)


12053
12054
12055
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12053

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12060
12061
12062
12063
12064
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12060

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @partial_failures = args[:partial_failures] if args.key?(:partial_failures)
  @update_time = args[:update_time] if args.key?(:update_time)
end