Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenericOperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Generic Metadata shared by all operations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GenericOperationMetadata

Returns a new instance of GoogleCloudAiplatformV1GenericOperationMetadata.



10121
10122
10123
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10121

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Time when the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


10106
10107
10108
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10106

def create_time
  @create_time
end

#partial_failuresArray<Google::Apis::AiplatformV1::GoogleRpcStatus>

Output only. Partial failures encountered. E.g. single files that couldn't be read. This field should never exceed 20 entries. Status details field will contain standard Google Cloud error details. Corresponds to the JSON property partialFailures



10113
10114
10115
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10113

def partial_failures
  @partial_failures
end

#update_timeString

Output only. Time when the operation was updated for the last time. If the operation has finished (successfully or not), this is the finish time. Corresponds to the JSON property updateTime

Returns:

  • (String)


10119
10120
10121
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10119

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10126
10127
10128
10129
10130
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10126

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @partial_failures = args[:partial_failures] if args.key?(:partial_failures)
  @update_time = args[:update_time] if args.key?(:update_time)
end