Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GoogleMaps

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Tool to retrieve public maps data for grounding, powered by Google.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GoogleMaps

Returns a new instance of GoogleCloudAiplatformV1GoogleMaps.



17810
17811
17812
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17810

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_widgetBoolean Also known as: enable_widget?

Optional. Deprecated: The Google Maps contextual widget behavior in Grounding with Google Maps is being deprecated; this field is planned for removal and no longer has any effect once removed. If true, include the widget context token in the response. Corresponds to the JSON property enableWidget

Returns:

  • (Boolean)


17807
17808
17809
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17807

def enable_widget
  @enable_widget
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17815
17816
17817
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17815

def update!(**args)
  @enable_widget = args[:enable_widget] if args.key?(:enable_widget)
end