Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GoogleMaps

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Tool to retrieve public maps data for grounding, powered by Google.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GoogleMaps

Returns a new instance of GoogleCloudAiplatformV1GoogleMaps.



16340
16341
16342
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16340

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_widgetBoolean Also known as: enable_widget?

Optional. If true, include the widget context token in the response. Corresponds to the JSON property enableWidget

Returns:

  • (Boolean)


16337
16338
16339
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16337

def enable_widget
  @enable_widget
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16345
16346
16347
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16345

def update!(**args)
  @enable_widget = args[:enable_widget] if args.key?(:enable_widget)
end