Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GoogleMaps
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GoogleMaps
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Tool to retrieve public maps data for grounding, powered by Google.
Instance Attribute Summary collapse
-
#enable_widget ⇒ Boolean
(also: #enable_widget?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GoogleMaps
constructor
A new instance of GoogleCloudAiplatformV1GoogleMaps.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GoogleMaps
Returns a new instance of GoogleCloudAiplatformV1GoogleMaps.
16139 16140 16141 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16139 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable_widget ⇒ Boolean Also known as: enable_widget?
Optional. If true, include the widget context token in the response.
Corresponds to the JSON property enableWidget
16136 16137 16138 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16136 def @enable_widget end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16144 16145 16146 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16144 def update!(**args) @enable_widget = args[:enable_widget] if args.key?(:enable_widget) end |