Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunk
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunk
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A piece of evidence that supports a claim made by the model. This is used to
show a citation for a claim made by the model. When grounding is enabled, the
model returns a GroundingChunk that contains a reference to the source of
the information.
Instance Attribute Summary collapse
-
#image ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkImage
An
Imagechunk is a piece of evidence that comes from an image search result. -
#maps ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMaps
A
Mapschunk is a piece of evidence that comes from Google Maps, containing information about places or routes. -
#retrieved_context ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkRetrievedContext
Context retrieved from a data source to ground the model's response.
-
#web ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkWeb
A
Webchunk is a piece of evidence that comes from a web page.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunk
constructor
A new instance of GoogleCloudAiplatformV1GroundingChunk.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunk
Returns a new instance of GoogleCloudAiplatformV1GroundingChunk.
18321 18322 18323 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18321 def initialize(**args) update!(**args) end |
Instance Attribute Details
#image ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkImage
An Image chunk is a piece of evidence that comes from an image search result.
It contains the URI of the image search result and the URI of the image. This
is used to provide the user with a link to the source of the information.
Corresponds to the JSON property image
18298 18299 18300 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18298 def image @image end |
#maps ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMaps
A Maps chunk is a piece of evidence that comes from Google Maps, containing
information about places or routes. This is used to provide the user with rich,
location-based information.
Corresponds to the JSON property maps
18305 18306 18307 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18305 def maps @maps end |
#retrieved_context ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkRetrievedContext
Context retrieved from a data source to ground the model's response. This is
used when a retrieval tool fetches information from a user-provided corpus or
a public dataset.
Corresponds to the JSON property retrievedContext
18312 18313 18314 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18312 def retrieved_context @retrieved_context end |
#web ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkWeb
A Web chunk is a piece of evidence that comes from a web page. It contains
the URI of the web page, the title of the page, and the domain of the page.
This is used to provide the user with a link to the source of the information.
Corresponds to the JSON property web
18319 18320 18321 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18319 def web @web end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18326 18327 18328 18329 18330 18331 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18326 def update!(**args) @image = args[:image] if args.key?(:image) @maps = args[:maps] if args.key?(:maps) @retrieved_context = args[:retrieved_context] if args.key?(:retrieved_context) @web = args[:web] if args.key?(:web) end |