Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunk
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunk
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A piece of evidence that supports a claim made by the model. This is used to
show a citation for a claim made by the model. When grounding is enabled, the
model returns a GroundingChunk that contains a reference to the source of
the information.
Instance Attribute Summary collapse
-
#maps ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMaps
A
Mapschunk is a piece of evidence that comes from Google Maps. -
#retrieved_context ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkRetrievedContext
Context retrieved from a data source to ground the model's response.
-
#web ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkWeb
A
Webchunk is a piece of evidence that comes from a web page.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunk
constructor
A new instance of GoogleCloudAiplatformV1GroundingChunk.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunk
Returns a new instance of GoogleCloudAiplatformV1GroundingChunk.
16297 16298 16299 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16297 def initialize(**args) update!(**args) end |
Instance Attribute Details
#maps ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMaps
A Maps chunk is a piece of evidence that comes from Google Maps. It contains
information about a place, such as its name, address, and reviews. This is
used to provide the user with rich, location-based information.
Corresponds to the JSON property maps
16281 16282 16283 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16281 def maps @maps end |
#retrieved_context ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkRetrievedContext
Context retrieved from a data source to ground the model's response. This is
used when a retrieval tool fetches information from a user-provided corpus or
a public dataset.
Corresponds to the JSON property retrievedContext
16288 16289 16290 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16288 def retrieved_context @retrieved_context end |
#web ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkWeb
A Web chunk is a piece of evidence that comes from a web page. It contains
the URI of the web page, the title of the page, and the domain of the page.
This is used to provide the user with a link to the source of the information.
Corresponds to the JSON property web
16295 16296 16297 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16295 def web @web end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16302 16303 16304 16305 16306 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16302 def update!(**args) @maps = args[:maps] if args.key?(:maps) @retrieved_context = args[:retrieved_context] if args.key?(:retrieved_context) @web = args[:web] if args.key?(:web) end |