Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkImage
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkImage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
An Image chunk is a piece of evidence that comes from an image search result.
It contains the URI of the image search result and the URI of the image. This
is used to provide the user with a link to the source of the information.
Instance Attribute Summary collapse
-
#domain ⇒ String
The domain of the image search result page.
-
#image_uri ⇒ String
The URI of the image.
-
#source_uri ⇒ String
The URI of the image search result page.
-
#title ⇒ String
The title of the image search result page.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkImage
constructor
A new instance of GoogleCloudAiplatformV1GroundingChunkImage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkImage
Returns a new instance of GoogleCloudAiplatformV1GroundingChunkImage.
19147 19148 19149 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19147 def initialize(**args) update!(**args) end |
Instance Attribute Details
#domain ⇒ String
The domain of the image search result page.
Corresponds to the JSON property domain
19130 19131 19132 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19130 def domain @domain end |
#image_uri ⇒ String
The URI of the image.
Corresponds to the JSON property imageUri
19135 19136 19137 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19135 def image_uri @image_uri end |
#source_uri ⇒ String
The URI of the image search result page.
Corresponds to the JSON property sourceUri
19140 19141 19142 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19140 def source_uri @source_uri end |
#title ⇒ String
The title of the image search result page.
Corresponds to the JSON property title
19145 19146 19147 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19145 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19152 19153 19154 19155 19156 19157 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19152 def update!(**args) @domain = args[:domain] if args.key?(:domain) @image_uri = args[:image_uri] if args.key?(:image_uri) @source_uri = args[:source_uri] if args.key?(:source_uri) @title = args[:title] if args.key?(:title) end |