Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkImage
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkImage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
An Image chunk is a piece of evidence that comes from an image search result.
It contains the URI of the image search result and the URI of the image. This
is used to provide the user with a link to the source of the information.
Instance Attribute Summary collapse
-
#domain ⇒ String
The domain of the image search result page.
-
#image_uri ⇒ String
The URI of the image.
-
#source_uri ⇒ String
The URI of the image search result page.
-
#title ⇒ String
The title of the image search result page.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkImage
constructor
A new instance of GoogleCloudAiplatformV1GroundingChunkImage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkImage
Returns a new instance of GoogleCloudAiplatformV1GroundingChunkImage.
18721 18722 18723 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18721 def initialize(**args) update!(**args) end |
Instance Attribute Details
#domain ⇒ String
The domain of the image search result page.
Corresponds to the JSON property domain
18704 18705 18706 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18704 def domain @domain end |
#image_uri ⇒ String
The URI of the image.
Corresponds to the JSON property imageUri
18709 18710 18711 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18709 def image_uri @image_uri end |
#source_uri ⇒ String
The URI of the image search result page.
Corresponds to the JSON property sourceUri
18714 18715 18716 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18714 def source_uri @source_uri end |
#title ⇒ String
The title of the image search result page.
Corresponds to the JSON property title
18719 18720 18721 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18719 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18726 18727 18728 18729 18730 18731 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18726 def update!(**args) @domain = args[:domain] if args.key?(:domain) @image_uri = args[:image_uri] if args.key?(:image_uri) @source_uri = args[:source_uri] if args.key?(:source_uri) @title = args[:title] if args.key?(:title) end |