Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkImage
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkImage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
An Image chunk is a piece of evidence that comes from an image search result.
It contains the URI of the image search result and the URI of the image. This
is used to provide the user with a link to the source of the information.
Instance Attribute Summary collapse
-
#domain ⇒ String
The domain of the image search result page.
-
#image_uri ⇒ String
The URI of the image.
-
#source_uri ⇒ String
The URI of the image search result page.
-
#title ⇒ String
The title of the image search result page.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkImage
constructor
A new instance of GoogleCloudAiplatformV1GroundingChunkImage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkImage
Returns a new instance of GoogleCloudAiplatformV1GroundingChunkImage.
18360 18361 18362 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18360 def initialize(**args) update!(**args) end |
Instance Attribute Details
#domain ⇒ String
The domain of the image search result page.
Corresponds to the JSON property domain
18343 18344 18345 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18343 def domain @domain end |
#image_uri ⇒ String
The URI of the image.
Corresponds to the JSON property imageUri
18348 18349 18350 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18348 def image_uri @image_uri end |
#source_uri ⇒ String
The URI of the image search result page.
Corresponds to the JSON property sourceUri
18353 18354 18355 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18353 def source_uri @source_uri end |
#title ⇒ String
The title of the image search result page.
Corresponds to the JSON property title
18358 18359 18360 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18358 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18365 18366 18367 18368 18369 18370 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18365 def update!(**args) @domain = args[:domain] if args.key?(:domain) @image_uri = args[:image_uri] if args.key?(:image_uri) @source_uri = args[:source_uri] if args.key?(:source_uri) @title = args[:title] if args.key?(:title) end |