Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkImage
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkImage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
An Image chunk is a piece of evidence that comes from an image search result.
It contains the URI of the image search result and the URI of the image. This
is used to provide the user with a link to the source of the information.
Instance Attribute Summary collapse
-
#domain ⇒ String
The domain of the image search result page.
-
#image_uri ⇒ String
The URI of the image.
-
#source_uri ⇒ String
The URI of the image search result page.
-
#title ⇒ String
The title of the image search result page.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkImage
constructor
A new instance of GoogleCloudAiplatformV1GroundingChunkImage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkImage
Returns a new instance of GoogleCloudAiplatformV1GroundingChunkImage.
17393 17394 17395 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17393 def initialize(**args) update!(**args) end |
Instance Attribute Details
#domain ⇒ String
The domain of the image search result page.
Corresponds to the JSON property domain
17376 17377 17378 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17376 def domain @domain end |
#image_uri ⇒ String
The URI of the image.
Corresponds to the JSON property imageUri
17381 17382 17383 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17381 def image_uri @image_uri end |
#source_uri ⇒ String
The URI of the image search result page.
Corresponds to the JSON property sourceUri
17386 17387 17388 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17386 def source_uri @source_uri end |
#title ⇒ String
The title of the image search result page.
Corresponds to the JSON property title
17391 17392 17393 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17391 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17398 17399 17400 17401 17402 17403 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17398 def update!(**args) @domain = args[:domain] if args.key?(:domain) @image_uri = args[:image_uri] if args.key?(:image_uri) @source_uri = args[:source_uri] if args.key?(:source_uri) @title = args[:title] if args.key?(:title) end |