Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMaps

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A Maps chunk is a piece of evidence that comes from Google Maps, containing information about places or routes. This is used to provide the user with rich, location-based information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkMaps

Returns a new instance of GoogleCloudAiplatformV1GroundingChunkMaps.



19179
19180
19181
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19179

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#place_answer_sourcesGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSources

The sources that were used to generate the place answer. This includes review snippets and photos that were used to generate the answer, as well as URIs to flag content. Corresponds to the JSON property placeAnswerSources



19151
19152
19153
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19151

def place_answer_sources
  @place_answer_sources
end

#place_idString

This Place's resource name, in places/place_id`format. This can be used to look up the place in the Google Maps API. Corresponds to the JSON propertyplaceId`

Returns:

  • (String)


19157
19158
19159
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19157

def place_id
  @place_id
end

#routeGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMapsRoute

Route information from Google Maps. Corresponds to the JSON property route



19162
19163
19164
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19162

def route
  @route
end

#textString

The text of the place answer. Corresponds to the JSON property text

Returns:

  • (String)


19167
19168
19169
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19167

def text
  @text
end

#titleString

The title of the place. Corresponds to the JSON property title

Returns:

  • (String)


19172
19173
19174
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19172

def title
  @title
end

#uriString

The URI of the place. Corresponds to the JSON property uri

Returns:

  • (String)


19177
19178
19179
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19177

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19184
19185
19186
19187
19188
19189
19190
19191
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19184

def update!(**args)
  @place_answer_sources = args[:place_answer_sources] if args.key?(:place_answer_sources)
  @place_id = args[:place_id] if args.key?(:place_id)
  @route = args[:route] if args.key?(:route)
  @text = args[:text] if args.key?(:text)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end