Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMaps
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMaps
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A Maps chunk is a piece of evidence that comes from Google Maps, containing
information about places or routes. This is used to provide the user with rich,
location-based information.
Instance Attribute Summary collapse
-
#place_answer_sources ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSources
The sources that were used to generate the place answer.
-
#place_id ⇒ String
This Place's resource name, in
places/place_id`` format. -
#route ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMapsRoute
Route information from Google Maps.
-
#text ⇒ String
The text of the place answer.
-
#title ⇒ String
The title of the place.
-
#uri ⇒ String
The URI of the place.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkMaps
constructor
A new instance of GoogleCloudAiplatformV1GroundingChunkMaps.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkMaps
Returns a new instance of GoogleCloudAiplatformV1GroundingChunkMaps.
18412 18413 18414 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18412 def initialize(**args) update!(**args) end |
Instance Attribute Details
#place_answer_sources ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSources
The sources that were used to generate the place answer. This includes review
snippets and photos that were used to generate the answer, as well as URIs to
flag content.
Corresponds to the JSON property placeAnswerSources
18384 18385 18386 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18384 def place_answer_sources @place_answer_sources end |
#place_id ⇒ String
This Place's resource name, in places/place_id`format. This can be used to
look up the place in the Google Maps API.
Corresponds to the JSON propertyplaceId`
18390 18391 18392 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18390 def place_id @place_id end |
#route ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMapsRoute
Route information from Google Maps.
Corresponds to the JSON property route
18395 18396 18397 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18395 def route @route end |
#text ⇒ String
The text of the place answer.
Corresponds to the JSON property text
18400 18401 18402 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18400 def text @text end |
#title ⇒ String
The title of the place.
Corresponds to the JSON property title
18405 18406 18407 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18405 def title @title end |
#uri ⇒ String
The URI of the place.
Corresponds to the JSON property uri
18410 18411 18412 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18410 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18417 18418 18419 18420 18421 18422 18423 18424 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18417 def update!(**args) @place_answer_sources = args[:place_answer_sources] if args.key?(:place_answer_sources) @place_id = args[:place_id] if args.key?(:place_id) @route = args[:route] if args.key?(:route) @text = args[:text] if args.key?(:text) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) end |