Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMaps
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMaps
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A Maps chunk is a piece of evidence that comes from Google Maps, containing
information about places or routes. This is used to provide the user with rich,
location-based information.
Instance Attribute Summary collapse
-
#place_answer_sources ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSources
The sources that were used to generate the place answer.
-
#place_id ⇒ String
This Place's resource name, in
places/place_id`` format. -
#route ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMapsRoute
Route information from Google Maps.
-
#text ⇒ String
The text of the place answer.
-
#title ⇒ String
The title of the place.
-
#uri ⇒ String
The URI of the place.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkMaps
constructor
A new instance of GoogleCloudAiplatformV1GroundingChunkMaps.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkMaps
Returns a new instance of GoogleCloudAiplatformV1GroundingChunkMaps.
18066 18067 18068 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18066 def initialize(**args) update!(**args) end |
Instance Attribute Details
#place_answer_sources ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSources
The sources that were used to generate the place answer. This includes review
snippets and photos that were used to generate the answer, as well as URIs to
flag content.
Corresponds to the JSON property placeAnswerSources
18038 18039 18040 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18038 def place_answer_sources @place_answer_sources end |
#place_id ⇒ String
This Place's resource name, in places/place_id`format. This can be used to
look up the place in the Google Maps API.
Corresponds to the JSON propertyplaceId`
18044 18045 18046 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18044 def place_id @place_id end |
#route ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMapsRoute
Route information from Google Maps.
Corresponds to the JSON property route
18049 18050 18051 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18049 def route @route end |
#text ⇒ String
The text of the place answer.
Corresponds to the JSON property text
18054 18055 18056 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18054 def text @text end |
#title ⇒ String
The title of the place.
Corresponds to the JSON property title
18059 18060 18061 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18059 def title @title end |
#uri ⇒ String
The URI of the place.
Corresponds to the JSON property uri
18064 18065 18066 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18064 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18071 18072 18073 18074 18075 18076 18077 18078 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18071 def update!(**args) @place_answer_sources = args[:place_answer_sources] if args.key?(:place_answer_sources) @place_id = args[:place_id] if args.key?(:place_id) @route = args[:route] if args.key?(:route) @text = args[:text] if args.key?(:text) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) end |