Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMaps
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMaps
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A Maps chunk is a piece of evidence that comes from Google Maps, containing
information about places or routes. This is used to provide the user with rich,
location-based information.
Instance Attribute Summary collapse
-
#place_answer_sources ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSources
The sources that were used to generate the place answer.
-
#place_id ⇒ String
This Place's resource name, in
places/place_id`` format. -
#route ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMapsRoute
Route information from Google Maps.
-
#text ⇒ String
The text of the place answer.
-
#title ⇒ String
The title of the place.
-
#uri ⇒ String
The URI of the place.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkMaps
constructor
A new instance of GoogleCloudAiplatformV1GroundingChunkMaps.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkMaps
Returns a new instance of GoogleCloudAiplatformV1GroundingChunkMaps.
17557 17558 17559 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17557 def initialize(**args) update!(**args) end |
Instance Attribute Details
#place_answer_sources ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSources
The sources that were used to generate the place answer. This includes review
snippets and photos that were used to generate the answer, as well as URIs to
flag content.
Corresponds to the JSON property placeAnswerSources
17529 17530 17531 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17529 def place_answer_sources @place_answer_sources end |
#place_id ⇒ String
This Place's resource name, in places/place_id`format. This can be used to
look up the place in the Google Maps API.
Corresponds to the JSON propertyplaceId`
17535 17536 17537 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17535 def place_id @place_id end |
#route ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMapsRoute
Route information from Google Maps.
Corresponds to the JSON property route
17540 17541 17542 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17540 def route @route end |
#text ⇒ String
The text of the place answer.
Corresponds to the JSON property text
17545 17546 17547 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17545 def text @text end |
#title ⇒ String
The title of the place.
Corresponds to the JSON property title
17550 17551 17552 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17550 def title @title end |
#uri ⇒ String
The URI of the place.
Corresponds to the JSON property uri
17555 17556 17557 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17555 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17562 17563 17564 17565 17566 17567 17568 17569 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17562 def update!(**args) @place_answer_sources = args[:place_answer_sources] if args.key?(:place_answer_sources) @place_id = args[:place_id] if args.key?(:place_id) @route = args[:route] if args.key?(:route) @text = args[:text] if args.key?(:text) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) end |