Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMaps
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMaps
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A Maps chunk is a piece of evidence that comes from Google Maps, containing
information about places or routes. This is used to provide the user with rich,
location-based information.
Instance Attribute Summary collapse
-
#place_answer_sources ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSources
The sources that were used to generate the place answer.
-
#place_id ⇒ String
This Place's resource name, in
places/place_id`` format. -
#route ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMapsRoute
Route information from Google Maps.
-
#text ⇒ String
The text of the place answer.
-
#title ⇒ String
The title of the place.
-
#uri ⇒ String
The URI of the place.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkMaps
constructor
A new instance of GoogleCloudAiplatformV1GroundingChunkMaps.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkMaps
Returns a new instance of GoogleCloudAiplatformV1GroundingChunkMaps.
17388 17389 17390 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17388 def initialize(**args) update!(**args) end |
Instance Attribute Details
#place_answer_sources ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSources
The sources that were used to generate the place answer. This includes review
snippets and photos that were used to generate the answer, as well as URIs to
flag content.
Corresponds to the JSON property placeAnswerSources
17360 17361 17362 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17360 def place_answer_sources @place_answer_sources end |
#place_id ⇒ String
This Place's resource name, in places/place_id`format. This can be used to
look up the place in the Google Maps API.
Corresponds to the JSON propertyplaceId`
17366 17367 17368 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17366 def place_id @place_id end |
#route ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMapsRoute
Route information from Google Maps.
Corresponds to the JSON property route
17371 17372 17373 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17371 def route @route end |
#text ⇒ String
The text of the place answer.
Corresponds to the JSON property text
17376 17377 17378 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17376 def text @text end |
#title ⇒ String
The title of the place.
Corresponds to the JSON property title
17381 17382 17383 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17381 def title @title end |
#uri ⇒ String
The URI of the place.
Corresponds to the JSON property uri
17386 17387 17388 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17386 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17393 17394 17395 17396 17397 17398 17399 17400 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17393 def update!(**args) @place_answer_sources = args[:place_answer_sources] if args.key?(:place_answer_sources) @place_id = args[:place_id] if args.key?(:place_id) @route = args[:route] if args.key?(:route) @text = args[:text] if args.key?(:text) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) end |