Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMaps

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A Maps chunk is a piece of evidence that comes from Google Maps, containing information about places or routes. This is used to provide the user with rich, location-based information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkMaps

Returns a new instance of GoogleCloudAiplatformV1GroundingChunkMaps.



17341
17342
17343
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17341

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#place_answer_sourcesGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSources

The sources that were used to generate the place answer. This includes review snippets and photos that were used to generate the answer, as well as URIs to flag content. Corresponds to the JSON property placeAnswerSources



17313
17314
17315
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17313

def place_answer_sources
  @place_answer_sources
end

#place_idString

This Place's resource name, in places/place_id`format. This can be used to look up the place in the Google Maps API. Corresponds to the JSON propertyplaceId`

Returns:

  • (String)


17319
17320
17321
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17319

def place_id
  @place_id
end

#routeGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMapsRoute

Route information from Google Maps. Corresponds to the JSON property route



17324
17325
17326
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17324

def route
  @route
end

#textString

The text of the place answer. Corresponds to the JSON property text

Returns:

  • (String)


17329
17330
17331
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17329

def text
  @text
end

#titleString

The title of the place. Corresponds to the JSON property title

Returns:

  • (String)


17334
17335
17336
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17334

def title
  @title
end

#uriString

The URI of the place. Corresponds to the JSON property uri

Returns:

  • (String)


17339
17340
17341
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17339

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17346
17347
17348
17349
17350
17351
17352
17353
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17346

def update!(**args)
  @place_answer_sources = args[:place_answer_sources] if args.key?(:place_answer_sources)
  @place_id = args[:place_id] if args.key?(:place_id)
  @route = args[:route] if args.key?(:route)
  @text = args[:text] if args.key?(:text)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end