Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMaps
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMaps
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A Maps chunk is a piece of evidence that comes from Google Maps. It contains
information about a place, such as its name, address, and reviews. This is
used to provide the user with rich, location-based information.
Instance Attribute Summary collapse
-
#place_answer_sources ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSources
The sources that were used to generate the place answer.
-
#place_id ⇒ String
This Place's resource name, in
places/place_id`` format. -
#text ⇒ String
The text of the place answer.
-
#title ⇒ String
The title of the place.
-
#uri ⇒ String
The URI of the place.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkMaps
constructor
A new instance of GoogleCloudAiplatformV1GroundingChunkMaps.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkMaps
Returns a new instance of GoogleCloudAiplatformV1GroundingChunkMaps.
16544 16545 16546 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16544 def initialize(**args) update!(**args) end |
Instance Attribute Details
#place_answer_sources ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSources
The sources that were used to generate the place answer. This includes review
snippets and photos that were used to generate the answer, as well as URIs to
flag content.
Corresponds to the JSON property placeAnswerSources
16521 16522 16523 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16521 def place_answer_sources @place_answer_sources end |
#place_id ⇒ String
This Place's resource name, in places/place_id`format. This can be used to
look up the place in the Google Maps API.
Corresponds to the JSON propertyplaceId`
16527 16528 16529 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16527 def place_id @place_id end |
#text ⇒ String
The text of the place answer.
Corresponds to the JSON property text
16532 16533 16534 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16532 def text @text end |
#title ⇒ String
The title of the place.
Corresponds to the JSON property title
16537 16538 16539 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16537 def title @title end |
#uri ⇒ String
The URI of the place.
Corresponds to the JSON property uri
16542 16543 16544 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16542 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16549 16550 16551 16552 16553 16554 16555 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16549 def update!(**args) @place_answer_sources = args[:place_answer_sources] if args.key?(:place_answer_sources) @place_id = args[:place_id] if args.key?(:place_id) @text = args[:text] if args.key?(:text) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) end |