Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMaps

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A Maps chunk is a piece of evidence that comes from Google Maps. It contains information about a place, such as its name, address, and reviews. This is used to provide the user with rich, location-based information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkMaps

Returns a new instance of GoogleCloudAiplatformV1GroundingChunkMaps.



16343
16344
16345
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16343

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#place_answer_sourcesGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSources

The sources that were used to generate the place answer. This includes review snippets and photos that were used to generate the answer, as well as URIs to flag content. Corresponds to the JSON property placeAnswerSources



16320
16321
16322
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16320

def place_answer_sources
  @place_answer_sources
end

#place_idString

This Place's resource name, in places/place_id`format. This can be used to look up the place in the Google Maps API. Corresponds to the JSON propertyplaceId`

Returns:

  • (String)


16326
16327
16328
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16326

def place_id
  @place_id
end

#textString

The text of the place answer. Corresponds to the JSON property text

Returns:

  • (String)


16331
16332
16333
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16331

def text
  @text
end

#titleString

The title of the place. Corresponds to the JSON property title

Returns:

  • (String)


16336
16337
16338
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16336

def title
  @title
end

#uriString

The URI of the place. Corresponds to the JSON property uri

Returns:

  • (String)


16341
16342
16343
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16341

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16348
16349
16350
16351
16352
16353
16354
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16348

def update!(**args)
  @place_answer_sources = args[:place_answer_sources] if args.key?(:place_answer_sources)
  @place_id = args[:place_id] if args.key?(:place_id)
  @text = args[:text] if args.key?(:text)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end