Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSources
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSources
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The sources that were used to generate the place answer. This includes review snippets and photos that were used to generate the answer, as well as URIs to flag content.
Instance Attribute Summary collapse
-
#review_snippets ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet>
Snippets of reviews that were used to generate the answer.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSources
constructor
A new instance of GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSources.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSources
Returns a new instance of GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSources.
19225 19226 19227 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19225 def initialize(**args) update!(**args) end |
Instance Attribute Details
#review_snippets ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet>
Snippets of reviews that were used to generate the answer.
Corresponds to the JSON property reviewSnippets
19223 19224 19225 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19223 def review_snippets @review_snippets end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19230 19231 19232 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19230 def update!(**args) @review_snippets = args[:review_snippets] if args.key?(:review_snippets) end |