Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSources

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The sources that were used to generate the place answer. This includes review snippets and photos that were used to generate the answer, as well as URIs to flag content.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSources

Returns a new instance of GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSources.



18425
18426
18427
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18425

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#review_snippetsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet>

Snippets of reviews that were used to generate the answer. Corresponds to the JSON property reviewSnippets



18423
18424
18425
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18423

def review_snippets
  @review_snippets
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18430
18431
18432
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18430

def update!(**args)
  @review_snippets = args[:review_snippets] if args.key?(:review_snippets)
end