Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSources

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Sources used to generate the place answer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSources

Returns a new instance of GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSources.



13610
13611
13612
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13610

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#flag_content_uriString

A link where users can flag a problem with the generated answer. Corresponds to the JSON property flagContentUri

Returns:

  • (String)


13603
13604
13605
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13603

def flag_content_uri
  @flag_content_uri
end

#review_snippetsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet>

Snippets of reviews that are used to generate the answer. Corresponds to the JSON property reviewSnippets



13608
13609
13610
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13608

def review_snippets
  @review_snippets
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13615
13616
13617
13618
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13615

def update!(**args)
  @flag_content_uri = args[:flag_content_uri] if args.key?(:flag_content_uri)
  @review_snippets = args[:review_snippets] if args.key?(:review_snippets)
end