Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSources
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSources
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Sources used to generate the place answer.
Instance Attribute Summary collapse
-
#flag_content_uri ⇒ String
A link where users can flag a problem with the generated answer.
-
#review_snippets ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet>
Snippets of reviews that are used to generate the answer.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSources
constructor
A new instance of GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSources.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSources
Returns a new instance of GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSources.
13595 13596 13597 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13595 def initialize(**args) update!(**args) end |
Instance Attribute Details
#flag_content_uri ⇒ String
A link where users can flag a problem with the generated answer.
Corresponds to the JSON property flagContentUri
13588 13589 13590 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13588 def flag_content_uri @flag_content_uri end |
#review_snippets ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet>
Snippets of reviews that are used to generate the answer.
Corresponds to the JSON property reviewSnippets
13593 13594 13595 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13593 def review_snippets @review_snippets end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13600 13601 13602 13603 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13600 def update!(**args) @flag_content_uri = args[:flag_content_uri] if args.key?(:flag_content_uri) @review_snippets = args[:review_snippets] if args.key?(:review_snippets) end |