Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSourcesAuthorAttribution

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Author attribution for a photo or review.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSourcesAuthorAttribution

Returns a new instance of GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSourcesAuthorAttribution.



13625
13626
13627
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13625

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Name of the author of the Photo or Review. Corresponds to the JSON property displayName

Returns:

  • (String)


13613
13614
13615
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13613

def display_name
  @display_name
end

#photo_uriString

Profile photo URI of the author of the Photo or Review. Corresponds to the JSON property photoUri

Returns:

  • (String)


13618
13619
13620
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13618

def photo_uri
  @photo_uri
end

#uriString

URI of the author of the Photo or Review. Corresponds to the JSON property uri

Returns:

  • (String)


13623
13624
13625
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13623

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13630
13631
13632
13633
13634
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13630

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @photo_uri = args[:photo_uri] if args.key?(:photo_uri)
  @uri = args[:uri] if args.key?(:uri)
end