Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A review snippet that is used to generate the answer.
Instance Attribute Summary collapse
-
#google_maps_uri ⇒ String
A link to show the review on Google Maps.
-
#review_id ⇒ String
The ID of the review that is being referenced.
-
#title ⇒ String
The title of the review.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet
constructor
A new instance of GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet
Returns a new instance of GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet.
17500 17501 17502 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17500 def initialize(**args) update!(**args) end |
Instance Attribute Details
#google_maps_uri ⇒ String
A link to show the review on Google Maps.
Corresponds to the JSON property googleMapsUri
17488 17489 17490 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17488 def google_maps_uri @google_maps_uri end |
#review_id ⇒ String
The ID of the review that is being referenced.
Corresponds to the JSON property reviewId
17493 17494 17495 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17493 def review_id @review_id end |
#title ⇒ String
The title of the review.
Corresponds to the JSON property title
17498 17499 17500 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17498 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17505 17506 17507 17508 17509 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17505 def update!(**args) @google_maps_uri = args[:google_maps_uri] if args.key?(:google_maps_uri) @review_id = args[:review_id] if args.key?(:review_id) @title = args[:title] if args.key?(:title) end |