Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A review snippet that is used to generate the answer.
Instance Attribute Summary collapse
-
#google_maps_uri ⇒ String
A link to show the review on Google Maps.
-
#review_id ⇒ String
The ID of the review that is being referenced.
-
#title ⇒ String
The title of the review.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet
constructor
A new instance of GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet
Returns a new instance of GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet.
17396 17397 17398 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17396 def initialize(**args) update!(**args) end |
Instance Attribute Details
#google_maps_uri ⇒ String
A link to show the review on Google Maps.
Corresponds to the JSON property googleMapsUri
17384 17385 17386 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17384 def google_maps_uri @google_maps_uri end |
#review_id ⇒ String
The ID of the review that is being referenced.
Corresponds to the JSON property reviewId
17389 17390 17391 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17389 def review_id @review_id end |
#title ⇒ String
The title of the review.
Corresponds to the JSON property title
17394 17395 17396 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17394 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17401 17402 17403 17404 17405 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17401 def update!(**args) @google_maps_uri = args[:google_maps_uri] if args.key?(:google_maps_uri) @review_id = args[:review_id] if args.key?(:review_id) @title = args[:title] if args.key?(:title) end |