Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A review snippet that is used to generate the answer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet

Returns a new instance of GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet.



16397
16398
16399
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16397

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#google_maps_uriString

A link to show the review on Google Maps. Corresponds to the JSON property googleMapsUri

Returns:

  • (String)


16385
16386
16387
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16385

def google_maps_uri
  @google_maps_uri
end

#review_idString

The ID of the review that is being referenced. Corresponds to the JSON property reviewId

Returns:

  • (String)


16390
16391
16392
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16390

def review_id
  @review_id
end

#titleString

The title of the review. Corresponds to the JSON property title

Returns:

  • (String)


16395
16396
16397
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16395

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16402
16403
16404
16405
16406
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16402

def update!(**args)
  @google_maps_uri = args[:google_maps_uri] if args.key?(:google_maps_uri)
  @review_id = args[:review_id] if args.key?(:review_id)
  @title = args[:title] if args.key?(:title)
end