Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Encapsulates a review snippet.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet

Returns a new instance of GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet.



13683
13684
13685
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13683

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#author_attributionGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSourcesAuthorAttribution

Author attribution for a photo or review. Corresponds to the JSON property authorAttribution



13659
13660
13661
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13659

def author_attribution
  @author_attribution
end

#flag_content_uriString

A link where users can flag a problem with the review. Corresponds to the JSON property flagContentUri

Returns:

  • (String)


13664
13665
13666
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13664

def flag_content_uri
  @flag_content_uri
end

#google_maps_uriString

A link to show the review on Google Maps. Corresponds to the JSON property googleMapsUri

Returns:

  • (String)


13669
13670
13671
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13669

def google_maps_uri
  @google_maps_uri
end

#relative_publish_time_descriptionString

A string of formatted recent time, expressing the review time relative to the current time in a form appropriate for the language and country. Corresponds to the JSON property relativePublishTimeDescription

Returns:

  • (String)


13675
13676
13677
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13675

def relative_publish_time_description
  @relative_publish_time_description
end

#reviewString

A reference representing this place review which may be used to look up this place review again. Corresponds to the JSON property review

Returns:

  • (String)


13681
13682
13683
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13681

def review
  @review
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13688
13689
13690
13691
13692
13693
13694
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13688

def update!(**args)
  @author_attribution = args[:author_attribution] if args.key?(:author_attribution)
  @flag_content_uri = args[:flag_content_uri] if args.key?(:flag_content_uri)
  @google_maps_uri = args[:google_maps_uri] if args.key?(:google_maps_uri)
  @relative_publish_time_description = args[:relative_publish_time_description] if args.key?(:relative_publish_time_description)
  @review = args[:review] if args.key?(:review)
end