Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Encapsulates a review snippet.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet

Returns a new instance of GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet.



13668
13669
13670
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13668

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#author_attributionGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSourcesAuthorAttribution

Author attribution for a photo or review. Corresponds to the JSON property authorAttribution



13644
13645
13646
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13644

def author_attribution
  @author_attribution
end

#flag_content_uriString

A link where users can flag a problem with the review. Corresponds to the JSON property flagContentUri

Returns:

  • (String)


13649
13650
13651
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13649

def flag_content_uri
  @flag_content_uri
end

#google_maps_uriString

A link to show the review on Google Maps. Corresponds to the JSON property googleMapsUri

Returns:

  • (String)


13654
13655
13656
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13654

def google_maps_uri
  @google_maps_uri
end

#relative_publish_time_descriptionString

A string of formatted recent time, expressing the review time relative to the current time in a form appropriate for the language and country. Corresponds to the JSON property relativePublishTimeDescription

Returns:

  • (String)


13660
13661
13662
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13660

def relative_publish_time_description
  @relative_publish_time_description
end

#reviewString

A reference representing this place review which may be used to look up this place review again. Corresponds to the JSON property review

Returns:

  • (String)


13666
13667
13668
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13666

def review
  @review
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13673
13674
13675
13676
13677
13678
13679
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13673

def update!(**args)
  @author_attribution = args[:author_attribution] if args.key?(:author_attribution)
  @flag_content_uri = args[:flag_content_uri] if args.key?(:flag_content_uri)
  @google_maps_uri = args[:google_maps_uri] if args.key?(:google_maps_uri)
  @relative_publish_time_description = args[:relative_publish_time_description] if args.key?(:relative_publish_time_description)
  @review = args[:review] if args.key?(:review)
end