Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkRetrievedContext

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Context retrieved from a data source to ground the model's response. This is used when a retrieval tool fetches information from a user-provided corpus or a public dataset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkRetrievedContext

Returns a new instance of GoogleCloudAiplatformV1GroundingChunkRetrievedContext.



17522
17523
17524
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17522

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#document_nameString

Output only. The full resource name of the referenced Vertex AI Search document. This is used to identify the specific document that was retrieved. The format is projects/project/locations/location/collections/collection /dataStores/data_store/branches/branch/documents/document`. Corresponds to the JSON propertydocumentName`

Returns:

  • (String)


17499
17500
17501
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17499

def document_name
  @document_name
end

#rag_chunkGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RagChunk

A RagChunk includes the content of a chunk of a RagFile, and associated metadata. Corresponds to the JSON property ragChunk



17505
17506
17507
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17505

def rag_chunk
  @rag_chunk
end

#textString

The content of the retrieved data source. Corresponds to the JSON property text

Returns:

  • (String)


17510
17511
17512
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17510

def text
  @text
end

#titleString

The title of the retrieved data source. Corresponds to the JSON property title

Returns:

  • (String)


17515
17516
17517
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17515

def title
  @title
end

#uriString

The URI of the retrieved data source. Corresponds to the JSON property uri

Returns:

  • (String)


17520
17521
17522
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17520

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17527
17528
17529
17530
17531
17532
17533
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17527

def update!(**args)
  @document_name = args[:document_name] if args.key?(:document_name)
  @rag_chunk = args[:rag_chunk] if args.key?(:rag_chunk)
  @text = args[:text] if args.key?(:text)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end