Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkRetrievedContext

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Context retrieved from a data source to ground the model's response. This is used when a retrieval tool fetches information from a user-provided corpus or a public dataset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkRetrievedContext

Returns a new instance of GoogleCloudAiplatformV1GroundingChunkRetrievedContext.



16645
16646
16647
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16645

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#document_nameString

Output only. The full resource name of the referenced Vertex AI Search document. This is used to identify the specific document that was retrieved. The format is projects/project/locations/location/collections/collection /dataStores/data_store/branches/branch/documents/document`. Corresponds to the JSON propertydocumentName`

Returns:

  • (String)


16622
16623
16624
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16622

def document_name
  @document_name
end

#rag_chunkGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RagChunk

A RagChunk includes the content of a chunk of a RagFile, and associated metadata. Corresponds to the JSON property ragChunk



16628
16629
16630
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16628

def rag_chunk
  @rag_chunk
end

#textString

The content of the retrieved data source. Corresponds to the JSON property text

Returns:

  • (String)


16633
16634
16635
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16633

def text
  @text
end

#titleString

The title of the retrieved data source. Corresponds to the JSON property title

Returns:

  • (String)


16638
16639
16640
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16638

def title
  @title
end

#uriString

The URI of the retrieved data source. Corresponds to the JSON property uri

Returns:

  • (String)


16643
16644
16645
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16643

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16650
16651
16652
16653
16654
16655
16656
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16650

def update!(**args)
  @document_name = args[:document_name] if args.key?(:document_name)
  @rag_chunk = args[:rag_chunk] if args.key?(:rag_chunk)
  @text = args[:text] if args.key?(:text)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end