Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkRetrievedContext
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkRetrievedContext
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Context retrieved from a data source to ground the model's response. This is used when a retrieval tool fetches information from a user-provided corpus or a public dataset.
Instance Attribute Summary collapse
-
#document_name ⇒ String
Output only.
-
#rag_chunk ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagChunk
A RagChunk includes the content of a chunk of a RagFile, and associated metadata.
-
#text ⇒ String
The content of the retrieved data source.
-
#title ⇒ String
The title of the retrieved data source.
-
#uri ⇒ String
The URI of the retrieved data source.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkRetrievedContext
constructor
A new instance of GoogleCloudAiplatformV1GroundingChunkRetrievedContext.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkRetrievedContext
Returns a new instance of GoogleCloudAiplatformV1GroundingChunkRetrievedContext.
16444 16445 16446 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16444 def initialize(**args) update!(**args) end |
Instance Attribute Details
#document_name ⇒ String
Output only. The full resource name of the referenced Vertex AI Search
document. This is used to identify the specific document that was retrieved.
The format is projects/project/locations/location/collections/collection
/dataStores/data_store/branches/branch/documents/document`.
Corresponds to the JSON propertydocumentName`
16421 16422 16423 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16421 def document_name @document_name end |
#rag_chunk ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagChunk
A RagChunk includes the content of a chunk of a RagFile, and associated
metadata.
Corresponds to the JSON property ragChunk
16427 16428 16429 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16427 def rag_chunk @rag_chunk end |
#text ⇒ String
The content of the retrieved data source.
Corresponds to the JSON property text
16432 16433 16434 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16432 def text @text end |
#title ⇒ String
The title of the retrieved data source.
Corresponds to the JSON property title
16437 16438 16439 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16437 def title @title end |
#uri ⇒ String
The URI of the retrieved data source.
Corresponds to the JSON property uri
16442 16443 16444 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16442 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16449 16450 16451 16452 16453 16454 16455 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16449 def update!(**args) @document_name = args[:document_name] if args.key?(:document_name) @rag_chunk = args[:rag_chunk] if args.key?(:rag_chunk) @text = args[:text] if args.key?(:text) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) end |