Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkRetrievedContext
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkRetrievedContext
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Chunk from context retrieved by the retrieval tools.
Instance Attribute Summary collapse
-
#rag_chunk ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagChunk
A RagChunk includes the content of a chunk of a RagFile, and associated metadata.
-
#text ⇒ String
Text of the attribution.
-
#title ⇒ String
Title of the attribution.
-
#uri ⇒ String
URI reference of the attribution.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkRetrievedContext
constructor
A new instance of GoogleCloudAiplatformV1GroundingChunkRetrievedContext.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkRetrievedContext
Returns a new instance of GoogleCloudAiplatformV1GroundingChunkRetrievedContext.
12966 12967 12968 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12966 def initialize(**args) update!(**args) end |
Instance Attribute Details
#rag_chunk ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagChunk
A RagChunk includes the content of a chunk of a RagFile, and associated
metadata.
Corresponds to the JSON property ragChunk
12949 12950 12951 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12949 def rag_chunk @rag_chunk end |
#text ⇒ String
Text of the attribution.
Corresponds to the JSON property text
12954 12955 12956 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12954 def text @text end |
#title ⇒ String
Title of the attribution.
Corresponds to the JSON property title
12959 12960 12961 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12959 def title @title end |
#uri ⇒ String
URI reference of the attribution.
Corresponds to the JSON property uri
12964 12965 12966 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12964 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12971 12972 12973 12974 12975 12976 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12971 def update!(**args) @rag_chunk = args[:rag_chunk] if args.key?(:rag_chunk) @text = args[:text] if args.key?(:text) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) end |