Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkRetrievedContext
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkRetrievedContext
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Chunk from context retrieved by the retrieval tools.
Instance Attribute Summary collapse
-
#rag_chunk ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagChunk
A RagChunk includes the content of a chunk of a RagFile, and associated metadata.
-
#text ⇒ String
Text of the attribution.
-
#title ⇒ String
Title of the attribution.
-
#uri ⇒ String
URI reference of the attribution.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkRetrievedContext
constructor
A new instance of GoogleCloudAiplatformV1GroundingChunkRetrievedContext.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkRetrievedContext
Returns a new instance of GoogleCloudAiplatformV1GroundingChunkRetrievedContext.
12657 12658 12659 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12657 def initialize(**args) update!(**args) end |
Instance Attribute Details
#rag_chunk ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagChunk
A RagChunk includes the content of a chunk of a RagFile, and associated
metadata.
Corresponds to the JSON property ragChunk
12640 12641 12642 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12640 def rag_chunk @rag_chunk end |
#text ⇒ String
Text of the attribution.
Corresponds to the JSON property text
12645 12646 12647 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12645 def text @text end |
#title ⇒ String
Title of the attribution.
Corresponds to the JSON property title
12650 12651 12652 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12650 def title @title end |
#uri ⇒ String
URI reference of the attribution.
Corresponds to the JSON property uri
12655 12656 12657 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12655 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12662 12663 12664 12665 12666 12667 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12662 def update!(**args) @rag_chunk = args[:rag_chunk] if args.key?(:rag_chunk) @text = args[:text] if args.key?(:text) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) end |