Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkWeb
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkWeb
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A Web chunk is a piece of evidence that comes from a web page. It contains
the URI of the web page, the title of the page, and the domain of the page.
This is used to provide the user with a link to the source of the information.
Instance Attribute Summary collapse
-
#domain ⇒ String
The domain of the web page that contains the evidence.
-
#title ⇒ String
The title of the web page that contains the evidence.
-
#uri ⇒ String
The URI of the web page that contains the evidence.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkWeb
constructor
A new instance of GoogleCloudAiplatformV1GroundingChunkWeb.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkWeb
Returns a new instance of GoogleCloudAiplatformV1GroundingChunkWeb.
18943 18944 18945 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18943 def initialize(**args) update!(**args) end |
Instance Attribute Details
#domain ⇒ String
The domain of the web page that contains the evidence. This can be used to
filter out low-quality sources.
Corresponds to the JSON property domain
18931 18932 18933 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18931 def domain @domain end |
#title ⇒ String
The title of the web page that contains the evidence.
Corresponds to the JSON property title
18936 18937 18938 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18936 def title @title end |
#uri ⇒ String
The URI of the web page that contains the evidence.
Corresponds to the JSON property uri
18941 18942 18943 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18941 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18948 18949 18950 18951 18952 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18948 def update!(**args) @domain = args[:domain] if args.key?(:domain) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) end |