Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkWeb

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A Web chunk is a piece of evidence that comes from a web page. It contains the URI of the web page, the title of the page, and the domain of the page. This is used to provide the user with a link to the source of the information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkWeb

Returns a new instance of GoogleCloudAiplatformV1GroundingChunkWeb.



17727
17728
17729
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17727

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#domainString

The domain of the web page that contains the evidence. This can be used to filter out low-quality sources. Corresponds to the JSON property domain

Returns:

  • (String)


17715
17716
17717
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17715

def domain
  @domain
end

#titleString

The title of the web page that contains the evidence. Corresponds to the JSON property title

Returns:

  • (String)


17720
17721
17722
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17720

def title
  @title
end

#uriString

The URI of the web page that contains the evidence. Corresponds to the JSON property uri

Returns:

  • (String)


17725
17726
17727
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17725

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17732
17733
17734
17735
17736
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17732

def update!(**args)
  @domain = args[:domain] if args.key?(:domain)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end