Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunkWeb

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A Web chunk is a piece of evidence that comes from a web page. It contains the URI of the web page, the title of the page, and the domain of the page. This is used to provide the user with a link to the source of the information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingChunkWeb

Returns a new instance of GoogleCloudAiplatformV1GroundingChunkWeb.



16681
16682
16683
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16681

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#domainString

The domain of the web page that contains the evidence. This can be used to filter out low-quality sources. Corresponds to the JSON property domain

Returns:

  • (String)


16669
16670
16671
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16669

def domain
  @domain
end

#titleString

The title of the web page that contains the evidence. Corresponds to the JSON property title

Returns:

  • (String)


16674
16675
16676
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16674

def title
  @title
end

#uriString

The URI of the web page that contains the evidence. Corresponds to the JSON property uri

Returns:

  • (String)


16679
16680
16681
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16679

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16686
16687
16688
16689
16690
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16686

def update!(**args)
  @domain = args[:domain] if args.key?(:domain)
  @title = args[:title] if args.key?(:title)
  @uri = args[:uri] if args.key?(:uri)
end