Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Information about the sources that support the content of a response. When grounding is enabled, the model returns citations for claims in the response. This object contains the retrieved sources.
Instance Attribute Summary collapse
-
#google_maps_widget_context_token ⇒ String
Optional.
-
#grounding_chunks ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunk>
A list of supporting references retrieved from the grounding source.
-
#grounding_supports ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingSupport>
Optional.
-
#image_search_queries ⇒ Array<String>
Optional.
-
#retrieval_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrievalMetadata
Metadata related to the retrieval grounding source.
-
#search_entry_point ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SearchEntryPoint
An entry point for displaying Google Search results.
-
#source_flagging_uris ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingMetadataSourceFlaggingUri>
Optional.
-
#web_search_queries ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingMetadata
constructor
A new instance of GoogleCloudAiplatformV1GroundingMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingMetadata
Returns a new instance of GoogleCloudAiplatformV1GroundingMetadata.
18657 18658 18659 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18657 def initialize(**args) update!(**args) end |
Instance Attribute Details
#google_maps_widget_context_token ⇒ String
Optional. Output only. Deprecated: The Google Maps contextual widget behavior
in Grounding with Google Maps is being deprecated; this field is planned for
removal and will no longer be populated once removed. A token that can be used
to render a Google Maps widget with the contextual data. This field is
populated only when the grounding source is Google Maps.
Corresponds to the JSON property googleMapsWidgetContextToken
18607 18608 18609 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18607 def @google_maps_widget_context_token end |
#grounding_chunks ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunk>
A list of supporting references retrieved from the grounding source. This
field is populated when the grounding source is Google Search, Vertex AI
Search, or Google Maps.
Corresponds to the JSON property groundingChunks
18614 18615 18616 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18614 def grounding_chunks @grounding_chunks end |
#grounding_supports ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingSupport>
Optional. A list of grounding supports that connect the generated content to
the grounding chunks. This field is populated when the grounding source is
Google Search or Vertex AI Search.
Corresponds to the JSON property groundingSupports
18621 18622 18623 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18621 def grounding_supports @grounding_supports end |
#image_search_queries ⇒ Array<String>
Optional. The image search queries that were used to generate the content.
This field is populated only when the grounding source is Google Search with
the Image Search search_type enabled.
Corresponds to the JSON property imageSearchQueries
18628 18629 18630 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18628 def image_search_queries @image_search_queries end |
#retrieval_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrievalMetadata
Metadata related to the retrieval grounding source. This is part of the
GroundingMetadata returned when grounding is enabled.
Corresponds to the JSON property retrievalMetadata
18634 18635 18636 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18634 def @retrieval_metadata end |
#search_entry_point ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SearchEntryPoint
An entry point for displaying Google Search results. A SearchEntryPoint is
populated when the grounding source for a model's response is Google Search.
It provides information that you can use to display the search results in your
application.
Corresponds to the JSON property searchEntryPoint
18642 18643 18644 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18642 def search_entry_point @search_entry_point end |
#source_flagging_uris ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingMetadataSourceFlaggingUri>
Optional. Output only. A list of URIs that can be used to flag a place or
review for inappropriate content. This field is populated only when the
grounding source is Google Maps.
Corresponds to the JSON property sourceFlaggingUris
18649 18650 18651 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18649 def source_flagging_uris @source_flagging_uris end |
#web_search_queries ⇒ Array<String>
Optional. The web search queries that were used to generate the content. This
field is populated only when the grounding source is Google Search.
Corresponds to the JSON property webSearchQueries
18655 18656 18657 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18655 def web_search_queries @web_search_queries end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18662 18663 18664 18665 18666 18667 18668 18669 18670 18671 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18662 def update!(**args) @google_maps_widget_context_token = args[:google_maps_widget_context_token] if args.key?(:google_maps_widget_context_token) @grounding_chunks = args[:grounding_chunks] if args.key?(:grounding_chunks) @grounding_supports = args[:grounding_supports] if args.key?(:grounding_supports) @image_search_queries = args[:image_search_queries] if args.key?(:image_search_queries) @retrieval_metadata = args[:retrieval_metadata] if args.key?(:retrieval_metadata) @search_entry_point = args[:search_entry_point] if args.key?(:search_entry_point) @source_flagging_uris = args[:source_flagging_uris] if args.key?(:source_flagging_uris) @web_search_queries = args[:web_search_queries] if args.key?(:web_search_queries) end |