Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Information about the sources that support the content of a response. When grounding is enabled, the model returns citations for claims in the response. This object contains the retrieved sources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingMetadata

Returns a new instance of GoogleCloudAiplatformV1GroundingMetadata.



17800
17801
17802
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17800

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#google_maps_widget_context_tokenString

Optional. Output only. A token that can be used to render a Google Maps widget with the contextual data. This field is populated only when the grounding source is Google Maps. Corresponds to the JSON property googleMapsWidgetContextToken

Returns:

  • (String)


17750
17751
17752
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17750

def google_maps_widget_context_token
  @google_maps_widget_context_token
end

#grounding_chunksArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunk>

A list of supporting references retrieved from the grounding source. This field is populated when the grounding source is Google Search, Vertex AI Search, or Google Maps. Corresponds to the JSON property groundingChunks



17757
17758
17759
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17757

def grounding_chunks
  @grounding_chunks
end

#grounding_supportsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingSupport>

Optional. A list of grounding supports that connect the generated content to the grounding chunks. This field is populated when the grounding source is Google Search or Vertex AI Search. Corresponds to the JSON property groundingSupports



17764
17765
17766
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17764

def grounding_supports
  @grounding_supports
end

#image_search_queriesArray<String>

Optional. The image search queries that were used to generate the content. This field is populated only when the grounding source is Google Search with the Image Search search_type enabled. Corresponds to the JSON property imageSearchQueries

Returns:

  • (Array<String>)


17771
17772
17773
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17771

def image_search_queries
  @image_search_queries
end

#retrieval_metadataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrievalMetadata

Metadata related to the retrieval grounding source. This is part of the GroundingMetadata returned when grounding is enabled. Corresponds to the JSON property retrievalMetadata



17777
17778
17779
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17777

def 
  @retrieval_metadata
end

#search_entry_pointGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SearchEntryPoint

An entry point for displaying Google Search results. A SearchEntryPoint is populated when the grounding source for a model's response is Google Search. It provides information that you can use to display the search results in your application. Corresponds to the JSON property searchEntryPoint



17785
17786
17787
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17785

def search_entry_point
  @search_entry_point
end

#source_flagging_urisArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingMetadataSourceFlaggingUri>

Optional. Output only. A list of URIs that can be used to flag a place or review for inappropriate content. This field is populated only when the grounding source is Google Maps. Corresponds to the JSON property sourceFlaggingUris



17792
17793
17794
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17792

def source_flagging_uris
  @source_flagging_uris
end

#web_search_queriesArray<String>

Optional. The web search queries that were used to generate the content. This field is populated only when the grounding source is Google Search. Corresponds to the JSON property webSearchQueries

Returns:

  • (Array<String>)


17798
17799
17800
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17798

def web_search_queries
  @web_search_queries
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17805
17806
17807
17808
17809
17810
17811
17812
17813
17814
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17805

def update!(**args)
  @google_maps_widget_context_token = args[:google_maps_widget_context_token] if args.key?(:google_maps_widget_context_token)
  @grounding_chunks = args[:grounding_chunks] if args.key?(:grounding_chunks)
  @grounding_supports = args[:grounding_supports] if args.key?(:grounding_supports)
  @image_search_queries = args[:image_search_queries] if args.key?(:image_search_queries)
  @retrieval_metadata = args[:retrieval_metadata] if args.key?(:retrieval_metadata)
  @search_entry_point = args[:search_entry_point] if args.key?(:search_entry_point)
  @source_flagging_uris = args[:source_flagging_uris] if args.key?(:source_flagging_uris)
  @web_search_queries = args[:web_search_queries] if args.key?(:web_search_queries)
end