Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Information about the sources that support the content of a response. When grounding is enabled, the model returns citations for claims in the response. This object contains the retrieved sources.
Instance Attribute Summary collapse
-
#google_maps_widget_context_token ⇒ String
Optional.
-
#grounding_chunks ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunk>
A list of supporting references retrieved from the grounding source.
-
#grounding_supports ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingSupport>
Optional.
-
#image_search_queries ⇒ Array<String>
Optional.
-
#retrieval_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrievalMetadata
Metadata related to the retrieval grounding source.
-
#search_entry_point ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SearchEntryPoint
An entry point for displaying Google Search results.
-
#source_flagging_uris ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingMetadataSourceFlaggingUri>
Optional.
-
#web_search_queries ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingMetadata
constructor
A new instance of GoogleCloudAiplatformV1GroundingMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingMetadata
Returns a new instance of GoogleCloudAiplatformV1GroundingMetadata.
17688 17689 17690 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17688 def initialize(**args) update!(**args) end |
Instance Attribute Details
#google_maps_widget_context_token ⇒ String
Optional. Output only. A token that can be used to render a Google Maps widget
with the contextual data. This field is populated only when the grounding
source is Google Maps.
Corresponds to the JSON property googleMapsWidgetContextToken
17638 17639 17640 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17638 def @google_maps_widget_context_token end |
#grounding_chunks ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunk>
A list of supporting references retrieved from the grounding source. This
field is populated when the grounding source is Google Search, Vertex AI
Search, or Google Maps.
Corresponds to the JSON property groundingChunks
17645 17646 17647 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17645 def grounding_chunks @grounding_chunks end |
#grounding_supports ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingSupport>
Optional. A list of grounding supports that connect the generated content to
the grounding chunks. This field is populated when the grounding source is
Google Search or Vertex AI Search.
Corresponds to the JSON property groundingSupports
17652 17653 17654 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17652 def grounding_supports @grounding_supports end |
#image_search_queries ⇒ Array<String>
Optional. The image search queries that were used to generate the content.
This field is populated only when the grounding source is Google Search with
the Image Search search_type enabled.
Corresponds to the JSON property imageSearchQueries
17659 17660 17661 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17659 def image_search_queries @image_search_queries end |
#retrieval_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrievalMetadata
Metadata related to the retrieval grounding source. This is part of the
GroundingMetadata returned when grounding is enabled.
Corresponds to the JSON property retrievalMetadata
17665 17666 17667 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17665 def @retrieval_metadata end |
#search_entry_point ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SearchEntryPoint
An entry point for displaying Google Search results. A SearchEntryPoint is
populated when the grounding source for a model's response is Google Search.
It provides information that you can use to display the search results in your
application.
Corresponds to the JSON property searchEntryPoint
17673 17674 17675 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17673 def search_entry_point @search_entry_point end |
#source_flagging_uris ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingMetadataSourceFlaggingUri>
Optional. Output only. A list of URIs that can be used to flag a place or
review for inappropriate content. This field is populated only when the
grounding source is Google Maps.
Corresponds to the JSON property sourceFlaggingUris
17680 17681 17682 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17680 def source_flagging_uris @source_flagging_uris end |
#web_search_queries ⇒ Array<String>
Optional. The web search queries that were used to generate the content. This
field is populated only when the grounding source is Google Search.
Corresponds to the JSON property webSearchQueries
17686 17687 17688 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17686 def web_search_queries @web_search_queries end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17693 17694 17695 17696 17697 17698 17699 17700 17701 17702 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17693 def update!(**args) @google_maps_widget_context_token = args[:google_maps_widget_context_token] if args.key?(:google_maps_widget_context_token) @grounding_chunks = args[:grounding_chunks] if args.key?(:grounding_chunks) @grounding_supports = args[:grounding_supports] if args.key?(:grounding_supports) @image_search_queries = args[:image_search_queries] if args.key?(:image_search_queries) @retrieval_metadata = args[:retrieval_metadata] if args.key?(:retrieval_metadata) @search_entry_point = args[:search_entry_point] if args.key?(:search_entry_point) @source_flagging_uris = args[:source_flagging_uris] if args.key?(:source_flagging_uris) @web_search_queries = args[:web_search_queries] if args.key?(:web_search_queries) end |