Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Information about the sources that support the content of a response. When grounding is enabled, the model returns citations for claims in the response. This object contains the retrieved sources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingMetadata

Returns a new instance of GoogleCloudAiplatformV1GroundingMetadata.



16747
16748
16749
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16747

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#google_maps_widget_context_tokenString

Optional. Output only. A token that can be used to render a Google Maps widget with the contextual data. This field is populated only when the grounding source is Google Maps. Corresponds to the JSON property googleMapsWidgetContextToken

Returns:

  • (String)


16704
16705
16706
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16704

def google_maps_widget_context_token
  @google_maps_widget_context_token
end

#grounding_chunksArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunk>

A list of supporting references retrieved from the grounding source. This field is populated when the grounding source is Google Search, Vertex AI Search, or Google Maps. Corresponds to the JSON property groundingChunks



16711
16712
16713
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16711

def grounding_chunks
  @grounding_chunks
end

#grounding_supportsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingSupport>

Optional. A list of grounding supports that connect the generated content to the grounding chunks. This field is populated when the grounding source is Google Search or Vertex AI Search. Corresponds to the JSON property groundingSupports



16718
16719
16720
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16718

def grounding_supports
  @grounding_supports
end

#retrieval_metadataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrievalMetadata

Metadata related to the retrieval grounding source. This is part of the GroundingMetadata returned when grounding is enabled. Corresponds to the JSON property retrievalMetadata



16724
16725
16726
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16724

def 
  @retrieval_metadata
end

#search_entry_pointGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SearchEntryPoint

An entry point for displaying Google Search results. A SearchEntryPoint is populated when the grounding source for a model's response is Google Search. It provides information that you can use to display the search results in your application. Corresponds to the JSON property searchEntryPoint



16732
16733
16734
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16732

def search_entry_point
  @search_entry_point
end

#source_flagging_urisArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingMetadataSourceFlaggingUri>

Optional. Output only. A list of URIs that can be used to flag a place or review for inappropriate content. This field is populated only when the grounding source is Google Maps. Corresponds to the JSON property sourceFlaggingUris



16739
16740
16741
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16739

def source_flagging_uris
  @source_flagging_uris
end

#web_search_queriesArray<String>

Optional. The web search queries that were used to generate the content. This field is populated only when the grounding source is Google Search. Corresponds to the JSON property webSearchQueries

Returns:

  • (Array<String>)


16745
16746
16747
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16745

def web_search_queries
  @web_search_queries
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16752
16753
16754
16755
16756
16757
16758
16759
16760
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16752

def update!(**args)
  @google_maps_widget_context_token = args[:google_maps_widget_context_token] if args.key?(:google_maps_widget_context_token)
  @grounding_chunks = args[:grounding_chunks] if args.key?(:grounding_chunks)
  @grounding_supports = args[:grounding_supports] if args.key?(:grounding_supports)
  @retrieval_metadata = args[:retrieval_metadata] if args.key?(:retrieval_metadata)
  @search_entry_point = args[:search_entry_point] if args.key?(:search_entry_point)
  @source_flagging_uris = args[:source_flagging_uris] if args.key?(:source_flagging_uris)
  @web_search_queries = args[:web_search_queries] if args.key?(:web_search_queries)
end