Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Metadata returned to client when grounding is enabled.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingMetadata

Returns a new instance of GoogleCloudAiplatformV1GroundingMetadata.



13802
13803
13804
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13802

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#google_maps_widget_context_tokenString

Optional. Output only. Resource name of the Google Maps widget context token to be used with the PlacesContextElement widget to render contextual data. This is populated only for Google Maps grounding. Corresponds to the JSON property googleMapsWidgetContextToken

Returns:

  • (String)


13775
13776
13777
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13775

def google_maps_widget_context_token
  @google_maps_widget_context_token
end

#grounding_chunksArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunk>

List of supporting references retrieved from specified grounding source. Corresponds to the JSON property groundingChunks



13780
13781
13782
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13780

def grounding_chunks
  @grounding_chunks
end

#grounding_supportsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingSupport>

Optional. List of grounding support. Corresponds to the JSON property groundingSupports



13785
13786
13787
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13785

def grounding_supports
  @grounding_supports
end

#retrieval_metadataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrievalMetadata

Metadata related to retrieval in the grounding flow. Corresponds to the JSON property retrievalMetadata



13790
13791
13792
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13790

def 
  @retrieval_metadata
end

#search_entry_pointGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SearchEntryPoint

Google search entry point. Corresponds to the JSON property searchEntryPoint



13795
13796
13797
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13795

def search_entry_point
  @search_entry_point
end

#web_search_queriesArray<String>

Optional. Web search queries for the following-up web search. Corresponds to the JSON property webSearchQueries

Returns:

  • (Array<String>)


13800
13801
13802
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13800

def web_search_queries
  @web_search_queries
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13807
13808
13809
13810
13811
13812
13813
13814
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13807

def update!(**args)
  @google_maps_widget_context_token = args[:google_maps_widget_context_token] if args.key?(:google_maps_widget_context_token)
  @grounding_chunks = args[:grounding_chunks] if args.key?(:grounding_chunks)
  @grounding_supports = args[:grounding_supports] if args.key?(:grounding_supports)
  @retrieval_metadata = args[:retrieval_metadata] if args.key?(:retrieval_metadata)
  @search_entry_point = args[:search_entry_point] if args.key?(:search_entry_point)
  @web_search_queries = args[:web_search_queries] if args.key?(:web_search_queries)
end