Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Metadata returned to client when grounding is enabled.
Instance Attribute Summary collapse
-
#google_maps_widget_context_token ⇒ String
Optional.
-
#grounding_chunks ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunk>
List of supporting references retrieved from specified grounding source.
-
#grounding_supports ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingSupport>
Optional.
-
#retrieval_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrievalMetadata
Metadata related to retrieval in the grounding flow.
-
#search_entry_point ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SearchEntryPoint
Google search entry point.
-
#web_search_queries ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingMetadata
constructor
A new instance of GoogleCloudAiplatformV1GroundingMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingMetadata
Returns a new instance of GoogleCloudAiplatformV1GroundingMetadata.
13787 13788 13789 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13787 def initialize(**args) update!(**args) end |
Instance Attribute Details
#google_maps_widget_context_token ⇒ String
Optional. Output only. Resource name of the Google Maps widget context token
to be used with the PlacesContextElement widget to render contextual data.
This is populated only for Google Maps grounding.
Corresponds to the JSON property googleMapsWidgetContextToken
13760 13761 13762 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13760 def @google_maps_widget_context_token end |
#grounding_chunks ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunk>
List of supporting references retrieved from specified grounding source.
Corresponds to the JSON property groundingChunks
13765 13766 13767 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13765 def grounding_chunks @grounding_chunks end |
#grounding_supports ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingSupport>
Optional. List of grounding support.
Corresponds to the JSON property groundingSupports
13770 13771 13772 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13770 def grounding_supports @grounding_supports end |
#retrieval_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrievalMetadata
Metadata related to retrieval in the grounding flow.
Corresponds to the JSON property retrievalMetadata
13775 13776 13777 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13775 def @retrieval_metadata end |
#search_entry_point ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SearchEntryPoint
Google search entry point.
Corresponds to the JSON property searchEntryPoint
13780 13781 13782 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13780 def search_entry_point @search_entry_point end |
#web_search_queries ⇒ Array<String>
Optional. Web search queries for the following-up web search.
Corresponds to the JSON property webSearchQueries
13785 13786 13787 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13785 def web_search_queries @web_search_queries end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13792 13793 13794 13795 13796 13797 13798 13799 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13792 def update!(**args) @google_maps_widget_context_token = args[:google_maps_widget_context_token] if args.key?(:google_maps_widget_context_token) @grounding_chunks = args[:grounding_chunks] if args.key?(:grounding_chunks) @grounding_supports = args[:grounding_supports] if args.key?(:grounding_supports) @retrieval_metadata = args[:retrieval_metadata] if args.key?(:retrieval_metadata) @search_entry_point = args[:search_entry_point] if args.key?(:search_entry_point) @web_search_queries = args[:web_search_queries] if args.key?(:web_search_queries) end |