Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Metadata returned to client when grounding is enabled.
Instance Attribute Summary collapse
-
#grounding_chunks ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunk>
List of supporting references retrieved from specified grounding source.
-
#grounding_supports ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingSupport>
Optional.
-
#retrieval_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrievalMetadata
Metadata related to retrieval in the grounding flow.
-
#search_entry_point ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SearchEntryPoint
Google search entry point.
-
#web_search_queries ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingMetadata
constructor
A new instance of GoogleCloudAiplatformV1GroundingMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingMetadata
Returns a new instance of GoogleCloudAiplatformV1GroundingMetadata.
12670 12671 12672 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12670 def initialize(**args) update!(**args) end |
Instance Attribute Details
#grounding_chunks ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunk>
List of supporting references retrieved from specified grounding source.
Corresponds to the JSON property groundingChunks
12648 12649 12650 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12648 def grounding_chunks @grounding_chunks end |
#grounding_supports ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingSupport>
Optional. List of grounding support.
Corresponds to the JSON property groundingSupports
12653 12654 12655 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12653 def grounding_supports @grounding_supports end |
#retrieval_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrievalMetadata
Metadata related to retrieval in the grounding flow.
Corresponds to the JSON property retrievalMetadata
12658 12659 12660 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12658 def @retrieval_metadata end |
#search_entry_point ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SearchEntryPoint
Google search entry point.
Corresponds to the JSON property searchEntryPoint
12663 12664 12665 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12663 def search_entry_point @search_entry_point end |
#web_search_queries ⇒ Array<String>
Optional. Web search queries for the following-up web search.
Corresponds to the JSON property webSearchQueries
12668 12669 12670 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12668 def web_search_queries @web_search_queries end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12675 12676 12677 12678 12679 12680 12681 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12675 def update!(**args) @grounding_chunks = args[:grounding_chunks] if args.key?(:grounding_chunks) @grounding_supports = args[:grounding_supports] if args.key?(:grounding_supports) @retrieval_metadata = args[:retrieval_metadata] if args.key?(:retrieval_metadata) @search_entry_point = args[:search_entry_point] if args.key?(:search_entry_point) @web_search_queries = args[:web_search_queries] if args.key?(:web_search_queries) end |