Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Metadata returned to client when grounding is enabled.
Instance Attribute Summary collapse
-
#grounding_chunks ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunk>
List of supporting references retrieved from specified grounding source.
-
#grounding_supports ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingSupport>
Optional.
-
#retrieval_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrievalMetadata
Metadata related to retrieval in the grounding flow.
-
#search_entry_point ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SearchEntryPoint
Google search entry point.
-
#web_search_queries ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingMetadata
constructor
A new instance of GoogleCloudAiplatformV1GroundingMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingMetadata
Returns a new instance of GoogleCloudAiplatformV1GroundingMetadata.
12629 12630 12631 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12629 def initialize(**args) update!(**args) end |
Instance Attribute Details
#grounding_chunks ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingChunk>
List of supporting references retrieved from specified grounding source.
Corresponds to the JSON property groundingChunks
12607 12608 12609 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12607 def grounding_chunks @grounding_chunks end |
#grounding_supports ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingSupport>
Optional. List of grounding support.
Corresponds to the JSON property groundingSupports
12612 12613 12614 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12612 def grounding_supports @grounding_supports end |
#retrieval_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrievalMetadata
Metadata related to retrieval in the grounding flow.
Corresponds to the JSON property retrievalMetadata
12617 12618 12619 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12617 def @retrieval_metadata end |
#search_entry_point ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SearchEntryPoint
Google search entry point.
Corresponds to the JSON property searchEntryPoint
12622 12623 12624 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12622 def search_entry_point @search_entry_point end |
#web_search_queries ⇒ Array<String>
Optional. Web search queries for the following-up web search.
Corresponds to the JSON property webSearchQueries
12627 12628 12629 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12627 def web_search_queries @web_search_queries end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12634 12635 12636 12637 12638 12639 12640 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12634 def update!(**args) @grounding_chunks = args[:grounding_chunks] if args.key?(:grounding_chunks) @grounding_supports = args[:grounding_supports] if args.key?(:grounding_supports) @retrieval_metadata = args[:retrieval_metadata] if args.key?(:retrieval_metadata) @search_entry_point = args[:search_entry_point] if args.key?(:search_entry_point) @web_search_queries = args[:web_search_queries] if args.key?(:web_search_queries) end |