Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingMetadataSourceFlaggingUri
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingMetadataSourceFlaggingUri
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A URI that can be used to flag a place or review for inappropriate content. This is populated only when the grounding source is Google Maps.
Instance Attribute Summary collapse
-
#flag_content_uri ⇒ String
The URI that can be used to flag the content.
-
#source_id ⇒ String
The ID of the place or review.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingMetadataSourceFlaggingUri
constructor
A new instance of GoogleCloudAiplatformV1GroundingMetadataSourceFlaggingUri.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingMetadataSourceFlaggingUri
Returns a new instance of GoogleCloudAiplatformV1GroundingMetadataSourceFlaggingUri.
17616 17617 17618 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17616 def initialize(**args) update!(**args) end |
Instance Attribute Details
#flag_content_uri ⇒ String
The URI that can be used to flag the content.
Corresponds to the JSON property flagContentUri
17609 17610 17611 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17609 def flag_content_uri @flag_content_uri end |
#source_id ⇒ String
The ID of the place or review.
Corresponds to the JSON property sourceId
17614 17615 17616 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17614 def source_id @source_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17621 17622 17623 17624 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17621 def update!(**args) @flag_content_uri = args[:flag_content_uri] if args.key?(:flag_content_uri) @source_id = args[:source_id] if args.key?(:source_id) end |