Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingMetadataSourceFlaggingUri
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingMetadataSourceFlaggingUri
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A URI that can be used to flag a place or review for inappropriate content. This is populated only when the grounding source is Google Maps.
Instance Attribute Summary collapse
-
#flag_content_uri ⇒ String
The URI that can be used to flag the content.
-
#source_id ⇒ String
The ID of the place or review.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingMetadataSourceFlaggingUri
constructor
A new instance of GoogleCloudAiplatformV1GroundingMetadataSourceFlaggingUri.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingMetadataSourceFlaggingUri
Returns a new instance of GoogleCloudAiplatformV1GroundingMetadataSourceFlaggingUri.
16778 16779 16780 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16778 def initialize(**args) update!(**args) end |
Instance Attribute Details
#flag_content_uri ⇒ String
The URI that can be used to flag the content.
Corresponds to the JSON property flagContentUri
16771 16772 16773 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16771 def flag_content_uri @flag_content_uri end |
#source_id ⇒ String
The ID of the place or review.
Corresponds to the JSON property sourceId
16776 16777 16778 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16776 def source_id @source_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16783 16784 16785 16786 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16783 def update!(**args) @flag_content_uri = args[:flag_content_uri] if args.key?(:flag_content_uri) @source_id = args[:source_id] if args.key?(:source_id) end |