Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingSupport
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingSupport
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A collection of supporting references for a segment of the model's response.
Instance Attribute Summary collapse
-
#confidence_scores ⇒ Array<Float>
The confidence scores for the support references.
-
#grounding_chunk_indices ⇒ Array<Fixnum>
A list of indices into the
grounding_chunksfield of theGroundingMetadatamessage. -
#segment ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Segment
A segment of the content.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingSupport
constructor
A new instance of GoogleCloudAiplatformV1GroundingSupport.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingSupport
Returns a new instance of GoogleCloudAiplatformV1GroundingSupport.
16817 16818 16819 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16817 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence_scores ⇒ Array<Float>
The confidence scores for the support references. This list is parallel to the
grounding_chunk_indices list. A score is a value between 0.0 and 1.0, with a
higher score indicating a higher confidence that the reference supports the
claim. For Gemini 2.0 and before, this list has the same size as
grounding_chunk_indices. For Gemini 2.5 and later, this list is empty and
should be ignored.
Corresponds to the JSON property confidenceScores
16801 16802 16803 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16801 def confidence_scores @confidence_scores end |
#grounding_chunk_indices ⇒ Array<Fixnum>
A list of indices into the grounding_chunks field of the GroundingMetadata
message. These indices specify which grounding chunks support the claim made
in the content segment. For example, if this field has the values [1, 3], it
means that grounding_chunks[1] and grounding_chunks[3] are the sources for
the claim in the content segment.
Corresponds to the JSON property groundingChunkIndices
16810 16811 16812 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16810 def grounding_chunk_indices @grounding_chunk_indices end |
#segment ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Segment
A segment of the content.
Corresponds to the JSON property segment
16815 16816 16817 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16815 def segment @segment end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16822 16823 16824 16825 16826 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16822 def update!(**args) @confidence_scores = args[:confidence_scores] if args.key?(:confidence_scores) @grounding_chunk_indices = args[:grounding_chunk_indices] if args.key?(:grounding_chunk_indices) @segment = args[:segment] if args.key?(:segment) end |