Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GroundingSupport

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A collection of supporting references for a segment of the model's response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1GroundingSupport

Returns a new instance of GoogleCloudAiplatformV1GroundingSupport.



16616
16617
16618
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16616

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidence_scoresArray<Float>

The confidence scores for the support references. This list is parallel to the grounding_chunk_indices list. A score is a value between 0.0 and 1.0, with a higher score indicating a higher confidence that the reference supports the claim. For Gemini 2.0 and before, this list has the same size as grounding_chunk_indices. For Gemini 2.5 and later, this list is empty and should be ignored. Corresponds to the JSON property confidenceScores

Returns:

  • (Array<Float>)


16600
16601
16602
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16600

def confidence_scores
  @confidence_scores
end

#grounding_chunk_indicesArray<Fixnum>

A list of indices into the grounding_chunks field of the GroundingMetadata message. These indices specify which grounding chunks support the claim made in the content segment. For example, if this field has the values [1, 3], it means that grounding_chunks[1] and grounding_chunks[3] are the sources for the claim in the content segment. Corresponds to the JSON property groundingChunkIndices

Returns:

  • (Array<Fixnum>)


16609
16610
16611
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16609

def grounding_chunk_indices
  @grounding_chunk_indices
end

#segmentGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Segment

A segment of the content. Corresponds to the JSON property segment



16614
16615
16616
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16614

def segment
  @segment
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16621
16622
16623
16624
16625
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16621

def update!(**args)
  @confidence_scores = args[:confidence_scores] if args.key?(:confidence_scores)
  @grounding_chunk_indices = args[:grounding_chunk_indices] if args.key?(:grounding_chunk_indices)
  @segment = args[:segment] if args.key?(:segment)
end