Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1HyperparameterTuningJob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents a HyperparameterTuningJob. A HyperparameterTuningJob has a Study specification and multiple CustomJobs with identical CustomJob specification.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1HyperparameterTuningJob

Returns a new instance of GoogleCloudAiplatformV1HyperparameterTuningJob.



16942
16943
16944
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16942

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Time when the HyperparameterTuningJob was created. Corresponds to the JSON property createTime

Returns:

  • (String)


16837
16838
16839
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16837

def create_time
  @create_time
end

#display_nameString

Required. The display name of the HyperparameterTuningJob. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


16843
16844
16845
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16843

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



16849
16850
16851
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16849

def encryption_spec
  @encryption_spec
end

#end_timeString

Output only. Time when the HyperparameterTuningJob entered any of the following states: JOB_STATE_SUCCEEDED, JOB_STATE_FAILED, JOB_STATE_CANCELLED. Corresponds to the JSON property endTime

Returns:

  • (String)


16856
16857
16858
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16856

def end_time
  @end_time
end

#errorGoogle::Apis::AiplatformV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



16866
16867
16868
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16866

def error
  @error
end

#labelsHash<String,String>

The labels with user-defined metadata to organize HyperparameterTuningJobs. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


16875
16876
16877
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16875

def labels
  @labels
end

#max_failed_trial_countFixnum

The number of failed Trials that need to be seen before failing the HyperparameterTuningJob. If set to 0, Vertex AI decides how many Trials must fail before the whole job fails. Corresponds to the JSON property maxFailedTrialCount

Returns:

  • (Fixnum)


16882
16883
16884
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16882

def max_failed_trial_count
  @max_failed_trial_count
end

#max_trial_countFixnum

Required. The desired total number of Trials. Corresponds to the JSON property maxTrialCount

Returns:

  • (Fixnum)


16887
16888
16889
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16887

def max_trial_count
  @max_trial_count
end

#nameString

Output only. Resource name of the HyperparameterTuningJob. Corresponds to the JSON property name

Returns:

  • (String)


16892
16893
16894
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16892

def name
  @name
end

#parallel_trial_countFixnum

Required. The desired number of Trials to run in parallel. Corresponds to the JSON property parallelTrialCount

Returns:

  • (Fixnum)


16897
16898
16899
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16897

def parallel_trial_count
  @parallel_trial_count
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


16902
16903
16904
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16902

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


16908
16909
16910
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16908

def satisfies_pzs
  @satisfies_pzs
end

#start_timeString

Output only. Time when the HyperparameterTuningJob for the first time entered the JOB_STATE_RUNNING state. Corresponds to the JSON property startTime

Returns:

  • (String)


16915
16916
16917
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16915

def start_time
  @start_time
end

#stateString

Output only. The detailed state of the job. Corresponds to the JSON property state

Returns:

  • (String)


16920
16921
16922
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16920

def state
  @state
end

#study_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpec

Represents specification of a Study. Corresponds to the JSON property studySpec



16925
16926
16927
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16925

def study_spec
  @study_spec
end

#trial_job_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1CustomJobSpec

Represents the spec of a CustomJob. Corresponds to the JSON property trialJobSpec



16930
16931
16932
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16930

def trial_job_spec
  @trial_job_spec
end

#trialsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Trial>

Output only. Trials of the HyperparameterTuningJob. Corresponds to the JSON property trials



16935
16936
16937
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16935

def trials
  @trials
end

#update_timeString

Output only. Time when the HyperparameterTuningJob was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


16940
16941
16942
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16940

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16947
16948
16949
16950
16951
16952
16953
16954
16955
16956
16957
16958
16959
16960
16961
16962
16963
16964
16965
16966
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16947

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @end_time = args[:end_time] if args.key?(:end_time)
  @error = args[:error] if args.key?(:error)
  @labels = args[:labels] if args.key?(:labels)
  @max_failed_trial_count = args[:max_failed_trial_count] if args.key?(:max_failed_trial_count)
  @max_trial_count = args[:max_trial_count] if args.key?(:max_trial_count)
  @name = args[:name] if args.key?(:name)
  @parallel_trial_count = args[:parallel_trial_count] if args.key?(:parallel_trial_count)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @study_spec = args[:study_spec] if args.key?(:study_spec)
  @trial_job_spec = args[:trial_job_spec] if args.key?(:trial_job_spec)
  @trials = args[:trials] if args.key?(:trials)
  @update_time = args[:update_time] if args.key?(:update_time)
end