Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1HyperparameterTuningJob
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1HyperparameterTuningJob
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Represents a HyperparameterTuningJob. A HyperparameterTuningJob has a Study specification and multiple CustomJobs with identical CustomJob specification.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Required.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top- level resource.
-
#end_time ⇒ String
Output only.
-
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize HyperparameterTuningJobs.
-
#max_failed_trial_count ⇒ Fixnum
The number of failed Trials that need to be seen before failing the HyperparameterTuningJob.
-
#max_trial_count ⇒ Fixnum
Required.
-
#name ⇒ String
Output only.
-
#parallel_trial_count ⇒ Fixnum
Required.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#study_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpec
Represents specification of a Study.
-
#trial_job_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CustomJobSpec
Represents the spec of a CustomJob.
-
#trials ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Trial>
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1HyperparameterTuningJob
constructor
A new instance of GoogleCloudAiplatformV1HyperparameterTuningJob.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1HyperparameterTuningJob
Returns a new instance of GoogleCloudAiplatformV1HyperparameterTuningJob.
13967 13968 13969 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13967 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Time when the HyperparameterTuningJob was created.
Corresponds to the JSON property createTime
13862 13863 13864 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13862 def create_time @create_time end |
#display_name ⇒ String
Required. The display name of the HyperparameterTuningJob. The name can be up
to 128 characters long and can consist of any UTF-8 characters.
Corresponds to the JSON property displayName
13868 13869 13870 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13868 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top-
level resource.
Corresponds to the JSON property encryptionSpec
13874 13875 13876 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13874 def encryption_spec @encryption_spec end |
#end_time ⇒ String
Output only. Time when the HyperparameterTuningJob entered any of the
following states: JOB_STATE_SUCCEEDED, JOB_STATE_FAILED,
JOB_STATE_CANCELLED.
Corresponds to the JSON property endTime
13881 13882 13883 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13881 def end_time @end_time end |
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
13891 13892 13893 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13891 def error @error end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize HyperparameterTuningJobs.
Label keys and values can be no longer than 64 characters (Unicode codepoints),
can only contain lowercase letters, numeric characters, underscores and
dashes. International characters are allowed. See https://goo.gl/xmQnxf for
more information and examples of labels.
Corresponds to the JSON property labels
13900 13901 13902 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13900 def labels @labels end |
#max_failed_trial_count ⇒ Fixnum
The number of failed Trials that need to be seen before failing the
HyperparameterTuningJob. If set to 0, Vertex AI decides how many Trials must
fail before the whole job fails.
Corresponds to the JSON property maxFailedTrialCount
13907 13908 13909 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13907 def max_failed_trial_count @max_failed_trial_count end |
#max_trial_count ⇒ Fixnum
Required. The desired total number of Trials.
Corresponds to the JSON property maxTrialCount
13912 13913 13914 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13912 def max_trial_count @max_trial_count end |
#name ⇒ String
Output only. Resource name of the HyperparameterTuningJob.
Corresponds to the JSON property name
13917 13918 13919 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13917 def name @name end |
#parallel_trial_count ⇒ Fixnum
Required. The desired number of Trials to run in parallel.
Corresponds to the JSON property parallelTrialCount
13922 13923 13924 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13922 def parallel_trial_count @parallel_trial_count end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
13927 13928 13929 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13927 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
13933 13934 13935 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13933 def satisfies_pzs @satisfies_pzs end |
#start_time ⇒ String
Output only. Time when the HyperparameterTuningJob for the first time entered
the JOB_STATE_RUNNING state.
Corresponds to the JSON property startTime
13940 13941 13942 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13940 def start_time @start_time end |
#state ⇒ String
Output only. The detailed state of the job.
Corresponds to the JSON property state
13945 13946 13947 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13945 def state @state end |
#study_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpec
Represents specification of a Study.
Corresponds to the JSON property studySpec
13950 13951 13952 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13950 def study_spec @study_spec end |
#trial_job_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CustomJobSpec
Represents the spec of a CustomJob.
Corresponds to the JSON property trialJobSpec
13955 13956 13957 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13955 def trial_job_spec @trial_job_spec end |
#trials ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Trial>
Output only. Trials of the HyperparameterTuningJob.
Corresponds to the JSON property trials
13960 13961 13962 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13960 def trials @trials end |
#update_time ⇒ String
Output only. Time when the HyperparameterTuningJob was most recently updated.
Corresponds to the JSON property updateTime
13965 13966 13967 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13965 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13972 13973 13974 13975 13976 13977 13978 13979 13980 13981 13982 13983 13984 13985 13986 13987 13988 13989 13990 13991 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13972 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @end_time = args[:end_time] if args.key?(:end_time) @error = args[:error] if args.key?(:error) @labels = args[:labels] if args.key?(:labels) @max_failed_trial_count = args[:max_failed_trial_count] if args.key?(:max_failed_trial_count) @max_trial_count = args[:max_trial_count] if args.key?(:max_trial_count) @name = args[:name] if args.key?(:name) @parallel_trial_count = args[:parallel_trial_count] if args.key?(:parallel_trial_count) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @study_spec = args[:study_spec] if args.key?(:study_spec) @trial_job_spec = args[:trial_job_spec] if args.key?(:trial_job_spec) @trials = args[:trials] if args.key?(:trials) @update_time = args[:update_time] if args.key?(:update_time) end |