Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1HyperparameterTuningJob
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1HyperparameterTuningJob
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Represents a HyperparameterTuningJob. A HyperparameterTuningJob has a Study specification and multiple CustomJobs with identical CustomJob specification.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Required.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top- level resource.
-
#end_time ⇒ String
Output only.
-
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize HyperparameterTuningJobs.
-
#max_failed_trial_count ⇒ Fixnum
The number of failed Trials that need to be seen before failing the HyperparameterTuningJob.
-
#max_trial_count ⇒ Fixnum
Required.
-
#name ⇒ String
Output only.
-
#parallel_trial_count ⇒ Fixnum
Required.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#study_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpec
Represents specification of a Study.
-
#trial_job_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CustomJobSpec
Represents the spec of a CustomJob.
-
#trials ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Trial>
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1HyperparameterTuningJob
constructor
A new instance of GoogleCloudAiplatformV1HyperparameterTuningJob.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1HyperparameterTuningJob
Returns a new instance of GoogleCloudAiplatformV1HyperparameterTuningJob.
11255 11256 11257 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11255 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Time when the HyperparameterTuningJob was created.
Corresponds to the JSON property createTime
11150 11151 11152 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11150 def create_time @create_time end |
#display_name ⇒ String
Required. The display name of the HyperparameterTuningJob. The name can be up
to 128 characters long and can consist of any UTF-8 characters.
Corresponds to the JSON property displayName
11156 11157 11158 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11156 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top-
level resource.
Corresponds to the JSON property encryptionSpec
11162 11163 11164 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11162 def encryption_spec @encryption_spec end |
#end_time ⇒ String
Output only. Time when the HyperparameterTuningJob entered any of the
following states: JOB_STATE_SUCCEEDED, JOB_STATE_FAILED,
JOB_STATE_CANCELLED.
Corresponds to the JSON property endTime
11169 11170 11171 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11169 def end_time @end_time end |
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
11179 11180 11181 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11179 def error @error end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize HyperparameterTuningJobs.
Label keys and values can be no longer than 64 characters (Unicode codepoints),
can only contain lowercase letters, numeric characters, underscores and
dashes. International characters are allowed. See https://goo.gl/xmQnxf for
more information and examples of labels.
Corresponds to the JSON property labels
11188 11189 11190 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11188 def labels @labels end |
#max_failed_trial_count ⇒ Fixnum
The number of failed Trials that need to be seen before failing the
HyperparameterTuningJob. If set to 0, Vertex AI decides how many Trials must
fail before the whole job fails.
Corresponds to the JSON property maxFailedTrialCount
11195 11196 11197 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11195 def max_failed_trial_count @max_failed_trial_count end |
#max_trial_count ⇒ Fixnum
Required. The desired total number of Trials.
Corresponds to the JSON property maxTrialCount
11200 11201 11202 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11200 def max_trial_count @max_trial_count end |
#name ⇒ String
Output only. Resource name of the HyperparameterTuningJob.
Corresponds to the JSON property name
11205 11206 11207 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11205 def name @name end |
#parallel_trial_count ⇒ Fixnum
Required. The desired number of Trials to run in parallel.
Corresponds to the JSON property parallelTrialCount
11210 11211 11212 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11210 def parallel_trial_count @parallel_trial_count end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
11215 11216 11217 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11215 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
11221 11222 11223 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11221 def satisfies_pzs @satisfies_pzs end |
#start_time ⇒ String
Output only. Time when the HyperparameterTuningJob for the first time entered
the JOB_STATE_RUNNING state.
Corresponds to the JSON property startTime
11228 11229 11230 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11228 def start_time @start_time end |
#state ⇒ String
Output only. The detailed state of the job.
Corresponds to the JSON property state
11233 11234 11235 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11233 def state @state end |
#study_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpec
Represents specification of a Study.
Corresponds to the JSON property studySpec
11238 11239 11240 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11238 def study_spec @study_spec end |
#trial_job_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CustomJobSpec
Represents the spec of a CustomJob.
Corresponds to the JSON property trialJobSpec
11243 11244 11245 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11243 def trial_job_spec @trial_job_spec end |
#trials ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Trial>
Output only. Trials of the HyperparameterTuningJob.
Corresponds to the JSON property trials
11248 11249 11250 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11248 def trials @trials end |
#update_time ⇒ String
Output only. Time when the HyperparameterTuningJob was most recently updated.
Corresponds to the JSON property updateTime
11253 11254 11255 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11253 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11260 11261 11262 11263 11264 11265 11266 11267 11268 11269 11270 11271 11272 11273 11274 11275 11276 11277 11278 11279 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11260 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @end_time = args[:end_time] if args.key?(:end_time) @error = args[:error] if args.key?(:error) @labels = args[:labels] if args.key?(:labels) @max_failed_trial_count = args[:max_failed_trial_count] if args.key?(:max_failed_trial_count) @max_trial_count = args[:max_trial_count] if args.key?(:max_trial_count) @name = args[:name] if args.key?(:name) @parallel_trial_count = args[:parallel_trial_count] if args.key?(:parallel_trial_count) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @study_spec = args[:study_spec] if args.key?(:study_spec) @trial_job_spec = args[:trial_job_spec] if args.key?(:trial_job_spec) @trials = args[:trials] if args.key?(:trials) @update_time = args[:update_time] if args.key?(:update_time) end |