Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1HyperparameterTuningJob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents a HyperparameterTuningJob. A HyperparameterTuningJob has a Study specification and multiple CustomJobs with identical CustomJob specification.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1HyperparameterTuningJob

Returns a new instance of GoogleCloudAiplatformV1HyperparameterTuningJob.



9377
9378
9379
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9377

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Time when the HyperparameterTuningJob was created. Corresponds to the JSON property createTime

Returns:

  • (String)


9284
9285
9286
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9284

def create_time
  @create_time
end

#display_nameString

Required. The display name of the HyperparameterTuningJob. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


9290
9291
9292
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9290

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key spec that can be applied to a top- level resource. Corresponds to the JSON property encryptionSpec



9296
9297
9298
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9296

def encryption_spec
  @encryption_spec
end

#end_timeString

Output only. Time when the HyperparameterTuningJob entered any of the following states: JOB_STATE_SUCCEEDED, JOB_STATE_FAILED, JOB_STATE_CANCELLED. Corresponds to the JSON property endTime

Returns:

  • (String)


9303
9304
9305
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9303

def end_time
  @end_time
end

#errorGoogle::Apis::AiplatformV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



9313
9314
9315
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9313

def error
  @error
end

#labelsHash<String,String>

The labels with user-defined metadata to organize HyperparameterTuningJobs. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


9322
9323
9324
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9322

def labels
  @labels
end

#max_failed_trial_countFixnum

The number of failed Trials that need to be seen before failing the HyperparameterTuningJob. If set to 0, Vertex AI decides how many Trials must fail before the whole job fails. Corresponds to the JSON property maxFailedTrialCount

Returns:

  • (Fixnum)


9329
9330
9331
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9329

def max_failed_trial_count
  @max_failed_trial_count
end

#max_trial_countFixnum

Required. The desired total number of Trials. Corresponds to the JSON property maxTrialCount

Returns:

  • (Fixnum)


9334
9335
9336
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9334

def max_trial_count
  @max_trial_count
end

#nameString

Output only. Resource name of the HyperparameterTuningJob. Corresponds to the JSON property name

Returns:

  • (String)


9339
9340
9341
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9339

def name
  @name
end

#parallel_trial_countFixnum

Required. The desired number of Trials to run in parallel. Corresponds to the JSON property parallelTrialCount

Returns:

  • (Fixnum)


9344
9345
9346
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9344

def parallel_trial_count
  @parallel_trial_count
end

#start_timeString

Output only. Time when the HyperparameterTuningJob for the first time entered the JOB_STATE_RUNNING state. Corresponds to the JSON property startTime

Returns:

  • (String)


9350
9351
9352
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9350

def start_time
  @start_time
end

#stateString

Output only. The detailed state of the job. Corresponds to the JSON property state

Returns:

  • (String)


9355
9356
9357
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9355

def state
  @state
end

#study_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpec

Represents specification of a Study. Corresponds to the JSON property studySpec



9360
9361
9362
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9360

def study_spec
  @study_spec
end

#trial_job_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1CustomJobSpec

Represents the spec of a CustomJob. Corresponds to the JSON property trialJobSpec



9365
9366
9367
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9365

def trial_job_spec
  @trial_job_spec
end

#trialsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Trial>

Output only. Trials of the HyperparameterTuningJob. Corresponds to the JSON property trials



9370
9371
9372
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9370

def trials
  @trials
end

#update_timeString

Output only. Time when the HyperparameterTuningJob was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


9375
9376
9377
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9375

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9382
9383
9384
9385
9386
9387
9388
9389
9390
9391
9392
9393
9394
9395
9396
9397
9398
9399
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 9382

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @end_time = args[:end_time] if args.key?(:end_time)
  @error = args[:error] if args.key?(:error)
  @labels = args[:labels] if args.key?(:labels)
  @max_failed_trial_count = args[:max_failed_trial_count] if args.key?(:max_failed_trial_count)
  @max_trial_count = args[:max_trial_count] if args.key?(:max_trial_count)
  @name = args[:name] if args.key?(:name)
  @parallel_trial_count = args[:parallel_trial_count] if args.key?(:parallel_trial_count)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @study_spec = args[:study_spec] if args.key?(:study_spec)
  @trial_job_spec = args[:trial_job_spec] if args.key?(:trial_job_spec)
  @trials = args[:trials] if args.key?(:trials)
  @update_time = args[:update_time] if args.key?(:update_time)
end