Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ImageConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ImageConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Configuration for image generation. This message allows you to control various aspects of image generation, such as the output format, aspect ratio, and whether the model can generate images of people.
Instance Attribute Summary collapse
-
#aspect_ratio ⇒ String
Optional.
-
#image_output_options ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ImageConfigImageOutputOptions
The image output format for generated images.
-
#image_size ⇒ String
Optional.
-
#person_generation ⇒ String
Optional.
-
#prominent_people ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ImageConfig
constructor
A new instance of GoogleCloudAiplatformV1ImageConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ImageConfig
Returns a new instance of GoogleCloudAiplatformV1ImageConfig.
19724 19725 19726 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19724 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aspect_ratio ⇒ String
Optional. The desired aspect ratio for the generated images. The following
aspect ratios are supported: "1:1" "2:3", "3:2" "3:4", "4:3" "4:5", "5:4" "9:
16", "16:9" "21:9"
Corresponds to the JSON property aspectRatio
19697 19698 19699 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19697 def aspect_ratio @aspect_ratio end |
#image_output_options ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ImageConfigImageOutputOptions
The image output format for generated images.
Corresponds to the JSON property imageOutputOptions
19702 19703 19704 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19702 def @image_output_options end |
#image_size ⇒ String
Optional. Specifies the size of generated images. Supported values are 1K,
2K, 4K. If not specified, the model will use default value 1K.
Corresponds to the JSON property imageSize
19708 19709 19710 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19708 def image_size @image_size end |
#person_generation ⇒ String
Optional. Controls whether the model can generate people.
Corresponds to the JSON property personGeneration
19713 19714 19715 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19713 def person_generation @person_generation end |
#prominent_people ⇒ String
Optional. Controls whether prominent people (celebrities) generation is
allowed. If used with personGeneration, personGeneration enum would take
precedence. For instance, if ALLOW_NONE is set, all person generation would be
blocked. If this field is unspecified, the default behavior is to allow
prominent people.
Corresponds to the JSON property prominentPeople
19722 19723 19724 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19722 def prominent_people @prominent_people end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19729 19730 19731 19732 19733 19734 19735 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19729 def update!(**args) @aspect_ratio = args[:aspect_ratio] if args.key?(:aspect_ratio) @image_output_options = args[:image_output_options] if args.key?(:image_output_options) @image_size = args[:image_size] if args.key?(:image_size) @person_generation = args[:person_generation] if args.key?(:person_generation) @prominent_people = args[:prominent_people] if args.key?(:prominent_people) end |