Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ImageConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ImageConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Configuration for image generation. This message allows you to control various aspects of image generation, such as the output format, aspect ratio, and whether the model can generate images of people.
Instance Attribute Summary collapse
-
#aspect_ratio ⇒ String
Optional.
-
#image_output_options ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ImageConfigImageOutputOptions
The image output format for generated images.
-
#image_size ⇒ String
Optional.
-
#person_generation ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ImageConfig
constructor
A new instance of GoogleCloudAiplatformV1ImageConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ImageConfig
Returns a new instance of GoogleCloudAiplatformV1ImageConfig.
17020 17021 17022 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17020 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aspect_ratio ⇒ String
Optional. The desired aspect ratio for the generated images. The following
aspect ratios are supported: "1:1" "2:3", "3:2" "3:4", "4:3" "4:5", "5:4" "9:
16", "16:9" "21:9"
Corresponds to the JSON property aspectRatio
17002 17003 17004 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17002 def aspect_ratio @aspect_ratio end |
#image_output_options ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ImageConfigImageOutputOptions
The image output format for generated images.
Corresponds to the JSON property imageOutputOptions
17007 17008 17009 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17007 def @image_output_options end |
#image_size ⇒ String
Optional. Specifies the size of generated images. Supported values are 1K,
2K, 4K. If not specified, the model will use default value 1K.
Corresponds to the JSON property imageSize
17013 17014 17015 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17013 def image_size @image_size end |
#person_generation ⇒ String
Optional. Controls whether the model can generate people.
Corresponds to the JSON property personGeneration
17018 17019 17020 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17018 def person_generation @person_generation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17025 17026 17027 17028 17029 17030 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17025 def update!(**args) @aspect_ratio = args[:aspect_ratio] if args.key?(:aspect_ratio) @image_output_options = args[:image_output_options] if args.key?(:image_output_options) @image_size = args[:image_size] if args.key?(:image_size) @person_generation = args[:person_generation] if args.key?(:person_generation) end |