Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ImageConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Configuration for image generation. This message allows you to control various aspects of image generation, such as the output format, aspect ratio, and whether the model can generate images of people.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ImageConfig

Returns a new instance of GoogleCloudAiplatformV1ImageConfig.



16819
16820
16821
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16819

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aspect_ratioString

Optional. The desired aspect ratio for the generated images. The following aspect ratios are supported: "1:1" "2:3", "3:2" "3:4", "4:3" "4:5", "5:4" "9: 16", "16:9" "21:9" Corresponds to the JSON property aspectRatio

Returns:

  • (String)


16801
16802
16803
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16801

def aspect_ratio
  @aspect_ratio
end

#image_output_optionsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ImageConfigImageOutputOptions

The image output format for generated images. Corresponds to the JSON property imageOutputOptions



16806
16807
16808
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16806

def image_output_options
  @image_output_options
end

#image_sizeString

Optional. Specifies the size of generated images. Supported values are 1K, 2K, 4K. If not specified, the model will use default value 1K. Corresponds to the JSON property imageSize

Returns:

  • (String)


16812
16813
16814
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16812

def image_size
  @image_size
end

#person_generationString

Optional. Controls whether the model can generate people. Corresponds to the JSON property personGeneration

Returns:

  • (String)


16817
16818
16819
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16817

def person_generation
  @person_generation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16824
16825
16826
16827
16828
16829
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16824

def update!(**args)
  @aspect_ratio = args[:aspect_ratio] if args.key?(:aspect_ratio)
  @image_output_options = args[:image_output_options] if args.key?(:image_output_options)
  @image_size = args[:image_size] if args.key?(:image_size)
  @person_generation = args[:person_generation] if args.key?(:person_generation)
end