Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ImportDataConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ImportDataConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Describes the location from where we import data into a Dataset, together with the labels that will be applied to the DataItems and the Annotations.
Instance Attribute Summary collapse
-
#annotation_labels ⇒ Hash<String,String>
Labels that will be applied to newly imported Annotations.
-
#data_item_labels ⇒ Hash<String,String>
Labels that will be applied to newly imported DataItems.
-
#gcs_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsSource
The Google Cloud Storage location for the input content.
-
#import_schema_uri ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ImportDataConfig
constructor
A new instance of GoogleCloudAiplatformV1ImportDataConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ImportDataConfig
Returns a new instance of GoogleCloudAiplatformV1ImportDataConfig.
17956 17957 17958 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17956 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotation_labels ⇒ Hash<String,String>
Labels that will be applied to newly imported Annotations. If two Annotations
are identical, one of them will be deduped. Two Annotations are considered
identical if their payload, payload_schema_uri and all of their labels are the
same. These labels will be overridden by Annotation labels specified inside
index file referenced by import_schema_uri, e.g. jsonl file.
Corresponds to the JSON property annotationLabels
17927 17928 17929 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17927 def annotation_labels @annotation_labels end |
#data_item_labels ⇒ Hash<String,String>
Labels that will be applied to newly imported DataItems. If an identical
DataItem as one being imported already exists in the Dataset, then these
labels will be appended to these of the already existing one, and if labels
with identical key is imported before, the old label value will be overwritten.
If two DataItems are identical in the same import data operation, the labels
will be combined and if key collision happens in this case, one of the values
will be picked randomly. Two DataItems are considered identical if their
content bytes are identical (e.g. image bytes or pdf bytes). These labels will
be overridden by Annotation labels specified inside index file referenced by
import_schema_uri, e.g. jsonl file.
Corresponds to the JSON property dataItemLabels
17941 17942 17943 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17941 def data_item_labels @data_item_labels end |
#gcs_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsSource
The Google Cloud Storage location for the input content.
Corresponds to the JSON property gcsSource
17946 17947 17948 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17946 def gcs_source @gcs_source end |
#import_schema_uri ⇒ String
Required. Points to a YAML file stored on Google Cloud Storage describing the
import format. Validation will be done against the schema. The schema is
defined as an OpenAPI 3.0.2 Schema Object.
Corresponds to the JSON property importSchemaUri
17954 17955 17956 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17954 def import_schema_uri @import_schema_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17961 17962 17963 17964 17965 17966 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17961 def update!(**args) @annotation_labels = args[:annotation_labels] if args.key?(:annotation_labels) @data_item_labels = args[:data_item_labels] if args.key?(:data_item_labels) @gcs_source = args[:gcs_source] if args.key?(:gcs_source) @import_schema_uri = args[:import_schema_uri] if args.key?(:import_schema_uri) end |