Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ImportEvaluationSetRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for EvaluationManagementService.ImportEvaluationSet.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ImportEvaluationSetRequest

Returns a new instance of GoogleCloudAiplatformV1ImportEvaluationSetRequest.



19953
19954
19955
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19953

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_engine_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ImportEvaluationSetRequestAgentEngineSource

Source for loading Agent Engine sessions. Corresponds to the JSON property agentEngineSource



19913
19914
19915
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19913

def agent_engine_source
  @agent_engine_source
end

#bigquery_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQueryRequestSet

The request set for the evaluation run. Corresponds to the JSON property bigquerySource



19918
19919
19920
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19918

def bigquery_source
  @bigquery_source
end

#cloud_trace_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ImportEvaluationSetRequestCloudTraceSource

Source for loading traces directly from Cloud Trace. Corresponds to the JSON property cloudTraceSource



19923
19924
19925
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19923

def cloud_trace_source
  @cloud_trace_source
end

#evaluation_setGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationSet

EvaluationSet is a collection of related EvaluationItems that are evaluated together. Corresponds to the JSON property evaluationSet



19929
19930
19931
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19929

def evaluation_set
  @evaluation_set
end

#gcs_destinationGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsDestination

The Google Cloud Storage location where the output is to be written to. Corresponds to the JSON property gcsDestination



19934
19935
19936
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19934

def gcs_destination
  @gcs_destination
end

#gcs_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ImportEvaluationSetRequestGcsSource

Source for loading data from Cloud Storage. Corresponds to the JSON property gcsSource



19939
19940
19941
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19939

def gcs_source
  @gcs_source
end

#inline_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ImportEvaluationSetRequestInlineSource

Wrapper for inline data. Corresponds to the JSON property inlineSource



19944
19945
19946
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19944

def inline_source
  @inline_source
end

#interactions_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ImportEvaluationSetRequestInteractionsSource

Source for importing interactions from the Interactions API into an EvaluationSet. The agent identity is specified once, with a list of interaction IDs to import. Corresponds to the JSON property interactionsSource



19951
19952
19953
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19951

def interactions_source
  @interactions_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19958
19959
19960
19961
19962
19963
19964
19965
19966
19967
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19958

def update!(**args)
  @agent_engine_source = args[:agent_engine_source] if args.key?(:agent_engine_source)
  @bigquery_source = args[:bigquery_source] if args.key?(:bigquery_source)
  @cloud_trace_source = args[:cloud_trace_source] if args.key?(:cloud_trace_source)
  @evaluation_set = args[:evaluation_set] if args.key?(:evaluation_set)
  @gcs_destination = args[:gcs_destination] if args.key?(:gcs_destination)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @inline_source = args[:inline_source] if args.key?(:inline_source)
  @interactions_source = args[:interactions_source] if args.key?(:interactions_source)
end