Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ImportEvaluationSetRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ImportEvaluationSetRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Request message for EvaluationManagementService.ImportEvaluationSet.
Instance Attribute Summary collapse
-
#agent_engine_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ImportEvaluationSetRequestAgentEngineSource
Source for loading Agent Engine sessions.
-
#bigquery_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQueryRequestSet
The request set for the evaluation run.
-
#cloud_trace_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ImportEvaluationSetRequestCloudTraceSource
Source for loading traces directly from Cloud Trace.
-
#evaluation_set ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationSet
EvaluationSet is a collection of related EvaluationItems that are evaluated together.
-
#gcs_destination ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsDestination
The Google Cloud Storage location where the output is to be written to.
-
#gcs_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ImportEvaluationSetRequestGcsSource
Source for loading data from Cloud Storage.
-
#inline_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ImportEvaluationSetRequestInlineSource
Wrapper for inline data.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ImportEvaluationSetRequest
constructor
A new instance of GoogleCloudAiplatformV1ImportEvaluationSetRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ImportEvaluationSetRequest
Returns a new instance of GoogleCloudAiplatformV1ImportEvaluationSetRequest.
18825 18826 18827 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18825 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_engine_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ImportEvaluationSetRequestAgentEngineSource
Source for loading Agent Engine sessions.
Corresponds to the JSON property agentEngineSource
18792 18793 18794 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18792 def agent_engine_source @agent_engine_source end |
#bigquery_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQueryRequestSet
The request set for the evaluation run.
Corresponds to the JSON property bigquerySource
18797 18798 18799 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18797 def bigquery_source @bigquery_source end |
#cloud_trace_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ImportEvaluationSetRequestCloudTraceSource
Source for loading traces directly from Cloud Trace.
Corresponds to the JSON property cloudTraceSource
18802 18803 18804 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18802 def cloud_trace_source @cloud_trace_source end |
#evaluation_set ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluationSet
EvaluationSet is a collection of related EvaluationItems that are evaluated
together.
Corresponds to the JSON property evaluationSet
18808 18809 18810 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18808 def evaluation_set @evaluation_set end |
#gcs_destination ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsDestination
The Google Cloud Storage location where the output is to be written to.
Corresponds to the JSON property gcsDestination
18813 18814 18815 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18813 def gcs_destination @gcs_destination end |
#gcs_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ImportEvaluationSetRequestGcsSource
Source for loading data from Cloud Storage.
Corresponds to the JSON property gcsSource
18818 18819 18820 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18818 def gcs_source @gcs_source end |
#inline_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ImportEvaluationSetRequestInlineSource
Wrapper for inline data.
Corresponds to the JSON property inlineSource
18823 18824 18825 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18823 def inline_source @inline_source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18830 18831 18832 18833 18834 18835 18836 18837 18838 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18830 def update!(**args) @agent_engine_source = args[:agent_engine_source] if args.key?(:agent_engine_source) @bigquery_source = args[:bigquery_source] if args.key?(:bigquery_source) @cloud_trace_source = args[:cloud_trace_source] if args.key?(:cloud_trace_source) @evaluation_set = args[:evaluation_set] if args.key?(:evaluation_set) @gcs_destination = args[:gcs_destination] if args.key?(:gcs_destination) @gcs_source = args[:gcs_source] if args.key?(:gcs_source) @inline_source = args[:inline_source] if args.key?(:inline_source) end |