Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ImportFeatureValuesOperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Details of operations that perform import Feature values.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ImportFeatureValuesOperationMetadata

Returns a new instance of GoogleCloudAiplatformV1ImportFeatureValuesOperationMetadata.



13399
13400
13401
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13399

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blocking_operation_idsArray<Fixnum>

List of ImportFeatureValues operations running under a single EntityType that are blocking this operation. Corresponds to the JSON property blockingOperationIds

Returns:

  • (Array<Fixnum>)


13364
13365
13366
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13364

def blocking_operation_ids
  @blocking_operation_ids
end

#generic_metadataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GenericOperationMetadata

Generic Metadata shared by all operations. Corresponds to the JSON property genericMetadata



13369
13370
13371
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13369

def 
  @generic_metadata
end

#imported_entity_countFixnum

Number of entities that have been imported by the operation. Corresponds to the JSON property importedEntityCount

Returns:

  • (Fixnum)


13374
13375
13376
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13374

def imported_entity_count
  @imported_entity_count
end

#imported_feature_value_countFixnum

Number of Feature values that have been imported by the operation. Corresponds to the JSON property importedFeatureValueCount

Returns:

  • (Fixnum)


13379
13380
13381
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13379

def imported_feature_value_count
  @imported_feature_value_count
end

#invalid_row_countFixnum

The number of rows in input source that weren't imported due to either * Not having any featureValues. * Having a null entityId. * Having a null timestamp.

  • Not being parsable (applicable for CSV sources). Corresponds to the JSON property invalidRowCount

Returns:

  • (Fixnum)


13386
13387
13388
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13386

def invalid_row_count
  @invalid_row_count
end

#source_urisArray<String>

The source URI from where Feature values are imported. Corresponds to the JSON property sourceUris

Returns:

  • (Array<String>)


13391
13392
13393
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13391

def source_uris
  @source_uris
end

#timestamp_outside_retention_rows_countFixnum

The number rows that weren't ingested due to having timestamps outside the retention boundary. Corresponds to the JSON property timestampOutsideRetentionRowsCount

Returns:

  • (Fixnum)


13397
13398
13399
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13397

def timestamp_outside_retention_rows_count
  @timestamp_outside_retention_rows_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13404
13405
13406
13407
13408
13409
13410
13411
13412
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13404

def update!(**args)
  @blocking_operation_ids = args[:blocking_operation_ids] if args.key?(:blocking_operation_ids)
  @generic_metadata = args[:generic_metadata] if args.key?(:generic_metadata)
  @imported_entity_count = args[:imported_entity_count] if args.key?(:imported_entity_count)
  @imported_feature_value_count = args[:imported_feature_value_count] if args.key?(:imported_feature_value_count)
  @invalid_row_count = args[:invalid_row_count] if args.key?(:invalid_row_count)
  @source_uris = args[:source_uris] if args.key?(:source_uris)
  @timestamp_outside_retention_rows_count = args[:timestamp_outside_retention_rows_count] if args.key?(:timestamp_outside_retention_rows_count)
end