Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ImportFeatureValuesOperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Details of operations that perform import Feature values.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ImportFeatureValuesOperationMetadata

Returns a new instance of GoogleCloudAiplatformV1ImportFeatureValuesOperationMetadata.



12867
12868
12869
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12867

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blocking_operation_idsArray<Fixnum>

List of ImportFeatureValues operations running under a single EntityType that are blocking this operation. Corresponds to the JSON property blockingOperationIds

Returns:

  • (Array<Fixnum>)


12832
12833
12834
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12832

def blocking_operation_ids
  @blocking_operation_ids
end

#generic_metadataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GenericOperationMetadata

Generic Metadata shared by all operations. Corresponds to the JSON property genericMetadata



12837
12838
12839
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12837

def 
  @generic_metadata
end

#imported_entity_countFixnum

Number of entities that have been imported by the operation. Corresponds to the JSON property importedEntityCount

Returns:

  • (Fixnum)


12842
12843
12844
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12842

def imported_entity_count
  @imported_entity_count
end

#imported_feature_value_countFixnum

Number of Feature values that have been imported by the operation. Corresponds to the JSON property importedFeatureValueCount

Returns:

  • (Fixnum)


12847
12848
12849
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12847

def imported_feature_value_count
  @imported_feature_value_count
end

#invalid_row_countFixnum

The number of rows in input source that weren't imported due to either * Not having any featureValues. * Having a null entityId. * Having a null timestamp.

  • Not being parsable (applicable for CSV sources). Corresponds to the JSON property invalidRowCount

Returns:

  • (Fixnum)


12854
12855
12856
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12854

def invalid_row_count
  @invalid_row_count
end

#source_urisArray<String>

The source URI from where Feature values are imported. Corresponds to the JSON property sourceUris

Returns:

  • (Array<String>)


12859
12860
12861
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12859

def source_uris
  @source_uris
end

#timestamp_outside_retention_rows_countFixnum

The number rows that weren't ingested due to having timestamps outside the retention boundary. Corresponds to the JSON property timestampOutsideRetentionRowsCount

Returns:

  • (Fixnum)


12865
12866
12867
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12865

def timestamp_outside_retention_rows_count
  @timestamp_outside_retention_rows_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12872
12873
12874
12875
12876
12877
12878
12879
12880
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12872

def update!(**args)
  @blocking_operation_ids = args[:blocking_operation_ids] if args.key?(:blocking_operation_ids)
  @generic_metadata = args[:generic_metadata] if args.key?(:generic_metadata)
  @imported_entity_count = args[:imported_entity_count] if args.key?(:imported_entity_count)
  @imported_feature_value_count = args[:imported_feature_value_count] if args.key?(:imported_feature_value_count)
  @invalid_row_count = args[:invalid_row_count] if args.key?(:invalid_row_count)
  @source_uris = args[:source_uris] if args.key?(:source_uris)
  @timestamp_outside_retention_rows_count = args[:timestamp_outside_retention_rows_count] if args.key?(:timestamp_outside_retention_rows_count)
end