Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ImportFeatureValuesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for FeaturestoreService.ImportFeatureValues.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ImportFeatureValuesRequest

Returns a new instance of GoogleCloudAiplatformV1ImportFeatureValuesRequest.



18148
18149
18150
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18148

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#avro_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1AvroSource

The storage details for Avro input content. Corresponds to the JSON property avroSource



18087
18088
18089
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18087

def avro_source
  @avro_source
end

#bigquery_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQuerySource

The BigQuery location for the input content. Corresponds to the JSON property bigquerySource



18092
18093
18094
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18092

def bigquery_source
  @bigquery_source
end

#csv_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1CsvSource

The storage details for CSV input content. Corresponds to the JSON property csvSource



18097
18098
18099
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18097

def csv_source
  @csv_source
end

#disable_ingestion_analysisBoolean Also known as: disable_ingestion_analysis?

If true, API doesn't start ingestion analysis pipeline. Corresponds to the JSON property disableIngestionAnalysis

Returns:

  • (Boolean)


18102
18103
18104
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18102

def disable_ingestion_analysis
  @disable_ingestion_analysis
end

#disable_online_servingBoolean Also known as: disable_online_serving?

If set, data will not be imported for online serving. This is typically used for backfilling, where Feature generation timestamps are not in the timestamp range needed for online serving. Corresponds to the JSON property disableOnlineServing

Returns:

  • (Boolean)


18110
18111
18112
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18110

def disable_online_serving
  @disable_online_serving
end

#entity_id_fieldString

Source column that holds entity IDs. If not provided, entity IDs are extracted from the column named entity_id. Corresponds to the JSON property entityIdField

Returns:

  • (String)


18117
18118
18119
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18117

def entity_id_field
  @entity_id_field
end

#feature_specsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ImportFeatureValuesRequestFeatureSpec>

Required. Specifications defining which Feature values to import from the entity. The request fails if no feature_specs are provided, and having multiple feature_specs for one Feature is not allowed. Corresponds to the JSON property featureSpecs



18124
18125
18126
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18124

def feature_specs
  @feature_specs
end

#feature_timeString

Single Feature timestamp for all entities being imported. The timestamp must not have higher than millisecond precision. Corresponds to the JSON property featureTime

Returns:

  • (String)


18130
18131
18132
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18130

def feature_time
  @feature_time
end

#feature_time_fieldString

Source column that holds the Feature timestamp for all Feature values in each entity. Corresponds to the JSON property featureTimeField

Returns:

  • (String)


18136
18137
18138
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18136

def feature_time_field
  @feature_time_field
end

#worker_countFixnum

Specifies the number of workers that are used to write data to the Featurestore. Consider the online serving capacity that you require to achieve the desired import throughput without interfering with online serving. The value must be positive, and less than or equal to 100. If not set, defaults to using 1 worker. The low count ensures minimal impact on online serving performance. Corresponds to the JSON property workerCount

Returns:

  • (Fixnum)


18146
18147
18148
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18146

def worker_count
  @worker_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18153
18154
18155
18156
18157
18158
18159
18160
18161
18162
18163
18164
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18153

def update!(**args)
  @avro_source = args[:avro_source] if args.key?(:avro_source)
  @bigquery_source = args[:bigquery_source] if args.key?(:bigquery_source)
  @csv_source = args[:csv_source] if args.key?(:csv_source)
  @disable_ingestion_analysis = args[:disable_ingestion_analysis] if args.key?(:disable_ingestion_analysis)
  @disable_online_serving = args[:disable_online_serving] if args.key?(:disable_online_serving)
  @entity_id_field = args[:entity_id_field] if args.key?(:entity_id_field)
  @feature_specs = args[:feature_specs] if args.key?(:feature_specs)
  @feature_time = args[:feature_time] if args.key?(:feature_time)
  @feature_time_field = args[:feature_time_field] if args.key?(:feature_time_field)
  @worker_count = args[:worker_count] if args.key?(:worker_count)
end