Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ImportFeatureValuesRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ImportFeatureValuesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Request message for FeaturestoreService.ImportFeatureValues.
Instance Attribute Summary collapse
-
#avro_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AvroSource
The storage details for Avro input content.
-
#bigquery_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQuerySource
The BigQuery location for the input content.
-
#csv_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CsvSource
The storage details for CSV input content.
-
#disable_ingestion_analysis ⇒ Boolean
(also: #disable_ingestion_analysis?)
If true, API doesn't start ingestion analysis pipeline.
-
#disable_online_serving ⇒ Boolean
(also: #disable_online_serving?)
If set, data will not be imported for online serving.
-
#entity_id_field ⇒ String
Source column that holds entity IDs.
-
#feature_specs ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ImportFeatureValuesRequestFeatureSpec>
Required.
-
#feature_time ⇒ String
Single Feature timestamp for all entities being imported.
-
#feature_time_field ⇒ String
Source column that holds the Feature timestamp for all Feature values in each entity.
-
#worker_count ⇒ Fixnum
Specifies the number of workers that are used to write data to the Featurestore.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ImportFeatureValuesRequest
constructor
A new instance of GoogleCloudAiplatformV1ImportFeatureValuesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ImportFeatureValuesRequest
Returns a new instance of GoogleCloudAiplatformV1ImportFeatureValuesRequest.
13483 13484 13485 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13483 def initialize(**args) update!(**args) end |
Instance Attribute Details
#avro_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AvroSource
The storage details for Avro input content.
Corresponds to the JSON property avroSource
13422 13423 13424 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13422 def avro_source @avro_source end |
#bigquery_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQuerySource
The BigQuery location for the input content.
Corresponds to the JSON property bigquerySource
13427 13428 13429 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13427 def bigquery_source @bigquery_source end |
#csv_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CsvSource
The storage details for CSV input content.
Corresponds to the JSON property csvSource
13432 13433 13434 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13432 def csv_source @csv_source end |
#disable_ingestion_analysis ⇒ Boolean Also known as: disable_ingestion_analysis?
If true, API doesn't start ingestion analysis pipeline.
Corresponds to the JSON property disableIngestionAnalysis
13437 13438 13439 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13437 def disable_ingestion_analysis @disable_ingestion_analysis end |
#disable_online_serving ⇒ Boolean Also known as: disable_online_serving?
If set, data will not be imported for online serving. This is typically used
for backfilling, where Feature generation timestamps are not in the timestamp
range needed for online serving.
Corresponds to the JSON property disableOnlineServing
13445 13446 13447 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13445 def disable_online_serving @disable_online_serving end |
#entity_id_field ⇒ String
Source column that holds entity IDs. If not provided, entity IDs are extracted
from the column named entity_id.
Corresponds to the JSON property entityIdField
13452 13453 13454 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13452 def entity_id_field @entity_id_field end |
#feature_specs ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ImportFeatureValuesRequestFeatureSpec>
Required. Specifications defining which Feature values to import from the
entity. The request fails if no feature_specs are provided, and having
multiple feature_specs for one Feature is not allowed.
Corresponds to the JSON property featureSpecs
13459 13460 13461 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13459 def feature_specs @feature_specs end |
#feature_time ⇒ String
Single Feature timestamp for all entities being imported. The timestamp must
not have higher than millisecond precision.
Corresponds to the JSON property featureTime
13465 13466 13467 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13465 def feature_time @feature_time end |
#feature_time_field ⇒ String
Source column that holds the Feature timestamp for all Feature values in each
entity.
Corresponds to the JSON property featureTimeField
13471 13472 13473 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13471 def feature_time_field @feature_time_field end |
#worker_count ⇒ Fixnum
Specifies the number of workers that are used to write data to the
Featurestore. Consider the online serving capacity that you require to achieve
the desired import throughput without interfering with online serving. The
value must be positive, and less than or equal to 100. If not set, defaults to
using 1 worker. The low count ensures minimal impact on online serving
performance.
Corresponds to the JSON property workerCount
13481 13482 13483 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13481 def worker_count @worker_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13488 13489 13490 13491 13492 13493 13494 13495 13496 13497 13498 13499 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13488 def update!(**args) @avro_source = args[:avro_source] if args.key?(:avro_source) @bigquery_source = args[:bigquery_source] if args.key?(:bigquery_source) @csv_source = args[:csv_source] if args.key?(:csv_source) @disable_ingestion_analysis = args[:disable_ingestion_analysis] if args.key?(:disable_ingestion_analysis) @disable_online_serving = args[:disable_online_serving] if args.key?(:disable_online_serving) @entity_id_field = args[:entity_id_field] if args.key?(:entity_id_field) @feature_specs = args[:feature_specs] if args.key?(:feature_specs) @feature_time = args[:feature_time] if args.key?(:feature_time) @feature_time_field = args[:feature_time_field] if args.key?(:feature_time_field) @worker_count = args[:worker_count] if args.key?(:worker_count) end |