Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ImportFeatureValuesResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ImportFeatureValuesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Response message for FeaturestoreService.ImportFeatureValues.
Instance Attribute Summary collapse
-
#imported_entity_count ⇒ Fixnum
Number of entities that have been imported by the operation.
-
#imported_feature_value_count ⇒ Fixnum
Number of Feature values that have been imported by the operation.
-
#invalid_row_count ⇒ Fixnum
The number of rows in input source that weren't imported due to either * Not having any featureValues.
-
#timestamp_outside_retention_rows_count ⇒ Fixnum
The number rows that weren't ingested due to having feature timestamps outside the retention boundary.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ImportFeatureValuesResponse
constructor
A new instance of GoogleCloudAiplatformV1ImportFeatureValuesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ImportFeatureValuesResponse
Returns a new instance of GoogleCloudAiplatformV1ImportFeatureValuesResponse.
14322 14323 14324 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14322 def initialize(**args) update!(**args) end |
Instance Attribute Details
#imported_entity_count ⇒ Fixnum
Number of entities that have been imported by the operation.
Corresponds to the JSON property importedEntityCount
14302 14303 14304 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14302 def imported_entity_count @imported_entity_count end |
#imported_feature_value_count ⇒ Fixnum
Number of Feature values that have been imported by the operation.
Corresponds to the JSON property importedFeatureValueCount
14307 14308 14309 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14307 def imported_feature_value_count @imported_feature_value_count end |
#invalid_row_count ⇒ Fixnum
The number of rows in input source that weren't imported due to either * Not having any featureValues. * Having a null entityId. * Having a null timestamp.
- Not being parsable (applicable for CSV sources).
Corresponds to the JSON property
invalidRowCount
14314 14315 14316 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14314 def invalid_row_count @invalid_row_count end |
#timestamp_outside_retention_rows_count ⇒ Fixnum
The number rows that weren't ingested due to having feature timestamps outside
the retention boundary.
Corresponds to the JSON property timestampOutsideRetentionRowsCount
14320 14321 14322 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14320 def @timestamp_outside_retention_rows_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14327 14328 14329 14330 14331 14332 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14327 def update!(**args) @imported_entity_count = args[:imported_entity_count] if args.key?(:imported_entity_count) @imported_feature_value_count = args[:imported_feature_value_count] if args.key?(:imported_feature_value_count) @invalid_row_count = args[:invalid_row_count] if args.key?(:invalid_row_count) @timestamp_outside_retention_rows_count = args[:timestamp_outside_retention_rows_count] if args.key?(:timestamp_outside_retention_rows_count) end |