Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ImportRagFilesConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ImportRagFilesConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Config for importing RagFiles.
Instance Attribute Summary collapse
-
#gcs_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsSource
The Google Cloud Storage location for the input content.
-
#google_drive_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GoogleDriveSource
The Google Drive location for the input content.
-
#import_result_bigquery_sink ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQueryDestination
The BigQuery location for the output content.
-
#import_result_gcs_sink ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsDestination
The Google Cloud Storage location where the output is to be written to.
-
#jira_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1JiraSource
The Jira source for the ImportRagFilesRequest.
-
#max_embedding_requests_per_min ⇒ Fixnum
Optional.
-
#partial_failure_bigquery_sink ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQueryDestination
The BigQuery location for the output content.
-
#partial_failure_gcs_sink ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsDestination
The Google Cloud Storage location where the output is to be written to.
-
#rag_file_parsing_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagFileParsingConfig
Specifies the parsing config for RagFiles.
-
#rag_file_transformation_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagFileTransformationConfig
Specifies the transformation config for RagFiles.
-
#rebuild_ann_index ⇒ Boolean
(also: #rebuild_ann_index?)
Rebuilds the ANN index to optimize for recall on the imported data.
-
#share_point_sources ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SharePointSources
The SharePointSources to pass to ImportRagFiles.
-
#slack_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SlackSource
The Slack source for the ImportRagFilesRequest.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ImportRagFilesConfig
constructor
A new instance of GoogleCloudAiplatformV1ImportRagFilesConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ImportRagFilesConfig
Returns a new instance of GoogleCloudAiplatformV1ImportRagFilesConfig.
18379 18380 18381 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18379 def initialize(**args) update!(**args) end |
Instance Attribute Details
#gcs_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsSource
The Google Cloud Storage location for the input content.
Corresponds to the JSON property gcsSource
18308 18309 18310 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18308 def gcs_source @gcs_source end |
#google_drive_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GoogleDriveSource
The Google Drive location for the input content.
Corresponds to the JSON property googleDriveSource
18313 18314 18315 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18313 def google_drive_source @google_drive_source end |
#import_result_bigquery_sink ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQueryDestination
The BigQuery location for the output content.
Corresponds to the JSON property importResultBigquerySink
18318 18319 18320 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18318 def import_result_bigquery_sink @import_result_bigquery_sink end |
#import_result_gcs_sink ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsDestination
The Google Cloud Storage location where the output is to be written to.
Corresponds to the JSON property importResultGcsSink
18323 18324 18325 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18323 def import_result_gcs_sink @import_result_gcs_sink end |
#jira_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1JiraSource
The Jira source for the ImportRagFilesRequest.
Corresponds to the JSON property jiraSource
18328 18329 18330 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18328 def jira_source @jira_source end |
#max_embedding_requests_per_min ⇒ Fixnum
Optional. The max number of queries per minute that this job is allowed to
make to the embedding model specified on the corpus. This value is specific to
this job and not shared across other import jobs. Consult the Quotas page on
the project to set an appropriate value here. If unspecified, a default value
of 1,000 QPM would be used.
Corresponds to the JSON property maxEmbeddingRequestsPerMin
18337 18338 18339 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18337 def @max_embedding_requests_per_min end |
#partial_failure_bigquery_sink ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQueryDestination
The BigQuery location for the output content.
Corresponds to the JSON property partialFailureBigquerySink
18342 18343 18344 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18342 def partial_failure_bigquery_sink @partial_failure_bigquery_sink end |
#partial_failure_gcs_sink ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsDestination
The Google Cloud Storage location where the output is to be written to.
Corresponds to the JSON property partialFailureGcsSink
18347 18348 18349 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18347 def partial_failure_gcs_sink @partial_failure_gcs_sink end |
#rag_file_parsing_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagFileParsingConfig
Specifies the parsing config for RagFiles.
Corresponds to the JSON property ragFileParsingConfig
18352 18353 18354 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18352 def rag_file_parsing_config @rag_file_parsing_config end |
#rag_file_transformation_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagFileTransformationConfig
Specifies the transformation config for RagFiles.
Corresponds to the JSON property ragFileTransformationConfig
18357 18358 18359 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18357 def rag_file_transformation_config @rag_file_transformation_config end |
#rebuild_ann_index ⇒ Boolean Also known as: rebuild_ann_index?
Rebuilds the ANN index to optimize for recall on the imported data. Only
applicable for RagCorpora running on RagManagedDb with retrieval_strategy
set to ANN. The rebuild will be performed using the existing ANN config set
on the RagCorpus. To change the ANN config, please use the UpdateRagCorpus API.
Default is false, i.e., index is not rebuilt.
Corresponds to the JSON property rebuildAnnIndex
18366 18367 18368 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18366 def rebuild_ann_index @rebuild_ann_index end |
#share_point_sources ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SharePointSources
The SharePointSources to pass to ImportRagFiles.
Corresponds to the JSON property sharePointSources
18372 18373 18374 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18372 def share_point_sources @share_point_sources end |
#slack_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SlackSource
The Slack source for the ImportRagFilesRequest.
Corresponds to the JSON property slackSource
18377 18378 18379 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18377 def slack_source @slack_source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18384 18385 18386 18387 18388 18389 18390 18391 18392 18393 18394 18395 18396 18397 18398 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18384 def update!(**args) @gcs_source = args[:gcs_source] if args.key?(:gcs_source) @google_drive_source = args[:google_drive_source] if args.key?(:google_drive_source) @import_result_bigquery_sink = args[:import_result_bigquery_sink] if args.key?(:import_result_bigquery_sink) @import_result_gcs_sink = args[:import_result_gcs_sink] if args.key?(:import_result_gcs_sink) @jira_source = args[:jira_source] if args.key?(:jira_source) @max_embedding_requests_per_min = args[:max_embedding_requests_per_min] if args.key?(:max_embedding_requests_per_min) @partial_failure_bigquery_sink = args[:partial_failure_bigquery_sink] if args.key?(:partial_failure_bigquery_sink) @partial_failure_gcs_sink = args[:partial_failure_gcs_sink] if args.key?(:partial_failure_gcs_sink) @rag_file_parsing_config = args[:rag_file_parsing_config] if args.key?(:rag_file_parsing_config) @rag_file_transformation_config = args[:rag_file_transformation_config] if args.key?(:rag_file_transformation_config) @rebuild_ann_index = args[:rebuild_ann_index] if args.key?(:rebuild_ann_index) @share_point_sources = args[:share_point_sources] if args.key?(:share_point_sources) @slack_source = args[:slack_source] if args.key?(:slack_source) end |