Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ImportRagFilesConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Config for importing RagFiles.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ImportRagFilesConfig

Returns a new instance of GoogleCloudAiplatformV1ImportRagFilesConfig.



17475
17476
17477
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17475

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gcs_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsSource

The Google Cloud Storage location for the input content. Corresponds to the JSON property gcsSource



17404
17405
17406
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17404

def gcs_source
  @gcs_source
end

#google_drive_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GoogleDriveSource

The Google Drive location for the input content. Corresponds to the JSON property googleDriveSource



17409
17410
17411
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17409

def google_drive_source
  @google_drive_source
end

#import_result_bigquery_sinkGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQueryDestination

The BigQuery location for the output content. Corresponds to the JSON property importResultBigquerySink



17414
17415
17416
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17414

def import_result_bigquery_sink
  @import_result_bigquery_sink
end

#import_result_gcs_sinkGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsDestination

The Google Cloud Storage location where the output is to be written to. Corresponds to the JSON property importResultGcsSink



17419
17420
17421
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17419

def import_result_gcs_sink
  @import_result_gcs_sink
end

#jira_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1JiraSource

The Jira source for the ImportRagFilesRequest. Corresponds to the JSON property jiraSource



17424
17425
17426
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17424

def jira_source
  @jira_source
end

#max_embedding_requests_per_minFixnum

Optional. The max number of queries per minute that this job is allowed to make to the embedding model specified on the corpus. This value is specific to this job and not shared across other import jobs. Consult the Quotas page on the project to set an appropriate value here. If unspecified, a default value of 1,000 QPM would be used. Corresponds to the JSON property maxEmbeddingRequestsPerMin

Returns:

  • (Fixnum)


17433
17434
17435
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17433

def max_embedding_requests_per_min
  @max_embedding_requests_per_min
end

#partial_failure_bigquery_sinkGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQueryDestination

The BigQuery location for the output content. Corresponds to the JSON property partialFailureBigquerySink



17438
17439
17440
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17438

def partial_failure_bigquery_sink
  @partial_failure_bigquery_sink
end

#partial_failure_gcs_sinkGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsDestination

The Google Cloud Storage location where the output is to be written to. Corresponds to the JSON property partialFailureGcsSink



17443
17444
17445
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17443

def partial_failure_gcs_sink
  @partial_failure_gcs_sink
end

#rag_file_parsing_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RagFileParsingConfig

Specifies the parsing config for RagFiles. Corresponds to the JSON property ragFileParsingConfig



17448
17449
17450
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17448

def rag_file_parsing_config
  @rag_file_parsing_config
end

#rag_file_transformation_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RagFileTransformationConfig

Specifies the transformation config for RagFiles. Corresponds to the JSON property ragFileTransformationConfig



17453
17454
17455
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17453

def rag_file_transformation_config
  @rag_file_transformation_config
end

#rebuild_ann_indexBoolean Also known as: rebuild_ann_index?

Rebuilds the ANN index to optimize for recall on the imported data. Only applicable for RagCorpora running on RagManagedDb with retrieval_strategy set to ANN. The rebuild will be performed using the existing ANN config set on the RagCorpus. To change the ANN config, please use the UpdateRagCorpus API. Default is false, i.e., index is not rebuilt. Corresponds to the JSON property rebuildAnnIndex

Returns:

  • (Boolean)


17462
17463
17464
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17462

def rebuild_ann_index
  @rebuild_ann_index
end

#share_point_sourcesGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SharePointSources

The SharePointSources to pass to ImportRagFiles. Corresponds to the JSON property sharePointSources



17468
17469
17470
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17468

def share_point_sources
  @share_point_sources
end

#slack_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SlackSource

The Slack source for the ImportRagFilesRequest. Corresponds to the JSON property slackSource



17473
17474
17475
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17473

def slack_source
  @slack_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17480
17481
17482
17483
17484
17485
17486
17487
17488
17489
17490
17491
17492
17493
17494
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17480

def update!(**args)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @google_drive_source = args[:google_drive_source] if args.key?(:google_drive_source)
  @import_result_bigquery_sink = args[:import_result_bigquery_sink] if args.key?(:import_result_bigquery_sink)
  @import_result_gcs_sink = args[:import_result_gcs_sink] if args.key?(:import_result_gcs_sink)
  @jira_source = args[:jira_source] if args.key?(:jira_source)
  @max_embedding_requests_per_min = args[:max_embedding_requests_per_min] if args.key?(:max_embedding_requests_per_min)
  @partial_failure_bigquery_sink = args[:partial_failure_bigquery_sink] if args.key?(:partial_failure_bigquery_sink)
  @partial_failure_gcs_sink = args[:partial_failure_gcs_sink] if args.key?(:partial_failure_gcs_sink)
  @rag_file_parsing_config = args[:rag_file_parsing_config] if args.key?(:rag_file_parsing_config)
  @rag_file_transformation_config = args[:rag_file_transformation_config] if args.key?(:rag_file_transformation_config)
  @rebuild_ann_index = args[:rebuild_ann_index] if args.key?(:rebuild_ann_index)
  @share_point_sources = args[:share_point_sources] if args.key?(:share_point_sources)
  @slack_source = args[:slack_source] if args.key?(:slack_source)
end