Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ImportRagFilesConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Config for importing RagFiles.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ImportRagFilesConfig

Returns a new instance of GoogleCloudAiplatformV1ImportRagFilesConfig.



14040
14041
14042
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14040

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gcs_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsSource

The Google Cloud Storage location for the input content. Corresponds to the JSON property gcsSource



13969
13970
13971
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13969

def gcs_source
  @gcs_source
end

#google_drive_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GoogleDriveSource

The Google Drive location for the input content. Corresponds to the JSON property googleDriveSource



13974
13975
13976
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13974

def google_drive_source
  @google_drive_source
end

#import_result_bigquery_sinkGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQueryDestination

The BigQuery location for the output content. Corresponds to the JSON property importResultBigquerySink



13979
13980
13981
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13979

def import_result_bigquery_sink
  @import_result_bigquery_sink
end

#import_result_gcs_sinkGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsDestination

The Google Cloud Storage location where the output is to be written to. Corresponds to the JSON property importResultGcsSink



13984
13985
13986
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13984

def import_result_gcs_sink
  @import_result_gcs_sink
end

#jira_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1JiraSource

The Jira source for the ImportRagFilesRequest. Corresponds to the JSON property jiraSource



13989
13990
13991
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13989

def jira_source
  @jira_source
end

#max_embedding_requests_per_minFixnum

Optional. The max number of queries per minute that this job is allowed to make to the embedding model specified on the corpus. This value is specific to this job and not shared across other import jobs. Consult the Quotas page on the project to set an appropriate value here. If unspecified, a default value of 1,000 QPM would be used. Corresponds to the JSON property maxEmbeddingRequestsPerMin

Returns:

  • (Fixnum)


13998
13999
14000
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13998

def max_embedding_requests_per_min
  @max_embedding_requests_per_min
end

#partial_failure_bigquery_sinkGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQueryDestination

The BigQuery location for the output content. Corresponds to the JSON property partialFailureBigquerySink



14003
14004
14005
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14003

def partial_failure_bigquery_sink
  @partial_failure_bigquery_sink
end

#partial_failure_gcs_sinkGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsDestination

The Google Cloud Storage location where the output is to be written to. Corresponds to the JSON property partialFailureGcsSink



14008
14009
14010
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14008

def partial_failure_gcs_sink
  @partial_failure_gcs_sink
end

#rag_file_parsing_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RagFileParsingConfig

Specifies the parsing config for RagFiles. Corresponds to the JSON property ragFileParsingConfig



14013
14014
14015
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14013

def rag_file_parsing_config
  @rag_file_parsing_config
end

#rag_file_transformation_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RagFileTransformationConfig

Specifies the transformation config for RagFiles. Corresponds to the JSON property ragFileTransformationConfig



14018
14019
14020
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14018

def rag_file_transformation_config
  @rag_file_transformation_config
end

#rebuild_ann_indexBoolean Also known as: rebuild_ann_index?

Rebuilds the ANN index to optimize for recall on the imported data. Only applicable for RagCorpora running on RagManagedDb with retrieval_strategy set to ANN. The rebuild will be performed using the existing ANN config set on the RagCorpus. To change the ANN config, please use the UpdateRagCorpus API. Default is false, i.e., index is not rebuilt. Corresponds to the JSON property rebuildAnnIndex

Returns:

  • (Boolean)


14027
14028
14029
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14027

def rebuild_ann_index
  @rebuild_ann_index
end

#share_point_sourcesGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SharePointSources

The SharePointSources to pass to ImportRagFiles. Corresponds to the JSON property sharePointSources



14033
14034
14035
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14033

def share_point_sources
  @share_point_sources
end

#slack_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SlackSource

The Slack source for the ImportRagFilesRequest. Corresponds to the JSON property slackSource



14038
14039
14040
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14038

def slack_source
  @slack_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14045
14046
14047
14048
14049
14050
14051
14052
14053
14054
14055
14056
14057
14058
14059
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14045

def update!(**args)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @google_drive_source = args[:google_drive_source] if args.key?(:google_drive_source)
  @import_result_bigquery_sink = args[:import_result_bigquery_sink] if args.key?(:import_result_bigquery_sink)
  @import_result_gcs_sink = args[:import_result_gcs_sink] if args.key?(:import_result_gcs_sink)
  @jira_source = args[:jira_source] if args.key?(:jira_source)
  @max_embedding_requests_per_min = args[:max_embedding_requests_per_min] if args.key?(:max_embedding_requests_per_min)
  @partial_failure_bigquery_sink = args[:partial_failure_bigquery_sink] if args.key?(:partial_failure_bigquery_sink)
  @partial_failure_gcs_sink = args[:partial_failure_gcs_sink] if args.key?(:partial_failure_gcs_sink)
  @rag_file_parsing_config = args[:rag_file_parsing_config] if args.key?(:rag_file_parsing_config)
  @rag_file_transformation_config = args[:rag_file_transformation_config] if args.key?(:rag_file_transformation_config)
  @rebuild_ann_index = args[:rebuild_ann_index] if args.key?(:rebuild_ann_index)
  @share_point_sources = args[:share_point_sources] if args.key?(:share_point_sources)
  @slack_source = args[:slack_source] if args.key?(:slack_source)
end