Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ImportRagFilesConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Config for importing RagFiles.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ImportRagFilesConfig

Returns a new instance of GoogleCloudAiplatformV1ImportRagFilesConfig.



13348
13349
13350
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13348

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gcs_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsSource

The Google Cloud Storage location for the input content. Corresponds to the JSON property gcsSource



13287
13288
13289
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13287

def gcs_source
  @gcs_source
end

#google_drive_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GoogleDriveSource

The Google Drive location for the input content. Corresponds to the JSON property googleDriveSource



13292
13293
13294
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13292

def google_drive_source
  @google_drive_source
end

#import_result_bigquery_sinkGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQueryDestination

The BigQuery location for the output content. Corresponds to the JSON property importResultBigquerySink



13297
13298
13299
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13297

def import_result_bigquery_sink
  @import_result_bigquery_sink
end

#import_result_gcs_sinkGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsDestination

The Google Cloud Storage location where the output is to be written to. Corresponds to the JSON property importResultGcsSink



13302
13303
13304
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13302

def import_result_gcs_sink
  @import_result_gcs_sink
end

#jira_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1JiraSource

The Jira source for the ImportRagFilesRequest. Corresponds to the JSON property jiraSource



13307
13308
13309
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13307

def jira_source
  @jira_source
end

#max_embedding_requests_per_minFixnum

Optional. The max number of queries per minute that this job is allowed to make to the embedding model specified on the corpus. This value is specific to this job and not shared across other import jobs. Consult the Quotas page on the project to set an appropriate value here. If unspecified, a default value of 1,000 QPM would be used. Corresponds to the JSON property maxEmbeddingRequestsPerMin

Returns:

  • (Fixnum)


13316
13317
13318
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13316

def max_embedding_requests_per_min
  @max_embedding_requests_per_min
end

#partial_failure_bigquery_sinkGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQueryDestination

The BigQuery location for the output content. Corresponds to the JSON property partialFailureBigquerySink



13321
13322
13323
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13321

def partial_failure_bigquery_sink
  @partial_failure_bigquery_sink
end

#partial_failure_gcs_sinkGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsDestination

The Google Cloud Storage location where the output is to be written to. Corresponds to the JSON property partialFailureGcsSink



13326
13327
13328
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13326

def partial_failure_gcs_sink
  @partial_failure_gcs_sink
end

#rag_file_parsing_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RagFileParsingConfig

Specifies the parsing config for RagFiles. Corresponds to the JSON property ragFileParsingConfig



13331
13332
13333
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13331

def rag_file_parsing_config
  @rag_file_parsing_config
end

#rag_file_transformation_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RagFileTransformationConfig

Specifies the transformation config for RagFiles. Corresponds to the JSON property ragFileTransformationConfig



13336
13337
13338
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13336

def rag_file_transformation_config
  @rag_file_transformation_config
end

#share_point_sourcesGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SharePointSources

The SharePointSources to pass to ImportRagFiles. Corresponds to the JSON property sharePointSources



13341
13342
13343
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13341

def share_point_sources
  @share_point_sources
end

#slack_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SlackSource

The Slack source for the ImportRagFilesRequest. Corresponds to the JSON property slackSource



13346
13347
13348
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13346

def slack_source
  @slack_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13353
13354
13355
13356
13357
13358
13359
13360
13361
13362
13363
13364
13365
13366
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13353

def update!(**args)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @google_drive_source = args[:google_drive_source] if args.key?(:google_drive_source)
  @import_result_bigquery_sink = args[:import_result_bigquery_sink] if args.key?(:import_result_bigquery_sink)
  @import_result_gcs_sink = args[:import_result_gcs_sink] if args.key?(:import_result_gcs_sink)
  @jira_source = args[:jira_source] if args.key?(:jira_source)
  @max_embedding_requests_per_min = args[:max_embedding_requests_per_min] if args.key?(:max_embedding_requests_per_min)
  @partial_failure_bigquery_sink = args[:partial_failure_bigquery_sink] if args.key?(:partial_failure_bigquery_sink)
  @partial_failure_gcs_sink = args[:partial_failure_gcs_sink] if args.key?(:partial_failure_gcs_sink)
  @rag_file_parsing_config = args[:rag_file_parsing_config] if args.key?(:rag_file_parsing_config)
  @rag_file_transformation_config = args[:rag_file_transformation_config] if args.key?(:rag_file_transformation_config)
  @share_point_sources = args[:share_point_sources] if args.key?(:share_point_sources)
  @slack_source = args[:slack_source] if args.key?(:slack_source)
end