Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ImportRagFilesConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Config for importing RagFiles.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ImportRagFilesConfig

Returns a new instance of GoogleCloudAiplatformV1ImportRagFilesConfig.



13125
13126
13127
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13125

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gcs_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsSource

The Google Cloud Storage location for the input content. Corresponds to the JSON property gcsSource



13064
13065
13066
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13064

def gcs_source
  @gcs_source
end

#google_drive_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GoogleDriveSource

The Google Drive location for the input content. Corresponds to the JSON property googleDriveSource



13069
13070
13071
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13069

def google_drive_source
  @google_drive_source
end

#import_result_bigquery_sinkGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQueryDestination

The BigQuery location for the output content. Corresponds to the JSON property importResultBigquerySink



13074
13075
13076
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13074

def import_result_bigquery_sink
  @import_result_bigquery_sink
end

#import_result_gcs_sinkGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsDestination

The Google Cloud Storage location where the output is to be written to. Corresponds to the JSON property importResultGcsSink



13079
13080
13081
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13079

def import_result_gcs_sink
  @import_result_gcs_sink
end

#jira_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1JiraSource

The Jira source for the ImportRagFilesRequest. Corresponds to the JSON property jiraSource



13084
13085
13086
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13084

def jira_source
  @jira_source
end

#max_embedding_requests_per_minFixnum

Optional. The max number of queries per minute that this job is allowed to make to the embedding model specified on the corpus. This value is specific to this job and not shared across other import jobs. Consult the Quotas page on the project to set an appropriate value here. If unspecified, a default value of 1,000 QPM would be used. Corresponds to the JSON property maxEmbeddingRequestsPerMin

Returns:

  • (Fixnum)


13093
13094
13095
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13093

def max_embedding_requests_per_min
  @max_embedding_requests_per_min
end

#partial_failure_bigquery_sinkGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQueryDestination

The BigQuery location for the output content. Corresponds to the JSON property partialFailureBigquerySink



13098
13099
13100
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13098

def partial_failure_bigquery_sink
  @partial_failure_bigquery_sink
end

#partial_failure_gcs_sinkGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsDestination

The Google Cloud Storage location where the output is to be written to. Corresponds to the JSON property partialFailureGcsSink



13103
13104
13105
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13103

def partial_failure_gcs_sink
  @partial_failure_gcs_sink
end

#rag_file_parsing_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RagFileParsingConfig

Specifies the parsing config for RagFiles. Corresponds to the JSON property ragFileParsingConfig



13108
13109
13110
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13108

def rag_file_parsing_config
  @rag_file_parsing_config
end

#rag_file_transformation_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RagFileTransformationConfig

Specifies the transformation config for RagFiles. Corresponds to the JSON property ragFileTransformationConfig



13113
13114
13115
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13113

def rag_file_transformation_config
  @rag_file_transformation_config
end

#share_point_sourcesGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SharePointSources

The SharePointSources to pass to ImportRagFiles. Corresponds to the JSON property sharePointSources



13118
13119
13120
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13118

def share_point_sources
  @share_point_sources
end

#slack_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SlackSource

The Slack source for the ImportRagFilesRequest. Corresponds to the JSON property slackSource



13123
13124
13125
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13123

def slack_source
  @slack_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13130
13131
13132
13133
13134
13135
13136
13137
13138
13139
13140
13141
13142
13143
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13130

def update!(**args)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @google_drive_source = args[:google_drive_source] if args.key?(:google_drive_source)
  @import_result_bigquery_sink = args[:import_result_bigquery_sink] if args.key?(:import_result_bigquery_sink)
  @import_result_gcs_sink = args[:import_result_gcs_sink] if args.key?(:import_result_gcs_sink)
  @jira_source = args[:jira_source] if args.key?(:jira_source)
  @max_embedding_requests_per_min = args[:max_embedding_requests_per_min] if args.key?(:max_embedding_requests_per_min)
  @partial_failure_bigquery_sink = args[:partial_failure_bigquery_sink] if args.key?(:partial_failure_bigquery_sink)
  @partial_failure_gcs_sink = args[:partial_failure_gcs_sink] if args.key?(:partial_failure_gcs_sink)
  @rag_file_parsing_config = args[:rag_file_parsing_config] if args.key?(:rag_file_parsing_config)
  @rag_file_transformation_config = args[:rag_file_transformation_config] if args.key?(:rag_file_transformation_config)
  @share_point_sources = args[:share_point_sources] if args.key?(:share_point_sources)
  @slack_source = args[:slack_source] if args.key?(:slack_source)
end