Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ImportRagFilesConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Config for importing RagFiles.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ImportRagFilesConfig

Returns a new instance of GoogleCloudAiplatformV1ImportRagFilesConfig.



13103
13104
13105
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13103

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gcs_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsSource

The Google Cloud Storage location for the input content. Corresponds to the JSON property gcsSource



13057
13058
13059
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13057

def gcs_source
  @gcs_source
end

#google_drive_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GoogleDriveSource

The Google Drive location for the input content. Corresponds to the JSON property googleDriveSource



13062
13063
13064
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13062

def google_drive_source
  @google_drive_source
end

#jira_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1JiraSource

The Jira source for the ImportRagFilesRequest. Corresponds to the JSON property jiraSource



13067
13068
13069
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13067

def jira_source
  @jira_source
end

#max_embedding_requests_per_minFixnum

Optional. The max number of queries per minute that this job is allowed to make to the embedding model specified on the corpus. This value is specific to this job and not shared across other import jobs. Consult the Quotas page on the project to set an appropriate value here. If unspecified, a default value of 1,000 QPM would be used. Corresponds to the JSON property maxEmbeddingRequestsPerMin

Returns:

  • (Fixnum)


13076
13077
13078
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13076

def max_embedding_requests_per_min
  @max_embedding_requests_per_min
end

#partial_failure_bigquery_sinkGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQueryDestination

The BigQuery location for the output content. Corresponds to the JSON property partialFailureBigquerySink



13081
13082
13083
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13081

def partial_failure_bigquery_sink
  @partial_failure_bigquery_sink
end

#partial_failure_gcs_sinkGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsDestination

The Google Cloud Storage location where the output is to be written to. Corresponds to the JSON property partialFailureGcsSink



13086
13087
13088
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13086

def partial_failure_gcs_sink
  @partial_failure_gcs_sink
end

#rag_file_transformation_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RagFileTransformationConfig

Specifies the transformation config for RagFiles. Corresponds to the JSON property ragFileTransformationConfig



13091
13092
13093
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13091

def rag_file_transformation_config
  @rag_file_transformation_config
end

#share_point_sourcesGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SharePointSources

The SharePointSources to pass to ImportRagFiles. Corresponds to the JSON property sharePointSources



13096
13097
13098
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13096

def share_point_sources
  @share_point_sources
end

#slack_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SlackSource

The Slack source for the ImportRagFilesRequest. Corresponds to the JSON property slackSource



13101
13102
13103
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13101

def slack_source
  @slack_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13108
13109
13110
13111
13112
13113
13114
13115
13116
13117
13118
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13108

def update!(**args)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @google_drive_source = args[:google_drive_source] if args.key?(:google_drive_source)
  @jira_source = args[:jira_source] if args.key?(:jira_source)
  @max_embedding_requests_per_min = args[:max_embedding_requests_per_min] if args.key?(:max_embedding_requests_per_min)
  @partial_failure_bigquery_sink = args[:partial_failure_bigquery_sink] if args.key?(:partial_failure_bigquery_sink)
  @partial_failure_gcs_sink = args[:partial_failure_gcs_sink] if args.key?(:partial_failure_gcs_sink)
  @rag_file_transformation_config = args[:rag_file_transformation_config] if args.key?(:rag_file_transformation_config)
  @share_point_sources = args[:share_point_sources] if args.key?(:share_point_sources)
  @slack_source = args[:slack_source] if args.key?(:slack_source)
end