Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Index

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A representation of a collection of database items organized in a way that allows for approximate nearest neighbor (a.k.a ANN) algorithms search.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Index

Returns a new instance of GoogleCloudAiplatformV1Index.



11650
11651
11652
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11650

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this Index was created. Corresponds to the JSON property createTime

Returns:

  • (String)


11554
11555
11556
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11554

def create_time
  @create_time
end

#deployed_indexesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployedIndexRef>

Output only. The pointers to DeployedIndexes created from this Index. An Index can be only deleted if all its DeployedIndexes had been undeployed first. Corresponds to the JSON property deployedIndexes



11560
11561
11562
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11560

def deployed_indexes
  @deployed_indexes
end

#descriptionString

The description of the Index. Corresponds to the JSON property description

Returns:

  • (String)


11565
11566
11567
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11565

def description
  @description
end

#display_nameString

Required. The display name of the Index. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


11571
11572
11573
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11571

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key spec that can be applied to a top- level resource. Corresponds to the JSON property encryptionSpec



11577
11578
11579
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11577

def encryption_spec
  @encryption_spec
end

#etagString

Used to perform consistent read-modify-write updates. If not set, a blind " overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


11583
11584
11585
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11583

def etag
  @etag
end

#index_statsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexStats

Stats of the Index. Corresponds to the JSON property indexStats



11588
11589
11590
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11588

def index_stats
  @index_stats
end

#index_update_methodString

Immutable. The update method to use with this Index. If not set, BATCH_UPDATE will be used by default. Corresponds to the JSON property indexUpdateMethod

Returns:

  • (String)


11594
11595
11596
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11594

def index_update_method
  @index_update_method
end

#labelsHash<String,String>

The labels with user-defined metadata to organize your Indexes. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


11603
11604
11605
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11603

def labels
  @labels
end

#metadataObject

An additional information about the Index; the schema of the metadata can be found in metadata_schema. Corresponds to the JSON property metadata

Returns:

  • (Object)


11609
11610
11611
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11609

def 
  @metadata
end

#metadata_schema_uriString

Immutable. Points to a YAML file stored on Google Cloud Storage describing additional information about the Index, that is specific to it. Unset if the Index does not have any additional information. The schema is defined as an OpenAPI 3.0.2 Schema Object. Note: The URI given on output will be immutable and probably different, including the URI scheme, than the one given on input. The output URI will point to a location where the user only has a read access. Corresponds to the JSON property metadataSchemaUri

Returns:

  • (String)


11621
11622
11623
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11621

def 
  @metadata_schema_uri
end

#nameString

Output only. The resource name of the Index. Corresponds to the JSON property name

Returns:

  • (String)


11626
11627
11628
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11626

def name
  @name
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


11631
11632
11633
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11631

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


11637
11638
11639
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11637

def satisfies_pzs
  @satisfies_pzs
end

#update_timeString

Output only. Timestamp when this Index was most recently updated. This also includes any update to the contents of the Index. Note that Operations working on this Index may have their Operations.metadata.generic_metadata.update_time a little after the value of this timestamp, yet that does not mean their results are not already reflected in the Index. Result of any successfully completed Operation on the Index is reflected in it. Corresponds to the JSON property updateTime

Returns:

  • (String)


11648
11649
11650
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11648

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11655
11656
11657
11658
11659
11660
11661
11662
11663
11664
11665
11666
11667
11668
11669
11670
11671
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11655

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @deployed_indexes = args[:deployed_indexes] if args.key?(:deployed_indexes)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @etag = args[:etag] if args.key?(:etag)
  @index_stats = args[:index_stats] if args.key?(:index_stats)
  @index_update_method = args[:index_update_method] if args.key?(:index_update_method)
  @labels = args[:labels] if args.key?(:labels)
  @metadata = args[:metadata] if args.key?(:metadata)
  @metadata_schema_uri = args[:metadata_schema_uri] if args.key?(:metadata_schema_uri)
  @name = args[:name] if args.key?(:name)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @update_time = args[:update_time] if args.key?(:update_time)
end