Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Index

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A representation of a collection of database items organized in a way that allows for approximate nearest neighbor (a.k.a ANN) algorithms search.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Index

Returns a new instance of GoogleCloudAiplatformV1Index.



11141
11142
11143
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11141

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this Index was created. Corresponds to the JSON property createTime

Returns:

  • (String)


11057
11058
11059
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11057

def create_time
  @create_time
end

#deployed_indexesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployedIndexRef>

Output only. The pointers to DeployedIndexes created from this Index. An Index can be only deleted if all its DeployedIndexes had been undeployed first. Corresponds to the JSON property deployedIndexes



11063
11064
11065
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11063

def deployed_indexes
  @deployed_indexes
end

#descriptionString

The description of the Index. Corresponds to the JSON property description

Returns:

  • (String)


11068
11069
11070
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11068

def description
  @description
end

#display_nameString

Required. The display name of the Index. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


11074
11075
11076
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11074

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key spec that can be applied to a top- level resource. Corresponds to the JSON property encryptionSpec



11080
11081
11082
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11080

def encryption_spec
  @encryption_spec
end

#etagString

Used to perform consistent read-modify-write updates. If not set, a blind " overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


11086
11087
11088
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11086

def etag
  @etag
end

#index_statsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexStats

Stats of the Index. Corresponds to the JSON property indexStats



11091
11092
11093
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11091

def index_stats
  @index_stats
end

#index_update_methodString

Immutable. The update method to use with this Index. If not set, BATCH_UPDATE will be used by default. Corresponds to the JSON property indexUpdateMethod

Returns:

  • (String)


11097
11098
11099
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11097

def index_update_method
  @index_update_method
end

#labelsHash<String,String>

The labels with user-defined metadata to organize your Indexes. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


11106
11107
11108
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11106

def labels
  @labels
end

#metadataObject

An additional information about the Index; the schema of the metadata can be found in metadata_schema. Corresponds to the JSON property metadata

Returns:

  • (Object)


11112
11113
11114
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11112

def 
  @metadata
end

#metadata_schema_uriString

Immutable. Points to a YAML file stored on Google Cloud Storage describing additional information about the Index, that is specific to it. Unset if the Index does not have any additional information. The schema is defined as an OpenAPI 3.0.2 Schema Object. Note: The URI given on output will be immutable and probably different, including the URI scheme, than the one given on input. The output URI will point to a location where the user only has a read access. Corresponds to the JSON property metadataSchemaUri

Returns:

  • (String)


11124
11125
11126
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11124

def 
  @metadata_schema_uri
end

#nameString

Output only. The resource name of the Index. Corresponds to the JSON property name

Returns:

  • (String)


11129
11130
11131
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11129

def name
  @name
end

#update_timeString

Output only. Timestamp when this Index was most recently updated. This also includes any update to the contents of the Index. Note that Operations working on this Index may have their Operations.metadata.generic_metadata.update_time a little after the value of this timestamp, yet that does not mean their results are not already reflected in the Index. Result of any successfully completed Operation on the Index is reflected in it. Corresponds to the JSON property updateTime

Returns:

  • (String)


11139
11140
11141
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11139

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11146
11147
11148
11149
11150
11151
11152
11153
11154
11155
11156
11157
11158
11159
11160
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11146

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @deployed_indexes = args[:deployed_indexes] if args.key?(:deployed_indexes)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @etag = args[:etag] if args.key?(:etag)
  @index_stats = args[:index_stats] if args.key?(:index_stats)
  @index_update_method = args[:index_update_method] if args.key?(:index_update_method)
  @labels = args[:labels] if args.key?(:labels)
  @metadata = args[:metadata] if args.key?(:metadata)
  @metadata_schema_uri = args[:metadata_schema_uri] if args.key?(:metadata_schema_uri)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end