Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapoint
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A datapoint of Index.
Instance Attribute Summary collapse
-
#crowding_tag ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapointCrowdingTag
Crowding tag is a constraint on a neighbor list produced by nearest neighbor search requiring that no more than some value k' of the k neighbors returned have the same value of crowding_attribute.
-
#datapoint_id ⇒ String
Required.
-
#embedding_metadata ⇒ Hash<String,Object>
Optional.
-
#feature_vector ⇒ Array<Float>
Required.
-
#numeric_restricts ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapointNumericRestriction>
Optional.
-
#restricts ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapointRestriction>
Optional.
-
#sparse_embedding ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapointSparseEmbedding
Feature embedding vector for sparse index.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1IndexDatapoint
constructor
A new instance of GoogleCloudAiplatformV1IndexDatapoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1IndexDatapoint
Returns a new instance of GoogleCloudAiplatformV1IndexDatapoint.
19514 19515 19516 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19514 def initialize(**args) update!(**args) end |
Instance Attribute Details
#crowding_tag ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapointCrowdingTag
Crowding tag is a constraint on a neighbor list produced by nearest neighbor
search requiring that no more than some value k' of the k neighbors returned
have the same value of crowding_attribute.
Corresponds to the JSON property crowdingTag
19475 19476 19477 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19475 def crowding_tag @crowding_tag end |
#datapoint_id ⇒ String
Required. Unique identifier of the datapoint.
Corresponds to the JSON property datapointId
19480 19481 19482 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19480 def datapoint_id @datapoint_id end |
#embedding_metadata ⇒ Hash<String,Object>
Optional. The key-value map of additional metadata for the datapoint.
Corresponds to the JSON property embeddingMetadata
19485 19486 19487 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19485 def @embedding_metadata end |
#feature_vector ⇒ Array<Float>
Required. Feature embedding vector for dense index. An array of numbers with
the length of [NearestNeighborSearchConfig.dimensions].
Corresponds to the JSON property featureVector
19491 19492 19493 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19491 def feature_vector @feature_vector end |
#numeric_restricts ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapointNumericRestriction>
Optional. List of Restrict of the datapoint, used to perform "restricted
searches" where boolean rule are used to filter the subset of the database
eligible for matching. This uses numeric comparisons.
Corresponds to the JSON property numericRestricts
19498 19499 19500 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19498 def numeric_restricts @numeric_restricts end |
#restricts ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapointRestriction>
Optional. List of Restrict of the datapoint, used to perform "restricted
searches" where boolean rule are used to filter the subset of the database
eligible for matching. This uses categorical tokens. See: https://cloud.google.
com/vertex-ai/docs/matching-engine/filtering
Corresponds to the JSON property restricts
19506 19507 19508 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19506 def restricts @restricts end |
#sparse_embedding ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapointSparseEmbedding
Feature embedding vector for sparse index. An array of numbers whose values
are located in the specified dimensions.
Corresponds to the JSON property sparseEmbedding
19512 19513 19514 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19512 def @sparse_embedding end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19519 19520 19521 19522 19523 19524 19525 19526 19527 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19519 def update!(**args) @crowding_tag = args[:crowding_tag] if args.key?(:crowding_tag) @datapoint_id = args[:datapoint_id] if args.key?(:datapoint_id) @embedding_metadata = args[:embedding_metadata] if args.key?(:embedding_metadata) @feature_vector = args[:feature_vector] if args.key?(:feature_vector) @numeric_restricts = args[:numeric_restricts] if args.key?(:numeric_restricts) @restricts = args[:restricts] if args.key?(:restricts) @sparse_embedding = args[:sparse_embedding] if args.key?(:sparse_embedding) end |