Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapoint
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A datapoint of Index.
Instance Attribute Summary collapse
-
#crowding_tag ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapointCrowdingTag
Crowding tag is a constraint on a neighbor list produced by nearest neighbor search requiring that no more than some value k' of the k neighbors returned have the same value of crowding_attribute.
-
#datapoint_id ⇒ String
Required.
-
#embedding_metadata ⇒ Hash<String,Object>
Optional.
-
#feature_vector ⇒ Array<Float>
Required.
-
#numeric_restricts ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapointNumericRestriction>
Optional.
-
#restricts ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapointRestriction>
Optional.
-
#sparse_embedding ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapointSparseEmbedding
Feature embedding vector for sparse index.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1IndexDatapoint
constructor
A new instance of GoogleCloudAiplatformV1IndexDatapoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1IndexDatapoint
Returns a new instance of GoogleCloudAiplatformV1IndexDatapoint.
18765 18766 18767 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18765 def initialize(**args) update!(**args) end |
Instance Attribute Details
#crowding_tag ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapointCrowdingTag
Crowding tag is a constraint on a neighbor list produced by nearest neighbor
search requiring that no more than some value k' of the k neighbors returned
have the same value of crowding_attribute.
Corresponds to the JSON property crowdingTag
18726 18727 18728 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18726 def crowding_tag @crowding_tag end |
#datapoint_id ⇒ String
Required. Unique identifier of the datapoint.
Corresponds to the JSON property datapointId
18731 18732 18733 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18731 def datapoint_id @datapoint_id end |
#embedding_metadata ⇒ Hash<String,Object>
Optional. The key-value map of additional metadata for the datapoint.
Corresponds to the JSON property embeddingMetadata
18736 18737 18738 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18736 def @embedding_metadata end |
#feature_vector ⇒ Array<Float>
Required. Feature embedding vector for dense index. An array of numbers with
the length of [NearestNeighborSearchConfig.dimensions].
Corresponds to the JSON property featureVector
18742 18743 18744 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18742 def feature_vector @feature_vector end |
#numeric_restricts ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapointNumericRestriction>
Optional. List of Restrict of the datapoint, used to perform "restricted
searches" where boolean rule are used to filter the subset of the database
eligible for matching. This uses numeric comparisons.
Corresponds to the JSON property numericRestricts
18749 18750 18751 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18749 def numeric_restricts @numeric_restricts end |
#restricts ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapointRestriction>
Optional. List of Restrict of the datapoint, used to perform "restricted
searches" where boolean rule are used to filter the subset of the database
eligible for matching. This uses categorical tokens. See: https://cloud.google.
com/vertex-ai/docs/matching-engine/filtering
Corresponds to the JSON property restricts
18757 18758 18759 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18757 def restricts @restricts end |
#sparse_embedding ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapointSparseEmbedding
Feature embedding vector for sparse index. An array of numbers whose values
are located in the specified dimensions.
Corresponds to the JSON property sparseEmbedding
18763 18764 18765 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18763 def @sparse_embedding end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18770 18771 18772 18773 18774 18775 18776 18777 18778 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18770 def update!(**args) @crowding_tag = args[:crowding_tag] if args.key?(:crowding_tag) @datapoint_id = args[:datapoint_id] if args.key?(:datapoint_id) @embedding_metadata = args[:embedding_metadata] if args.key?(:embedding_metadata) @feature_vector = args[:feature_vector] if args.key?(:feature_vector) @numeric_restricts = args[:numeric_restricts] if args.key?(:numeric_restricts) @restricts = args[:restricts] if args.key?(:restricts) @sparse_embedding = args[:sparse_embedding] if args.key?(:sparse_embedding) end |