Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A datapoint of Index.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1IndexDatapoint

Returns a new instance of GoogleCloudAiplatformV1IndexDatapoint.



13917
13918
13919
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13917

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#crowding_tagGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapointCrowdingTag

Crowding tag is a constraint on a neighbor list produced by nearest neighbor search requiring that no more than some value k' of the k neighbors returned have the same value of crowding_attribute. Corresponds to the JSON property crowdingTag



13883
13884
13885
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13883

def crowding_tag
  @crowding_tag
end

#datapoint_idString

Required. Unique identifier of the datapoint. Corresponds to the JSON property datapointId

Returns:

  • (String)


13888
13889
13890
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13888

def datapoint_id
  @datapoint_id
end

#feature_vectorArray<Float>

Required. Feature embedding vector for dense index. An array of numbers with the length of [NearestNeighborSearchConfig.dimensions]. Corresponds to the JSON property featureVector

Returns:

  • (Array<Float>)


13894
13895
13896
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13894

def feature_vector
  @feature_vector
end

#numeric_restrictsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapointNumericRestriction>

Optional. List of Restrict of the datapoint, used to perform "restricted searches" where boolean rule are used to filter the subset of the database eligible for matching. This uses numeric comparisons. Corresponds to the JSON property numericRestricts



13901
13902
13903
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13901

def numeric_restricts
  @numeric_restricts
end

#restrictsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapointRestriction>

Optional. List of Restrict of the datapoint, used to perform "restricted searches" where boolean rule are used to filter the subset of the database eligible for matching. This uses categorical tokens. See: https://cloud.google. com/vertex-ai/docs/matching-engine/filtering Corresponds to the JSON property restricts



13909
13910
13911
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13909

def restricts
  @restricts
end

#sparse_embeddingGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapointSparseEmbedding

Feature embedding vector for sparse index. An array of numbers whose values are located in the specified dimensions. Corresponds to the JSON property sparseEmbedding



13915
13916
13917
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13915

def sparse_embedding
  @sparse_embedding
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13922
13923
13924
13925
13926
13927
13928
13929
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13922

def update!(**args)
  @crowding_tag = args[:crowding_tag] if args.key?(:crowding_tag)
  @datapoint_id = args[:datapoint_id] if args.key?(:datapoint_id)
  @feature_vector = args[:feature_vector] if args.key?(:feature_vector)
  @numeric_restricts = args[:numeric_restricts] if args.key?(:numeric_restricts)
  @restricts = args[:restricts] if args.key?(:restricts)
  @sparse_embedding = args[:sparse_embedding] if args.key?(:sparse_embedding)
end