Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A datapoint of Index.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1IndexDatapoint

Returns a new instance of GoogleCloudAiplatformV1IndexDatapoint.



13559
13560
13561
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13559

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#crowding_tagGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapointCrowdingTag

Crowding tag is a constraint on a neighbor list produced by nearest neighbor search requiring that no more than some value k' of the k neighbors returned have the same value of crowding_attribute. Corresponds to the JSON property crowdingTag



13525
13526
13527
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13525

def crowding_tag
  @crowding_tag
end

#datapoint_idString

Required. Unique identifier of the datapoint. Corresponds to the JSON property datapointId

Returns:

  • (String)


13530
13531
13532
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13530

def datapoint_id
  @datapoint_id
end

#feature_vectorArray<Float>

Required. Feature embedding vector for dense index. An array of numbers with the length of [NearestNeighborSearchConfig.dimensions]. Corresponds to the JSON property featureVector

Returns:

  • (Array<Float>)


13536
13537
13538
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13536

def feature_vector
  @feature_vector
end

#numeric_restrictsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapointNumericRestriction>

Optional. List of Restrict of the datapoint, used to perform "restricted searches" where boolean rule are used to filter the subset of the database eligible for matching. This uses numeric comparisons. Corresponds to the JSON property numericRestricts



13543
13544
13545
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13543

def numeric_restricts
  @numeric_restricts
end

#restrictsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapointRestriction>

Optional. List of Restrict of the datapoint, used to perform "restricted searches" where boolean rule are used to filter the subset of the database eligible for matching. This uses categorical tokens. See: https://cloud.google. com/vertex-ai/docs/matching-engine/filtering Corresponds to the JSON property restricts



13551
13552
13553
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13551

def restricts
  @restricts
end

#sparse_embeddingGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapointSparseEmbedding

Feature embedding vector for sparse index. An array of numbers whose values are located in the specified dimensions. Corresponds to the JSON property sparseEmbedding



13557
13558
13559
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13557

def sparse_embedding
  @sparse_embedding
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13564
13565
13566
13567
13568
13569
13570
13571
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13564

def update!(**args)
  @crowding_tag = args[:crowding_tag] if args.key?(:crowding_tag)
  @datapoint_id = args[:datapoint_id] if args.key?(:datapoint_id)
  @feature_vector = args[:feature_vector] if args.key?(:feature_vector)
  @numeric_restricts = args[:numeric_restricts] if args.key?(:numeric_restricts)
  @restricts = args[:restricts] if args.key?(:restricts)
  @sparse_embedding = args[:sparse_embedding] if args.key?(:sparse_embedding)
end