Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapoint
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A datapoint of Index.
Instance Attribute Summary collapse
-
#crowding_tag ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapointCrowdingTag
Crowding tag is a constraint on a neighbor list produced by nearest neighbor search requiring that no more than some value k' of the k neighbors returned have the same value of crowding_attribute.
-
#datapoint_id ⇒ String
Required.
-
#feature_vector ⇒ Array<Float>
Required.
-
#numeric_restricts ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapointNumericRestriction>
Optional.
-
#restricts ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapointRestriction>
Optional.
-
#sparse_embedding ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapointSparseEmbedding
Feature embedding vector for sparse index.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1IndexDatapoint
constructor
A new instance of GoogleCloudAiplatformV1IndexDatapoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1IndexDatapoint
Returns a new instance of GoogleCloudAiplatformV1IndexDatapoint.
11717 11718 11719 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11717 def initialize(**args) update!(**args) end |
Instance Attribute Details
#crowding_tag ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapointCrowdingTag
Crowding tag is a constraint on a neighbor list produced by nearest neighbor
search requiring that no more than some value k' of the k neighbors returned
have the same value of crowding_attribute.
Corresponds to the JSON property crowdingTag
11683 11684 11685 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11683 def crowding_tag @crowding_tag end |
#datapoint_id ⇒ String
Required. Unique identifier of the datapoint.
Corresponds to the JSON property datapointId
11688 11689 11690 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11688 def datapoint_id @datapoint_id end |
#feature_vector ⇒ Array<Float>
Required. Feature embedding vector for dense index. An array of numbers with
the length of [NearestNeighborSearchConfig.dimensions].
Corresponds to the JSON property featureVector
11694 11695 11696 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11694 def feature_vector @feature_vector end |
#numeric_restricts ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapointNumericRestriction>
Optional. List of Restrict of the datapoint, used to perform "restricted
searches" where boolean rule are used to filter the subset of the database
eligible for matching. This uses numeric comparisons.
Corresponds to the JSON property numericRestricts
11701 11702 11703 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11701 def numeric_restricts @numeric_restricts end |
#restricts ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapointRestriction>
Optional. List of Restrict of the datapoint, used to perform "restricted
searches" where boolean rule are used to filter the subset of the database
eligible for matching. This uses categorical tokens. See: https://cloud.google.
com/vertex-ai/docs/matching-engine/filtering
Corresponds to the JSON property restricts
11709 11710 11711 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11709 def restricts @restricts end |
#sparse_embedding ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapointSparseEmbedding
Feature embedding vector for sparse index. An array of numbers whose values
are located in the specified dimensions.
Corresponds to the JSON property sparseEmbedding
11715 11716 11717 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11715 def @sparse_embedding end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11722 11723 11724 11725 11726 11727 11728 11729 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11722 def update!(**args) @crowding_tag = args[:crowding_tag] if args.key?(:crowding_tag) @datapoint_id = args[:datapoint_id] if args.key?(:datapoint_id) @feature_vector = args[:feature_vector] if args.key?(:feature_vector) @numeric_restricts = args[:numeric_restricts] if args.key?(:numeric_restricts) @restricts = args[:restricts] if args.key?(:restricts) @sparse_embedding = args[:sparse_embedding] if args.key?(:sparse_embedding) end |