Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A datapoint of Index.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1IndexDatapoint

Returns a new instance of GoogleCloudAiplatformV1IndexDatapoint.



10883
10884
10885
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10883

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#crowding_tagGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapointCrowdingTag

Crowding tag is a constraint on a neighbor list produced by nearest neighbor search requiring that no more than some value k' of the k neighbors returned have the same value of crowding_attribute. Corresponds to the JSON property crowdingTag



10855
10856
10857
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10855

def crowding_tag
  @crowding_tag
end

#datapoint_idString

Required. Unique identifier of the datapoint. Corresponds to the JSON property datapointId

Returns:

  • (String)


10860
10861
10862
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10860

def datapoint_id
  @datapoint_id
end

#feature_vectorArray<Float>

Required. Feature embedding vector. An array of numbers with the length of [ NearestNeighborSearchConfig.dimensions]. Corresponds to the JSON property featureVector

Returns:

  • (Array<Float>)


10866
10867
10868
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10866

def feature_vector
  @feature_vector
end

#numeric_restrictsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapointNumericRestriction>

Optional. List of Restrict of the datapoint, used to perform "restricted searches" where boolean rule are used to filter the subset of the database eligible for matching. This uses numeric comparisons. Corresponds to the JSON property numericRestricts



10873
10874
10875
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10873

def numeric_restricts
  @numeric_restricts
end

#restrictsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapointRestriction>

Optional. List of Restrict of the datapoint, used to perform "restricted searches" where boolean rule are used to filter the subset of the database eligible for matching. This uses categorical tokens. See: https://cloud.google. com/vertex-ai/docs/matching-engine/filtering Corresponds to the JSON property restricts



10881
10882
10883
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10881

def restricts
  @restricts
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10888
10889
10890
10891
10892
10893
10894
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 10888

def update!(**args)
  @crowding_tag = args[:crowding_tag] if args.key?(:crowding_tag)
  @datapoint_id = args[:datapoint_id] if args.key?(:datapoint_id)
  @feature_vector = args[:feature_vector] if args.key?(:feature_vector)
  @numeric_restricts = args[:numeric_restricts] if args.key?(:numeric_restricts)
  @restricts = args[:restricts] if args.key?(:restricts)
end