Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapointSparseEmbedding

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Feature embedding vector for sparse index. An array of numbers whose values are located in the specified dimensions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1IndexDatapointSparseEmbedding

Returns a new instance of GoogleCloudAiplatformV1IndexDatapointSparseEmbedding.



19646
19647
19648
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19646

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dimensionsArray<Fixnum>

Required. The list of indexes for the embedding values of the sparse vector. Corresponds to the JSON property dimensions

Returns:

  • (Array<Fixnum>)


19639
19640
19641
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19639

def dimensions
  @dimensions
end

#valuesArray<Float>

Required. The list of embedding values of the sparse vector. Corresponds to the JSON property values

Returns:

  • (Array<Float>)


19644
19645
19646
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19644

def values
  @values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19651
19652
19653
19654
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19651

def update!(**args)
  @dimensions = args[:dimensions] if args.key?(:dimensions)
  @values = args[:values] if args.key?(:values)
end