Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapointSparseEmbedding
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapointSparseEmbedding
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Feature embedding vector for sparse index. An array of numbers whose values are located in the specified dimensions.
Instance Attribute Summary collapse
-
#dimensions ⇒ Array<Fixnum>
Required.
-
#values ⇒ Array<Float>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1IndexDatapointSparseEmbedding
constructor
A new instance of GoogleCloudAiplatformV1IndexDatapointSparseEmbedding.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1IndexDatapointSparseEmbedding
Returns a new instance of GoogleCloudAiplatformV1IndexDatapointSparseEmbedding.
18785 18786 18787 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18785 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dimensions ⇒ Array<Fixnum>
Required. The list of indexes for the embedding values of the sparse vector.
Corresponds to the JSON property dimensions
18778 18779 18780 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18778 def dimensions @dimensions end |
#values ⇒ Array<Float>
Required. The list of embedding values of the sparse vector.
Corresponds to the JSON property values
18783 18784 18785 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18783 def values @values end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18790 18791 18792 18793 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18790 def update!(**args) @dimensions = args[:dimensions] if args.key?(:dimensions) @values = args[:values] if args.key?(:values) end |