Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapointSparseEmbedding

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Feature embedding vector for sparse index. An array of numbers whose values are located in the specified dimensions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1IndexDatapointSparseEmbedding

Returns a new instance of GoogleCloudAiplatformV1IndexDatapointSparseEmbedding.



14767
14768
14769
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14767

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dimensionsArray<Fixnum>

Required. The list of indexes for the embedding values of the sparse vector. Corresponds to the JSON property dimensions

Returns:

  • (Array<Fixnum>)


14760
14761
14762
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14760

def dimensions
  @dimensions
end

#valuesArray<Float>

Required. The list of embedding values of the sparse vector. Corresponds to the JSON property values

Returns:

  • (Array<Float>)


14765
14766
14767
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14765

def values
  @values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14772
14773
14774
14775
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14772

def update!(**args)
  @dimensions = args[:dimensions] if args.key?(:dimensions)
  @values = args[:values] if args.key?(:values)
end