Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexEndpoint
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexEndpoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Indexes are deployed into it. An IndexEndpoint can have multiple DeployedIndexes.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#deployed_indexes ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployedIndex>
Output only.
-
#description ⇒ String
The description of the IndexEndpoint.
-
#display_name ⇒ String
Required.
-
#enable_private_service_connect ⇒ Boolean
(also: #enable_private_service_connect?)
Optional.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top- level resource.
-
#etag ⇒ String
Used to perform consistent read-modify-write updates.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your IndexEndpoints.
-
#name ⇒ String
Output only.
-
#network ⇒ String
Optional.
-
#private_service_connect_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PrivateServiceConnectConfig
Represents configuration for private service connect.
-
#public_endpoint_domain_name ⇒ String
Output only.
-
#public_endpoint_enabled ⇒ Boolean
(also: #public_endpoint_enabled?)
Optional.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1IndexEndpoint
constructor
A new instance of GoogleCloudAiplatformV1IndexEndpoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1IndexEndpoint
Returns a new instance of GoogleCloudAiplatformV1IndexEndpoint.
13750 13751 13752 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13750 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this IndexEndpoint was created.
Corresponds to the JSON property createTime
13649 13650 13651 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13649 def create_time @create_time end |
#deployed_indexes ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployedIndex>
Output only. The indexes deployed in this endpoint.
Corresponds to the JSON property deployedIndexes
13654 13655 13656 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13654 def deployed_indexes @deployed_indexes end |
#description ⇒ String
The description of the IndexEndpoint.
Corresponds to the JSON property description
13659 13660 13661 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13659 def description @description end |
#display_name ⇒ String
Required. The display name of the IndexEndpoint. The name can be up to 128
characters long and can consist of any UTF-8 characters.
Corresponds to the JSON property displayName
13665 13666 13667 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13665 def display_name @display_name end |
#enable_private_service_connect ⇒ Boolean Also known as: enable_private_service_connect?
Optional. Deprecated: If true, expose the IndexEndpoint via private service
connect. Only one of the fields, network or enable_private_service_connect,
can be set.
Corresponds to the JSON property enablePrivateServiceConnect
13672 13673 13674 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13672 def enable_private_service_connect @enable_private_service_connect end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top-
level resource.
Corresponds to the JSON property encryptionSpec
13679 13680 13681 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13679 def encryption_spec @encryption_spec end |
#etag ⇒ String
Used to perform consistent read-modify-write updates. If not set, a blind "
overwrite" update happens.
Corresponds to the JSON property etag
13685 13686 13687 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13685 def etag @etag end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your IndexEndpoints. Label
keys and values can be no longer than 64 characters (Unicode codepoints), can
only contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. See https://goo.gl/xmQnxf for more
information and examples of labels.
Corresponds to the JSON property labels
13694 13695 13696 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13694 def labels @labels end |
#name ⇒ String
Output only. The resource name of the IndexEndpoint.
Corresponds to the JSON property name
13699 13700 13701 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13699 def name @name end |
#network ⇒ String
Optional. The full name of the Google Compute Engine network to which the
IndexEndpoint should be peered. Private services access must already be
configured for the network. If left unspecified, the Endpoint is not peered
with any network. network and private_service_connect_config are mutually
exclusive. Format: projects/project/global/networks/network`. Where
projectis a project number, as in '12345', andnetworkis network name.
Corresponds to the JSON propertynetwork`
13711 13712 13713 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13711 def network @network end |
#private_service_connect_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PrivateServiceConnectConfig
Represents configuration for private service connect.
Corresponds to the JSON property privateServiceConnectConfig
13716 13717 13718 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13716 def private_service_connect_config @private_service_connect_config end |
#public_endpoint_domain_name ⇒ String
Output only. If public_endpoint_enabled is true, this field will be populated
with the domain name to use for this index endpoint.
Corresponds to the JSON property publicEndpointDomainName
13722 13723 13724 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13722 def public_endpoint_domain_name @public_endpoint_domain_name end |
#public_endpoint_enabled ⇒ Boolean Also known as: public_endpoint_enabled?
Optional. If true, the deployed index will be accessible through public
endpoint.
Corresponds to the JSON property publicEndpointEnabled
13728 13729 13730 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13728 def public_endpoint_enabled @public_endpoint_enabled end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
13734 13735 13736 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13734 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
13740 13741 13742 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13740 def satisfies_pzs @satisfies_pzs end |
#update_time ⇒ String
Output only. Timestamp when this IndexEndpoint was last updated. This
timestamp is not updated when the endpoint's DeployedIndexes are updated, e.g.
due to updates of the original Indexes they are the deployments of.
Corresponds to the JSON property updateTime
13748 13749 13750 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13748 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13755 13756 13757 13758 13759 13760 13761 13762 13763 13764 13765 13766 13767 13768 13769 13770 13771 13772 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13755 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @deployed_indexes = args[:deployed_indexes] if args.key?(:deployed_indexes) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @enable_private_service_connect = args[:enable_private_service_connect] if args.key?(:enable_private_service_connect) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @private_service_connect_config = args[:private_service_connect_config] if args.key?(:private_service_connect_config) @public_endpoint_domain_name = args[:public_endpoint_domain_name] if args.key?(:public_endpoint_domain_name) @public_endpoint_enabled = args[:public_endpoint_enabled] if args.key?(:public_endpoint_enabled) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @update_time = args[:update_time] if args.key?(:update_time) end |