Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexEndpoint
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexEndpoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Indexes are deployed into it. An IndexEndpoint can have multiple DeployedIndexes.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#deployed_indexes ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployedIndex>
Output only.
-
#description ⇒ String
The description of the IndexEndpoint.
-
#display_name ⇒ String
Required.
-
#enable_private_service_connect ⇒ Boolean
(also: #enable_private_service_connect?)
Optional.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top- level resource.
-
#etag ⇒ String
Used to perform consistent read-modify-write updates.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your IndexEndpoints.
-
#name ⇒ String
Output only.
-
#network ⇒ String
Optional.
-
#private_service_connect_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PrivateServiceConnectConfig
Represents configuration for private service connect.
-
#public_endpoint_domain_name ⇒ String
Output only.
-
#public_endpoint_enabled ⇒ Boolean
(also: #public_endpoint_enabled?)
Optional.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1IndexEndpoint
constructor
A new instance of GoogleCloudAiplatformV1IndexEndpoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1IndexEndpoint
Returns a new instance of GoogleCloudAiplatformV1IndexEndpoint.
12065 12066 12067 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12065 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this IndexEndpoint was created.
Corresponds to the JSON property createTime
11964 11965 11966 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11964 def create_time @create_time end |
#deployed_indexes ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployedIndex>
Output only. The indexes deployed in this endpoint.
Corresponds to the JSON property deployedIndexes
11969 11970 11971 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11969 def deployed_indexes @deployed_indexes end |
#description ⇒ String
The description of the IndexEndpoint.
Corresponds to the JSON property description
11974 11975 11976 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11974 def description @description end |
#display_name ⇒ String
Required. The display name of the IndexEndpoint. The name can be up to 128
characters long and can consist of any UTF-8 characters.
Corresponds to the JSON property displayName
11980 11981 11982 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11980 def display_name @display_name end |
#enable_private_service_connect ⇒ Boolean Also known as: enable_private_service_connect?
Optional. Deprecated: If true, expose the IndexEndpoint via private service
connect. Only one of the fields, network or enable_private_service_connect,
can be set.
Corresponds to the JSON property enablePrivateServiceConnect
11987 11988 11989 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11987 def enable_private_service_connect @enable_private_service_connect end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top-
level resource.
Corresponds to the JSON property encryptionSpec
11994 11995 11996 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11994 def encryption_spec @encryption_spec end |
#etag ⇒ String
Used to perform consistent read-modify-write updates. If not set, a blind "
overwrite" update happens.
Corresponds to the JSON property etag
12000 12001 12002 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12000 def etag @etag end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your IndexEndpoints. Label
keys and values can be no longer than 64 characters (Unicode codepoints), can
only contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. See https://goo.gl/xmQnxf for more
information and examples of labels.
Corresponds to the JSON property labels
12009 12010 12011 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12009 def labels @labels end |
#name ⇒ String
Output only. The resource name of the IndexEndpoint.
Corresponds to the JSON property name
12014 12015 12016 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12014 def name @name end |
#network ⇒ String
Optional. The full name of the Google Compute Engine network to which the
IndexEndpoint should be peered. Private services access must already be
configured for the network. If left unspecified, the Endpoint is not peered
with any network. network and private_service_connect_config are mutually
exclusive. Format: projects/project/global/networks/network`. Where
projectis a project number, as in '12345', andnetworkis network name.
Corresponds to the JSON propertynetwork`
12026 12027 12028 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12026 def network @network end |
#private_service_connect_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PrivateServiceConnectConfig
Represents configuration for private service connect.
Corresponds to the JSON property privateServiceConnectConfig
12031 12032 12033 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12031 def private_service_connect_config @private_service_connect_config end |
#public_endpoint_domain_name ⇒ String
Output only. If public_endpoint_enabled is true, this field will be populated
with the domain name to use for this index endpoint.
Corresponds to the JSON property publicEndpointDomainName
12037 12038 12039 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12037 def public_endpoint_domain_name @public_endpoint_domain_name end |
#public_endpoint_enabled ⇒ Boolean Also known as: public_endpoint_enabled?
Optional. If true, the deployed index will be accessible through public
endpoint.
Corresponds to the JSON property publicEndpointEnabled
12043 12044 12045 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12043 def public_endpoint_enabled @public_endpoint_enabled end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
12049 12050 12051 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12049 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
12055 12056 12057 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12055 def satisfies_pzs @satisfies_pzs end |
#update_time ⇒ String
Output only. Timestamp when this IndexEndpoint was last updated. This
timestamp is not updated when the endpoint's DeployedIndexes are updated, e.g.
due to updates of the original Indexes they are the deployments of.
Corresponds to the JSON property updateTime
12063 12064 12065 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12063 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12070 12071 12072 12073 12074 12075 12076 12077 12078 12079 12080 12081 12082 12083 12084 12085 12086 12087 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12070 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @deployed_indexes = args[:deployed_indexes] if args.key?(:deployed_indexes) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @enable_private_service_connect = args[:enable_private_service_connect] if args.key?(:enable_private_service_connect) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @private_service_connect_config = args[:private_service_connect_config] if args.key?(:private_service_connect_config) @public_endpoint_domain_name = args[:public_endpoint_domain_name] if args.key?(:public_endpoint_domain_name) @public_endpoint_enabled = args[:public_endpoint_enabled] if args.key?(:public_endpoint_enabled) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @update_time = args[:update_time] if args.key?(:update_time) end |