Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexEndpoint
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexEndpoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Indexes are deployed into it. An IndexEndpoint can have multiple DeployedIndexes.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#deployed_indexes ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployedIndex>
Output only.
-
#description ⇒ String
The description of the IndexEndpoint.
-
#display_name ⇒ String
Required.
-
#enable_private_service_connect ⇒ Boolean
(also: #enable_private_service_connect?)
Optional.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top- level resource.
-
#etag ⇒ String
Used to perform consistent read-modify-write updates.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your IndexEndpoints.
-
#name ⇒ String
Output only.
-
#network ⇒ String
Optional.
-
#private_service_connect_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PrivateServiceConnectConfig
Represents configuration for private service connect.
-
#public_endpoint_domain_name ⇒ String
Output only.
-
#public_endpoint_enabled ⇒ Boolean
(also: #public_endpoint_enabled?)
Optional.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1IndexEndpoint
constructor
A new instance of GoogleCloudAiplatformV1IndexEndpoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1IndexEndpoint
Returns a new instance of GoogleCloudAiplatformV1IndexEndpoint.
11445 11446 11447 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11445 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this IndexEndpoint was created.
Corresponds to the JSON property createTime
11356 11357 11358 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11356 def create_time @create_time end |
#deployed_indexes ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployedIndex>
Output only. The indexes deployed in this endpoint.
Corresponds to the JSON property deployedIndexes
11361 11362 11363 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11361 def deployed_indexes @deployed_indexes end |
#description ⇒ String
The description of the IndexEndpoint.
Corresponds to the JSON property description
11366 11367 11368 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11366 def description @description end |
#display_name ⇒ String
Required. The display name of the IndexEndpoint. The name can be up to 128
characters long and can consist of any UTF-8 characters.
Corresponds to the JSON property displayName
11372 11373 11374 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11372 def display_name @display_name end |
#enable_private_service_connect ⇒ Boolean Also known as: enable_private_service_connect?
Optional. Deprecated: If true, expose the IndexEndpoint via private service
connect. Only one of the fields, network or enable_private_service_connect,
can be set.
Corresponds to the JSON property enablePrivateServiceConnect
11379 11380 11381 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11379 def enable_private_service_connect @enable_private_service_connect end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top-
level resource.
Corresponds to the JSON property encryptionSpec
11386 11387 11388 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11386 def encryption_spec @encryption_spec end |
#etag ⇒ String
Used to perform consistent read-modify-write updates. If not set, a blind "
overwrite" update happens.
Corresponds to the JSON property etag
11392 11393 11394 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11392 def etag @etag end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your IndexEndpoints. Label
keys and values can be no longer than 64 characters (Unicode codepoints), can
only contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. See https://goo.gl/xmQnxf for more
information and examples of labels.
Corresponds to the JSON property labels
11401 11402 11403 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11401 def labels @labels end |
#name ⇒ String
Output only. The resource name of the IndexEndpoint.
Corresponds to the JSON property name
11406 11407 11408 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11406 def name @name end |
#network ⇒ String
Optional. The full name of the Google Compute Engine network to which the
IndexEndpoint should be peered. Private services access must already be
configured for the network. If left unspecified, the Endpoint is not peered
with any network. network and private_service_connect_config are mutually
exclusive. Format: projects/project/global/networks/network`. Where
projectis a project number, as in '12345', andnetworkis network name.
Corresponds to the JSON propertynetwork`
11418 11419 11420 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11418 def network @network end |
#private_service_connect_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PrivateServiceConnectConfig
Represents configuration for private service connect.
Corresponds to the JSON property privateServiceConnectConfig
11423 11424 11425 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11423 def private_service_connect_config @private_service_connect_config end |
#public_endpoint_domain_name ⇒ String
Output only. If public_endpoint_enabled is true, this field will be populated
with the domain name to use for this index endpoint.
Corresponds to the JSON property publicEndpointDomainName
11429 11430 11431 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11429 def public_endpoint_domain_name @public_endpoint_domain_name end |
#public_endpoint_enabled ⇒ Boolean Also known as: public_endpoint_enabled?
Optional. If true, the deployed index will be accessible through public
endpoint.
Corresponds to the JSON property publicEndpointEnabled
11435 11436 11437 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11435 def public_endpoint_enabled @public_endpoint_enabled end |
#update_time ⇒ String
Output only. Timestamp when this IndexEndpoint was last updated. This
timestamp is not updated when the endpoint's DeployedIndexes are updated, e.g.
due to updates of the original Indexes they are the deployments of.
Corresponds to the JSON property updateTime
11443 11444 11445 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11443 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11450 11451 11452 11453 11454 11455 11456 11457 11458 11459 11460 11461 11462 11463 11464 11465 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11450 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @deployed_indexes = args[:deployed_indexes] if args.key?(:deployed_indexes) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @enable_private_service_connect = args[:enable_private_service_connect] if args.key?(:enable_private_service_connect) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @private_service_connect_config = args[:private_service_connect_config] if args.key?(:private_service_connect_config) @public_endpoint_domain_name = args[:public_endpoint_domain_name] if args.key?(:public_endpoint_domain_name) @public_endpoint_enabled = args[:public_endpoint_enabled] if args.key?(:public_endpoint_enabled) @update_time = args[:update_time] if args.key?(:update_time) end |