Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexPrivateEndpoints
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexPrivateEndpoints
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
IndexPrivateEndpoints proto is used to provide paths for users to send requests via private endpoints (e.g. private service access, private service connect). To send request via private service access, use match_grpc_address. To send request via private service connect, use service_attachment.
Instance Attribute Summary collapse
-
#match_grpc_address ⇒ String
Output only.
-
#psc_automated_endpoints ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PscAutomatedEndpoints>
Output only.
-
#service_attachment ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1IndexPrivateEndpoints
constructor
A new instance of GoogleCloudAiplatformV1IndexPrivateEndpoints.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1IndexPrivateEndpoints
Returns a new instance of GoogleCloudAiplatformV1IndexPrivateEndpoints.
20148 20149 20150 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20148 def initialize(**args) update!(**args) end |
Instance Attribute Details
#match_grpc_address ⇒ String
Output only. The ip address used to send match gRPC requests.
Corresponds to the JSON property matchGrpcAddress
20134 20135 20136 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20134 def match_grpc_address @match_grpc_address end |
#psc_automated_endpoints ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PscAutomatedEndpoints>
Output only. PscAutomatedEndpoints is populated if private service connect is
enabled if PscAutomatedConfig is set.
Corresponds to the JSON property pscAutomatedEndpoints
20140 20141 20142 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20140 def psc_automated_endpoints @psc_automated_endpoints end |
#service_attachment ⇒ String
Output only. The name of the service attachment resource. Populated if private
service connect is enabled.
Corresponds to the JSON property serviceAttachment
20146 20147 20148 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20146 def @service_attachment end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20153 20154 20155 20156 20157 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20153 def update!(**args) @match_grpc_address = args[:match_grpc_address] if args.key?(:match_grpc_address) @psc_automated_endpoints = args[:psc_automated_endpoints] if args.key?(:psc_automated_endpoints) @service_attachment = args[:service_attachment] if args.key?(:service_attachment) end |