Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexPrivateEndpoints

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

IndexPrivateEndpoints proto is used to provide paths for users to send requests via private endpoints (e.g. private service access, private service connect). To send request via private service access, use match_grpc_address. To send request via private service connect, use service_attachment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1IndexPrivateEndpoints

Returns a new instance of GoogleCloudAiplatformV1IndexPrivateEndpoints.



12017
12018
12019
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12017

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#match_grpc_addressString

Output only. The ip address used to send match gRPC requests. Corresponds to the JSON property matchGrpcAddress

Returns:

  • (String)


12003
12004
12005
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12003

def match_grpc_address
  @match_grpc_address
end

#psc_automated_endpointsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PscAutomatedEndpoints>

Output only. PscAutomatedEndpoints is populated if private service connect is enabled if PscAutomatedConfig is set. Corresponds to the JSON property pscAutomatedEndpoints



12009
12010
12011
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12009

def psc_automated_endpoints
  @psc_automated_endpoints
end

#service_attachmentString

Output only. The name of the service attachment resource. Populated if private service connect is enabled. Corresponds to the JSON property serviceAttachment

Returns:

  • (String)


12015
12016
12017
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12015

def service_attachment
  @service_attachment
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12022
12023
12024
12025
12026
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12022

def update!(**args)
  @match_grpc_address = args[:match_grpc_address] if args.key?(:match_grpc_address)
  @psc_automated_endpoints = args[:psc_automated_endpoints] if args.key?(:psc_automated_endpoints)
  @service_attachment = args[:service_attachment] if args.key?(:service_attachment)
end