Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IngestEventsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for MemoryBankService.IngestEvents.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1IngestEventsRequest

Returns a new instance of GoogleCloudAiplatformV1IngestEventsRequest.



21085
21086
21087
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21085

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#direct_contents_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1IngestionDirectContentsSource

Ingest events directly from the request. Corresponds to the JSON property directContentsSource



21023
21024
21025
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21023

def direct_contents_source
  @direct_contents_source
end

#disable_memory_revisionsBoolean Also known as: disable_memory_revisions?

Optional. If true, no revisions will be created for this request. Corresponds to the JSON property disableMemoryRevisions

Returns:

  • (Boolean)


21028
21029
21030
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21028

def disable_memory_revisions
  @disable_memory_revisions
end

#force_flushBoolean Also known as: force_flush?

Optional. Forces a flush of all pending events in the stream and triggers memory generation immediately bypassing any conditions configured in the generation_trigger_config. Corresponds to the JSON property forceFlush

Returns:

  • (Boolean)


21036
21037
21038
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21036

def force_flush
  @force_flush
end

#generation_trigger_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryGenerationTriggerConfig

Represents configuration for triggering generation. Corresponds to the JSON property generationTriggerConfig



21042
21043
21044
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21042

def generation_trigger_config
  @generation_trigger_config
end

#metadataHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryMetadataValue>

Optional. User-provided metadata for the generated memories. This is not generated by Memory Bank. Corresponds to the JSON property metadata



21048
21049
21050
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21048

def 
  @metadata
end

#metadata_merge_strategyString

Optional. The strategy to use when applying metadata to existing memories. Corresponds to the JSON property metadataMergeStrategy

Returns:

  • (String)


21053
21054
21055
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21053

def 
  @metadata_merge_strategy
end

#revision_expire_timeString

Optional. Timestamp of when the revision is considered expired. If not set, the memory revision will be kept until manually deleted. Corresponds to the JSON property revisionExpireTime

Returns:

  • (String)


21059
21060
21061
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21059

def revision_expire_time
  @revision_expire_time
end

#revision_labelsHash<String,String>

Optional. Labels to be applied to the generated memory revisions. For example, you can use this to label a revision with its data source. Corresponds to the JSON property revisionLabels

Returns:

  • (Hash<String,String>)


21065
21066
21067
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21065

def revision_labels
  @revision_labels
end

#revision_ttlString

Optional. The TTL for the revision. The expiration time is computed: now + TTL. Corresponds to the JSON property revisionTtl

Returns:

  • (String)


21070
21071
21072
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21070

def revision_ttl
  @revision_ttl
end

#scopeHash<String,String>

Required. The scope of the memories that should be generated from the stream. Memories will be consolidated across memories with the same scope. Scope values cannot contain the wildcard character '*'. Corresponds to the JSON property scope

Returns:

  • (Hash<String,String>)


21077
21078
21079
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21077

def scope
  @scope
end

#stream_idString

Optional. The ID of the stream to ingest events into. If not provided, a new one will be created. Corresponds to the JSON property streamId

Returns:

  • (String)


21083
21084
21085
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21083

def stream_id
  @stream_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21090
21091
21092
21093
21094
21095
21096
21097
21098
21099
21100
21101
21102
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21090

def update!(**args)
  @direct_contents_source = args[:direct_contents_source] if args.key?(:direct_contents_source)
  @disable_memory_revisions = args[:disable_memory_revisions] if args.key?(:disable_memory_revisions)
  @force_flush = args[:force_flush] if args.key?(:force_flush)
  @generation_trigger_config = args[:generation_trigger_config] if args.key?(:generation_trigger_config)
  @metadata = args[:metadata] if args.key?(:metadata)
  @metadata_merge_strategy = args[:metadata_merge_strategy] if args.key?(:metadata_merge_strategy)
  @revision_expire_time = args[:revision_expire_time] if args.key?(:revision_expire_time)
  @revision_labels = args[:revision_labels] if args.key?(:revision_labels)
  @revision_ttl = args[:revision_ttl] if args.key?(:revision_ttl)
  @scope = args[:scope] if args.key?(:scope)
  @stream_id = args[:stream_id] if args.key?(:stream_id)
end