Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IngestEventsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for MemoryBankService.IngestEvents.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1IngestEventsRequest

Returns a new instance of GoogleCloudAiplatformV1IngestEventsRequest.



20642
20643
20644
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20642

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#direct_contents_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1IngestionDirectContentsSource

Ingest events directly from the request. Corresponds to the JSON property directContentsSource



20580
20581
20582
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20580

def direct_contents_source
  @direct_contents_source
end

#disable_memory_revisionsBoolean Also known as: disable_memory_revisions?

Optional. If true, no revisions will be created for this request. Corresponds to the JSON property disableMemoryRevisions

Returns:

  • (Boolean)


20585
20586
20587
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20585

def disable_memory_revisions
  @disable_memory_revisions
end

#force_flushBoolean Also known as: force_flush?

Optional. Forces a flush of all pending events in the stream and triggers memory generation immediately bypassing any conditions configured in the generation_trigger_config. Corresponds to the JSON property forceFlush

Returns:

  • (Boolean)


20593
20594
20595
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20593

def force_flush
  @force_flush
end

#generation_trigger_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryGenerationTriggerConfig

Represents configuration for triggering generation. Corresponds to the JSON property generationTriggerConfig



20599
20600
20601
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20599

def generation_trigger_config
  @generation_trigger_config
end

#metadataHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryMetadataValue>

Optional. User-provided metadata for the generated memories. This is not generated by Memory Bank. Corresponds to the JSON property metadata



20605
20606
20607
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20605

def 
  @metadata
end

#metadata_merge_strategyString

Optional. The strategy to use when applying metadata to existing memories. Corresponds to the JSON property metadataMergeStrategy

Returns:

  • (String)


20610
20611
20612
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20610

def 
  @metadata_merge_strategy
end

#revision_expire_timeString

Optional. Timestamp of when the revision is considered expired. If not set, the memory revision will be kept until manually deleted. Corresponds to the JSON property revisionExpireTime

Returns:

  • (String)


20616
20617
20618
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20616

def revision_expire_time
  @revision_expire_time
end

#revision_labelsHash<String,String>

Optional. Labels to be applied to the generated memory revisions. For example, you can use this to label a revision with its data source. Corresponds to the JSON property revisionLabels

Returns:

  • (Hash<String,String>)


20622
20623
20624
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20622

def revision_labels
  @revision_labels
end

#revision_ttlString

Optional. The TTL for the revision. The expiration time is computed: now + TTL. Corresponds to the JSON property revisionTtl

Returns:

  • (String)


20627
20628
20629
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20627

def revision_ttl
  @revision_ttl
end

#scopeHash<String,String>

Required. The scope of the memories that should be generated from the stream. Memories will be consolidated across memories with the same scope. Scope values cannot contain the wildcard character '*'. Corresponds to the JSON property scope

Returns:

  • (Hash<String,String>)


20634
20635
20636
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20634

def scope
  @scope
end

#stream_idString

Optional. The ID of the stream to ingest events into. If not provided, a new one will be created. Corresponds to the JSON property streamId

Returns:

  • (String)


20640
20641
20642
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20640

def stream_id
  @stream_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20647
20648
20649
20650
20651
20652
20653
20654
20655
20656
20657
20658
20659
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20647

def update!(**args)
  @direct_contents_source = args[:direct_contents_source] if args.key?(:direct_contents_source)
  @disable_memory_revisions = args[:disable_memory_revisions] if args.key?(:disable_memory_revisions)
  @force_flush = args[:force_flush] if args.key?(:force_flush)
  @generation_trigger_config = args[:generation_trigger_config] if args.key?(:generation_trigger_config)
  @metadata = args[:metadata] if args.key?(:metadata)
  @metadata_merge_strategy = args[:metadata_merge_strategy] if args.key?(:metadata_merge_strategy)
  @revision_expire_time = args[:revision_expire_time] if args.key?(:revision_expire_time)
  @revision_labels = args[:revision_labels] if args.key?(:revision_labels)
  @revision_ttl = args[:revision_ttl] if args.key?(:revision_ttl)
  @scope = args[:scope] if args.key?(:scope)
  @stream_id = args[:stream_id] if args.key?(:stream_id)
end