Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IngestEventsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for MemoryBankService.IngestEvents.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1IngestEventsRequest

Returns a new instance of GoogleCloudAiplatformV1IngestEventsRequest.



20260
20261
20262
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20260

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#direct_contents_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1IngestionDirectContentsSource

Ingest events directly from the request. Corresponds to the JSON property directContentsSource



20198
20199
20200
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20198

def direct_contents_source
  @direct_contents_source
end

#disable_memory_revisionsBoolean Also known as: disable_memory_revisions?

Optional. If true, no revisions will be created for this request. Corresponds to the JSON property disableMemoryRevisions

Returns:

  • (Boolean)


20203
20204
20205
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20203

def disable_memory_revisions
  @disable_memory_revisions
end

#force_flushBoolean Also known as: force_flush?

Optional. Forces a flush of all pending events in the stream and triggers memory generation immediately bypassing any conditions configured in the generation_trigger_config. Corresponds to the JSON property forceFlush

Returns:

  • (Boolean)


20211
20212
20213
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20211

def force_flush
  @force_flush
end

#generation_trigger_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryGenerationTriggerConfig

Represents configuration for triggering generation. Corresponds to the JSON property generationTriggerConfig



20217
20218
20219
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20217

def generation_trigger_config
  @generation_trigger_config
end

#metadataHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryMetadataValue>

Optional. User-provided metadata for the generated memories. This is not generated by Memory Bank. Corresponds to the JSON property metadata



20223
20224
20225
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20223

def 
  @metadata
end

#metadata_merge_strategyString

Optional. The strategy to use when applying metadata to existing memories. Corresponds to the JSON property metadataMergeStrategy

Returns:

  • (String)


20228
20229
20230
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20228

def 
  @metadata_merge_strategy
end

#revision_expire_timeString

Optional. Timestamp of when the revision is considered expired. If not set, the memory revision will be kept until manually deleted. Corresponds to the JSON property revisionExpireTime

Returns:

  • (String)


20234
20235
20236
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20234

def revision_expire_time
  @revision_expire_time
end

#revision_labelsHash<String,String>

Optional. Labels to be applied to the generated memory revisions. For example, you can use this to label a revision with its data source. Corresponds to the JSON property revisionLabels

Returns:

  • (Hash<String,String>)


20240
20241
20242
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20240

def revision_labels
  @revision_labels
end

#revision_ttlString

Optional. The TTL for the revision. The expiration time is computed: now + TTL. Corresponds to the JSON property revisionTtl

Returns:

  • (String)


20245
20246
20247
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20245

def revision_ttl
  @revision_ttl
end

#scopeHash<String,String>

Required. The scope of the memories that should be generated from the stream. Memories will be consolidated across memories with the same scope. Scope values cannot contain the wildcard character '*'. Corresponds to the JSON property scope

Returns:

  • (Hash<String,String>)


20252
20253
20254
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20252

def scope
  @scope
end

#stream_idString

Optional. The ID of the stream to ingest events into. If not provided, a new one will be created. Corresponds to the JSON property streamId

Returns:

  • (String)


20258
20259
20260
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20258

def stream_id
  @stream_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20265
20266
20267
20268
20269
20270
20271
20272
20273
20274
20275
20276
20277
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20265

def update!(**args)
  @direct_contents_source = args[:direct_contents_source] if args.key?(:direct_contents_source)
  @disable_memory_revisions = args[:disable_memory_revisions] if args.key?(:disable_memory_revisions)
  @force_flush = args[:force_flush] if args.key?(:force_flush)
  @generation_trigger_config = args[:generation_trigger_config] if args.key?(:generation_trigger_config)
  @metadata = args[:metadata] if args.key?(:metadata)
  @metadata_merge_strategy = args[:metadata_merge_strategy] if args.key?(:metadata_merge_strategy)
  @revision_expire_time = args[:revision_expire_time] if args.key?(:revision_expire_time)
  @revision_labels = args[:revision_labels] if args.key?(:revision_labels)
  @revision_ttl = args[:revision_ttl] if args.key?(:revision_ttl)
  @scope = args[:scope] if args.key?(:scope)
  @stream_id = args[:stream_id] if args.key?(:stream_id)
end