Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IngestEventsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for MemoryBankService.IngestEvents.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1IngestEventsRequest

Returns a new instance of GoogleCloudAiplatformV1IngestEventsRequest.



19893
19894
19895
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19893

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#direct_contents_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1IngestionDirectContentsSource

Ingest events directly from the request. Corresponds to the JSON property directContentsSource



19865
19866
19867
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19865

def direct_contents_source
  @direct_contents_source
end

#force_flushBoolean Also known as: force_flush?

Optional. Forces a flush of all pending events in the stream and triggers memory generation immediately bypassing any conditions configured in the generation_trigger_config. Corresponds to the JSON property forceFlush

Returns:

  • (Boolean)


19872
19873
19874
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19872

def force_flush
  @force_flush
end

#generation_trigger_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryGenerationTriggerConfig

Represents configuration for triggering generation. Corresponds to the JSON property generationTriggerConfig



19878
19879
19880
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19878

def generation_trigger_config
  @generation_trigger_config
end

#scopeHash<String,String>

Required. The scope of the memories that should be generated from the stream. Memories will be consolidated across memories with the same scope. Scope values cannot contain the wildcard character '*'. Corresponds to the JSON property scope

Returns:

  • (Hash<String,String>)


19885
19886
19887
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19885

def scope
  @scope
end

#stream_idString

Optional. The ID of the stream to ingest events into. If not provided, a new one will be created. Corresponds to the JSON property streamId

Returns:

  • (String)


19891
19892
19893
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19891

def stream_id
  @stream_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19898
19899
19900
19901
19902
19903
19904
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19898

def update!(**args)
  @direct_contents_source = args[:direct_contents_source] if args.key?(:direct_contents_source)
  @force_flush = args[:force_flush] if args.key?(:force_flush)
  @generation_trigger_config = args[:generation_trigger_config] if args.key?(:generation_trigger_config)
  @scope = args[:scope] if args.key?(:scope)
  @stream_id = args[:stream_id] if args.key?(:stream_id)
end