Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IntegratedGradientsAttribution
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IntegratedGradientsAttribution
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
An attribution method that computes the Aumann-Shapley value taking advantage of the model's fully differentiable structure. Refer to this paper for more details: https://arxiv.org/abs/1703.01365
Instance Attribute Summary collapse
-
#blur_baseline_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BlurBaselineConfig
Config for blur baseline.
-
#smooth_grad_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SmoothGradConfig
Config for SmoothGrad approximation of gradients.
-
#step_count ⇒ Fixnum
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1IntegratedGradientsAttribution
constructor
A new instance of GoogleCloudAiplatformV1IntegratedGradientsAttribution.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1IntegratedGradientsAttribution
Returns a new instance of GoogleCloudAiplatformV1IntegratedGradientsAttribution.
14031 14032 14033 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14031 def initialize(**args) update!(**args) end |
Instance Attribute Details
#blur_baseline_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BlurBaselineConfig
Config for blur baseline. When enabled, a linear path from the maximally
blurred image to the input image is created. Using a blurred baseline instead
of zero (black image) is motivated by the BlurIG approach explained here:
https://arxiv.org/abs/2004.03383
Corresponds to the JSON property blurBaselineConfig
14013 14014 14015 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14013 def blur_baseline_config @blur_baseline_config end |
#smooth_grad_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SmoothGradConfig
Config for SmoothGrad approximation of gradients. When enabled, the gradients
are approximated by averaging the gradients from noisy samples in the vicinity
of the inputs. Adding noise can help improve the computed gradients. Refer to
this paper for more details: https://arxiv.org/pdf/1706.03825.pdf
Corresponds to the JSON property smoothGradConfig
14021 14022 14023 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14021 def smooth_grad_config @smooth_grad_config end |
#step_count ⇒ Fixnum
Required. The number of steps for approximating the path integral. A good
value to start is 50 and gradually increase until the sum to diff property is
within the desired error range. Valid range of its value is [1, 100],
inclusively.
Corresponds to the JSON property stepCount
14029 14030 14031 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14029 def step_count @step_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14036 14037 14038 14039 14040 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14036 def update!(**args) @blur_baseline_config = args[:blur_baseline_config] if args.key?(:blur_baseline_config) @smooth_grad_config = args[:smooth_grad_config] if args.key?(:smooth_grad_config) @step_count = args[:step_count] if args.key?(:step_count) end |