Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IntegratedGradientsAttribution

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

An attribution method that computes the Aumann-Shapley value taking advantage of the model's fully differentiable structure. Refer to this paper for more details: https://arxiv.org/abs/1703.01365

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1IntegratedGradientsAttribution

Returns a new instance of GoogleCloudAiplatformV1IntegratedGradientsAttribution.



13892
13893
13894
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13892

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blur_baseline_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1BlurBaselineConfig

Config for blur baseline. When enabled, a linear path from the maximally blurred image to the input image is created. Using a blurred baseline instead of zero (black image) is motivated by the BlurIG approach explained here: https://arxiv.org/abs/2004.03383 Corresponds to the JSON property blurBaselineConfig



13874
13875
13876
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13874

def blur_baseline_config
  @blur_baseline_config
end

#smooth_grad_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SmoothGradConfig

Config for SmoothGrad approximation of gradients. When enabled, the gradients are approximated by averaging the gradients from noisy samples in the vicinity of the inputs. Adding noise can help improve the computed gradients. Refer to this paper for more details: https://arxiv.org/pdf/1706.03825.pdf Corresponds to the JSON property smoothGradConfig



13882
13883
13884
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13882

def smooth_grad_config
  @smooth_grad_config
end

#step_countFixnum

Required. The number of steps for approximating the path integral. A good value to start is 50 and gradually increase until the sum to diff property is within the desired error range. Valid range of its value is [1, 100], inclusively. Corresponds to the JSON property stepCount

Returns:

  • (Fixnum)


13890
13891
13892
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13890

def step_count
  @step_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13897
13898
13899
13900
13901
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13897

def update!(**args)
  @blur_baseline_config = args[:blur_baseline_config] if args.key?(:blur_baseline_config)
  @smooth_grad_config = args[:smooth_grad_config] if args.key?(:smooth_grad_config)
  @step_count = args[:step_count] if args.key?(:step_count)
end