Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IntermediateExtractedMemory

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

An extracted memory that is the intermediate result before consolidation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1IntermediateExtractedMemory

Returns a new instance of GoogleCloudAiplatformV1IntermediateExtractedMemory.



20183
20184
20185
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20183

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contextString

Output only. Represents the explanation of why the information was extracted from the source content. Corresponds to the JSON property context

Returns:

  • (String)


20171
20172
20173
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20171

def context
  @context
end

#factString

Output only. Represents the fact of the extracted memory. Corresponds to the JSON property fact

Returns:

  • (String)


20176
20177
20178
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20176

def fact
  @fact
end

#structured_dataHash<String,Object>

Output only. Represents the structured value of the extracted memory. Corresponds to the JSON property structuredData

Returns:

  • (Hash<String,Object>)


20181
20182
20183
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20181

def structured_data
  @structured_data
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20188
20189
20190
20191
20192
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20188

def update!(**args)
  @context = args[:context] if args.key?(:context)
  @fact = args[:fact] if args.key?(:fact)
  @structured_data = args[:structured_data] if args.key?(:structured_data)
end