Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IntermediateExtractedMemory

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

An extracted memory that is the intermediate result before consolidation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1IntermediateExtractedMemory

Returns a new instance of GoogleCloudAiplatformV1IntermediateExtractedMemory.



19114
19115
19116
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19114

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contextString

Output only. Represents the explanation of why the information was extracted from the source content. Corresponds to the JSON property context

Returns:

  • (String)


19102
19103
19104
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19102

def context
  @context
end

#factString

Output only. Represents the fact of the extracted memory. Corresponds to the JSON property fact

Returns:

  • (String)


19107
19108
19109
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19107

def fact
  @fact
end

#structured_dataHash<String,Object>

Output only. Represents the structured value of the extracted memory. Corresponds to the JSON property structuredData

Returns:

  • (Hash<String,Object>)


19112
19113
19114
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19112

def structured_data
  @structured_data
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19119
19120
19121
19122
19123
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19119

def update!(**args)
  @context = args[:context] if args.key?(:context)
  @fact = args[:fact] if args.key?(:fact)
  @structured_data = args[:structured_data] if args.key?(:structured_data)
end