Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IntermediateExtractedMemory
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IntermediateExtractedMemory
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
An extracted memory that is the intermediate result before consolidation.
Instance Attribute Summary collapse
-
#context ⇒ String
Output only.
-
#fact ⇒ String
Output only.
-
#structured_data ⇒ Hash<String,Object>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1IntermediateExtractedMemory
constructor
A new instance of GoogleCloudAiplatformV1IntermediateExtractedMemory.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1IntermediateExtractedMemory
Returns a new instance of GoogleCloudAiplatformV1IntermediateExtractedMemory.
19114 19115 19116 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19114 def initialize(**args) update!(**args) end |
Instance Attribute Details
#context ⇒ String
Output only. Represents the explanation of why the information was extracted
from the source content.
Corresponds to the JSON property context
19102 19103 19104 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19102 def context @context end |
#fact ⇒ String
Output only. Represents the fact of the extracted memory.
Corresponds to the JSON property fact
19107 19108 19109 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19107 def fact @fact end |
#structured_data ⇒ Hash<String,Object>
Output only. Represents the structured value of the extracted memory.
Corresponds to the JSON property structuredData
19112 19113 19114 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19112 def structured_data @structured_data end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19119 19120 19121 19122 19123 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19119 def update!(**args) @context = args[:context] if args.key?(:context) @fact = args[:fact] if args.key?(:fact) @structured_data = args[:structured_data] if args.key?(:structured_data) end |