Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1InvokeRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1InvokeRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Request message for PredictionService.Invoke.
Instance Attribute Summary collapse
-
#deployed_model_id ⇒ String
ID of the DeployedModel that serves the invoke request.
-
#http_body ⇒ Google::Apis::AiplatformV1::GoogleApiHttpBody
Message that represents an arbitrary HTTP body.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1InvokeRequest
constructor
A new instance of GoogleCloudAiplatformV1InvokeRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1InvokeRequest
Returns a new instance of GoogleCloudAiplatformV1InvokeRequest.
18084 18085 18086 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18084 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deployed_model_id ⇒ String
ID of the DeployedModel that serves the invoke request.
Corresponds to the JSON property deployedModelId
18062 18063 18064 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18062 def deployed_model_id @deployed_model_id end |
#http_body ⇒ Google::Apis::AiplatformV1::GoogleApiHttpBody
Message that represents an arbitrary HTTP body. It should only be used for
payload formats that can't be represented as JSON, such as raw binary or an
HTML page. This message can be used both in streaming and non-streaming API
methods in the request as well as the response. It can be used as a top-level
request field, which is convenient if one wants to extract parameters from
either the URL or HTTP template into the request fields and also want access
to the raw HTTP body. Example: message GetResourceRequest // A unique
request id. string request_id = 1; // The raw HTTP body is bound to this field.
google.api.HttpBody http_body = 2; service ResourceService rpc
GetResource(GetResourceRequest) returns (google.api.HttpBody); rpc
UpdateResource(google.api.HttpBody) returns (google.protobuf.Empty); Example
with streaming methods: service CaldavService rpc GetCalendar(stream google.
api.HttpBody) returns (stream google.api.HttpBody); rpc UpdateCalendar(stream
google.api.HttpBody) returns (stream google.api.HttpBody); Use of this type
only changes how the request and response bodies are handled, all other
features will continue to work unchanged.
Corresponds to the JSON property httpBody
18082 18083 18084 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18082 def http_body @http_body end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18089 18090 18091 18092 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18089 def update!(**args) @deployed_model_id = args[:deployed_model_id] if args.key?(:deployed_model_id) @http_body = args[:http_body] if args.key?(:http_body) end |