Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1KeepAliveProbe

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents the configuration for keep-alive probe. Contains configuration on a specified endpoint that a deployment host should use to keep the container alive based on the probe settings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1KeepAliveProbe

Returns a new instance of GoogleCloudAiplatformV1KeepAliveProbe.



19463
19464
19465
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19463

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#http_getGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1KeepAliveProbeHttpGet

Specifies the HTTP GET configuration for the probe. Corresponds to the JSON property httpGet



19455
19456
19457
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19455

def http_get
  @http_get
end

#max_secondsFixnum

Optional. Specifies the maximum duration (in seconds) to keep the instance alive via this probe. Can be a maximum of 3600 seconds (1 hour). Corresponds to the JSON property maxSeconds

Returns:

  • (Fixnum)


19461
19462
19463
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19461

def max_seconds
  @max_seconds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19468
19469
19470
19471
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19468

def update!(**args)
  @http_get = args[:http_get] if args.key?(:http_get)
  @max_seconds = args[:max_seconds] if args.key?(:max_seconds)
end