Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1KeepAliveProbe
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1KeepAliveProbe
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Represents the configuration for keep-alive probe. Contains configuration on a specified endpoint that a deployment host should use to keep the container alive based on the probe settings.
Instance Attribute Summary collapse
-
#http_get ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1KeepAliveProbeHttpGet
Specifies the HTTP GET configuration for the probe.
-
#max_seconds ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1KeepAliveProbe
constructor
A new instance of GoogleCloudAiplatformV1KeepAliveProbe.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1KeepAliveProbe
Returns a new instance of GoogleCloudAiplatformV1KeepAliveProbe.
19247 19248 19249 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19247 def initialize(**args) update!(**args) end |
Instance Attribute Details
#http_get ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1KeepAliveProbeHttpGet
Specifies the HTTP GET configuration for the probe.
Corresponds to the JSON property httpGet
19239 19240 19241 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19239 def http_get @http_get end |
#max_seconds ⇒ Fixnum
Optional. Specifies the maximum duration (in seconds) to keep the instance
alive via this probe. Can be a maximum of 3600 seconds (1 hour).
Corresponds to the JSON property maxSeconds
19245 19246 19247 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19245 def max_seconds @max_seconds end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19252 19253 19254 19255 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19252 def update!(**args) @http_get = args[:http_get] if args.key?(:http_get) @max_seconds = args[:max_seconds] if args.key?(:max_seconds) end |