Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ListCustomJobsResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ListCustomJobsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Response message for JobService.ListCustomJobs
Instance Attribute Summary collapse
-
#custom_jobs ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CustomJob>
List of CustomJobs in the requested page.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ListCustomJobsResponse
constructor
A new instance of GoogleCloudAiplatformV1ListCustomJobsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ListCustomJobsResponse
Returns a new instance of GoogleCloudAiplatformV1ListCustomJobsResponse.
14129 14130 14131 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14129 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_jobs ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CustomJob>
List of CustomJobs in the requested page.
Corresponds to the JSON property customJobs
14121 14122 14123 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14121 def custom_jobs @custom_jobs end |
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass to ListCustomJobsRequest.
page_token to obtain that page.
Corresponds to the JSON property nextPageToken
14127 14128 14129 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14127 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14134 14135 14136 14137 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14134 def update!(**args) @custom_jobs = args[:custom_jobs] if args.key?(:custom_jobs) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |