Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ListCustomJobsResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ListCustomJobsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Response message for JobService.ListCustomJobs
Instance Attribute Summary collapse
-
#custom_jobs ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CustomJob>
List of CustomJobs in the requested page.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ListCustomJobsResponse
constructor
A new instance of GoogleCloudAiplatformV1ListCustomJobsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ListCustomJobsResponse
Returns a new instance of GoogleCloudAiplatformV1ListCustomJobsResponse.
12529 12530 12531 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12529 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_jobs ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CustomJob>
List of CustomJobs in the requested page.
Corresponds to the JSON property customJobs
12521 12522 12523 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12521 def custom_jobs @custom_jobs end |
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass to ListCustomJobsRequest.
page_token to obtain that page.
Corresponds to the JSON property nextPageToken
12527 12528 12529 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12527 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12534 12535 12536 12537 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12534 def update!(**args) @custom_jobs = args[:custom_jobs] if args.key?(:custom_jobs) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |