Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ListMemoriesResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ListMemoriesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Response message for MemoryBankService.ListMemories.
Instance Attribute Summary collapse
-
#memories ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Memory>
List of Memories in the requested page.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ListMemoriesResponse
constructor
A new instance of GoogleCloudAiplatformV1ListMemoriesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ListMemoriesResponse
Returns a new instance of GoogleCloudAiplatformV1ListMemoriesResponse.
19183 19184 19185 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19183 def initialize(**args) update!(**args) end |
Instance Attribute Details
#memories ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Memory>
List of Memories in the requested page.
Corresponds to the JSON property memories
19175 19176 19177 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19175 def memories @memories end |
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass to ListMemoriesRequest.
page_token to obtain that page.
Corresponds to the JSON property nextPageToken
19181 19182 19183 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19181 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19188 19189 19190 19191 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19188 def update!(**args) @memories = args[:memories] if args.key?(:memories) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |