Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ListMemoryRevisionsResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ListMemoryRevisionsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Response message for MemoryBankService.ListMemoryRevisions.
Instance Attribute Summary collapse
-
#memory_revisions ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryRevision>
The list of Memory Revisions in the request page.
-
#next_page_token ⇒ String
A token, which can be sent as
page_tokento retrieve the next page.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ListMemoryRevisionsResponse
constructor
A new instance of GoogleCloudAiplatformV1ListMemoryRevisionsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ListMemoryRevisionsResponse
Returns a new instance of GoogleCloudAiplatformV1ListMemoryRevisionsResponse.
19209 19210 19211 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19209 def initialize(**args) update!(**args) end |
Instance Attribute Details
#memory_revisions ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryRevision>
The list of Memory Revisions in the request page.
Corresponds to the JSON property memoryRevisions
19201 19202 19203 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19201 def memory_revisions @memory_revisions end |
#next_page_token ⇒ String
A token, which can be sent as page_token to retrieve the next page. If this
field is omitted, there are no subsequent pages.
Corresponds to the JSON property nextPageToken
19207 19208 19209 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19207 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19214 19215 19216 19217 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19214 def update!(**args) @memory_revisions = args[:memory_revisions] if args.key?(:memory_revisions) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |