Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ListModelVersionCheckpointsResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ListModelVersionCheckpointsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Response message for ModelService.ListModelVersionCheckpoints
Instance Attribute Summary collapse
-
#checkpoints ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelVersionCheckpoint>
List of Model Version checkpoints.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ListModelVersionCheckpointsResponse
constructor
A new instance of GoogleCloudAiplatformV1ListModelVersionCheckpointsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ListModelVersionCheckpointsResponse
Returns a new instance of GoogleCloudAiplatformV1ListModelVersionCheckpointsResponse.
14862 14863 14864 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14862 def initialize(**args) update!(**args) end |
Instance Attribute Details
#checkpoints ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelVersionCheckpoint>
List of Model Version checkpoints.
Corresponds to the JSON property checkpoints
14854 14855 14856 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14854 def checkpoints @checkpoints end |
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass to
ListModelVersionCheckpointsRequest.page_token to obtain that page.
Corresponds to the JSON property nextPageToken
14860 14861 14862 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14860 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14867 14868 14869 14870 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14867 def update!(**args) @checkpoints = args[:checkpoints] if args.key?(:checkpoints) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |