Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ListModelVersionsResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ListModelVersionsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Response message for ModelService.ListModelVersions
Instance Attribute Summary collapse
-
#models ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Model>
List of Model versions in the requested page.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ListModelVersionsResponse
constructor
A new instance of GoogleCloudAiplatformV1ListModelVersionsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ListModelVersionsResponse
Returns a new instance of GoogleCloudAiplatformV1ListModelVersionsResponse.
21419 21420 21421 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21419 def initialize(**args) update!(**args) end |
Instance Attribute Details
#models ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Model>
List of Model versions in the requested page. In the returned Model name field,
version ID instead of regvision tag will be included.
Corresponds to the JSON property models
21411 21412 21413 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21411 def models @models end |
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass to ListModelVersionsRequest.
page_token to obtain that page.
Corresponds to the JSON property nextPageToken
21417 21418 21419 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21417 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21424 21425 21426 21427 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21424 def update!(**args) @models = args[:models] if args.key?(:models) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |