Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ListModelVersionsResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ListModelVersionsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Response message for ModelService.ListModelVersions
Instance Attribute Summary collapse
-
#models ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Model>
List of Model versions in the requested page.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ListModelVersionsResponse
constructor
A new instance of GoogleCloudAiplatformV1ListModelVersionsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ListModelVersionsResponse
Returns a new instance of GoogleCloudAiplatformV1ListModelVersionsResponse.
20540 20541 20542 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20540 def initialize(**args) update!(**args) end |
Instance Attribute Details
#models ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Model>
List of Model versions in the requested page. In the returned Model name field,
version ID instead of regvision tag will be included.
Corresponds to the JSON property models
20532 20533 20534 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20532 def models @models end |
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass to ListModelVersionsRequest.
page_token to obtain that page.
Corresponds to the JSON property nextPageToken
20538 20539 20540 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20538 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20545 20546 20547 20548 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20545 def update!(**args) @models = args[:models] if args.key?(:models) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |