Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ListRagFilesResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ListRagFilesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Response message for VertexRagDataService.ListRagFiles.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
-
#rag_files ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagFile>
List of RagFiles in the requested page.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ListRagFilesResponse
constructor
A new instance of GoogleCloudAiplatformV1ListRagFilesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ListRagFilesResponse
Returns a new instance of GoogleCloudAiplatformV1ListRagFilesResponse.
14579 14580 14581 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14579 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass to ListRagFilesRequest.
page_token to obtain that page.
Corresponds to the JSON property nextPageToken
14572 14573 14574 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14572 def next_page_token @next_page_token end |
#rag_files ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagFile>
List of RagFiles in the requested page.
Corresponds to the JSON property ragFiles
14577 14578 14579 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14577 def rag_files @rag_files end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14584 14585 14586 14587 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14584 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @rag_files = args[:rag_files] if args.key?(:rag_files) end |