Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ListSavedQueriesResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ListSavedQueriesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Response message for DatasetService.ListSavedQueries.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
The standard List next-page token.
-
#saved_queries ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SavedQuery>
A list of SavedQueries that match the specified filter in the request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ListSavedQueriesResponse
constructor
A new instance of GoogleCloudAiplatformV1ListSavedQueriesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ListSavedQueriesResponse
Returns a new instance of GoogleCloudAiplatformV1ListSavedQueriesResponse.
15113 15114 15115 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15113 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
The standard List next-page token.
Corresponds to the JSON property nextPageToken
15106 15107 15108 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15106 def next_page_token @next_page_token end |
#saved_queries ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SavedQuery>
A list of SavedQueries that match the specified filter in the request.
Corresponds to the JSON property savedQueries
15111 15112 15113 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15111 def saved_queries @saved_queries end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15118 15119 15120 15121 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15118 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @saved_queries = args[:saved_queries] if args.key?(:saved_queries) end |