Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ListSchedulesResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ListSchedulesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Response message for ScheduleService.ListSchedules
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
-
#schedules ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schedule>
List of Schedules in the requested page.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ListSchedulesResponse
constructor
A new instance of GoogleCloudAiplatformV1ListSchedulesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ListSchedulesResponse
Returns a new instance of GoogleCloudAiplatformV1ListSchedulesResponse.
15362 15363 15364 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15362 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass to ListSchedulesRequest.
page_token to obtain that page.
Corresponds to the JSON property nextPageToken
15355 15356 15357 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15355 def next_page_token @next_page_token end |
#schedules ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schedule>
List of Schedules in the requested page.
Corresponds to the JSON property schedules
15360 15361 15362 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15360 def schedules @schedules end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15367 15368 15369 15370 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15367 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @schedules = args[:schedules] if args.key?(:schedules) end |