Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ListTrialsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Response message for VizierService.ListTrials.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ListTrialsResponse

Returns a new instance of GoogleCloudAiplatformV1ListTrialsResponse.



15337
15338
15339
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15337

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

Pass this token as the page_token field of the request for a subsequent call. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


15330
15331
15332
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15330

def next_page_token
  @next_page_token
end

#trialsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Trial>

The Trials associated with the Study. Corresponds to the JSON property trials



15335
15336
15337
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15335

def trials
  @trials
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15342
15343
15344
15345
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15342

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @trials = args[:trials] if args.key?(:trials)
end