Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ListTuningJobsResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ListTuningJobsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Response message for GenAiTuningService.ListTuningJobs
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
-
#tuning_jobs ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TuningJob>
List of TuningJobs in the requested page.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ListTuningJobsResponse
constructor
A new instance of GoogleCloudAiplatformV1ListTuningJobsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ListTuningJobsResponse
Returns a new instance of GoogleCloudAiplatformV1ListTuningJobsResponse.
16289 16290 16291 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16289 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass to ListTuningJobsRequest.
page_token to obtain that page.
Corresponds to the JSON property nextPageToken
16282 16283 16284 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16282 def next_page_token @next_page_token end |
#tuning_jobs ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TuningJob>
List of TuningJobs in the requested page.
Corresponds to the JSON property tuningJobs
16287 16288 16289 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16287 def tuning_jobs @tuning_jobs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16294 16295 16296 16297 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16294 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @tuning_jobs = args[:tuning_jobs] if args.key?(:tuning_jobs) end |