Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1LogprobsResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The log probabilities of the tokens generated by the model. This is useful for understanding the model's confidence in its predictions and for debugging. For example, you can use log probabilities to identify when the model is making a less confident prediction or to explore alternative responses that the model considered. A low log probability can also indicate that the model is " hallucinating" or generating factually incorrect information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1LogprobsResult

Returns a new instance of GoogleCloudAiplatformV1LogprobsResult.



23443
23444
23445
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23443

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chosen_candidatesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1LogprobsResultCandidate>

A list of the chosen candidate tokens at each decoding step. The length of this list is equal to the total number of decoding steps. Note that the chosen candidate might not be in top_candidates. Corresponds to the JSON property chosenCandidates



23435
23436
23437
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23435

def chosen_candidates
  @chosen_candidates
end

#top_candidatesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1LogprobsResultTopCandidates>

A list of the top candidate tokens at each decoding step. The length of this list is equal to the total number of decoding steps. Corresponds to the JSON property topCandidates



23441
23442
23443
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23441

def top_candidates
  @top_candidates
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23448
23449
23450
23451
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23448

def update!(**args)
  @chosen_candidates = args[:chosen_candidates] if args.key?(:chosen_candidates)
  @top_candidates = args[:top_candidates] if args.key?(:top_candidates)
end