Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1LogprobsResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The log probabilities of the tokens generated by the model. This is useful for understanding the model's confidence in its predictions and for debugging. For example, you can use log probabilities to identify when the model is making a less confident prediction or to explore alternative responses that the model considered. A low log probability can also indicate that the model is " hallucinating" or generating factually incorrect information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1LogprobsResult

Returns a new instance of GoogleCloudAiplatformV1LogprobsResult.



21288
21289
21290
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21288

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chosen_candidatesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1LogprobsResultCandidate>

A list of the chosen candidate tokens at each decoding step. The length of this list is equal to the total number of decoding steps. Note that the chosen candidate might not be in top_candidates. Corresponds to the JSON property chosenCandidates



21280
21281
21282
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21280

def chosen_candidates
  @chosen_candidates
end

#top_candidatesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1LogprobsResultTopCandidates>

A list of the top candidate tokens at each decoding step. The length of this list is equal to the total number of decoding steps. Corresponds to the JSON property topCandidates



21286
21287
21288
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21286

def top_candidates
  @top_candidates
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21293
21294
21295
21296
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21293

def update!(**args)
  @chosen_candidates = args[:chosen_candidates] if args.key?(:chosen_candidates)
  @top_candidates = args[:top_candidates] if args.key?(:top_candidates)
end