Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1LogprobsResult
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1LogprobsResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The log probabilities of the tokens generated by the model. This is useful for understanding the model's confidence in its predictions and for debugging. For example, you can use log probabilities to identify when the model is making a less confident prediction or to explore alternative responses that the model considered. A low log probability can also indicate that the model is " hallucinating" or generating factually incorrect information.
Instance Attribute Summary collapse
-
#chosen_candidates ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1LogprobsResultCandidate>
A list of the chosen candidate tokens at each decoding step.
-
#top_candidates ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1LogprobsResultTopCandidates>
A list of the top candidate tokens at each decoding step.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1LogprobsResult
constructor
A new instance of GoogleCloudAiplatformV1LogprobsResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1LogprobsResult
Returns a new instance of GoogleCloudAiplatformV1LogprobsResult.
21072 21073 21074 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21072 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chosen_candidates ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1LogprobsResultCandidate>
A list of the chosen candidate tokens at each decoding step. The length of
this list is equal to the total number of decoding steps. Note that the chosen
candidate might not be in top_candidates.
Corresponds to the JSON property chosenCandidates
21064 21065 21066 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21064 def chosen_candidates @chosen_candidates end |
#top_candidates ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1LogprobsResultTopCandidates>
A list of the top candidate tokens at each decoding step. The length of this
list is equal to the total number of decoding steps.
Corresponds to the JSON property topCandidates
21070 21071 21072 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21070 def top_candidates @top_candidates end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21077 21078 21079 21080 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21077 def update!(**args) @chosen_candidates = args[:chosen_candidates] if args.key?(:chosen_candidates) @top_candidates = args[:top_candidates] if args.key?(:top_candidates) end |