Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1LogprobsResultCandidate

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A single token and its associated log probability.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1LogprobsResultCandidate

Returns a new instance of GoogleCloudAiplatformV1LogprobsResultCandidate.



22654
22655
22656
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22654

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#log_probabilityFloat

The log probability of this token. A higher value indicates that the model was more confident in this token. The log probability can be used to assess the relative likelihood of different tokens and to identify when the model is uncertain. Corresponds to the JSON property logProbability

Returns:

  • (Float)


22639
22640
22641
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22639

def log_probability
  @log_probability
end

#tokenString

The token's string representation. Corresponds to the JSON property token

Returns:

  • (String)


22644
22645
22646
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22644

def token
  @token
end

#token_idFixnum

The token's numerical ID. While the token field provides the string representation of the token, the token_id is the numerical representation that the model uses internally. This can be useful for developers who want to build custom logic based on the model's vocabulary. Corresponds to the JSON property tokenId

Returns:

  • (Fixnum)


22652
22653
22654
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22652

def token_id
  @token_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22659
22660
22661
22662
22663
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22659

def update!(**args)
  @log_probability = args[:log_probability] if args.key?(:log_probability)
  @token = args[:token] if args.key?(:token)
  @token_id = args[:token_id] if args.key?(:token_id)
end