Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1LogprobsResultCandidate
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1LogprobsResultCandidate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A single token and its associated log probability.
Instance Attribute Summary collapse
-
#log_probability ⇒ Float
The log probability of this token.
-
#token ⇒ String
The token's string representation.
-
#token_id ⇒ Fixnum
The token's numerical ID.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1LogprobsResultCandidate
constructor
A new instance of GoogleCloudAiplatformV1LogprobsResultCandidate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1LogprobsResultCandidate
Returns a new instance of GoogleCloudAiplatformV1LogprobsResultCandidate.
21324 21325 21326 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21324 def initialize(**args) update!(**args) end |
Instance Attribute Details
#log_probability ⇒ Float
The log probability of this token. A higher value indicates that the model was
more confident in this token. The log probability can be used to assess the
relative likelihood of different tokens and to identify when the model is
uncertain.
Corresponds to the JSON property logProbability
21309 21310 21311 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21309 def log_probability @log_probability end |
#token ⇒ String
The token's string representation.
Corresponds to the JSON property token
21314 21315 21316 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21314 def token @token end |
#token_id ⇒ Fixnum
The token's numerical ID. While the token field provides the string
representation of the token, the token_id is the numerical representation
that the model uses internally. This can be useful for developers who want to
build custom logic based on the model's vocabulary.
Corresponds to the JSON property tokenId
21322 21323 21324 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21322 def token_id @token_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21329 21330 21331 21332 21333 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21329 def update!(**args) @log_probability = args[:log_probability] if args.key?(:log_probability) @token = args[:token] if args.key?(:token) @token_id = args[:token_id] if args.key?(:token_id) end |