Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1LogprobsResultTopCandidates

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A list of the top candidate tokens and their log probabilities at each decoding step. This can be used to see what other tokens the model considered.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1LogprobsResultTopCandidates

Returns a new instance of GoogleCloudAiplatformV1LogprobsResultTopCandidates.



22689
22690
22691
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22689

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#candidatesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1LogprobsResultCandidate>

The list of candidate tokens, sorted by log probability in descending order. Corresponds to the JSON property candidates



22687
22688
22689
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22687

def candidates
  @candidates
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22694
22695
22696
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22694

def update!(**args)
  @candidates = args[:candidates] if args.key?(:candidates)
end