Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1LogprobsResultTopCandidates

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A list of the top candidate tokens and their log probabilities at each decoding step. This can be used to see what other tokens the model considered.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1LogprobsResultTopCandidates

Returns a new instance of GoogleCloudAiplatformV1LogprobsResultTopCandidates.



22278
22279
22280
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22278

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#candidatesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1LogprobsResultCandidate>

The list of candidate tokens, sorted by log probability in descending order. Corresponds to the JSON property candidates



22276
22277
22278
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22276

def candidates
  @candidates
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22283
22284
22285
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22283

def update!(**args)
  @candidates = args[:candidates] if args.key?(:candidates)
end