Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1LogprobsResultTopCandidates
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1LogprobsResultTopCandidates
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A list of the top candidate tokens and their log probabilities at each decoding step. This can be used to see what other tokens the model considered.
Instance Attribute Summary collapse
-
#candidates ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1LogprobsResultCandidate>
The list of candidate tokens, sorted by log probability in descending order.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1LogprobsResultTopCandidates
constructor
A new instance of GoogleCloudAiplatformV1LogprobsResultTopCandidates.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1LogprobsResultTopCandidates
Returns a new instance of GoogleCloudAiplatformV1LogprobsResultTopCandidates.
21130 21131 21132 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21130 def initialize(**args) update!(**args) end |
Instance Attribute Details
#candidates ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1LogprobsResultCandidate>
The list of candidate tokens, sorted by log probability in descending order.
Corresponds to the JSON property candidates
21128 21129 21130 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21128 def candidates @candidates end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21135 21136 21137 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21135 def update!(**args) @candidates = args[:candidates] if args.key?(:candidates) end |