Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MachineSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Specification of a single machine.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1MachineSpec

Returns a new instance of GoogleCloudAiplatformV1MachineSpec.



16835
16836
16837
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16835

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accelerator_countFixnum

The number of accelerators to attach to the machine. Corresponds to the JSON property acceleratorCount

Returns:

  • (Fixnum)


16803
16804
16805
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16803

def accelerator_count
  @accelerator_count
end

#accelerator_typeString

Immutable. The type of accelerator(s) that may be attached to the machine as per accelerator_count. Corresponds to the JSON property acceleratorType

Returns:

  • (String)


16809
16810
16811
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16809

def accelerator_type
  @accelerator_type
end

#machine_typeString

Immutable. The type of the machine. See the list of machine types supported for prediction See the list of machine types supported for custom training. For DeployedModel this field is optional, and the default value is n1-standard-2. For BatchPredictionJob or as part of WorkerPoolSpec this field is required. Corresponds to the JSON property machineType

Returns:

  • (String)


16820
16821
16822
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16820

def machine_type
  @machine_type
end

#reservation_affinityGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ReservationAffinity

A ReservationAffinity can be used to configure a Vertex AI resource (e.g., a DeployedModel) to draw its Compute Engine resources from a Shared Reservation, or exclusively from on-demand capacity. Corresponds to the JSON property reservationAffinity



16827
16828
16829
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16827

def reservation_affinity
  @reservation_affinity
end

#tpu_topologyString

Immutable. The topology of the TPUs. Corresponds to the TPU topologies available from GKE. (Example: tpu_topology: "2x2x1"). Corresponds to the JSON property tpuTopology

Returns:

  • (String)


16833
16834
16835
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16833

def tpu_topology
  @tpu_topology
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16840
16841
16842
16843
16844
16845
16846
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16840

def update!(**args)
  @accelerator_count = args[:accelerator_count] if args.key?(:accelerator_count)
  @accelerator_type = args[:accelerator_type] if args.key?(:accelerator_type)
  @machine_type = args[:machine_type] if args.key?(:machine_type)
  @reservation_affinity = args[:reservation_affinity] if args.key?(:reservation_affinity)
  @tpu_topology = args[:tpu_topology] if args.key?(:tpu_topology)
end