Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MachineSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Specification of a single machine.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1MachineSpec

Returns a new instance of GoogleCloudAiplatformV1MachineSpec.



16435
16436
16437
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16435

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accelerator_countFixnum

The number of accelerators to attach to the machine. Corresponds to the JSON property acceleratorCount

Returns:

  • (Fixnum)


16403
16404
16405
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16403

def accelerator_count
  @accelerator_count
end

#accelerator_typeString

Immutable. The type of accelerator(s) that may be attached to the machine as per accelerator_count. Corresponds to the JSON property acceleratorType

Returns:

  • (String)


16409
16410
16411
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16409

def accelerator_type
  @accelerator_type
end

#machine_typeString

Immutable. The type of the machine. See the list of machine types supported for prediction See the list of machine types supported for custom training. For DeployedModel this field is optional, and the default value is n1-standard-2. For BatchPredictionJob or as part of WorkerPoolSpec this field is required. Corresponds to the JSON property machineType

Returns:

  • (String)


16420
16421
16422
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16420

def machine_type
  @machine_type
end

#reservation_affinityGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ReservationAffinity

A ReservationAffinity can be used to configure a Vertex AI resource (e.g., a DeployedModel) to draw its Compute Engine resources from a Shared Reservation, or exclusively from on-demand capacity. Corresponds to the JSON property reservationAffinity



16427
16428
16429
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16427

def reservation_affinity
  @reservation_affinity
end

#tpu_topologyString

Immutable. The topology of the TPUs. Corresponds to the TPU topologies available from GKE. (Example: tpu_topology: "2x2x1"). Corresponds to the JSON property tpuTopology

Returns:

  • (String)


16433
16434
16435
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16433

def tpu_topology
  @tpu_topology
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16440
16441
16442
16443
16444
16445
16446
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16440

def update!(**args)
  @accelerator_count = args[:accelerator_count] if args.key?(:accelerator_count)
  @accelerator_type = args[:accelerator_type] if args.key?(:accelerator_type)
  @machine_type = args[:machine_type] if args.key?(:machine_type)
  @reservation_affinity = args[:reservation_affinity] if args.key?(:reservation_affinity)
  @tpu_topology = args[:tpu_topology] if args.key?(:tpu_topology)
end