Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MachineSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MachineSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Specification of a single machine.
Instance Attribute Summary collapse
-
#accelerator_count ⇒ Fixnum
The number of accelerators to attach to the machine.
-
#accelerator_type ⇒ String
Immutable.
-
#machine_type ⇒ String
Immutable.
-
#reservation_affinity ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReservationAffinity
A ReservationAffinity can be used to configure a Vertex AI resource (e.g., a DeployedModel) to draw its Compute Engine resources from a Shared Reservation, or exclusively from on-demand capacity.
-
#tpu_topology ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1MachineSpec
constructor
A new instance of GoogleCloudAiplatformV1MachineSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1MachineSpec
Returns a new instance of GoogleCloudAiplatformV1MachineSpec.
15508 15509 15510 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15508 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accelerator_count ⇒ Fixnum
The number of accelerators to attach to the machine.
Corresponds to the JSON property acceleratorCount
15476 15477 15478 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15476 def accelerator_count @accelerator_count end |
#accelerator_type ⇒ String
Immutable. The type of accelerator(s) that may be attached to the machine as
per accelerator_count.
Corresponds to the JSON property acceleratorType
15482 15483 15484 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15482 def accelerator_type @accelerator_type end |
#machine_type ⇒ String
Immutable. The type of the machine. See the list of machine types supported
for prediction See the list of machine types supported for custom
training. For DeployedModel this field is optional, and the default
value is n1-standard-2. For BatchPredictionJob or as part of WorkerPoolSpec
this field is required.
Corresponds to the JSON property machineType
15493 15494 15495 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15493 def machine_type @machine_type end |
#reservation_affinity ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReservationAffinity
A ReservationAffinity can be used to configure a Vertex AI resource (e.g., a
DeployedModel) to draw its Compute Engine resources from a Shared Reservation,
or exclusively from on-demand capacity.
Corresponds to the JSON property reservationAffinity
15500 15501 15502 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15500 def reservation_affinity @reservation_affinity end |
#tpu_topology ⇒ String
Immutable. The topology of the TPUs. Corresponds to the TPU topologies
available from GKE. (Example: tpu_topology: "2x2x1").
Corresponds to the JSON property tpuTopology
15506 15507 15508 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15506 def tpu_topology @tpu_topology end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15513 15514 15515 15516 15517 15518 15519 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15513 def update!(**args) @accelerator_count = args[:accelerator_count] if args.key?(:accelerator_count) @accelerator_type = args[:accelerator_type] if args.key?(:accelerator_type) @machine_type = args[:machine_type] if args.key?(:machine_type) @reservation_affinity = args[:reservation_affinity] if args.key?(:reservation_affinity) @tpu_topology = args[:tpu_topology] if args.key?(:tpu_topology) end |