Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MachineSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MachineSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Specification of a single machine.
Instance Attribute Summary collapse
-
#accelerator_count ⇒ Fixnum
The number of accelerators to attach to the machine.
-
#accelerator_type ⇒ String
Immutable.
-
#machine_type ⇒ String
Immutable.
-
#tpu_topology ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1MachineSpec
constructor
A new instance of GoogleCloudAiplatformV1MachineSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1MachineSpec
Returns a new instance of GoogleCloudAiplatformV1MachineSpec.
11353 11354 11355 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11353 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accelerator_count ⇒ Fixnum
The number of accelerators to attach to the machine.
Corresponds to the JSON property acceleratorCount
11328 11329 11330 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11328 def accelerator_count @accelerator_count end |
#accelerator_type ⇒ String
Immutable. The type of accelerator(s) that may be attached to the machine as
per accelerator_count.
Corresponds to the JSON property acceleratorType
11334 11335 11336 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11334 def accelerator_type @accelerator_type end |
#machine_type ⇒ String
Immutable. The type of the machine. See the list of machine types supported
for prediction See the list of machine types supported for custom
training. For DeployedModel this field is optional, and the default
value is n1-standard-2. For BatchPredictionJob or as part of WorkerPoolSpec
this field is required.
Corresponds to the JSON property machineType
11345 11346 11347 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11345 def machine_type @machine_type end |
#tpu_topology ⇒ String
Immutable. The topology of the TPUs. Corresponds to the TPU topologies
available from GKE. (Example: tpu_topology: "2x2x1").
Corresponds to the JSON property tpuTopology
11351 11352 11353 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11351 def tpu_topology @tpu_topology end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11358 11359 11360 11361 11362 11363 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 11358 def update!(**args) @accelerator_count = args[:accelerator_count] if args.key?(:accelerator_count) @accelerator_type = args[:accelerator_type] if args.key?(:accelerator_type) @machine_type = args[:machine_type] if args.key?(:machine_type) @tpu_topology = args[:tpu_topology] if args.key?(:tpu_topology) end |