Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Memory

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A memory.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Memory

Returns a new instance of GoogleCloudAiplatformV1Memory.



23857
23858
23859
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23857

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Represents the timestamp when this Memory was created. Corresponds to the JSON property createTime

Returns:

  • (String)


23769
23770
23771
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23769

def create_time
  @create_time
end

#descriptionString

Optional. Represents the description of the Memory. Corresponds to the JSON property description

Returns:

  • (String)


23774
23775
23776
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23774

def description
  @description
end

#disable_memory_revisionsBoolean Also known as: disable_memory_revisions?

Optional. Input only. Indicates whether no revision will be created for this request. Corresponds to the JSON property disableMemoryRevisions

Returns:

  • (Boolean)


23780
23781
23782
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23780

def disable_memory_revisions
  @disable_memory_revisions
end

#display_nameString

Optional. Represents the display name of the Memory. Corresponds to the JSON property displayName

Returns:

  • (String)


23786
23787
23788
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23786

def display_name
  @display_name
end

#expire_timeString

Optional. Represents the timestamp of when this resource is considered expired. This is always provided on output when expiration is set on input, regardless of whether expire_time or ttl was provided. Corresponds to the JSON property expireTime

Returns:

  • (String)


23793
23794
23795
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23793

def expire_time
  @expire_time
end

#factString

Optional. Represents semantic knowledge extracted from the source content. Corresponds to the JSON property fact

Returns:

  • (String)


23798
23799
23800
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23798

def fact
  @fact
end

#metadataHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryMetadataValue>

Optional. Represents user-provided metadata for the Memory. This information was provided when creating, updating, or generating the Memory. It was not generated by Memory Bank. Corresponds to the JSON property metadata



23805
23806
23807
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23805

def 
  @metadata
end

#nameString

Identifier. Represents the resource name of the Memory. Format: projects/ project/locations/location/reasoningEngines/reasoning_engine/memories/ memory` Corresponds to the JSON propertyname`

Returns:

  • (String)


23812
23813
23814
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23812

def name
  @name
end

#revision_expire_timeString

Optional. Input only. Represents the timestamp of when the revision is considered expired. If not set, the memory revision will be kept until manually deleted. Corresponds to the JSON property revisionExpireTime

Returns:

  • (String)


23819
23820
23821
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23819

def revision_expire_time
  @revision_expire_time
end

#revision_labelsHash<String,String>

Optional. Input only. Represents the labels to apply to the Memory Revision created as a result of this request. Corresponds to the JSON property revisionLabels

Returns:

  • (Hash<String,String>)


23825
23826
23827
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23825

def revision_labels
  @revision_labels
end

#revision_ttlString

Optional. Input only. Represents the TTL for the revision. The expiration time is computed: now + TTL. Corresponds to the JSON property revisionTtl

Returns:

  • (String)


23831
23832
23833
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23831

def revision_ttl
  @revision_ttl
end

#scopeHash<String,String>

Required. Immutable. Represents the scope of the Memory. Memories are isolated within their scope. The scope is defined when creating or generating memories. Scope values cannot contain the wildcard character '*'. Corresponds to the JSON property scope

Returns:

  • (Hash<String,String>)


23838
23839
23840
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23838

def scope
  @scope
end

#topicsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryTopicId>

Optional. Represents the Topics of the Memory. Corresponds to the JSON property topics



23843
23844
23845
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23843

def topics
  @topics
end

#ttlString

Optional. Input only. Represents the TTL for this resource. The expiration time is computed: now + TTL. Corresponds to the JSON property ttl

Returns:

  • (String)


23849
23850
23851
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23849

def ttl
  @ttl
end

#update_timeString

Output only. Represents the timestamp when this Memory was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


23855
23856
23857
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23855

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23862
23863
23864
23865
23866
23867
23868
23869
23870
23871
23872
23873
23874
23875
23876
23877
23878
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23862

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @disable_memory_revisions = args[:disable_memory_revisions] if args.key?(:disable_memory_revisions)
  @display_name = args[:display_name] if args.key?(:display_name)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @fact = args[:fact] if args.key?(:fact)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @revision_expire_time = args[:revision_expire_time] if args.key?(:revision_expire_time)
  @revision_labels = args[:revision_labels] if args.key?(:revision_labels)
  @revision_ttl = args[:revision_ttl] if args.key?(:revision_ttl)
  @scope = args[:scope] if args.key?(:scope)
  @topics = args[:topics] if args.key?(:topics)
  @ttl = args[:ttl] if args.key?(:ttl)
  @update_time = args[:update_time] if args.key?(:update_time)
end