Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Memory

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A memory.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Memory

Returns a new instance of GoogleCloudAiplatformV1Memory.



22634
22635
22636
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22634

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Represents the timestamp when this Memory was created. Corresponds to the JSON property createTime

Returns:

  • (String)


22546
22547
22548
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22546

def create_time
  @create_time
end

#descriptionString

Optional. Represents the description of the Memory. Corresponds to the JSON property description

Returns:

  • (String)


22551
22552
22553
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22551

def description
  @description
end

#disable_memory_revisionsBoolean Also known as: disable_memory_revisions?

Optional. Input only. Indicates whether no revision will be created for this request. Corresponds to the JSON property disableMemoryRevisions

Returns:

  • (Boolean)


22557
22558
22559
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22557

def disable_memory_revisions
  @disable_memory_revisions
end

#display_nameString

Optional. Represents the display name of the Memory. Corresponds to the JSON property displayName

Returns:

  • (String)


22563
22564
22565
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22563

def display_name
  @display_name
end

#expire_timeString

Optional. Represents the timestamp of when this resource is considered expired. This is always provided on output when expiration is set on input, regardless of whether expire_time or ttl was provided. Corresponds to the JSON property expireTime

Returns:

  • (String)


22570
22571
22572
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22570

def expire_time
  @expire_time
end

#factString

Optional. Represents semantic knowledge extracted from the source content. Corresponds to the JSON property fact

Returns:

  • (String)


22575
22576
22577
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22575

def fact
  @fact
end

#metadataHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryMetadataValue>

Optional. Represents user-provided metadata for the Memory. This information was provided when creating, updating, or generating the Memory. It was not generated by Memory Bank. Corresponds to the JSON property metadata



22582
22583
22584
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22582

def 
  @metadata
end

#nameString

Identifier. Represents the resource name of the Memory. Format: projects/ project/locations/location/reasoningEngines/reasoning_engine/memories/ memory` Corresponds to the JSON propertyname`

Returns:

  • (String)


22589
22590
22591
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22589

def name
  @name
end

#revision_expire_timeString

Optional. Input only. Represents the timestamp of when the revision is considered expired. If not set, the memory revision will be kept until manually deleted. Corresponds to the JSON property revisionExpireTime

Returns:

  • (String)


22596
22597
22598
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22596

def revision_expire_time
  @revision_expire_time
end

#revision_labelsHash<String,String>

Optional. Input only. Represents the labels to apply to the Memory Revision created as a result of this request. Corresponds to the JSON property revisionLabels

Returns:

  • (Hash<String,String>)


22602
22603
22604
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22602

def revision_labels
  @revision_labels
end

#revision_ttlString

Optional. Input only. Represents the TTL for the revision. The expiration time is computed: now + TTL. Corresponds to the JSON property revisionTtl

Returns:

  • (String)


22608
22609
22610
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22608

def revision_ttl
  @revision_ttl
end

#scopeHash<String,String>

Required. Immutable. Represents the scope of the Memory. Memories are isolated within their scope. The scope is defined when creating or generating memories. Scope values cannot contain the wildcard character '*'. Corresponds to the JSON property scope

Returns:

  • (Hash<String,String>)


22615
22616
22617
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22615

def scope
  @scope
end

#topicsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryTopicId>

Optional. Represents the Topics of the Memory. Corresponds to the JSON property topics



22620
22621
22622
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22620

def topics
  @topics
end

#ttlString

Optional. Input only. Represents the TTL for this resource. The expiration time is computed: now + TTL. Corresponds to the JSON property ttl

Returns:

  • (String)


22626
22627
22628
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22626

def ttl
  @ttl
end

#update_timeString

Output only. Represents the timestamp when this Memory was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


22632
22633
22634
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22632

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22639
22640
22641
22642
22643
22644
22645
22646
22647
22648
22649
22650
22651
22652
22653
22654
22655
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22639

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @disable_memory_revisions = args[:disable_memory_revisions] if args.key?(:disable_memory_revisions)
  @display_name = args[:display_name] if args.key?(:display_name)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @fact = args[:fact] if args.key?(:fact)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @revision_expire_time = args[:revision_expire_time] if args.key?(:revision_expire_time)
  @revision_labels = args[:revision_labels] if args.key?(:revision_labels)
  @revision_ttl = args[:revision_ttl] if args.key?(:revision_ttl)
  @scope = args[:scope] if args.key?(:scope)
  @topics = args[:topics] if args.key?(:topics)
  @ttl = args[:ttl] if args.key?(:ttl)
  @update_time = args[:update_time] if args.key?(:update_time)
end