Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Memory

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A memory.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Memory

Returns a new instance of GoogleCloudAiplatformV1Memory.



21561
21562
21563
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21561

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Represents the timestamp when this Memory was created. Corresponds to the JSON property createTime

Returns:

  • (String)


21473
21474
21475
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21473

def create_time
  @create_time
end

#descriptionString

Optional. Represents the description of the Memory. Corresponds to the JSON property description

Returns:

  • (String)


21478
21479
21480
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21478

def description
  @description
end

#disable_memory_revisionsBoolean Also known as: disable_memory_revisions?

Optional. Input only. Indicates whether no revision will be created for this request. Corresponds to the JSON property disableMemoryRevisions

Returns:

  • (Boolean)


21484
21485
21486
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21484

def disable_memory_revisions
  @disable_memory_revisions
end

#display_nameString

Optional. Represents the display name of the Memory. Corresponds to the JSON property displayName

Returns:

  • (String)


21490
21491
21492
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21490

def display_name
  @display_name
end

#expire_timeString

Optional. Represents the timestamp of when this resource is considered expired. This is always provided on output when expiration is set on input, regardless of whether expire_time or ttl was provided. Corresponds to the JSON property expireTime

Returns:

  • (String)


21497
21498
21499
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21497

def expire_time
  @expire_time
end

#factString

Optional. Represents semantic knowledge extracted from the source content. Corresponds to the JSON property fact

Returns:

  • (String)


21502
21503
21504
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21502

def fact
  @fact
end

#metadataHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryMetadataValue>

Optional. Represents user-provided metadata for the Memory. This information was provided when creating, updating, or generating the Memory. It was not generated by Memory Bank. Corresponds to the JSON property metadata



21509
21510
21511
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21509

def 
  @metadata
end

#nameString

Identifier. Represents the resource name of the Memory. Format: projects/ project/locations/location/reasoningEngines/reasoning_engine/memories/ memory` Corresponds to the JSON propertyname`

Returns:

  • (String)


21516
21517
21518
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21516

def name
  @name
end

#revision_expire_timeString

Optional. Input only. Represents the timestamp of when the revision is considered expired. If not set, the memory revision will be kept until manually deleted. Corresponds to the JSON property revisionExpireTime

Returns:

  • (String)


21523
21524
21525
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21523

def revision_expire_time
  @revision_expire_time
end

#revision_labelsHash<String,String>

Optional. Input only. Represents the labels to apply to the Memory Revision created as a result of this request. Corresponds to the JSON property revisionLabels

Returns:

  • (Hash<String,String>)


21529
21530
21531
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21529

def revision_labels
  @revision_labels
end

#revision_ttlString

Optional. Input only. Represents the TTL for the revision. The expiration time is computed: now + TTL. Corresponds to the JSON property revisionTtl

Returns:

  • (String)


21535
21536
21537
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21535

def revision_ttl
  @revision_ttl
end

#scopeHash<String,String>

Required. Immutable. Represents the scope of the Memory. Memories are isolated within their scope. The scope is defined when creating or generating memories. Scope values cannot contain the wildcard character '*'. Corresponds to the JSON property scope

Returns:

  • (Hash<String,String>)


21542
21543
21544
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21542

def scope
  @scope
end

#topicsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryTopicId>

Optional. Represents the Topics of the Memory. Corresponds to the JSON property topics



21547
21548
21549
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21547

def topics
  @topics
end

#ttlString

Optional. Input only. Represents the TTL for this resource. The expiration time is computed: now + TTL. Corresponds to the JSON property ttl

Returns:

  • (String)


21553
21554
21555
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21553

def ttl
  @ttl
end

#update_timeString

Output only. Represents the timestamp when this Memory was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


21559
21560
21561
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21559

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21566
21567
21568
21569
21570
21571
21572
21573
21574
21575
21576
21577
21578
21579
21580
21581
21582
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21566

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @disable_memory_revisions = args[:disable_memory_revisions] if args.key?(:disable_memory_revisions)
  @display_name = args[:display_name] if args.key?(:display_name)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @fact = args[:fact] if args.key?(:fact)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @revision_expire_time = args[:revision_expire_time] if args.key?(:revision_expire_time)
  @revision_labels = args[:revision_labels] if args.key?(:revision_labels)
  @revision_ttl = args[:revision_ttl] if args.key?(:revision_ttl)
  @scope = args[:scope] if args.key?(:scope)
  @topics = args[:topics] if args.key?(:topics)
  @ttl = args[:ttl] if args.key?(:ttl)
  @update_time = args[:update_time] if args.key?(:update_time)
end