Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Memory
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Memory
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A memory.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#disable_memory_revisions ⇒ Boolean
(also: #disable_memory_revisions?)
Optional.
-
#display_name ⇒ String
Optional.
-
#expire_time ⇒ String
Optional.
-
#fact ⇒ String
Optional.
-
#metadata ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryMetadataValue>
Optional.
-
#name ⇒ String
Identifier.
-
#revision_expire_time ⇒ String
Optional.
-
#revision_labels ⇒ Hash<String,String>
Optional.
-
#revision_ttl ⇒ String
Optional.
-
#scope ⇒ Hash<String,String>
Required.
-
#topics ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryTopicId>
Optional.
-
#ttl ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Memory
constructor
A new instance of GoogleCloudAiplatformV1Memory.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Memory
Returns a new instance of GoogleCloudAiplatformV1Memory.
21457 21458 21459 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21457 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Represents the timestamp when this Memory was created.
Corresponds to the JSON property createTime
21369 21370 21371 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21369 def create_time @create_time end |
#description ⇒ String
Optional. Represents the description of the Memory.
Corresponds to the JSON property description
21374 21375 21376 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21374 def description @description end |
#disable_memory_revisions ⇒ Boolean Also known as: disable_memory_revisions?
Optional. Input only. Indicates whether no revision will be created for this
request.
Corresponds to the JSON property disableMemoryRevisions
21380 21381 21382 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21380 def disable_memory_revisions @disable_memory_revisions end |
#display_name ⇒ String
Optional. Represents the display name of the Memory.
Corresponds to the JSON property displayName
21386 21387 21388 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21386 def display_name @display_name end |
#expire_time ⇒ String
Optional. Represents the timestamp of when this resource is considered expired.
This is always provided on output when expiration is set on input,
regardless of whether expire_time or ttl was provided.
Corresponds to the JSON property expireTime
21393 21394 21395 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21393 def expire_time @expire_time end |
#fact ⇒ String
Optional. Represents semantic knowledge extracted from the source content.
Corresponds to the JSON property fact
21398 21399 21400 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21398 def fact @fact end |
#metadata ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryMetadataValue>
Optional. Represents user-provided metadata for the Memory. This information
was provided when creating, updating, or generating the Memory. It was not
generated by Memory Bank.
Corresponds to the JSON property metadata
21405 21406 21407 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21405 def @metadata end |
#name ⇒ String
Identifier. Represents the resource name of the Memory. Format: projects/
project/locations/location/reasoningEngines/reasoning_engine/memories/
memory`
Corresponds to the JSON propertyname`
21412 21413 21414 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21412 def name @name end |
#revision_expire_time ⇒ String
Optional. Input only. Represents the timestamp of when the revision is
considered expired. If not set, the memory revision will be kept until
manually deleted.
Corresponds to the JSON property revisionExpireTime
21419 21420 21421 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21419 def revision_expire_time @revision_expire_time end |
#revision_labels ⇒ Hash<String,String>
Optional. Input only. Represents the labels to apply to the Memory Revision
created as a result of this request.
Corresponds to the JSON property revisionLabels
21425 21426 21427 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21425 def revision_labels @revision_labels end |
#revision_ttl ⇒ String
Optional. Input only. Represents the TTL for the revision. The expiration time
is computed: now + TTL.
Corresponds to the JSON property revisionTtl
21431 21432 21433 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21431 def revision_ttl @revision_ttl end |
#scope ⇒ Hash<String,String>
Required. Immutable. Represents the scope of the Memory. Memories are isolated
within their scope. The scope is defined when creating or generating memories.
Scope values cannot contain the wildcard character '*'.
Corresponds to the JSON property scope
21438 21439 21440 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21438 def scope @scope end |
#topics ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryTopicId>
Optional. Represents the Topics of the Memory.
Corresponds to the JSON property topics
21443 21444 21445 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21443 def topics @topics end |
#ttl ⇒ String
Optional. Input only. Represents the TTL for this resource. The expiration
time is computed: now + TTL.
Corresponds to the JSON property ttl
21449 21450 21451 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21449 def ttl @ttl end |
#update_time ⇒ String
Output only. Represents the timestamp when this Memory was most recently
updated.
Corresponds to the JSON property updateTime
21455 21456 21457 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21455 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21462 21463 21464 21465 21466 21467 21468 21469 21470 21471 21472 21473 21474 21475 21476 21477 21478 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21462 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @disable_memory_revisions = args[:disable_memory_revisions] if args.key?(:disable_memory_revisions) @display_name = args[:display_name] if args.key?(:display_name) @expire_time = args[:expire_time] if args.key?(:expire_time) @fact = args[:fact] if args.key?(:fact) @metadata = args[:metadata] if args.key?(:metadata) @name = args[:name] if args.key?(:name) @revision_expire_time = args[:revision_expire_time] if args.key?(:revision_expire_time) @revision_labels = args[:revision_labels] if args.key?(:revision_labels) @revision_ttl = args[:revision_ttl] if args.key?(:revision_ttl) @scope = args[:scope] if args.key?(:scope) @topics = args[:topics] if args.key?(:topics) @ttl = args[:ttl] if args.key?(:ttl) @update_time = args[:update_time] if args.key?(:update_time) end |