Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Memory
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Memory
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A memory.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#disable_memory_revisions ⇒ Boolean
(also: #disable_memory_revisions?)
Optional.
-
#display_name ⇒ String
Optional.
-
#expire_time ⇒ String
Optional.
-
#fact ⇒ String
Required.
-
#metadata ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryMetadataValue>
Optional.
-
#name ⇒ String
Identifier.
-
#revision_expire_time ⇒ String
Optional.
-
#revision_labels ⇒ Hash<String,String>
Optional.
-
#revision_ttl ⇒ String
Optional.
-
#scope ⇒ Hash<String,String>
Required.
-
#topics ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryTopicId>
Optional.
-
#ttl ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Memory
constructor
A new instance of GoogleCloudAiplatformV1Memory.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Memory
Returns a new instance of GoogleCloudAiplatformV1Memory.
20468 20469 20470 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20468 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this Memory was created.
Corresponds to the JSON property createTime
20384 20385 20386 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20384 def create_time @create_time end |
#description ⇒ String
Optional. Description of the Memory.
Corresponds to the JSON property description
20389 20390 20391 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20389 def description @description end |
#disable_memory_revisions ⇒ Boolean Also known as: disable_memory_revisions?
Optional. Input only. If true, no revision will be created for this request.
Corresponds to the JSON property disableMemoryRevisions
20394 20395 20396 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20394 def disable_memory_revisions @disable_memory_revisions end |
#display_name ⇒ String
Optional. Display name of the Memory.
Corresponds to the JSON property displayName
20400 20401 20402 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20400 def display_name @display_name end |
#expire_time ⇒ String
Optional. Timestamp of when this resource is considered expired. This is *
always* provided on output when expiration is set on input, regardless of
whether expire_time or ttl was provided.
Corresponds to the JSON property expireTime
20407 20408 20409 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20407 def expire_time @expire_time end |
#fact ⇒ String
Required. Semantic knowledge extracted from the source content.
Corresponds to the JSON property fact
20412 20413 20414 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20412 def fact @fact end |
#metadata ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryMetadataValue>
Optional. User-provided metadata for the Memory. This information was provided
when creating, updating, or generating the Memory. It was not generated by
Memory Bank.
Corresponds to the JSON property metadata
20419 20420 20421 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20419 def @metadata end |
#name ⇒ String
Identifier. The resource name of the Memory. Format: projects/project/
locations/location/reasoningEngines/reasoning_engine/memories/memory`
Corresponds to the JSON propertyname`
20425 20426 20427 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20425 def name @name end |
#revision_expire_time ⇒ String
Optional. Input only. Timestamp of when the revision is considered expired. If
not set, the memory revision will be kept until manually deleted.
Corresponds to the JSON property revisionExpireTime
20431 20432 20433 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20431 def revision_expire_time @revision_expire_time end |
#revision_labels ⇒ Hash<String,String>
Optional. Input only. The labels to apply to the Memory Revision created as a
result of this request.
Corresponds to the JSON property revisionLabels
20437 20438 20439 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20437 def revision_labels @revision_labels end |
#revision_ttl ⇒ String
Optional. Input only. The TTL for the revision. The expiration time is
computed: now + TTL.
Corresponds to the JSON property revisionTtl
20443 20444 20445 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20443 def revision_ttl @revision_ttl end |
#scope ⇒ Hash<String,String>
Required. Immutable. The scope of the Memory. Memories are isolated within
their scope. The scope is defined when creating or generating memories. Scope
values cannot contain the wildcard character '*'.
Corresponds to the JSON property scope
20450 20451 20452 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20450 def scope @scope end |
#topics ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryTopicId>
Optional. The Topics of the Memory.
Corresponds to the JSON property topics
20455 20456 20457 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20455 def topics @topics end |
#ttl ⇒ String
Optional. Input only. The TTL for this resource. The expiration time is
computed: now + TTL.
Corresponds to the JSON property ttl
20461 20462 20463 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20461 def ttl @ttl end |
#update_time ⇒ String
Output only. Timestamp when this Memory was most recently updated.
Corresponds to the JSON property updateTime
20466 20467 20468 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20466 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20473 20474 20475 20476 20477 20478 20479 20480 20481 20482 20483 20484 20485 20486 20487 20488 20489 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20473 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @disable_memory_revisions = args[:disable_memory_revisions] if args.key?(:disable_memory_revisions) @display_name = args[:display_name] if args.key?(:display_name) @expire_time = args[:expire_time] if args.key?(:expire_time) @fact = args[:fact] if args.key?(:fact) @metadata = args[:metadata] if args.key?(:metadata) @name = args[:name] if args.key?(:name) @revision_expire_time = args[:revision_expire_time] if args.key?(:revision_expire_time) @revision_labels = args[:revision_labels] if args.key?(:revision_labels) @revision_ttl = args[:revision_ttl] if args.key?(:revision_ttl) @scope = args[:scope] if args.key?(:scope) @topics = args[:topics] if args.key?(:topics) @ttl = args[:ttl] if args.key?(:ttl) @update_time = args[:update_time] if args.key?(:update_time) end |