Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Memory

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A memory.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Memory

Returns a new instance of GoogleCloudAiplatformV1Memory.



20267
20268
20269
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20267

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this Memory was created. Corresponds to the JSON property createTime

Returns:

  • (String)


20183
20184
20185
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20183

def create_time
  @create_time
end

#descriptionString

Optional. Description of the Memory. Corresponds to the JSON property description

Returns:

  • (String)


20188
20189
20190
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20188

def description
  @description
end

#disable_memory_revisionsBoolean Also known as: disable_memory_revisions?

Optional. Input only. If true, no revision will be created for this request. Corresponds to the JSON property disableMemoryRevisions

Returns:

  • (Boolean)


20193
20194
20195
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20193

def disable_memory_revisions
  @disable_memory_revisions
end

#display_nameString

Optional. Display name of the Memory. Corresponds to the JSON property displayName

Returns:

  • (String)


20199
20200
20201
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20199

def display_name
  @display_name
end

#expire_timeString

Optional. Timestamp of when this resource is considered expired. This is * always* provided on output when expiration is set on input, regardless of whether expire_time or ttl was provided. Corresponds to the JSON property expireTime

Returns:

  • (String)


20206
20207
20208
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20206

def expire_time
  @expire_time
end

#factString

Required. Semantic knowledge extracted from the source content. Corresponds to the JSON property fact

Returns:

  • (String)


20211
20212
20213
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20211

def fact
  @fact
end

#metadataHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryMetadataValue>

Optional. User-provided metadata for the Memory. This information was provided when creating, updating, or generating the Memory. It was not generated by Memory Bank. Corresponds to the JSON property metadata



20218
20219
20220
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20218

def 
  @metadata
end

#nameString

Identifier. The resource name of the Memory. Format: projects/project/ locations/location/reasoningEngines/reasoning_engine/memories/memory` Corresponds to the JSON propertyname`

Returns:

  • (String)


20224
20225
20226
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20224

def name
  @name
end

#revision_expire_timeString

Optional. Input only. Timestamp of when the revision is considered expired. If not set, the memory revision will be kept until manually deleted. Corresponds to the JSON property revisionExpireTime

Returns:

  • (String)


20230
20231
20232
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20230

def revision_expire_time
  @revision_expire_time
end

#revision_labelsHash<String,String>

Optional. Input only. The labels to apply to the Memory Revision created as a result of this request. Corresponds to the JSON property revisionLabels

Returns:

  • (Hash<String,String>)


20236
20237
20238
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20236

def revision_labels
  @revision_labels
end

#revision_ttlString

Optional. Input only. The TTL for the revision. The expiration time is computed: now + TTL. Corresponds to the JSON property revisionTtl

Returns:

  • (String)


20242
20243
20244
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20242

def revision_ttl
  @revision_ttl
end

#scopeHash<String,String>

Required. Immutable. The scope of the Memory. Memories are isolated within their scope. The scope is defined when creating or generating memories. Scope values cannot contain the wildcard character '*'. Corresponds to the JSON property scope

Returns:

  • (Hash<String,String>)


20249
20250
20251
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20249

def scope
  @scope
end

#topicsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryTopicId>

Optional. The Topics of the Memory. Corresponds to the JSON property topics



20254
20255
20256
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20254

def topics
  @topics
end

#ttlString

Optional. Input only. The TTL for this resource. The expiration time is computed: now + TTL. Corresponds to the JSON property ttl

Returns:

  • (String)


20260
20261
20262
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20260

def ttl
  @ttl
end

#update_timeString

Output only. Timestamp when this Memory was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


20265
20266
20267
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20265

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20272
20273
20274
20275
20276
20277
20278
20279
20280
20281
20282
20283
20284
20285
20286
20287
20288
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20272

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @disable_memory_revisions = args[:disable_memory_revisions] if args.key?(:disable_memory_revisions)
  @display_name = args[:display_name] if args.key?(:display_name)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @fact = args[:fact] if args.key?(:fact)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @revision_expire_time = args[:revision_expire_time] if args.key?(:revision_expire_time)
  @revision_labels = args[:revision_labels] if args.key?(:revision_labels)
  @revision_ttl = args[:revision_ttl] if args.key?(:revision_ttl)
  @scope = args[:scope] if args.key?(:scope)
  @topics = args[:topics] if args.key?(:topics)
  @ttl = args[:ttl] if args.key?(:ttl)
  @update_time = args[:update_time] if args.key?(:update_time)
end