Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryBankCustomizationConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryBankCustomizationConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Represents configuration for organizing natural language memories for a particular scope.
Instance Attribute Summary collapse
-
#consolidation_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryBankCustomizationConfigConsolidationConfig
Represents configuration for customizing how memories are consolidated.
-
#disable_natural_language_memories ⇒ Boolean
(also: #disable_natural_language_memories?)
Optional.
-
#enable_third_person_memories ⇒ Boolean
(also: #enable_third_person_memories?)
Optional.
-
#generate_memories_examples ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryBankCustomizationConfigGenerateMemoriesExample>
Optional.
-
#memory_topics ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryBankCustomizationConfigMemoryTopic>
Optional.
-
#scope_keys ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1MemoryBankCustomizationConfig
constructor
A new instance of GoogleCloudAiplatformV1MemoryBankCustomizationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1MemoryBankCustomizationConfig
Returns a new instance of GoogleCloudAiplatformV1MemoryBankCustomizationConfig.
23486 23487 23488 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23486 def initialize(**args) update!(**args) end |
Instance Attribute Details
#consolidation_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryBankCustomizationConfigConsolidationConfig
Represents configuration for customizing how memories are consolidated.
Corresponds to the JSON property consolidationConfig
23446 23447 23448 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23446 def consolidation_config @consolidation_config end |
#disable_natural_language_memories ⇒ Boolean Also known as: disable_natural_language_memories?
Optional. Indicates whether natural language memory generation should be
disabled for all requests. By default, natural language memory generation is
enabled. Set this to true when you only want to generate structured memories.
Corresponds to the JSON property disableNaturalLanguageMemories
23453 23454 23455 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23453 def disable_natural_language_memories @disable_natural_language_memories end |
#enable_third_person_memories ⇒ Boolean Also known as: enable_third_person_memories?
Optional. Indicates whether the memories will be generated in the third person
(i.e. "The user generates memories with Memory Bank."). By default, the
memories will be generated in the first person (i.e. "I generate memories with
Memory Bank.")
Corresponds to the JSON property enableThirdPersonMemories
23462 23463 23464 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23462 def enable_third_person_memories @enable_third_person_memories end |
#generate_memories_examples ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryBankCustomizationConfigGenerateMemoriesExample>
Optional. Provides examples of how to generate memories for a particular scope.
Corresponds to the JSON property generateMemoriesExamples
23468 23469 23470 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23468 def generate_memories_examples @generate_memories_examples end |
#memory_topics ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryBankCustomizationConfigMemoryTopic>
Optional. Represents topics of information that should be extracted from
conversations and stored as memories. If not set, then Memory Bank's default
topics will be used.
Corresponds to the JSON property memoryTopics
23475 23476 23477 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23475 def memory_topics @memory_topics end |
#scope_keys ⇒ Array<String>
Optional. Represents the scope keys (i.e. 'user_id') for which to use this
config. A request's scope must include all of the provided keys for the config
to be used (order does not matter). If empty, then the config will be used for
all requests that do not have a more specific config. Only one default config
is allowed per Memory Bank.
Corresponds to the JSON property scopeKeys
23484 23485 23486 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23484 def scope_keys @scope_keys end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23491 23492 23493 23494 23495 23496 23497 23498 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23491 def update!(**args) @consolidation_config = args[:consolidation_config] if args.key?(:consolidation_config) @disable_natural_language_memories = args[:disable_natural_language_memories] if args.key?(:disable_natural_language_memories) @enable_third_person_memories = args[:enable_third_person_memories] if args.key?(:enable_third_person_memories) @generate_memories_examples = args[:generate_memories_examples] if args.key?(:generate_memories_examples) @memory_topics = args[:memory_topics] if args.key?(:memory_topics) @scope_keys = args[:scope_keys] if args.key?(:scope_keys) end |