Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryBankCustomizationConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryBankCustomizationConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Configuration for organizing memories for a particular scope.
Instance Attribute Summary collapse
-
#enable_third_person_memories ⇒ Boolean
(also: #enable_third_person_memories?)
Optional.
-
#generate_memories_examples ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryBankCustomizationConfigGenerateMemoriesExample>
Optional.
-
#memory_topics ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryBankCustomizationConfigMemoryTopic>
Optional.
-
#scope_keys ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1MemoryBankCustomizationConfig
constructor
A new instance of GoogleCloudAiplatformV1MemoryBankCustomizationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1MemoryBankCustomizationConfig
Returns a new instance of GoogleCloudAiplatformV1MemoryBankCustomizationConfig.
20325 20326 20327 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20325 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable_third_person_memories ⇒ Boolean Also known as: enable_third_person_memories?
Optional. If true, then the memories will be generated in the third person (i.
e. "The user generates memories with Memory Bank."). By default, the memories
will be generated in the first person (i.e. "I generate memories with Memory
Bank.")
Corresponds to the JSON property enableThirdPersonMemories
20301 20302 20303 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20301 def enable_third_person_memories @enable_third_person_memories end |
#generate_memories_examples ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryBankCustomizationConfigGenerateMemoriesExample>
Optional. Examples of how to generate memories for a particular scope.
Corresponds to the JSON property generateMemoriesExamples
20307 20308 20309 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20307 def generate_memories_examples @generate_memories_examples end |
#memory_topics ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryBankCustomizationConfigMemoryTopic>
Optional. Topics of information that should be extracted from conversations
and stored as memories. If not set, then Memory Bank's default topics will be
used.
Corresponds to the JSON property memoryTopics
20314 20315 20316 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20314 def memory_topics @memory_topics end |
#scope_keys ⇒ Array<String>
Optional. The scope keys (i.e. 'user_id') for which to use this config. A
request's scope must include all of the provided keys for the config to be
used (order does not matter). If empty, then the config will be used for all
requests that do not have a more specific config. Only one default config is
allowed per Memory Bank.
Corresponds to the JSON property scopeKeys
20323 20324 20325 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20323 def scope_keys @scope_keys end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20330 20331 20332 20333 20334 20335 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20330 def update!(**args) @enable_third_person_memories = args[:enable_third_person_memories] if args.key?(:enable_third_person_memories) @generate_memories_examples = args[:generate_memories_examples] if args.key?(:generate_memories_examples) @memory_topics = args[:memory_topics] if args.key?(:memory_topics) @scope_keys = args[:scope_keys] if args.key?(:scope_keys) end |