Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryBankCustomizationConfigGenerateMemoriesExample
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryBankCustomizationConfigGenerateMemoriesExample
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
An example of how to generate memories for a particular scope.
Instance Attribute Summary collapse
-
#conversation_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryBankCustomizationConfigGenerateMemoriesExampleConversationSource
A conversation source for the example.
-
#generated_memories ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryBankCustomizationConfigGenerateMemoriesExampleGeneratedMemory>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1MemoryBankCustomizationConfigGenerateMemoriesExample
constructor
A new instance of GoogleCloudAiplatformV1MemoryBankCustomizationConfigGenerateMemoriesExample.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1MemoryBankCustomizationConfigGenerateMemoriesExample
Returns a new instance of GoogleCloudAiplatformV1MemoryBankCustomizationConfigGenerateMemoriesExample.
23539 23540 23541 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23539 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversation_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryBankCustomizationConfigGenerateMemoriesExampleConversationSource
A conversation source for the example. This is similar to
DirectContentsSource.
Corresponds to the JSON property conversationSource
23530 23531 23532 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23530 def conversation_source @conversation_source end |
#generated_memories ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryBankCustomizationConfigGenerateMemoriesExampleGeneratedMemory>
Optional. Represents the memories that are expected to be generated from the
input conversation. An empty list indicates that no memories are expected to
be generated for the input conversation.
Corresponds to the JSON property generatedMemories
23537 23538 23539 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23537 def generated_memories @generated_memories end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23544 23545 23546 23547 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23544 def update!(**args) @conversation_source = args[:conversation_source] if args.key?(:conversation_source) @generated_memories = args[:generated_memories] if args.key?(:generated_memories) end |