Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryBankCustomizationConfigGenerateMemoriesExample
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryBankCustomizationConfigGenerateMemoriesExample
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
An example of how to generate memories for a particular scope.
Instance Attribute Summary collapse
-
#conversation_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryBankCustomizationConfigGenerateMemoriesExampleConversationSource
A conversation source for the example.
-
#generated_memories ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryBankCustomizationConfigGenerateMemoriesExampleGeneratedMemory>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1MemoryBankCustomizationConfigGenerateMemoriesExample
constructor
A new instance of GoogleCloudAiplatformV1MemoryBankCustomizationConfigGenerateMemoriesExample.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1MemoryBankCustomizationConfigGenerateMemoriesExample
Returns a new instance of GoogleCloudAiplatformV1MemoryBankCustomizationConfigGenerateMemoriesExample.
21799 21800 21801 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21799 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversation_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryBankCustomizationConfigGenerateMemoriesExampleConversationSource
A conversation source for the example. This is similar to
DirectContentsSource.
Corresponds to the JSON property conversationSource
21790 21791 21792 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21790 def conversation_source @conversation_source end |
#generated_memories ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryBankCustomizationConfigGenerateMemoriesExampleGeneratedMemory>
Optional. Represents the memories that are expected to be generated from the
input conversation. An empty list indicates that no memories are expected to
be generated for the input conversation.
Corresponds to the JSON property generatedMemories
21797 21798 21799 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21797 def generated_memories @generated_memories end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21804 21805 21806 21807 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21804 def update!(**args) @conversation_source = args[:conversation_source] if args.key?(:conversation_source) @generated_memories = args[:generated_memories] if args.key?(:generated_memories) end |