Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryBankCustomizationConfigGenerateMemoriesExampleGeneratedMemory

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A memory generated by the operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1MemoryBankCustomizationConfigGenerateMemoriesExampleGeneratedMemory

Returns a new instance of GoogleCloudAiplatformV1MemoryBankCustomizationConfigGenerateMemoriesExampleGeneratedMemory.



20624
20625
20626
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20624

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#factString

Required. The fact to generate a memory from. Corresponds to the JSON property fact

Returns:

  • (String)


20615
20616
20617
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20615

def fact
  @fact
end

#topicsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryTopicId>

Optional. The list of topics that the memory should be associated with. For example, use custom_memory_topic_label = "jargon" if the extracted memory is an example of memory extraction for the custom topic jargon. Corresponds to the JSON property topics



20622
20623
20624
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20622

def topics
  @topics
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20629
20630
20631
20632
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20629

def update!(**args)
  @fact = args[:fact] if args.key?(:fact)
  @topics = args[:topics] if args.key?(:topics)
end