Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryBankCustomizationConfigGenerateMemoriesExampleGeneratedMemory
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryBankCustomizationConfigGenerateMemoriesExampleGeneratedMemory
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A memory generated by the operation.
Instance Attribute Summary collapse
-
#fact ⇒ String
Required.
-
#topics ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryTopicId>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1MemoryBankCustomizationConfigGenerateMemoriesExampleGeneratedMemory
constructor
A new instance of GoogleCloudAiplatformV1MemoryBankCustomizationConfigGenerateMemoriesExampleGeneratedMemory.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1MemoryBankCustomizationConfigGenerateMemoriesExampleGeneratedMemory
Returns a new instance of GoogleCloudAiplatformV1MemoryBankCustomizationConfigGenerateMemoriesExampleGeneratedMemory.
20423 20424 20425 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20423 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fact ⇒ String
Required. The fact to generate a memory from.
Corresponds to the JSON property fact
20414 20415 20416 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20414 def fact @fact end |
#topics ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryTopicId>
Optional. The list of topics that the memory should be associated with. For
example, use custom_memory_topic_label = "jargon" if the extracted memory is
an example of memory extraction for the custom topic jargon.
Corresponds to the JSON property topics
20421 20422 20423 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20421 def topics @topics end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20428 20429 20430 20431 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20428 def update!(**args) @fact = args[:fact] if args.key?(:fact) @topics = args[:topics] if args.key?(:topics) end |