Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryGenerationTriggerConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryGenerationTriggerConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Represents configuration for triggering generation.
Instance Attribute Summary collapse
-
#generation_rule ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryGenerationTriggerConfigGenerationTriggerRule
Represents the active rule that determines when to flush the buffer.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1MemoryGenerationTriggerConfig
constructor
A new instance of GoogleCloudAiplatformV1MemoryGenerationTriggerConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1MemoryGenerationTriggerConfig
Returns a new instance of GoogleCloudAiplatformV1MemoryGenerationTriggerConfig.
23388 23389 23390 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23388 def initialize(**args) update!(**args) end |
Instance Attribute Details
#generation_rule ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryGenerationTriggerConfigGenerationTriggerRule
Represents the active rule that determines when to flush the buffer.
Corresponds to the JSON property generationRule
23386 23387 23388 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23386 def generation_rule @generation_rule end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23393 23394 23395 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23393 def update!(**args) @generation_rule = args[:generation_rule] if args.key?(:generation_rule) end |