Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryGenerationTriggerConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryGenerationTriggerConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Represents configuration for triggering generation.
Instance Attribute Summary collapse
-
#generation_rule ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryGenerationTriggerConfigGenerationTriggerRule
Represents the active rule that determines when to flush the buffer.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1MemoryGenerationTriggerConfig
constructor
A new instance of GoogleCloudAiplatformV1MemoryGenerationTriggerConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1MemoryGenerationTriggerConfig
Returns a new instance of GoogleCloudAiplatformV1MemoryGenerationTriggerConfig.
21800 21801 21802 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21800 def initialize(**args) update!(**args) end |
Instance Attribute Details
#generation_rule ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryGenerationTriggerConfigGenerationTriggerRule
Represents the active rule that determines when to flush the buffer.
Corresponds to the JSON property generationRule
21798 21799 21800 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21798 def generation_rule @generation_rule end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21805 21806 21807 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21805 def update!(**args) @generation_rule = args[:generation_rule] if args.key?(:generation_rule) end |