Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryGenerationTriggerConfigGenerationTriggerRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents the active rule that determines when to flush the buffer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1MemoryGenerationTriggerConfigGenerationTriggerRule

Returns a new instance of GoogleCloudAiplatformV1MemoryGenerationTriggerConfigGenerationTriggerRule.



23795
23796
23797
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23795

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#event_countFixnum

Optional. Specifies to trigger generation when the event count reaches this limit. Corresponds to the JSON property eventCount

Returns:

  • (Fixnum)


23775
23776
23777
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23775

def event_count
  @event_count
end

#fixed_intervalString

Optional. Specifies to trigger generation at a fixed interval. The duration must have a minute-level granularity. Corresponds to the JSON property fixedInterval

Returns:

  • (String)


23781
23782
23783
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23781

def fixed_interval
  @fixed_interval
end

#idle_durationString

Optional. Specifies to trigger generation if the stream is inactive for the specified duration after the most recent event. The duration must have a minute-level granularity. Corresponds to the JSON property idleDuration

Returns:

  • (String)


23788
23789
23790
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23788

def idle_duration
  @idle_duration
end

#overlap_event_countFixnum

Optional. Re-include the last N already-processed events in the next window. Corresponds to the JSON property overlapEventCount

Returns:

  • (Fixnum)


23793
23794
23795
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23793

def overlap_event_count
  @overlap_event_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23800
23801
23802
23803
23804
23805
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23800

def update!(**args)
  @event_count = args[:event_count] if args.key?(:event_count)
  @fixed_interval = args[:fixed_interval] if args.key?(:fixed_interval)
  @idle_duration = args[:idle_duration] if args.key?(:idle_duration)
  @overlap_event_count = args[:overlap_event_count] if args.key?(:overlap_event_count)
end