Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryGenerationTriggerConfigGenerationTriggerRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents the active rule that determines when to flush the buffer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1MemoryGenerationTriggerConfigGenerationTriggerRule

Returns a new instance of GoogleCloudAiplatformV1MemoryGenerationTriggerConfigGenerationTriggerRule.



21833
21834
21835
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21833

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#event_countFixnum

Optional. Specifies to trigger generation when the event count reaches this limit. Corresponds to the JSON property eventCount

Returns:

  • (Fixnum)


21818
21819
21820
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21818

def event_count
  @event_count
end

#fixed_intervalString

Optional. Specifies to trigger generation at a fixed interval. The duration must have a minute-level granularity. Corresponds to the JSON property fixedInterval

Returns:

  • (String)


21824
21825
21826
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21824

def fixed_interval
  @fixed_interval
end

#idle_durationString

Optional. Specifies to trigger generation if the stream is inactive for the specified duration after the most recent event. The duration must have a minute-level granularity. Corresponds to the JSON property idleDuration

Returns:

  • (String)


21831
21832
21833
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21831

def idle_duration
  @idle_duration
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21838
21839
21840
21841
21842
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21838

def update!(**args)
  @event_count = args[:event_count] if args.key?(:event_count)
  @fixed_interval = args[:fixed_interval] if args.key?(:fixed_interval)
  @idle_duration = args[:idle_duration] if args.key?(:idle_duration)
end