Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryRevision

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A revision of a Memory.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1MemoryRevision

Returns a new instance of GoogleCloudAiplatformV1MemoryRevision.



23513
23514
23515
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23513

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Represents the timestamp when this Memory Revision was created. Corresponds to the JSON property createTime

Returns:

  • (String)


23472
23473
23474
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23472

def create_time
  @create_time
end

#expire_timeString

Output only. Represents the timestamp of when this resource is considered expired. Corresponds to the JSON property expireTime

Returns:

  • (String)


23478
23479
23480
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23478

def expire_time
  @expire_time
end

#extracted_memoriesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IntermediateExtractedMemory>

Output only. Represents the extracted memories from the source content before consolidation when the memory was updated via GenerateMemories. This information was used to modify an existing Memory via Consolidation. Corresponds to the JSON property extractedMemories



23485
23486
23487
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23485

def extracted_memories
  @extracted_memories
end

#factString

Output only. Represents the fact of the Memory Revision. This corresponds to the fact field of the parent Memory at the time of revision creation. Corresponds to the JSON property fact

Returns:

  • (String)


23491
23492
23493
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23491

def fact
  @fact
end

#labelsHash<String,String>

Output only. Represents the labels of the Memory Revision. These labels are applied to the MemoryRevision when it is created based on GenerateMemoriesRequest.revision_labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


23498
23499
23500
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23498

def labels
  @labels
end

#nameString

Identifier. Represents the resource name of the Memory Revision. Format: projects/project/locations/location/reasoningEngines/reasoning_engine/ memories/memory/revisions/memory_revision` Corresponds to the JSON propertyname`

Returns:

  • (String)


23505
23506
23507
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23505

def name
  @name
end

#structured_dataHash<String,Object>

Output only. Represents the structured value of the memory at the time of revision creation. Corresponds to the JSON property structuredData

Returns:

  • (Hash<String,Object>)


23511
23512
23513
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23511

def structured_data
  @structured_data
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23518
23519
23520
23521
23522
23523
23524
23525
23526
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23518

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @extracted_memories = args[:extracted_memories] if args.key?(:extracted_memories)
  @fact = args[:fact] if args.key?(:fact)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @structured_data = args[:structured_data] if args.key?(:structured_data)
end