Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryRevision

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A revision of a Memory.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1MemoryRevision

Returns a new instance of GoogleCloudAiplatformV1MemoryRevision.



23109
23110
23111
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23109

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Represents the timestamp when this Memory Revision was created. Corresponds to the JSON property createTime

Returns:

  • (String)


23068
23069
23070
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23068

def create_time
  @create_time
end

#expire_timeString

Output only. Represents the timestamp of when this resource is considered expired. Corresponds to the JSON property expireTime

Returns:

  • (String)


23074
23075
23076
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23074

def expire_time
  @expire_time
end

#extracted_memoriesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IntermediateExtractedMemory>

Output only. Represents the extracted memories from the source content before consolidation when the memory was updated via GenerateMemories. This information was used to modify an existing Memory via Consolidation. Corresponds to the JSON property extractedMemories



23081
23082
23083
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23081

def extracted_memories
  @extracted_memories
end

#factString

Output only. Represents the fact of the Memory Revision. This corresponds to the fact field of the parent Memory at the time of revision creation. Corresponds to the JSON property fact

Returns:

  • (String)


23087
23088
23089
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23087

def fact
  @fact
end

#labelsHash<String,String>

Output only. Represents the labels of the Memory Revision. These labels are applied to the MemoryRevision when it is created based on GenerateMemoriesRequest.revision_labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


23094
23095
23096
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23094

def labels
  @labels
end

#nameString

Identifier. Represents the resource name of the Memory Revision. Format: projects/project/locations/location/reasoningEngines/reasoning_engine/ memories/memory/revisions/memory_revision` Corresponds to the JSON propertyname`

Returns:

  • (String)


23101
23102
23103
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23101

def name
  @name
end

#structured_dataHash<String,Object>

Output only. Represents the structured value of the memory at the time of revision creation. Corresponds to the JSON property structuredData

Returns:

  • (Hash<String,Object>)


23107
23108
23109
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23107

def structured_data
  @structured_data
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23114
23115
23116
23117
23118
23119
23120
23121
23122
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23114

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @extracted_memories = args[:extracted_memories] if args.key?(:extracted_memories)
  @fact = args[:fact] if args.key?(:fact)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @structured_data = args[:structured_data] if args.key?(:structured_data)
end