Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryRevision
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryRevision
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A revision of a Memory.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#expire_time ⇒ String
Output only.
-
#extracted_memories ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IntermediateExtractedMemory>
Output only.
-
#fact ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Output only.
-
#name ⇒ String
Identifier.
-
#structured_data ⇒ Hash<String,Object>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1MemoryRevision
constructor
A new instance of GoogleCloudAiplatformV1MemoryRevision.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1MemoryRevision
Returns a new instance of GoogleCloudAiplatformV1MemoryRevision.
22036 22037 22038 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22036 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Represents the timestamp when this Memory Revision was created.
Corresponds to the JSON property createTime
21995 21996 21997 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21995 def create_time @create_time end |
#expire_time ⇒ String
Output only. Represents the timestamp of when this resource is considered
expired.
Corresponds to the JSON property expireTime
22001 22002 22003 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22001 def expire_time @expire_time end |
#extracted_memories ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IntermediateExtractedMemory>
Output only. Represents the extracted memories from the source content before
consolidation when the memory was updated via GenerateMemories. This
information was used to modify an existing Memory via Consolidation.
Corresponds to the JSON property extractedMemories
22008 22009 22010 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22008 def extracted_memories @extracted_memories end |
#fact ⇒ String
Output only. Represents the fact of the Memory Revision. This corresponds to
the fact field of the parent Memory at the time of revision creation.
Corresponds to the JSON property fact
22014 22015 22016 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22014 def fact @fact end |
#labels ⇒ Hash<String,String>
Output only. Represents the labels of the Memory Revision. These labels are
applied to the MemoryRevision when it is created based on
GenerateMemoriesRequest.revision_labels.
Corresponds to the JSON property labels
22021 22022 22023 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22021 def labels @labels end |
#name ⇒ String
Identifier. Represents the resource name of the Memory Revision. Format:
projects/project/locations/location/reasoningEngines/reasoning_engine/
memories/memory/revisions/memory_revision`
Corresponds to the JSON propertyname`
22028 22029 22030 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22028 def name @name end |
#structured_data ⇒ Hash<String,Object>
Output only. Represents the structured value of the memory at the time of
revision creation.
Corresponds to the JSON property structuredData
22034 22035 22036 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22034 def structured_data @structured_data end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22041 22042 22043 22044 22045 22046 22047 22048 22049 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22041 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @expire_time = args[:expire_time] if args.key?(:expire_time) @extracted_memories = args[:extracted_memories] if args.key?(:extracted_memories) @fact = args[:fact] if args.key?(:fact) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @structured_data = args[:structured_data] if args.key?(:structured_data) end |