Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryRevision

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A revision of a Memory.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1MemoryRevision

Returns a new instance of GoogleCloudAiplatformV1MemoryRevision.



21979
21980
21981
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21979

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Represents the timestamp when this Memory Revision was created. Corresponds to the JSON property createTime

Returns:

  • (String)


21938
21939
21940
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21938

def create_time
  @create_time
end

#expire_timeString

Output only. Represents the timestamp of when this resource is considered expired. Corresponds to the JSON property expireTime

Returns:

  • (String)


21944
21945
21946
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21944

def expire_time
  @expire_time
end

#extracted_memoriesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IntermediateExtractedMemory>

Output only. Represents the extracted memories from the source content before consolidation when the memory was updated via GenerateMemories. This information was used to modify an existing Memory via Consolidation. Corresponds to the JSON property extractedMemories



21951
21952
21953
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21951

def extracted_memories
  @extracted_memories
end

#factString

Output only. Represents the fact of the Memory Revision. This corresponds to the fact field of the parent Memory at the time of revision creation. Corresponds to the JSON property fact

Returns:

  • (String)


21957
21958
21959
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21957

def fact
  @fact
end

#labelsHash<String,String>

Output only. Represents the labels of the Memory Revision. These labels are applied to the MemoryRevision when it is created based on GenerateMemoriesRequest.revision_labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


21964
21965
21966
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21964

def labels
  @labels
end

#nameString

Identifier. Represents the resource name of the Memory Revision. Format: projects/project/locations/location/reasoningEngines/reasoning_engine/ memories/memory/revisions/memory_revision` Corresponds to the JSON propertyname`

Returns:

  • (String)


21971
21972
21973
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21971

def name
  @name
end

#structured_dataHash<String,Object>

Output only. Represents the structured value of the memory at the time of revision creation. Corresponds to the JSON property structuredData

Returns:

  • (Hash<String,Object>)


21977
21978
21979
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21977

def structured_data
  @structured_data
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21984
21985
21986
21987
21988
21989
21990
21991
21992
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21984

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @extracted_memories = args[:extracted_memories] if args.key?(:extracted_memories)
  @fact = args[:fact] if args.key?(:fact)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @structured_data = args[:structured_data] if args.key?(:structured_data)
end