Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryRevision

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A revision of a Memory.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1MemoryRevision

Returns a new instance of GoogleCloudAiplatformV1MemoryRevision.



21932
21933
21934
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21932

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Represents the timestamp when this Memory Revision was created. Corresponds to the JSON property createTime

Returns:

  • (String)


21891
21892
21893
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21891

def create_time
  @create_time
end

#expire_timeString

Output only. Represents the timestamp of when this resource is considered expired. Corresponds to the JSON property expireTime

Returns:

  • (String)


21897
21898
21899
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21897

def expire_time
  @expire_time
end

#extracted_memoriesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IntermediateExtractedMemory>

Output only. Represents the extracted memories from the source content before consolidation when the memory was updated via GenerateMemories. This information was used to modify an existing Memory via Consolidation. Corresponds to the JSON property extractedMemories



21904
21905
21906
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21904

def extracted_memories
  @extracted_memories
end

#factString

Output only. Represents the fact of the Memory Revision. This corresponds to the fact field of the parent Memory at the time of revision creation. Corresponds to the JSON property fact

Returns:

  • (String)


21910
21911
21912
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21910

def fact
  @fact
end

#labelsHash<String,String>

Output only. Represents the labels of the Memory Revision. These labels are applied to the MemoryRevision when it is created based on GenerateMemoriesRequest.revision_labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


21917
21918
21919
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21917

def labels
  @labels
end

#nameString

Identifier. Represents the resource name of the Memory Revision. Format: projects/project/locations/location/reasoningEngines/reasoning_engine/ memories/memory/revisions/memory_revision` Corresponds to the JSON propertyname`

Returns:

  • (String)


21924
21925
21926
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21924

def name
  @name
end

#structured_dataHash<String,Object>

Output only. Represents the structured value of the memory at the time of revision creation. Corresponds to the JSON property structuredData

Returns:

  • (Hash<String,Object>)


21930
21931
21932
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21930

def structured_data
  @structured_data
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21937
21938
21939
21940
21941
21942
21943
21944
21945
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21937

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @extracted_memories = args[:extracted_memories] if args.key?(:extracted_memories)
  @fact = args[:fact] if args.key?(:fact)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @structured_data = args[:structured_data] if args.key?(:structured_data)
end