Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryRevision

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A revision of a Memory.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1MemoryRevision

Returns a new instance of GoogleCloudAiplatformV1MemoryRevision.



20844
20845
20846
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20844

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this Memory Revision was created. Corresponds to the JSON property createTime

Returns:

  • (String)


20810
20811
20812
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20810

def create_time
  @create_time
end

#expire_timeString

Output only. Timestamp of when this resource is considered expired. Corresponds to the JSON property expireTime

Returns:

  • (String)


20815
20816
20817
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20815

def expire_time
  @expire_time
end

#extracted_memoriesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IntermediateExtractedMemory>

Output only. The extracted memories from the source content before consolidation when the memory was updated via GenerateMemories. This information was used to modify an existing Memory via Consolidation. Corresponds to the JSON property extractedMemories



20822
20823
20824
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20822

def extracted_memories
  @extracted_memories
end

#factString

Output only. The fact of the Memory Revision. This corresponds to the fact field of the parent Memory at the time of revision creation. Corresponds to the JSON property fact

Returns:

  • (String)


20828
20829
20830
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20828

def fact
  @fact
end

#labelsHash<String,String>

Output only. The labels of the Memory Revision. These labels are applied to the MemoryRevision when it is created based on GenerateMemoriesRequest. revision_labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


20835
20836
20837
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20835

def labels
  @labels
end

#nameString

Identifier. The resource name of the Memory Revision. Format: projects/ project/locations/location/reasoningEngines/reasoning_engine/memories/ memory/revisions/memory_revision` Corresponds to the JSON propertyname`

Returns:

  • (String)


20842
20843
20844
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20842

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20849
20850
20851
20852
20853
20854
20855
20856
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20849

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @extracted_memories = args[:extracted_memories] if args.key?(:extracted_memories)
  @fact = args[:fact] if args.key?(:fact)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
end