Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryTopicId
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryTopicId
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A memory topic identifier. This will be used to label a Memory and to restrict which topics are eligible for generation or retrieval.
Instance Attribute Summary collapse
-
#custom_memory_topic_label ⇒ String
Optional.
-
#managed_memory_topic ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1MemoryTopicId
constructor
A new instance of GoogleCloudAiplatformV1MemoryTopicId.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1MemoryTopicId
Returns a new instance of GoogleCloudAiplatformV1MemoryTopicId.
20874 20875 20876 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20874 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_memory_topic_label ⇒ String
Optional. The custom memory topic label.
Corresponds to the JSON property customMemoryTopicLabel
20867 20868 20869 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20867 def custom_memory_topic_label @custom_memory_topic_label end |
#managed_memory_topic ⇒ String
Optional. The managed memory topic.
Corresponds to the JSON property managedMemoryTopic
20872 20873 20874 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20872 def managed_memory_topic @managed_memory_topic end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20879 20880 20881 20882 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20879 def update!(**args) @custom_memory_topic_label = args[:custom_memory_topic_label] if args.key?(:custom_memory_topic_label) @managed_memory_topic = args[:managed_memory_topic] if args.key?(:managed_memory_topic) end |