Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryTopicId
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryTopicId
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A memory topic identifier. This will be used to label a Memory and to restrict which topics are eligible for generation or retrieval.
Instance Attribute Summary collapse
-
#custom_memory_topic_label ⇒ String
Optional.
-
#managed_memory_topic ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1MemoryTopicId
constructor
A new instance of GoogleCloudAiplatformV1MemoryTopicId.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1MemoryTopicId
Returns a new instance of GoogleCloudAiplatformV1MemoryTopicId.
20673 20674 20675 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20673 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_memory_topic_label ⇒ String
Optional. The custom memory topic label.
Corresponds to the JSON property customMemoryTopicLabel
20666 20667 20668 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20666 def custom_memory_topic_label @custom_memory_topic_label end |
#managed_memory_topic ⇒ String
Optional. The managed memory topic.
Corresponds to the JSON property managedMemoryTopic
20671 20672 20673 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20671 def managed_memory_topic @managed_memory_topic end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20678 20679 20680 20681 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20678 def update!(**args) @custom_memory_topic_label = args[:custom_memory_topic_label] if args.key?(:custom_memory_topic_label) @managed_memory_topic = args[:managed_memory_topic] if args.key?(:managed_memory_topic) end |