Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MergeVersionAliasesRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MergeVersionAliasesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Request message for ModelService.MergeVersionAliases.
Instance Attribute Summary collapse
-
#version_aliases ⇒ Array<String>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1MergeVersionAliasesRequest
constructor
A new instance of GoogleCloudAiplatformV1MergeVersionAliasesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1MergeVersionAliasesRequest
Returns a new instance of GoogleCloudAiplatformV1MergeVersionAliasesRequest.
22207 22208 22209 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22207 def initialize(**args) update!(**args) end |
Instance Attribute Details
#version_aliases ⇒ Array<String>
Required. The set of version aliases to merge. The alias should be at most 128
characters, and match a-z0,126[a-z-0-9]. Add the - prefix to an alias
means removing that alias from the version. - is NOT counted in the 128
characters. Example: -golden means removing the golden alias from the
version. There is NO ordering in aliases, which means 1) The aliases returned
from GetModel API might not have the exactly same order from this
MergeVersionAliases API. 2) Adding and deleting the same alias in the request
is not recommended, and the 2 operations will be cancelled out.
Corresponds to the JSON property versionAliases
22205 22206 22207 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22205 def version_aliases @version_aliases end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22212 22213 22214 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22212 def update!(**args) @version_aliases = args[:version_aliases] if args.key?(:version_aliases) end |