Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MergeVersionAliasesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for ModelService.MergeVersionAliases.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1MergeVersionAliasesRequest

Returns a new instance of GoogleCloudAiplatformV1MergeVersionAliasesRequest.



13213
13214
13215
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13213

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#version_aliasesArray<String>

Required. The set of version aliases to merge. The alias should be at most 128 characters, and match a-z0,126[a-z-0-9]. Add the - prefix to an alias means removing that alias from the version. - is NOT counted in the 128 characters. Example: -golden means removing the golden alias from the version. There is NO ordering in aliases, which means 1) The aliases returned from GetModel API might not have the exactly same order from this MergeVersionAliases API. 2) Adding and deleting the same alias in the request is not recommended, and the 2 operations will be cancelled out. Corresponds to the JSON property versionAliases

Returns:

  • (Array<String>)


13211
13212
13213
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13211

def version_aliases
  @version_aliases
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13218
13219
13220
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13218

def update!(**args)
  @version_aliases = args[:version_aliases] if args.key?(:version_aliases)
end