Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Metadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Metadata for a chunk.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Metadata

Returns a new instance of GoogleCloudAiplatformV1Metadata.



23592
23593
23594
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23592

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attributesHash<String,String>

Optional. Attributes attached to the data. The keys have semantic conventions and the consumers of the attributes should know how to deserialize the value bytes based on the keys. Corresponds to the JSON property attributes

Returns:

  • (Hash<String,String>)


23590
23591
23592
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23590

def attributes
  @attributes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23597
23598
23599
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23597

def update!(**args)
  @attributes = args[:attributes] if args.key?(:attributes)
end