Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetadataSchema

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Instance of a general MetadataSchema.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1MetadataSchema

Returns a new instance of GoogleCloudAiplatformV1MetadataSchema.



15710
15711
15712
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15710

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this MetadataSchema was created. Corresponds to the JSON property createTime

Returns:

  • (String)


15676
15677
15678
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15676

def create_time
  @create_time
end

#descriptionString

Description of the Metadata Schema Corresponds to the JSON property description

Returns:

  • (String)


15681
15682
15683
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15681

def description
  @description
end

#nameString

Output only. The resource name of the MetadataSchema. Corresponds to the JSON property name

Returns:

  • (String)


15686
15687
15688
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15686

def name
  @name
end

#schemaString

Required. The raw YAML string representation of the MetadataSchema. The combination of [MetadataSchema.version] and the schema name given by title in [MetadataSchema.schema] must be unique within a MetadataStore. The schema is defined as an OpenAPI 3.0.2 MetadataSchema Object Corresponds to the JSON property schema

Returns:

  • (String)


15695
15696
15697
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15695

def schema
  @schema
end

#schema_typeString

The type of the MetadataSchema. This is a property that identifies which metadata types will use the MetadataSchema. Corresponds to the JSON property schemaType

Returns:

  • (String)


15701
15702
15703
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15701

def schema_type
  @schema_type
end

#schema_versionString

The version of the MetadataSchema. The version's format must match the following regular expression: ^[0-9]+.+.+$, which would allow to order/ compare different versions. Example: 1.0.0, 1.0.1, etc. Corresponds to the JSON property schemaVersion

Returns:

  • (String)


15708
15709
15710
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15708

def schema_version
  @schema_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15715
15716
15717
15718
15719
15720
15721
15722
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15715

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @name = args[:name] if args.key?(:name)
  @schema = args[:schema] if args.key?(:schema)
  @schema_type = args[:schema_type] if args.key?(:schema_type)
  @schema_version = args[:schema_version] if args.key?(:schema_version)
end