Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetadataSchema

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Instance of a general MetadataSchema.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1MetadataSchema

Returns a new instance of GoogleCloudAiplatformV1MetadataSchema.



12882
12883
12884
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12882

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this MetadataSchema was created. Corresponds to the JSON property createTime

Returns:

  • (String)


12848
12849
12850
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12848

def create_time
  @create_time
end

#descriptionString

Description of the Metadata Schema Corresponds to the JSON property description

Returns:

  • (String)


12853
12854
12855
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12853

def description
  @description
end

#nameString

Output only. The resource name of the MetadataSchema. Corresponds to the JSON property name

Returns:

  • (String)


12858
12859
12860
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12858

def name
  @name
end

#schemaString

Required. The raw YAML string representation of the MetadataSchema. The combination of [MetadataSchema.version] and the schema name given by title in [MetadataSchema.schema] must be unique within a MetadataStore. The schema is defined as an OpenAPI 3.0.2 MetadataSchema Object Corresponds to the JSON property schema

Returns:

  • (String)


12867
12868
12869
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12867

def schema
  @schema
end

#schema_typeString

The type of the MetadataSchema. This is a property that identifies which metadata types will use the MetadataSchema. Corresponds to the JSON property schemaType

Returns:

  • (String)


12873
12874
12875
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12873

def schema_type
  @schema_type
end

#schema_versionString

The version of the MetadataSchema. The version's format must match the following regular expression: ^[0-9]+.+.+$, which would allow to order/ compare different versions. Example: 1.0.0, 1.0.1, etc. Corresponds to the JSON property schemaVersion

Returns:

  • (String)


12880
12881
12882
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12880

def schema_version
  @schema_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12887
12888
12889
12890
12891
12892
12893
12894
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 12887

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @name = args[:name] if args.key?(:name)
  @schema = args[:schema] if args.key?(:schema)
  @schema_type = args[:schema_type] if args.key?(:schema_type)
  @schema_version = args[:schema_version] if args.key?(:schema_version)
end