Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetadataStore

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Instance of a metadata store. Contains a set of metadata that can be queried.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1MetadataStore

Returns a new instance of GoogleCloudAiplatformV1MetadataStore.



23711
23712
23713
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23711

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this MetadataStore was created. Corresponds to the JSON property createTime

Returns:

  • (String)


23678
23679
23680
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23678

def create_time
  @create_time
end

#dataplex_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1MetadataStoreDataplexConfig

Represents Dataplex integration settings. Corresponds to the JSON property dataplexConfig



23683
23684
23685
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23683

def dataplex_config
  @dataplex_config
end

#descriptionString

Description of the MetadataStore. Corresponds to the JSON property description

Returns:

  • (String)


23688
23689
23690
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23688

def description
  @description
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



23694
23695
23696
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23694

def encryption_spec
  @encryption_spec
end

#nameString

Output only. The resource name of the MetadataStore instance. Corresponds to the JSON property name

Returns:

  • (String)


23699
23700
23701
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23699

def name
  @name
end

#stateGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1MetadataStoreMetadataStoreState

Represents state information for a MetadataStore. Corresponds to the JSON property state



23704
23705
23706
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23704

def state
  @state
end

#update_timeString

Output only. Timestamp when this MetadataStore was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


23709
23710
23711
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23709

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23716
23717
23718
23719
23720
23721
23722
23723
23724
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23716

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @dataplex_config = args[:dataplex_config] if args.key?(:dataplex_config)
  @description = args[:description] if args.key?(:description)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end