Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetadataStore

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Instance of a metadata store. Contains a set of metadata that can be queried.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1MetadataStore

Returns a new instance of GoogleCloudAiplatformV1MetadataStore.



23698
23699
23700
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23698

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this MetadataStore was created. Corresponds to the JSON property createTime

Returns:

  • (String)


23665
23666
23667
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23665

def create_time
  @create_time
end

#dataplex_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1MetadataStoreDataplexConfig

Represents Dataplex integration settings. Corresponds to the JSON property dataplexConfig



23670
23671
23672
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23670

def dataplex_config
  @dataplex_config
end

#descriptionString

Description of the MetadataStore. Corresponds to the JSON property description

Returns:

  • (String)


23675
23676
23677
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23675

def description
  @description
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



23681
23682
23683
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23681

def encryption_spec
  @encryption_spec
end

#nameString

Output only. The resource name of the MetadataStore instance. Corresponds to the JSON property name

Returns:

  • (String)


23686
23687
23688
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23686

def name
  @name
end

#stateGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1MetadataStoreMetadataStoreState

Represents state information for a MetadataStore. Corresponds to the JSON property state



23691
23692
23693
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23691

def state
  @state
end

#update_timeString

Output only. Timestamp when this MetadataStore was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


23696
23697
23698
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23696

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23703
23704
23705
23706
23707
23708
23709
23710
23711
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23703

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @dataplex_config = args[:dataplex_config] if args.key?(:dataplex_config)
  @description = args[:description] if args.key?(:description)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end