Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetadataStore
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetadataStore
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Instance of a metadata store. Contains a set of metadata that can be queried.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#dataplex_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetadataStoreDataplexConfig
Represents Dataplex integration settings.
-
#description ⇒ String
Description of the MetadataStore.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.
-
#name ⇒ String
Output only.
-
#state ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetadataStoreMetadataStoreState
Represents state information for a MetadataStore.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1MetadataStore
constructor
A new instance of GoogleCloudAiplatformV1MetadataStore.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1MetadataStore
Returns a new instance of GoogleCloudAiplatformV1MetadataStore.
22164 22165 22166 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22164 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this MetadataStore was created.
Corresponds to the JSON property createTime
22131 22132 22133 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22131 def create_time @create_time end |
#dataplex_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetadataStoreDataplexConfig
Represents Dataplex integration settings.
Corresponds to the JSON property dataplexConfig
22136 22137 22138 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22136 def dataplex_config @dataplex_config end |
#description ⇒ String
Description of the MetadataStore.
Corresponds to the JSON property description
22141 22142 22143 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22141 def description @description end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied
to a Vertex AI resource.
Corresponds to the JSON property encryptionSpec
22147 22148 22149 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22147 def encryption_spec @encryption_spec end |
#name ⇒ String
Output only. The resource name of the MetadataStore instance.
Corresponds to the JSON property name
22152 22153 22154 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22152 def name @name end |
#state ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetadataStoreMetadataStoreState
Represents state information for a MetadataStore.
Corresponds to the JSON property state
22157 22158 22159 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22157 def state @state end |
#update_time ⇒ String
Output only. Timestamp when this MetadataStore was last updated.
Corresponds to the JSON property updateTime
22162 22163 22164 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22162 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22169 22170 22171 22172 22173 22174 22175 22176 22177 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22169 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @dataplex_config = args[:dataplex_config] if args.key?(:dataplex_config) @description = args[:description] if args.key?(:description) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |