Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetadataStore

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Instance of a metadata store. Contains a set of metadata that can be queried.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1MetadataStore

Returns a new instance of GoogleCloudAiplatformV1MetadataStore.



22117
22118
22119
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22117

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this MetadataStore was created. Corresponds to the JSON property createTime

Returns:

  • (String)


22084
22085
22086
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22084

def create_time
  @create_time
end

#dataplex_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1MetadataStoreDataplexConfig

Represents Dataplex integration settings. Corresponds to the JSON property dataplexConfig



22089
22090
22091
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22089

def dataplex_config
  @dataplex_config
end

#descriptionString

Description of the MetadataStore. Corresponds to the JSON property description

Returns:

  • (String)


22094
22095
22096
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22094

def description
  @description
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



22100
22101
22102
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22100

def encryption_spec
  @encryption_spec
end

#nameString

Output only. The resource name of the MetadataStore instance. Corresponds to the JSON property name

Returns:

  • (String)


22105
22106
22107
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22105

def name
  @name
end

#stateGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1MetadataStoreMetadataStoreState

Represents state information for a MetadataStore. Corresponds to the JSON property state



22110
22111
22112
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22110

def state
  @state
end

#update_timeString

Output only. Timestamp when this MetadataStore was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


22115
22116
22117
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22115

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22122
22123
22124
22125
22126
22127
22128
22129
22130
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22122

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @dataplex_config = args[:dataplex_config] if args.key?(:dataplex_config)
  @description = args[:description] if args.key?(:description)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end