Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetadataStore
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetadataStore
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Instance of a metadata store. Contains a set of metadata that can be queried.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#dataplex_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetadataStoreDataplexConfig
Represents Dataplex integration settings.
-
#description ⇒ String
Description of the MetadataStore.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.
-
#name ⇒ String
Output only.
-
#state ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetadataStoreMetadataStoreState
Represents state information for a MetadataStore.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1MetadataStore
constructor
A new instance of GoogleCloudAiplatformV1MetadataStore.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1MetadataStore
Returns a new instance of GoogleCloudAiplatformV1MetadataStore.
20827 20828 20829 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20827 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this MetadataStore was created.
Corresponds to the JSON property createTime
20794 20795 20796 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20794 def create_time @create_time end |
#dataplex_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetadataStoreDataplexConfig
Represents Dataplex integration settings.
Corresponds to the JSON property dataplexConfig
20799 20800 20801 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20799 def dataplex_config @dataplex_config end |
#description ⇒ String
Description of the MetadataStore.
Corresponds to the JSON property description
20804 20805 20806 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20804 def description @description end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied
to a Vertex AI resource.
Corresponds to the JSON property encryptionSpec
20810 20811 20812 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20810 def encryption_spec @encryption_spec end |
#name ⇒ String
Output only. The resource name of the MetadataStore instance.
Corresponds to the JSON property name
20815 20816 20817 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20815 def name @name end |
#state ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetadataStoreMetadataStoreState
Represents state information for a MetadataStore.
Corresponds to the JSON property state
20820 20821 20822 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20820 def state @state end |
#update_time ⇒ String
Output only. Timestamp when this MetadataStore was last updated.
Corresponds to the JSON property updateTime
20825 20826 20827 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20825 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20832 20833 20834 20835 20836 20837 20838 20839 20840 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20832 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @dataplex_config = args[:dataplex_config] if args.key?(:dataplex_config) @description = args[:description] if args.key?(:description) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |