Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetadataStore

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Instance of a metadata store. Contains a set of metadata that can be queried.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1MetadataStore

Returns a new instance of GoogleCloudAiplatformV1MetadataStore.



17056
17057
17058
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17056

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this MetadataStore was created. Corresponds to the JSON property createTime

Returns:

  • (String)


17023
17024
17025
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17023

def create_time
  @create_time
end

#dataplex_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1MetadataStoreDataplexConfig

Represents Dataplex integration settings. Corresponds to the JSON property dataplexConfig



17028
17029
17030
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17028

def dataplex_config
  @dataplex_config
end

#descriptionString

Description of the MetadataStore. Corresponds to the JSON property description

Returns:

  • (String)


17033
17034
17035
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17033

def description
  @description
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key spec that can be applied to a top- level resource. Corresponds to the JSON property encryptionSpec



17039
17040
17041
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17039

def encryption_spec
  @encryption_spec
end

#nameString

Output only. The resource name of the MetadataStore instance. Corresponds to the JSON property name

Returns:

  • (String)


17044
17045
17046
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17044

def name
  @name
end

#stateGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1MetadataStoreMetadataStoreState

Represents state information for a MetadataStore. Corresponds to the JSON property state



17049
17050
17051
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17049

def state
  @state
end

#update_timeString

Output only. Timestamp when this MetadataStore was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


17054
17055
17056
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17054

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17061
17062
17063
17064
17065
17066
17067
17068
17069
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17061

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @dataplex_config = args[:dataplex_config] if args.key?(:dataplex_config)
  @description = args[:description] if args.key?(:description)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end