Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetadataStore
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetadataStore
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Instance of a metadata store. Contains a set of metadata that can be queried.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#dataplex_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetadataStoreDataplexConfig
Represents Dataplex integration settings.
-
#description ⇒ String
Description of the MetadataStore.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top- level resource.
-
#name ⇒ String
Output only.
-
#state ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetadataStoreMetadataStoreState
Represents state information for a MetadataStore.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1MetadataStore
constructor
A new instance of GoogleCloudAiplatformV1MetadataStore.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1MetadataStore
Returns a new instance of GoogleCloudAiplatformV1MetadataStore.
15863 15864 15865 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15863 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this MetadataStore was created.
Corresponds to the JSON property createTime
15830 15831 15832 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15830 def create_time @create_time end |
#dataplex_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetadataStoreDataplexConfig
Represents Dataplex integration settings.
Corresponds to the JSON property dataplexConfig
15835 15836 15837 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15835 def dataplex_config @dataplex_config end |
#description ⇒ String
Description of the MetadataStore.
Corresponds to the JSON property description
15840 15841 15842 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15840 def description @description end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top-
level resource.
Corresponds to the JSON property encryptionSpec
15846 15847 15848 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15846 def encryption_spec @encryption_spec end |
#name ⇒ String
Output only. The resource name of the MetadataStore instance.
Corresponds to the JSON property name
15851 15852 15853 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15851 def name @name end |
#state ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetadataStoreMetadataStoreState
Represents state information for a MetadataStore.
Corresponds to the JSON property state
15856 15857 15858 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15856 def state @state end |
#update_time ⇒ String
Output only. Timestamp when this MetadataStore was last updated.
Corresponds to the JSON property updateTime
15861 15862 15863 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15861 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15868 15869 15870 15871 15872 15873 15874 15875 15876 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15868 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @dataplex_config = args[:dataplex_config] if args.key?(:dataplex_config) @description = args[:description] if args.key?(:description) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |