Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Metric
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Metric
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The metric used for running evaluations.
Instance Attribute Summary collapse
-
#aggregation_metrics ⇒ Array<String>
Optional.
-
#bleu_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BleuSpec
Spec for bleu score metric - calculates the precision of n-grams in the prediction as compared to reference - returns a score ranging between 0 to 1.
-
#computation_based_metric_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ComputationBasedMetricSpec
Specification for a computation based metric.
-
#custom_code_execution_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CustomCodeExecutionSpec
Specificies a metric that is populated by evaluating user-defined Python code.
-
#exact_match_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExactMatchSpec
Spec for exact match metric - returns 1 if prediction and reference exactly matches, otherwise 0.
-
#llm_based_metric_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1LlmBasedMetricSpec
Specification for an LLM based metric.
-
#metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetricMetadata
Metadata about the metric, used for visualization and organization.
-
#pairwise_metric_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PairwiseMetricSpec
Spec for pairwise metric.
-
#pointwise_metric_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PointwiseMetricSpec
Spec for pointwise metric.
-
#predefined_metric_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PredefinedMetricSpec
The spec for a pre-defined metric.
-
#rouge_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RougeSpec
Spec for rouge score metric - calculates the recall of n-grams in prediction as compared to reference - returns a score ranging between 0 and 1.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Metric
constructor
A new instance of GoogleCloudAiplatformV1Metric.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Metric
Returns a new instance of GoogleCloudAiplatformV1Metric.
23412 23413 23414 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23412 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aggregation_metrics ⇒ Array<String>
Optional. The aggregation metrics to use.
Corresponds to the JSON property aggregationMetrics
23357 23358 23359 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23357 def aggregation_metrics @aggregation_metrics end |
#bleu_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BleuSpec
Spec for bleu score metric - calculates the precision of n-grams in the
prediction as compared to reference - returns a score ranging between 0 to 1.
Corresponds to the JSON property bleuSpec
23363 23364 23365 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23363 def bleu_spec @bleu_spec end |
#computation_based_metric_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ComputationBasedMetricSpec
Specification for a computation based metric.
Corresponds to the JSON property computationBasedMetricSpec
23368 23369 23370 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23368 def computation_based_metric_spec @computation_based_metric_spec end |
#custom_code_execution_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CustomCodeExecutionSpec
Specificies a metric that is populated by evaluating user-defined Python code.
Corresponds to the JSON property customCodeExecutionSpec
23373 23374 23375 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23373 def custom_code_execution_spec @custom_code_execution_spec end |
#exact_match_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExactMatchSpec
Spec for exact match metric - returns 1 if prediction and reference exactly
matches, otherwise 0.
Corresponds to the JSON property exactMatchSpec
23379 23380 23381 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23379 def exact_match_spec @exact_match_spec end |
#llm_based_metric_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1LlmBasedMetricSpec
Specification for an LLM based metric.
Corresponds to the JSON property llmBasedMetricSpec
23384 23385 23386 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23384 def llm_based_metric_spec @llm_based_metric_spec end |
#metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetricMetadata
Metadata about the metric, used for visualization and organization.
Corresponds to the JSON property metadata
23389 23390 23391 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23389 def @metadata end |
#pairwise_metric_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PairwiseMetricSpec
Spec for pairwise metric.
Corresponds to the JSON property pairwiseMetricSpec
23394 23395 23396 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23394 def pairwise_metric_spec @pairwise_metric_spec end |
#pointwise_metric_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PointwiseMetricSpec
Spec for pointwise metric.
Corresponds to the JSON property pointwiseMetricSpec
23399 23400 23401 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23399 def pointwise_metric_spec @pointwise_metric_spec end |
#predefined_metric_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PredefinedMetricSpec
The spec for a pre-defined metric.
Corresponds to the JSON property predefinedMetricSpec
23404 23405 23406 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23404 def predefined_metric_spec @predefined_metric_spec end |
#rouge_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RougeSpec
Spec for rouge score metric - calculates the recall of n-grams in prediction
as compared to reference - returns a score ranging between 0 and 1.
Corresponds to the JSON property rougeSpec
23410 23411 23412 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23410 def rouge_spec @rouge_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23417 23418 23419 23420 23421 23422 23423 23424 23425 23426 23427 23428 23429 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23417 def update!(**args) @aggregation_metrics = args[:aggregation_metrics] if args.key?(:aggregation_metrics) @bleu_spec = args[:bleu_spec] if args.key?(:bleu_spec) @computation_based_metric_spec = args[:computation_based_metric_spec] if args.key?(:computation_based_metric_spec) @custom_code_execution_spec = args[:custom_code_execution_spec] if args.key?(:custom_code_execution_spec) @exact_match_spec = args[:exact_match_spec] if args.key?(:exact_match_spec) @llm_based_metric_spec = args[:llm_based_metric_spec] if args.key?(:llm_based_metric_spec) @metadata = args[:metadata] if args.key?(:metadata) @pairwise_metric_spec = args[:pairwise_metric_spec] if args.key?(:pairwise_metric_spec) @pointwise_metric_spec = args[:pointwise_metric_spec] if args.key?(:pointwise_metric_spec) @predefined_metric_spec = args[:predefined_metric_spec] if args.key?(:predefined_metric_spec) @rouge_spec = args[:rouge_spec] if args.key?(:rouge_spec) end |