Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Metric

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The metric used for running evaluations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Metric

Returns a new instance of GoogleCloudAiplatformV1Metric.



22339
22340
22341
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22339

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aggregation_metricsArray<String>

Optional. The aggregation metrics to use. Corresponds to the JSON property aggregationMetrics

Returns:

  • (Array<String>)


22284
22285
22286
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22284

def aggregation_metrics
  @aggregation_metrics
end

#bleu_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1BleuSpec

Spec for bleu score metric - calculates the precision of n-grams in the prediction as compared to reference - returns a score ranging between 0 to 1. Corresponds to the JSON property bleuSpec



22290
22291
22292
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22290

def bleu_spec
  @bleu_spec
end

#computation_based_metric_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ComputationBasedMetricSpec

Specification for a computation based metric. Corresponds to the JSON property computationBasedMetricSpec



22295
22296
22297
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22295

def computation_based_metric_spec
  @computation_based_metric_spec
end

#custom_code_execution_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1CustomCodeExecutionSpec

Specificies a metric that is populated by evaluating user-defined Python code. Corresponds to the JSON property customCodeExecutionSpec



22300
22301
22302
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22300

def custom_code_execution_spec
  @custom_code_execution_spec
end

#exact_match_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ExactMatchSpec

Spec for exact match metric - returns 1 if prediction and reference exactly matches, otherwise 0. Corresponds to the JSON property exactMatchSpec



22306
22307
22308
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22306

def exact_match_spec
  @exact_match_spec
end

#llm_based_metric_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1LlmBasedMetricSpec

Specification for an LLM based metric. Corresponds to the JSON property llmBasedMetricSpec



22311
22312
22313
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22311

def llm_based_metric_spec
  @llm_based_metric_spec
end

#metadataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1MetricMetadata

Metadata about the metric, used for visualization and organization. Corresponds to the JSON property metadata



22316
22317
22318
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22316

def 
  @metadata
end

#pairwise_metric_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PairwiseMetricSpec

Spec for pairwise metric. Corresponds to the JSON property pairwiseMetricSpec



22321
22322
22323
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22321

def pairwise_metric_spec
  @pairwise_metric_spec
end

#pointwise_metric_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PointwiseMetricSpec

Spec for pointwise metric. Corresponds to the JSON property pointwiseMetricSpec



22326
22327
22328
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22326

def pointwise_metric_spec
  @pointwise_metric_spec
end

#predefined_metric_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PredefinedMetricSpec

The spec for a pre-defined metric. Corresponds to the JSON property predefinedMetricSpec



22331
22332
22333
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22331

def predefined_metric_spec
  @predefined_metric_spec
end

#rouge_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RougeSpec

Spec for rouge score metric - calculates the recall of n-grams in prediction as compared to reference - returns a score ranging between 0 and 1. Corresponds to the JSON property rougeSpec



22337
22338
22339
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22337

def rouge_spec
  @rouge_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22344
22345
22346
22347
22348
22349
22350
22351
22352
22353
22354
22355
22356
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22344

def update!(**args)
  @aggregation_metrics = args[:aggregation_metrics] if args.key?(:aggregation_metrics)
  @bleu_spec = args[:bleu_spec] if args.key?(:bleu_spec)
  @computation_based_metric_spec = args[:computation_based_metric_spec] if args.key?(:computation_based_metric_spec)
  @custom_code_execution_spec = args[:custom_code_execution_spec] if args.key?(:custom_code_execution_spec)
  @exact_match_spec = args[:exact_match_spec] if args.key?(:exact_match_spec)
  @llm_based_metric_spec = args[:llm_based_metric_spec] if args.key?(:llm_based_metric_spec)
  @metadata = args[:metadata] if args.key?(:metadata)
  @pairwise_metric_spec = args[:pairwise_metric_spec] if args.key?(:pairwise_metric_spec)
  @pointwise_metric_spec = args[:pointwise_metric_spec] if args.key?(:pointwise_metric_spec)
  @predefined_metric_spec = args[:predefined_metric_spec] if args.key?(:predefined_metric_spec)
  @rouge_spec = args[:rouge_spec] if args.key?(:rouge_spec)
end