Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Metric

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The metric used for running evaluations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Metric

Returns a new instance of GoogleCloudAiplatformV1Metric.



22235
22236
22237
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22235

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aggregation_metricsArray<String>

Optional. The aggregation metrics to use. Corresponds to the JSON property aggregationMetrics

Returns:

  • (Array<String>)


22180
22181
22182
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22180

def aggregation_metrics
  @aggregation_metrics
end

#bleu_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1BleuSpec

Spec for bleu score metric - calculates the precision of n-grams in the prediction as compared to reference - returns a score ranging between 0 to 1. Corresponds to the JSON property bleuSpec



22186
22187
22188
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22186

def bleu_spec
  @bleu_spec
end

#computation_based_metric_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ComputationBasedMetricSpec

Specification for a computation based metric. Corresponds to the JSON property computationBasedMetricSpec



22191
22192
22193
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22191

def computation_based_metric_spec
  @computation_based_metric_spec
end

#custom_code_execution_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1CustomCodeExecutionSpec

Specificies a metric that is populated by evaluating user-defined Python code. Corresponds to the JSON property customCodeExecutionSpec



22196
22197
22198
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22196

def custom_code_execution_spec
  @custom_code_execution_spec
end

#exact_match_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ExactMatchSpec

Spec for exact match metric - returns 1 if prediction and reference exactly matches, otherwise 0. Corresponds to the JSON property exactMatchSpec



22202
22203
22204
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22202

def exact_match_spec
  @exact_match_spec
end

#llm_based_metric_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1LlmBasedMetricSpec

Specification for an LLM based metric. Corresponds to the JSON property llmBasedMetricSpec



22207
22208
22209
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22207

def llm_based_metric_spec
  @llm_based_metric_spec
end

#metadataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1MetricMetadata

Metadata about the metric, used for visualization and organization. Corresponds to the JSON property metadata



22212
22213
22214
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22212

def 
  @metadata
end

#pairwise_metric_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PairwiseMetricSpec

Spec for pairwise metric. Corresponds to the JSON property pairwiseMetricSpec



22217
22218
22219
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22217

def pairwise_metric_spec
  @pairwise_metric_spec
end

#pointwise_metric_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PointwiseMetricSpec

Spec for pointwise metric. Corresponds to the JSON property pointwiseMetricSpec



22222
22223
22224
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22222

def pointwise_metric_spec
  @pointwise_metric_spec
end

#predefined_metric_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PredefinedMetricSpec

The spec for a pre-defined metric. Corresponds to the JSON property predefinedMetricSpec



22227
22228
22229
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22227

def predefined_metric_spec
  @predefined_metric_spec
end

#rouge_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RougeSpec

Spec for rouge score metric - calculates the recall of n-grams in prediction as compared to reference - returns a score ranging between 0 and 1. Corresponds to the JSON property rougeSpec



22233
22234
22235
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22233

def rouge_spec
  @rouge_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22240
22241
22242
22243
22244
22245
22246
22247
22248
22249
22250
22251
22252
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22240

def update!(**args)
  @aggregation_metrics = args[:aggregation_metrics] if args.key?(:aggregation_metrics)
  @bleu_spec = args[:bleu_spec] if args.key?(:bleu_spec)
  @computation_based_metric_spec = args[:computation_based_metric_spec] if args.key?(:computation_based_metric_spec)
  @custom_code_execution_spec = args[:custom_code_execution_spec] if args.key?(:custom_code_execution_spec)
  @exact_match_spec = args[:exact_match_spec] if args.key?(:exact_match_spec)
  @llm_based_metric_spec = args[:llm_based_metric_spec] if args.key?(:llm_based_metric_spec)
  @metadata = args[:metadata] if args.key?(:metadata)
  @pairwise_metric_spec = args[:pairwise_metric_spec] if args.key?(:pairwise_metric_spec)
  @pointwise_metric_spec = args[:pointwise_metric_spec] if args.key?(:pointwise_metric_spec)
  @predefined_metric_spec = args[:predefined_metric_spec] if args.key?(:predefined_metric_spec)
  @rouge_spec = args[:rouge_spec] if args.key?(:rouge_spec)
end