Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetricMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Metadata about the metric, used for visualization and organization.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1MetricMetadata

Returns a new instance of GoogleCloudAiplatformV1MetricMetadata.



22379
22380
22381
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22379

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#other_metadataHash<String,Object>

Optional. Flexible metadata for user-defined attributes. Corresponds to the JSON property otherMetadata

Returns:

  • (Hash<String,Object>)


22366
22367
22368
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22366

def 
  @other_metadata
end

#score_rangeGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1MetricMetadataScoreRange

The range of possible scores for this metric, used for plotting. Corresponds to the JSON property scoreRange



22371
22372
22373
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22371

def score_range
  @score_range
end

#titleString

Optional. The user-friendly name for the metric. If not set for a registered metric, it will default to the metric's display name. Corresponds to the JSON property title

Returns:

  • (String)


22377
22378
22379
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22377

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22384
22385
22386
22387
22388
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22384

def update!(**args)
  @other_metadata = args[:other_metadata] if args.key?(:other_metadata)
  @score_range = args[:score_range] if args.key?(:score_range)
  @title = args[:title] if args.key?(:title)
end