Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetricMetadataScoreRange
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetricMetadataScoreRange
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The range of possible scores for this metric, used for plotting.
Instance Attribute Summary collapse
-
#description ⇒ String
Optional.
-
#max ⇒ Float
Required.
-
#min ⇒ Float
Required.
-
#step ⇒ Float
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1MetricMetadataScoreRange
constructor
A new instance of GoogleCloudAiplatformV1MetricMetadataScoreRange.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1MetricMetadataScoreRange
Returns a new instance of GoogleCloudAiplatformV1MetricMetadataScoreRange.
22416 22417 22418 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22416 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Optional. The description of the score explaining the directionality etc.
Corresponds to the JSON property description
22398 22399 22400 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22398 def description @description end |
#max ⇒ Float
Required. The maximum value of the score range (inclusive).
Corresponds to the JSON property max
22403 22404 22405 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22403 def max @max end |
#min ⇒ Float
Required. The minimum value of the score range (inclusive).
Corresponds to the JSON property min
22408 22409 22410 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22408 def min @min end |
#step ⇒ Float
Optional. The distance between discrete steps in the range. If unset, the
range is assumed to be continuous.
Corresponds to the JSON property step
22414 22415 22416 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22414 def step @step end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22421 22422 22423 22424 22425 22426 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22421 def update!(**args) @description = args[:description] if args.key?(:description) @max = args[:max] if args.key?(:max) @min = args[:min] if args.key?(:min) @step = args[:step] if args.key?(:step) end |