Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetricMetadataScoreRange
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetricMetadataScoreRange
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The range of possible scores for this metric, used for plotting.
Instance Attribute Summary collapse
-
#description ⇒ String
Optional.
-
#max ⇒ Float
Required.
-
#min ⇒ Float
Required.
-
#step ⇒ Float
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1MetricMetadataScoreRange
constructor
A new instance of GoogleCloudAiplatformV1MetricMetadataScoreRange.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1MetricMetadataScoreRange
Returns a new instance of GoogleCloudAiplatformV1MetricMetadataScoreRange.
22359 22360 22361 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22359 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Optional. The description of the score explaining the directionality etc.
Corresponds to the JSON property description
22341 22342 22343 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22341 def description @description end |
#max ⇒ Float
Required. The maximum value of the score range (inclusive).
Corresponds to the JSON property max
22346 22347 22348 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22346 def max @max end |
#min ⇒ Float
Required. The minimum value of the score range (inclusive).
Corresponds to the JSON property min
22351 22352 22353 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22351 def min @min end |
#step ⇒ Float
Optional. The distance between discrete steps in the range. If unset, the
range is assumed to be continuous.
Corresponds to the JSON property step
22357 22358 22359 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22357 def step @step end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22364 22365 22366 22367 22368 22369 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22364 def update!(**args) @description = args[:description] if args.key?(:description) @max = args[:max] if args.key?(:max) @min = args[:min] if args.key?(:min) @step = args[:step] if args.key?(:step) end |