Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetricMetadataScoreRange
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetricMetadataScoreRange
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The range of possible scores for this metric, used for plotting.
Instance Attribute Summary collapse
-
#description ⇒ String
Optional.
-
#max ⇒ Float
Required.
-
#min ⇒ Float
Required.
-
#step ⇒ Float
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1MetricMetadataScoreRange
constructor
A new instance of GoogleCloudAiplatformV1MetricMetadataScoreRange.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1MetricMetadataScoreRange
Returns a new instance of GoogleCloudAiplatformV1MetricMetadataScoreRange.
22312 22313 22314 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22312 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Optional. The description of the score explaining the directionality etc.
Corresponds to the JSON property description
22294 22295 22296 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22294 def description @description end |
#max ⇒ Float
Required. The maximum value of the score range (inclusive).
Corresponds to the JSON property max
22299 22300 22301 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22299 def max @max end |
#min ⇒ Float
Required. The minimum value of the score range (inclusive).
Corresponds to the JSON property min
22304 22305 22306 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22304 def min @min end |
#step ⇒ Float
Optional. The distance between discrete steps in the range. If unset, the
range is assumed to be continuous.
Corresponds to the JSON property step
22310 22311 22312 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22310 def step @step end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22317 22318 22319 22320 22321 22322 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22317 def update!(**args) @description = args[:description] if args.key?(:description) @max = args[:max] if args.key?(:max) @min = args[:min] if args.key?(:min) @step = args[:step] if args.key?(:step) end |