Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetricResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Result for a single metric on a single instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1MetricResult

Returns a new instance of GoogleCloudAiplatformV1MetricResult.



24318
24319
24320
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24318

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::AiplatformV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



24300
24301
24302
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24300

def error
  @error
end

#explanationString

Output only. The explanation for the metric result. Corresponds to the JSON property explanation

Returns:

  • (String)


24305
24306
24307
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24305

def explanation
  @explanation
end

#rubric_verdictsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricVerdict>

Output only. For rubric-based metrics, the verdicts for each rubric. Corresponds to the JSON property rubricVerdicts



24310
24311
24312
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24310

def rubric_verdicts
  @rubric_verdicts
end

#scoreFloat

Output only. The score for the metric. Please refer to each metric's documentation for the meaning of the score. Corresponds to the JSON property score

Returns:

  • (Float)


24316
24317
24318
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24316

def score
  @score
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24323
24324
24325
24326
24327
24328
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24323

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @explanation = args[:explanation] if args.key?(:explanation)
  @rubric_verdicts = args[:rubric_verdicts] if args.key?(:rubric_verdicts)
  @score = args[:score] if args.key?(:score)
end