Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetricResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Result for a single metric on a single instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1MetricResult

Returns a new instance of GoogleCloudAiplatformV1MetricResult.



22572
22573
22574
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22572

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::AiplatformV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



22554
22555
22556
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22554

def error
  @error
end

#explanationString

Output only. The explanation for the metric result. Corresponds to the JSON property explanation

Returns:

  • (String)


22559
22560
22561
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22559

def explanation
  @explanation
end

#rubric_verdictsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricVerdict>

Output only. For rubric-based metrics, the verdicts for each rubric. Corresponds to the JSON property rubricVerdicts



22564
22565
22566
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22564

def rubric_verdicts
  @rubric_verdicts
end

#scoreFloat

Output only. The score for the metric. Please refer to each metric's documentation for the meaning of the score. Corresponds to the JSON property score

Returns:

  • (Float)


22570
22571
22572
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22570

def score
  @score
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22577
22578
22579
22580
22581
22582
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22577

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @explanation = args[:explanation] if args.key?(:explanation)
  @rubric_verdicts = args[:rubric_verdicts] if args.key?(:rubric_verdicts)
  @score = args[:score] if args.key?(:score)
end