Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetricResult
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetricResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Result for a single metric on a single instance.
Instance Attribute Summary collapse
-
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#explanation ⇒ String
Output only.
-
#rubric_verdicts ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricVerdict>
Output only.
-
#score ⇒ Float
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1MetricResult
constructor
A new instance of GoogleCloudAiplatformV1MetricResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1MetricResult
Returns a new instance of GoogleCloudAiplatformV1MetricResult.
22459 22460 22461 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22459 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
22441 22442 22443 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22441 def error @error end |
#explanation ⇒ String
Output only. The explanation for the metric result.
Corresponds to the JSON property explanation
22446 22447 22448 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22446 def explanation @explanation end |
#rubric_verdicts ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricVerdict>
Output only. For rubric-based metrics, the verdicts for each rubric.
Corresponds to the JSON property rubricVerdicts
22451 22452 22453 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22451 def rubric_verdicts @rubric_verdicts end |
#score ⇒ Float
Output only. The score for the metric. Please refer to each metric's
documentation for the meaning of the score.
Corresponds to the JSON property score
22457 22458 22459 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22457 def score @score end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22464 22465 22466 22467 22468 22469 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22464 def update!(**args) @error = args[:error] if args.key?(:error) @explanation = args[:explanation] if args.key?(:explanation) @rubric_verdicts = args[:rubric_verdicts] if args.key?(:rubric_verdicts) @score = args[:score] if args.key?(:score) end |