Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Model
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Model
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A trained machine learning Model.
Instance Attribute Summary collapse
-
#artifact_uri ⇒ String
Immutable.
-
#base_model_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelBaseModelSource
User input field to specify the base model source.
-
#container_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelContainerSpec
Specification of a container for serving predictions.
-
#create_time ⇒ String
Output only.
-
#data_stats ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelDataStats
Stats of data used for train or evaluate the Model.
-
#deployed_models ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployedModelRef>
Output only.
-
#description ⇒ String
The description of the Model.
-
#display_name ⇒ String
Required.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top- level resource.
-
#etag ⇒ String
Used to perform consistent read-modify-write updates.
-
#explanation_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationSpec
Specification of Model explanation.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your Models.
-
#metadata ⇒ Object
Immutable.
-
#metadata_artifact ⇒ String
Output only.
-
#metadata_schema_uri ⇒ String
Immutable.
-
#model_source_info ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelSourceInfo
Detail description of the source information of the model.
-
#name ⇒ String
The resource name of the Model.
-
#original_model_info ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelOriginalModelInfo
Contains information about the original Model if this Model is a copy.
-
#pipeline_job ⇒ String
Optional.
-
#predict_schemata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PredictSchemata
Contains the schemata used in Model's predictions and explanations via PredictionService.Predict, PredictionService.Explain and BatchPredictionJob.
-
#supported_deployment_resources_types ⇒ Array<String>
Output only.
-
#supported_export_formats ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelExportFormat>
Output only.
-
#supported_input_storage_formats ⇒ Array<String>
Output only.
-
#supported_output_storage_formats ⇒ Array<String>
Output only.
-
#training_pipeline ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
-
#version_aliases ⇒ Array<String>
User provided version aliases so that a model version can be referenced via alias (i.e.
projects/project/locations/location/models/model_id@version_alias`instead of auto-generated version id (i.e.projects/project/ locations/location/models/model_id@version_id). The format is a-z0,126[a-z0-9] to distinguish from version_id. A default version alias will be created for the first version of the model, and there must be exactly one default version alias for a model. Corresponds to the JSON propertyversionAliases`. -
#version_create_time ⇒ String
Output only.
-
#version_description ⇒ String
The description of this version.
-
#version_id ⇒ String
Output only.
-
#version_update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Model
constructor
A new instance of GoogleCloudAiplatformV1Model.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Model
Returns a new instance of GoogleCloudAiplatformV1Model.
13769 13770 13771 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13769 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_uri ⇒ String
Immutable. The path to the directory containing the Model artifact and any of
its supporting files. Not required for AutoML Models.
Corresponds to the JSON property artifactUri
13546 13547 13548 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13546 def artifact_uri @artifact_uri end |
#base_model_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelBaseModelSource
User input field to specify the base model source. Currently it only supports
specifing the Model Garden models and Genie models.
Corresponds to the JSON property baseModelSource
13552 13553 13554 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13552 def base_model_source @base_model_source end |
#container_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelContainerSpec
Specification of a container for serving predictions. Some fields in this
message correspond to fields in the Kubernetes Container v1 core
specification.
Corresponds to the JSON property containerSpec
13560 13561 13562 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13560 def container_spec @container_spec end |
#create_time ⇒ String
Output only. Timestamp when this Model was uploaded into Vertex AI.
Corresponds to the JSON property createTime
13565 13566 13567 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13565 def create_time @create_time end |
#data_stats ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelDataStats
Stats of data used for train or evaluate the Model.
Corresponds to the JSON property dataStats
13570 13571 13572 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13570 def data_stats @data_stats end |
#deployed_models ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DeployedModelRef>
Output only. The pointers to DeployedModels created from this Model. Note that
Model could have been deployed to Endpoints in different Locations.
Corresponds to the JSON property deployedModels
13576 13577 13578 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13576 def deployed_models @deployed_models end |
#description ⇒ String
The description of the Model.
Corresponds to the JSON property description
13581 13582 13583 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13581 def description @description end |
#display_name ⇒ String
Required. The display name of the Model. The name can be up to 128 characters
long and can consist of any UTF-8 characters.
Corresponds to the JSON property displayName
13587 13588 13589 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13587 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top-
level resource.
Corresponds to the JSON property encryptionSpec
13593 13594 13595 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13593 def encryption_spec @encryption_spec end |
#etag ⇒ String
Used to perform consistent read-modify-write updates. If not set, a blind "
overwrite" update happens.
Corresponds to the JSON property etag
13599 13600 13601 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13599 def etag @etag end |
#explanation_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExplanationSpec
Specification of Model explanation.
Corresponds to the JSON property explanationSpec
13604 13605 13606 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13604 def explanation_spec @explanation_spec end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your Models. Label keys and
values can be no longer than 64 characters (Unicode codepoints), can only
contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. See https://goo.gl/xmQnxf for more
information and examples of labels.
Corresponds to the JSON property labels
13613 13614 13615 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13613 def labels @labels end |
#metadata ⇒ Object
Immutable. An additional information about the Model; the schema of the
metadata can be found in metadata_schema. Unset if the Model does not have any
additional information.
Corresponds to the JSON property metadata
13620 13621 13622 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13620 def @metadata end |
#metadata_artifact ⇒ String
Output only. The resource name of the Artifact that was created in
MetadataStore when creating the Model. The Artifact resource name pattern is
projects/project/locations/location/metadataStores/metadata_store/
artifacts/artifact`.
Corresponds to the JSON propertymetadataArtifact`
13628 13629 13630 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13628 def @metadata_artifact end |
#metadata_schema_uri ⇒ String
Immutable. Points to a YAML file stored on Google Cloud Storage describing
additional information about the Model, that is specific to it. Unset if the
Model does not have any additional information. The schema is defined as an
OpenAPI 3.0.2 Schema Object. AutoML Models always have this
field populated by Vertex AI, if no additional metadata is needed, this field
is set to an empty string. Note: The URI given on output will be immutable and
probably different, including the URI scheme, than the one given on input. The
output URI will point to a location where the user only has a read access.
Corresponds to the JSON property metadataSchemaUri
13641 13642 13643 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13641 def @metadata_schema_uri end |
#model_source_info ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelSourceInfo
Detail description of the source information of the model.
Corresponds to the JSON property modelSourceInfo
13646 13647 13648 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13646 def model_source_info @model_source_info end |
#name ⇒ String
The resource name of the Model.
Corresponds to the JSON property name
13651 13652 13653 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13651 def name @name end |
#original_model_info ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelOriginalModelInfo
Contains information about the original Model if this Model is a copy.
Corresponds to the JSON property originalModelInfo
13656 13657 13658 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13656 def original_model_info @original_model_info end |
#pipeline_job ⇒ String
Optional. This field is populated if the model is produced by a pipeline job.
Corresponds to the JSON property pipelineJob
13661 13662 13663 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13661 def pipeline_job @pipeline_job end |
#predict_schemata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PredictSchemata
Contains the schemata used in Model's predictions and explanations via
PredictionService.Predict, PredictionService.Explain and BatchPredictionJob.
Corresponds to the JSON property predictSchemata
13667 13668 13669 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13667 def predict_schemata @predict_schemata end |
#supported_deployment_resources_types ⇒ Array<String>
Output only. When this Model is deployed, its prediction resources are
described by the prediction_resources field of the Endpoint.deployed_models
object. Because not all Models support all resource configuration types, the
configuration types this Model supports are listed here. If no configuration
types are listed, the Model cannot be deployed to an Endpoint and does not
support online predictions (PredictionService.Predict or PredictionService.
Explain). Such a Model can serve predictions by using a BatchPredictionJob, if
it has at least one entry each in supported_input_storage_formats and
supported_output_storage_formats.
Corresponds to the JSON property supportedDeploymentResourcesTypes
13680 13681 13682 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13680 def supported_deployment_resources_types @supported_deployment_resources_types end |
#supported_export_formats ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelExportFormat>
Output only. The formats in which this Model may be exported. If empty, this
Model is not available for export.
Corresponds to the JSON property supportedExportFormats
13686 13687 13688 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13686 def supported_export_formats @supported_export_formats end |
#supported_input_storage_formats ⇒ Array<String>
Output only. The formats this Model supports in BatchPredictionJob.
input_config. If PredictSchemata.instance_schema_uri exists, the instances
should be given as per that schema. The possible formats are: * jsonl The
JSON Lines format, where each instance is a single line. Uses GcsSource. *
csv The CSV format, where each instance is a single comma-separated line. The
first line in the file is the header, containing comma-separated field names.
Uses GcsSource. * tf-record The TFRecord format, where each instance is a
single record in tfrecord syntax. Uses GcsSource. * tf-record-gzip Similar
to tf-record, but the file is gzipped. Uses GcsSource. * bigquery Each
instance is a single row in BigQuery. Uses BigQuerySource. * file-list Each
line of the file is the location of an instance to process, uses gcs_source
field of the InputConfig object. If this Model doesn't support any of these
formats it means it cannot be used with a BatchPredictionJob. However, if it
has supported_deployment_resources_types, it could serve online predictions by
using PredictionService.Predict or PredictionService.Explain.
Corresponds to the JSON property supportedInputStorageFormats
13705 13706 13707 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13705 def supported_input_storage_formats @supported_input_storage_formats end |
#supported_output_storage_formats ⇒ Array<String>
Output only. The formats this Model supports in BatchPredictionJob.
output_config. If both PredictSchemata.instance_schema_uri and PredictSchemata.
prediction_schema_uri exist, the predictions are returned together with their
instances. In other words, the prediction has the original instance data first,
followed by the actual prediction content (as per the schema). The possible
formats are: * jsonl The JSON Lines format, where each prediction is a
single line. Uses GcsDestination. * csv The CSV format, where each
prediction is a single comma-separated line. The first line in the file is the
header, containing comma-separated field names. Uses GcsDestination. *
bigquery Each prediction is a single row in a BigQuery table, uses
BigQueryDestination . If this Model doesn't support any of these formats it
means it cannot be used with a BatchPredictionJob. However, if it has
supported_deployment_resources_types, it could serve online predictions by
using PredictionService.Predict or PredictionService.Explain.
Corresponds to the JSON property supportedOutputStorageFormats
13723 13724 13725 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13723 def supported_output_storage_formats @supported_output_storage_formats end |
#training_pipeline ⇒ String
Output only. The resource name of the TrainingPipeline that uploaded this
Model, if any.
Corresponds to the JSON property trainingPipeline
13729 13730 13731 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13729 def training_pipeline @training_pipeline end |
#update_time ⇒ String
Output only. Timestamp when this Model was most recently updated.
Corresponds to the JSON property updateTime
13734 13735 13736 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13734 def update_time @update_time end |
#version_aliases ⇒ Array<String>
User provided version aliases so that a model version can be referenced via
alias (i.e. projects/project/locations/location/models/model_id@
version_alias`instead of auto-generated version id (i.e.projects/project/
locations/location/models/model_id@version_id). The format is a-z0,126
[a-z0-9] to distinguish from version_id. A default version alias will be
created for the first version of the model, and there must be exactly one
default version alias for a model.
Corresponds to the JSON propertyversionAliases`
13745 13746 13747 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13745 def version_aliases @version_aliases end |
#version_create_time ⇒ String
Output only. Timestamp when this version was created.
Corresponds to the JSON property versionCreateTime
13750 13751 13752 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13750 def version_create_time @version_create_time end |
#version_description ⇒ String
The description of this version.
Corresponds to the JSON property versionDescription
13755 13756 13757 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13755 def version_description @version_description end |
#version_id ⇒ String
Output only. Immutable. The version ID of the model. A new version is
committed when a new model version is uploaded or trained under an existing
model id. It is an auto-incrementing decimal number in string representation.
Corresponds to the JSON property versionId
13762 13763 13764 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13762 def version_id @version_id end |
#version_update_time ⇒ String
Output only. Timestamp when this version was most recently updated.
Corresponds to the JSON property versionUpdateTime
13767 13768 13769 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13767 def version_update_time @version_update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13774 13775 13776 13777 13778 13779 13780 13781 13782 13783 13784 13785 13786 13787 13788 13789 13790 13791 13792 13793 13794 13795 13796 13797 13798 13799 13800 13801 13802 13803 13804 13805 13806 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13774 def update!(**args) @artifact_uri = args[:artifact_uri] if args.key?(:artifact_uri) @base_model_source = args[:base_model_source] if args.key?(:base_model_source) @container_spec = args[:container_spec] if args.key?(:container_spec) @create_time = args[:create_time] if args.key?(:create_time) @data_stats = args[:data_stats] if args.key?(:data_stats) @deployed_models = args[:deployed_models] if args.key?(:deployed_models) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @etag = args[:etag] if args.key?(:etag) @explanation_spec = args[:explanation_spec] if args.key?(:explanation_spec) @labels = args[:labels] if args.key?(:labels) @metadata = args[:metadata] if args.key?(:metadata) @metadata_artifact = args[:metadata_artifact] if args.key?(:metadata_artifact) @metadata_schema_uri = args[:metadata_schema_uri] if args.key?(:metadata_schema_uri) @model_source_info = args[:model_source_info] if args.key?(:model_source_info) @name = args[:name] if args.key?(:name) @original_model_info = args[:original_model_info] if args.key?(:original_model_info) @pipeline_job = args[:pipeline_job] if args.key?(:pipeline_job) @predict_schemata = args[:predict_schemata] if args.key?(:predict_schemata) @supported_deployment_resources_types = args[:supported_deployment_resources_types] if args.key?(:supported_deployment_resources_types) @supported_export_formats = args[:supported_export_formats] if args.key?(:supported_export_formats) @supported_input_storage_formats = args[:supported_input_storage_formats] if args.key?(:supported_input_storage_formats) @supported_output_storage_formats = args[:supported_output_storage_formats] if args.key?(:supported_output_storage_formats) @training_pipeline = args[:training_pipeline] if args.key?(:training_pipeline) @update_time = args[:update_time] if args.key?(:update_time) @version_aliases = args[:version_aliases] if args.key?(:version_aliases) @version_create_time = args[:version_create_time] if args.key?(:version_create_time) @version_description = args[:version_description] if args.key?(:version_description) @version_id = args[:version_id] if args.key?(:version_id) @version_update_time = args[:version_update_time] if args.key?(:version_update_time) end |