Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelArmorConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Configuration for Model Armor. Model Armor is a Google Cloud service that provides safety and security filtering for prompts and responses. It helps protect your AI applications from risks such as harmful content, sensitive data leakage, and prompt injection attacks.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelArmorConfig

Returns a new instance of GoogleCloudAiplatformV1ModelArmorConfig.



23265
23266
23267
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23265

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#prompt_template_nameString

Optional. The resource name of the Model Armor template to use for prompt screening. A Model Armor template is a set of customized filters and thresholds that define how Model Armor screens content. If specified, Model Armor will use this template to check the user's prompt for safety and security risks before it is sent to the model. The name must be in the format projects/project/locations/location/templates/template`. Corresponds to the JSON propertypromptTemplateName`

Returns:

  • (String)


23253
23254
23255
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23253

def prompt_template_name
  @prompt_template_name
end

#response_template_nameString

Optional. The resource name of the Model Armor template to use for response screening. A Model Armor template is a set of customized filters and thresholds that define how Model Armor screens content. If specified, Model Armor will use this template to check the model's response for safety and security risks before it is returned to the user. The name must be in the format projects/project/locations/location/templates/template`. Corresponds to the JSON propertyresponseTemplateName`

Returns:

  • (String)


23263
23264
23265
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23263

def response_template_name
  @response_template_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23270
23271
23272
23273
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23270

def update!(**args)
  @prompt_template_name = args[:prompt_template_name] if args.key?(:prompt_template_name)
  @response_template_name = args[:response_template_name] if args.key?(:response_template_name)
end