Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelDataStats
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelDataStats
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Stats of data used for train or evaluate the Model.
Instance Attribute Summary collapse
-
#test_annotations_count ⇒ Fixnum
Number of Annotations that are used for evaluating this Model.
-
#test_data_items_count ⇒ Fixnum
Number of DataItems that were used for evaluating this Model.
-
#training_annotations_count ⇒ Fixnum
Number of Annotations that are used for training this Model.
-
#training_data_items_count ⇒ Fixnum
Number of DataItems that were used for training this Model.
-
#validation_annotations_count ⇒ Fixnum
Number of Annotations that are used for validating this Model during training.
-
#validation_data_items_count ⇒ Fixnum
Number of DataItems that were used for validating this Model during training.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelDataStats
constructor
A new instance of GoogleCloudAiplatformV1ModelDataStats.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelDataStats
Returns a new instance of GoogleCloudAiplatformV1ModelDataStats.
17198 17199 17200 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17198 def initialize(**args) update!(**args) end |
Instance Attribute Details
#test_annotations_count ⇒ Fixnum
Number of Annotations that are used for evaluating this Model. If the Model is
evaluated multiple times, this will be the number of test Annotations used by
the first evaluation. If the Model is not evaluated, the number is 0.
Corresponds to the JSON property testAnnotationsCount
17169 17170 17171 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17169 def test_annotations_count @test_annotations_count end |
#test_data_items_count ⇒ Fixnum
Number of DataItems that were used for evaluating this Model. If the Model is
evaluated multiple times, this will be the number of test DataItems used by
the first evaluation. If the Model is not evaluated, the number is 0.
Corresponds to the JSON property testDataItemsCount
17176 17177 17178 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17176 def test_data_items_count @test_data_items_count end |
#training_annotations_count ⇒ Fixnum
Number of Annotations that are used for training this Model.
Corresponds to the JSON property trainingAnnotationsCount
17181 17182 17183 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17181 def training_annotations_count @training_annotations_count end |
#training_data_items_count ⇒ Fixnum
Number of DataItems that were used for training this Model.
Corresponds to the JSON property trainingDataItemsCount
17186 17187 17188 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17186 def training_data_items_count @training_data_items_count end |
#validation_annotations_count ⇒ Fixnum
Number of Annotations that are used for validating this Model during training.
Corresponds to the JSON property validationAnnotationsCount
17191 17192 17193 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17191 def validation_annotations_count @validation_annotations_count end |
#validation_data_items_count ⇒ Fixnum
Number of DataItems that were used for validating this Model during training.
Corresponds to the JSON property validationDataItemsCount
17196 17197 17198 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17196 def validation_data_items_count @validation_data_items_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17203 17204 17205 17206 17207 17208 17209 17210 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17203 def update!(**args) @test_annotations_count = args[:test_annotations_count] if args.key?(:test_annotations_count) @test_data_items_count = args[:test_data_items_count] if args.key?(:test_data_items_count) @training_annotations_count = args[:training_annotations_count] if args.key?(:training_annotations_count) @training_data_items_count = args[:training_data_items_count] if args.key?(:training_data_items_count) @validation_annotations_count = args[:validation_annotations_count] if args.key?(:validation_annotations_count) @validation_data_items_count = args[:validation_data_items_count] if args.key?(:validation_data_items_count) end |