Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelDataStats

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Stats of data used for train or evaluate the Model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelDataStats

Returns a new instance of GoogleCloudAiplatformV1ModelDataStats.



17132
17133
17134
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17132

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#test_annotations_countFixnum

Number of Annotations that are used for evaluating this Model. If the Model is evaluated multiple times, this will be the number of test Annotations used by the first evaluation. If the Model is not evaluated, the number is 0. Corresponds to the JSON property testAnnotationsCount

Returns:

  • (Fixnum)


17103
17104
17105
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17103

def test_annotations_count
  @test_annotations_count
end

#test_data_items_countFixnum

Number of DataItems that were used for evaluating this Model. If the Model is evaluated multiple times, this will be the number of test DataItems used by the first evaluation. If the Model is not evaluated, the number is 0. Corresponds to the JSON property testDataItemsCount

Returns:

  • (Fixnum)


17110
17111
17112
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17110

def test_data_items_count
  @test_data_items_count
end

#training_annotations_countFixnum

Number of Annotations that are used for training this Model. Corresponds to the JSON property trainingAnnotationsCount

Returns:

  • (Fixnum)


17115
17116
17117
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17115

def training_annotations_count
  @training_annotations_count
end

#training_data_items_countFixnum

Number of DataItems that were used for training this Model. Corresponds to the JSON property trainingDataItemsCount

Returns:

  • (Fixnum)


17120
17121
17122
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17120

def training_data_items_count
  @training_data_items_count
end

#validation_annotations_countFixnum

Number of Annotations that are used for validating this Model during training. Corresponds to the JSON property validationAnnotationsCount

Returns:

  • (Fixnum)


17125
17126
17127
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17125

def validation_annotations_count
  @validation_annotations_count
end

#validation_data_items_countFixnum

Number of DataItems that were used for validating this Model during training. Corresponds to the JSON property validationDataItemsCount

Returns:

  • (Fixnum)


17130
17131
17132
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17130

def validation_data_items_count
  @validation_data_items_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17137
17138
17139
17140
17141
17142
17143
17144
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17137

def update!(**args)
  @test_annotations_count = args[:test_annotations_count] if args.key?(:test_annotations_count)
  @test_data_items_count = args[:test_data_items_count] if args.key?(:test_data_items_count)
  @training_annotations_count = args[:training_annotations_count] if args.key?(:training_annotations_count)
  @training_data_items_count = args[:training_data_items_count] if args.key?(:training_data_items_count)
  @validation_annotations_count = args[:validation_annotations_count] if args.key?(:validation_annotations_count)
  @validation_data_items_count = args[:validation_data_items_count] if args.key?(:validation_data_items_count)
end