Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelDataStats

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Stats of data used for train or evaluate the Model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelDataStats

Returns a new instance of GoogleCloudAiplatformV1ModelDataStats.



16993
16994
16995
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16993

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#test_annotations_countFixnum

Number of Annotations that are used for evaluating this Model. If the Model is evaluated multiple times, this will be the number of test Annotations used by the first evaluation. If the Model is not evaluated, the number is 0. Corresponds to the JSON property testAnnotationsCount

Returns:

  • (Fixnum)


16964
16965
16966
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16964

def test_annotations_count
  @test_annotations_count
end

#test_data_items_countFixnum

Number of DataItems that were used for evaluating this Model. If the Model is evaluated multiple times, this will be the number of test DataItems used by the first evaluation. If the Model is not evaluated, the number is 0. Corresponds to the JSON property testDataItemsCount

Returns:

  • (Fixnum)


16971
16972
16973
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16971

def test_data_items_count
  @test_data_items_count
end

#training_annotations_countFixnum

Number of Annotations that are used for training this Model. Corresponds to the JSON property trainingAnnotationsCount

Returns:

  • (Fixnum)


16976
16977
16978
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16976

def training_annotations_count
  @training_annotations_count
end

#training_data_items_countFixnum

Number of DataItems that were used for training this Model. Corresponds to the JSON property trainingDataItemsCount

Returns:

  • (Fixnum)


16981
16982
16983
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16981

def training_data_items_count
  @training_data_items_count
end

#validation_annotations_countFixnum

Number of Annotations that are used for validating this Model during training. Corresponds to the JSON property validationAnnotationsCount

Returns:

  • (Fixnum)


16986
16987
16988
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16986

def validation_annotations_count
  @validation_annotations_count
end

#validation_data_items_countFixnum

Number of DataItems that were used for validating this Model during training. Corresponds to the JSON property validationDataItemsCount

Returns:

  • (Fixnum)


16991
16992
16993
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16991

def validation_data_items_count
  @validation_data_items_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16998
16999
17000
17001
17002
17003
17004
17005
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16998

def update!(**args)
  @test_annotations_count = args[:test_annotations_count] if args.key?(:test_annotations_count)
  @test_data_items_count = args[:test_data_items_count] if args.key?(:test_data_items_count)
  @training_annotations_count = args[:training_annotations_count] if args.key?(:training_annotations_count)
  @training_data_items_count = args[:training_data_items_count] if args.key?(:training_data_items_count)
  @validation_annotations_count = args[:validation_annotations_count] if args.key?(:validation_annotations_count)
  @validation_data_items_count = args[:validation_data_items_count] if args.key?(:validation_data_items_count)
end