Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelDataStats

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Stats of data used for train or evaluate the Model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelDataStats

Returns a new instance of GoogleCloudAiplatformV1ModelDataStats.



16957
16958
16959
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16957

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#test_annotations_countFixnum

Number of Annotations that are used for evaluating this Model. If the Model is evaluated multiple times, this will be the number of test Annotations used by the first evaluation. If the Model is not evaluated, the number is 0. Corresponds to the JSON property testAnnotationsCount

Returns:

  • (Fixnum)


16928
16929
16930
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16928

def test_annotations_count
  @test_annotations_count
end

#test_data_items_countFixnum

Number of DataItems that were used for evaluating this Model. If the Model is evaluated multiple times, this will be the number of test DataItems used by the first evaluation. If the Model is not evaluated, the number is 0. Corresponds to the JSON property testDataItemsCount

Returns:

  • (Fixnum)


16935
16936
16937
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16935

def test_data_items_count
  @test_data_items_count
end

#training_annotations_countFixnum

Number of Annotations that are used for training this Model. Corresponds to the JSON property trainingAnnotationsCount

Returns:

  • (Fixnum)


16940
16941
16942
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16940

def training_annotations_count
  @training_annotations_count
end

#training_data_items_countFixnum

Number of DataItems that were used for training this Model. Corresponds to the JSON property trainingDataItemsCount

Returns:

  • (Fixnum)


16945
16946
16947
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16945

def training_data_items_count
  @training_data_items_count
end

#validation_annotations_countFixnum

Number of Annotations that are used for validating this Model during training. Corresponds to the JSON property validationAnnotationsCount

Returns:

  • (Fixnum)


16950
16951
16952
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16950

def validation_annotations_count
  @validation_annotations_count
end

#validation_data_items_countFixnum

Number of DataItems that were used for validating this Model during training. Corresponds to the JSON property validationDataItemsCount

Returns:

  • (Fixnum)


16955
16956
16957
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16955

def validation_data_items_count
  @validation_data_items_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16962
16963
16964
16965
16966
16967
16968
16969
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16962

def update!(**args)
  @test_annotations_count = args[:test_annotations_count] if args.key?(:test_annotations_count)
  @test_data_items_count = args[:test_data_items_count] if args.key?(:test_data_items_count)
  @training_annotations_count = args[:training_annotations_count] if args.key?(:training_annotations_count)
  @training_data_items_count = args[:training_data_items_count] if args.key?(:training_data_items_count)
  @validation_annotations_count = args[:validation_annotations_count] if args.key?(:validation_annotations_count)
  @validation_data_items_count = args[:validation_data_items_count] if args.key?(:validation_data_items_count)
end