Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelDataStats

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Stats of data used for train or evaluate the Model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelDataStats

Returns a new instance of GoogleCloudAiplatformV1ModelDataStats.



13857
13858
13859
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13857

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#test_annotations_countFixnum

Number of Annotations that are used for evaluating this Model. If the Model is evaluated multiple times, this will be the number of test Annotations used by the first evaluation. If the Model is not evaluated, the number is 0. Corresponds to the JSON property testAnnotationsCount

Returns:

  • (Fixnum)


13828
13829
13830
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13828

def test_annotations_count
  @test_annotations_count
end

#test_data_items_countFixnum

Number of DataItems that were used for evaluating this Model. If the Model is evaluated multiple times, this will be the number of test DataItems used by the first evaluation. If the Model is not evaluated, the number is 0. Corresponds to the JSON property testDataItemsCount

Returns:

  • (Fixnum)


13835
13836
13837
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13835

def test_data_items_count
  @test_data_items_count
end

#training_annotations_countFixnum

Number of Annotations that are used for training this Model. Corresponds to the JSON property trainingAnnotationsCount

Returns:

  • (Fixnum)


13840
13841
13842
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13840

def training_annotations_count
  @training_annotations_count
end

#training_data_items_countFixnum

Number of DataItems that were used for training this Model. Corresponds to the JSON property trainingDataItemsCount

Returns:

  • (Fixnum)


13845
13846
13847
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13845

def training_data_items_count
  @training_data_items_count
end

#validation_annotations_countFixnum

Number of Annotations that are used for validating this Model during training. Corresponds to the JSON property validationAnnotationsCount

Returns:

  • (Fixnum)


13850
13851
13852
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13850

def validation_annotations_count
  @validation_annotations_count
end

#validation_data_items_countFixnum

Number of DataItems that were used for validating this Model during training. Corresponds to the JSON property validationDataItemsCount

Returns:

  • (Fixnum)


13855
13856
13857
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13855

def validation_data_items_count
  @validation_data_items_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13862
13863
13864
13865
13866
13867
13868
13869
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13862

def update!(**args)
  @test_annotations_count = args[:test_annotations_count] if args.key?(:test_annotations_count)
  @test_data_items_count = args[:test_data_items_count] if args.key?(:test_data_items_count)
  @training_annotations_count = args[:training_annotations_count] if args.key?(:training_annotations_count)
  @training_data_items_count = args[:training_data_items_count] if args.key?(:training_data_items_count)
  @validation_annotations_count = args[:validation_annotations_count] if args.key?(:validation_annotations_count)
  @validation_data_items_count = args[:validation_data_items_count] if args.key?(:validation_data_items_count)
end