Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelDataStats
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelDataStats
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Stats of data used for train or evaluate the Model.
Instance Attribute Summary collapse
-
#test_annotations_count ⇒ Fixnum
Number of Annotations that are used for evaluating this Model.
-
#test_data_items_count ⇒ Fixnum
Number of DataItems that were used for evaluating this Model.
-
#training_annotations_count ⇒ Fixnum
Number of Annotations that are used for training this Model.
-
#training_data_items_count ⇒ Fixnum
Number of DataItems that were used for training this Model.
-
#validation_annotations_count ⇒ Fixnum
Number of Annotations that are used for validating this Model during training.
-
#validation_data_items_count ⇒ Fixnum
Number of DataItems that were used for validating this Model during training.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelDataStats
constructor
A new instance of GoogleCloudAiplatformV1ModelDataStats.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelDataStats
Returns a new instance of GoogleCloudAiplatformV1ModelDataStats.
13924 13925 13926 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13924 def initialize(**args) update!(**args) end |
Instance Attribute Details
#test_annotations_count ⇒ Fixnum
Number of Annotations that are used for evaluating this Model. If the Model is
evaluated multiple times, this will be the number of test Annotations used by
the first evaluation. If the Model is not evaluated, the number is 0.
Corresponds to the JSON property testAnnotationsCount
13895 13896 13897 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13895 def test_annotations_count @test_annotations_count end |
#test_data_items_count ⇒ Fixnum
Number of DataItems that were used for evaluating this Model. If the Model is
evaluated multiple times, this will be the number of test DataItems used by
the first evaluation. If the Model is not evaluated, the number is 0.
Corresponds to the JSON property testDataItemsCount
13902 13903 13904 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13902 def test_data_items_count @test_data_items_count end |
#training_annotations_count ⇒ Fixnum
Number of Annotations that are used for training this Model.
Corresponds to the JSON property trainingAnnotationsCount
13907 13908 13909 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13907 def training_annotations_count @training_annotations_count end |
#training_data_items_count ⇒ Fixnum
Number of DataItems that were used for training this Model.
Corresponds to the JSON property trainingDataItemsCount
13912 13913 13914 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13912 def training_data_items_count @training_data_items_count end |
#validation_annotations_count ⇒ Fixnum
Number of Annotations that are used for validating this Model during training.
Corresponds to the JSON property validationAnnotationsCount
13917 13918 13919 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13917 def validation_annotations_count @validation_annotations_count end |
#validation_data_items_count ⇒ Fixnum
Number of DataItems that were used for validating this Model during training.
Corresponds to the JSON property validationDataItemsCount
13922 13923 13924 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13922 def validation_data_items_count @validation_data_items_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13929 13930 13931 13932 13933 13934 13935 13936 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13929 def update!(**args) @test_annotations_count = args[:test_annotations_count] if args.key?(:test_annotations_count) @test_data_items_count = args[:test_data_items_count] if args.key?(:test_data_items_count) @training_annotations_count = args[:training_annotations_count] if args.key?(:training_annotations_count) @training_data_items_count = args[:training_data_items_count] if args.key?(:training_data_items_count) @validation_annotations_count = args[:validation_annotations_count] if args.key?(:validation_annotations_count) @validation_data_items_count = args[:validation_data_items_count] if args.key?(:validation_data_items_count) end |