Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelDeploymentMonitoringJob
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelDeploymentMonitoringJob
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Represents a job that runs periodically to monitor the deployed models in an endpoint. It will analyze the logged training & prediction data to detect any abnormal behaviors.
Instance Attribute Summary collapse
-
#analysis_instance_schema_uri ⇒ String
YAML schema file uri describing the format of a single instance that you want Tensorflow Data Validation (TFDV) to analyze.
-
#bigquery_tables ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelDeploymentMonitoringBigQueryTable>
Output only.
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Required.
-
#enable_monitoring_pipeline_logs ⇒ Boolean
(also: #enable_monitoring_pipeline_logs?)
If true, the scheduled monitoring pipeline logs are sent to Google Cloud Logging, including pipeline status and anomalies detected.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.
-
#endpoint ⇒ String
Required.
-
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your ModelDeploymentMonitoringJob.
-
#latest_monitoring_pipeline_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelDeploymentMonitoringJobLatestMonitoringPipelineMetadata
All metadata of most recent monitoring pipelines.
-
#log_ttl ⇒ String
The TTL of BigQuery tables in user projects which stores logs.
-
#logging_sampling_strategy ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SamplingStrategy
Sampling Strategy for logging, can be for both training and prediction dataset.
-
#model_deployment_monitoring_objective_configs ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelDeploymentMonitoringObjectiveConfig>
Required.
-
#model_deployment_monitoring_schedule_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelDeploymentMonitoringScheduleConfig
The config for scheduling monitoring job.
-
#model_monitoring_alert_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelMonitoringAlertConfig
The alert config for model monitoring.
-
#name ⇒ String
Output only.
-
#next_schedule_time ⇒ String
Output only.
-
#predict_instance_schema_uri ⇒ String
YAML schema file uri describing the format of a single instance, which are given to format this Endpoint's prediction (and explanation).
-
#sample_predict_instance ⇒ Object
Sample Predict instance, same format as PredictRequest.instances, this can be set as a replacement of ModelDeploymentMonitoringJob.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#schedule_state ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#stats_anomalies_base_directory ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsDestination
The Google Cloud Storage location where the output is to be written to.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelDeploymentMonitoringJob
constructor
A new instance of GoogleCloudAiplatformV1ModelDeploymentMonitoringJob.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelDeploymentMonitoringJob
Returns a new instance of GoogleCloudAiplatformV1ModelDeploymentMonitoringJob.
26228 26229 26230 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26228 def initialize(**args) update!(**args) end |
Instance Attribute Details
#analysis_instance_schema_uri ⇒ String
YAML schema file uri describing the format of a single instance that you want
Tensorflow Data Validation (TFDV) to analyze. If this field is empty, all the
feature data types are inferred from predict_instance_schema_uri, meaning that
TFDV will use the data in the exact format(data type) as prediction request/
response. If there are any data type differences between predict instance and
TFDV instance, this field can be used to override the schema. For models
trained with Vertex AI, this field must be set as all the fields in predict
instance formatted as string.
Corresponds to the JSON property analysisInstanceSchemaUri
26071 26072 26073 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26071 def analysis_instance_schema_uri @analysis_instance_schema_uri end |
#bigquery_tables ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelDeploymentMonitoringBigQueryTable>
Output only. The created bigquery tables for the job under customer project.
Customer could do their own query & analysis. There could be 4 log tables in
maximum: 1. Training data logging predict request/response 2. Serving data
logging predict request/response
Corresponds to the JSON property bigqueryTables
26079 26080 26081 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26079 def bigquery_tables @bigquery_tables end |
#create_time ⇒ String
Output only. Timestamp when this ModelDeploymentMonitoringJob was created.
Corresponds to the JSON property createTime
26084 26085 26086 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26084 def create_time @create_time end |
#display_name ⇒ String
Required. The user-defined name of the ModelDeploymentMonitoringJob. The name
can be up to 128 characters long and can consist of any UTF-8 characters.
Display name of a ModelDeploymentMonitoringJob.
Corresponds to the JSON property displayName
26091 26092 26093 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26091 def display_name @display_name end |
#enable_monitoring_pipeline_logs ⇒ Boolean Also known as: enable_monitoring_pipeline_logs?
If true, the scheduled monitoring pipeline logs are sent to Google Cloud
Logging, including pipeline status and anomalies detected. Please note the
logs incur cost, which are subject to Cloud Logging pricing.
Corresponds to the JSON property enableMonitoringPipelineLogs
26099 26100 26101 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26099 def enable_monitoring_pipeline_logs @enable_monitoring_pipeline_logs end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied
to a Vertex AI resource.
Corresponds to the JSON property encryptionSpec
26106 26107 26108 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26106 def encryption_spec @encryption_spec end |
#endpoint ⇒ String
Required. Endpoint resource name. Format: projects/project/locations/
location/endpoints/endpoint`
Corresponds to the JSON propertyendpoint`
26112 26113 26114 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26112 def endpoint @endpoint end |
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
26122 26123 26124 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26122 def error @error end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your
ModelDeploymentMonitoringJob. Label keys and values can be no longer than 64
characters (Unicode codepoints), can only contain lowercase letters, numeric
characters, underscores and dashes. International characters are allowed. See
https://goo.gl/xmQnxf for more information and examples of labels.
Corresponds to the JSON property labels
26131 26132 26133 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26131 def labels @labels end |
#latest_monitoring_pipeline_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelDeploymentMonitoringJobLatestMonitoringPipelineMetadata
All metadata of most recent monitoring pipelines.
Corresponds to the JSON property latestMonitoringPipelineMetadata
26136 26137 26138 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26136 def @latest_monitoring_pipeline_metadata end |
#log_ttl ⇒ String
The TTL of BigQuery tables in user projects which stores logs. A day is the
basic unit of the TTL and we take the ceil of TTL/86400(a day). e.g. second:
3600 indicates ttl = 1 day.
Corresponds to the JSON property logTtl
26143 26144 26145 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26143 def log_ttl @log_ttl end |
#logging_sampling_strategy ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SamplingStrategy
Sampling Strategy for logging, can be for both training and prediction dataset.
Corresponds to the JSON property loggingSamplingStrategy
26148 26149 26150 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26148 def logging_sampling_strategy @logging_sampling_strategy end |
#model_deployment_monitoring_objective_configs ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelDeploymentMonitoringObjectiveConfig>
Required. The config for monitoring objectives. This is a per DeployedModel
config. Each DeployedModel needs to be configured separately.
Corresponds to the JSON property modelDeploymentMonitoringObjectiveConfigs
26154 26155 26156 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26154 def model_deployment_monitoring_objective_configs @model_deployment_monitoring_objective_configs end |
#model_deployment_monitoring_schedule_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelDeploymentMonitoringScheduleConfig
The config for scheduling monitoring job.
Corresponds to the JSON property modelDeploymentMonitoringScheduleConfig
26159 26160 26161 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26159 def model_deployment_monitoring_schedule_config @model_deployment_monitoring_schedule_config end |
#model_monitoring_alert_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelMonitoringAlertConfig
The alert config for model monitoring.
Corresponds to the JSON property modelMonitoringAlertConfig
26164 26165 26166 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26164 def model_monitoring_alert_config @model_monitoring_alert_config end |
#name ⇒ String
Output only. Resource name of a ModelDeploymentMonitoringJob.
Corresponds to the JSON property name
26169 26170 26171 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26169 def name @name end |
#next_schedule_time ⇒ String
Output only. Timestamp when this monitoring pipeline will be scheduled to run
for the next round.
Corresponds to the JSON property nextScheduleTime
26175 26176 26177 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26175 def next_schedule_time @next_schedule_time end |
#predict_instance_schema_uri ⇒ String
YAML schema file uri describing the format of a single instance, which are
given to format this Endpoint's prediction (and explanation). If not set, we
will generate predict schema from collected predict requests.
Corresponds to the JSON property predictInstanceSchemaUri
26182 26183 26184 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26182 def predict_instance_schema_uri @predict_instance_schema_uri end |
#sample_predict_instance ⇒ Object
Sample Predict instance, same format as PredictRequest.instances, this can be
set as a replacement of ModelDeploymentMonitoringJob.
predict_instance_schema_uri. If not set, we will generate predict schema from
collected predict requests.
Corresponds to the JSON property samplePredictInstance
26190 26191 26192 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26190 def sample_predict_instance @sample_predict_instance end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
26195 26196 26197 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26195 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
26201 26202 26203 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26201 def satisfies_pzs @satisfies_pzs end |
#schedule_state ⇒ String
Output only. Schedule state when the monitoring job is in Running state.
Corresponds to the JSON property scheduleState
26207 26208 26209 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26207 def schedule_state @schedule_state end |
#state ⇒ String
Output only. The detailed state of the monitoring job. When the job is still
creating, the state will be 'PENDING'. Once the job is successfully created,
the state will be 'RUNNING'. Pause the job, the state will be 'PAUSED'. Resume
the job, the state will return to 'RUNNING'.
Corresponds to the JSON property state
26215 26216 26217 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26215 def state @state end |
#stats_anomalies_base_directory ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsDestination
The Google Cloud Storage location where the output is to be written to.
Corresponds to the JSON property statsAnomaliesBaseDirectory
26220 26221 26222 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26220 def stats_anomalies_base_directory @stats_anomalies_base_directory end |
#update_time ⇒ String
Output only. Timestamp when this ModelDeploymentMonitoringJob was updated most
recently.
Corresponds to the JSON property updateTime
26226 26227 26228 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26226 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26233 26234 26235 26236 26237 26238 26239 26240 26241 26242 26243 26244 26245 26246 26247 26248 26249 26250 26251 26252 26253 26254 26255 26256 26257 26258 26259 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26233 def update!(**args) @analysis_instance_schema_uri = args[:analysis_instance_schema_uri] if args.key?(:analysis_instance_schema_uri) @bigquery_tables = args[:bigquery_tables] if args.key?(:bigquery_tables) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @enable_monitoring_pipeline_logs = args[:enable_monitoring_pipeline_logs] if args.key?(:enable_monitoring_pipeline_logs) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @endpoint = args[:endpoint] if args.key?(:endpoint) @error = args[:error] if args.key?(:error) @labels = args[:labels] if args.key?(:labels) @latest_monitoring_pipeline_metadata = args[:latest_monitoring_pipeline_metadata] if args.key?(:latest_monitoring_pipeline_metadata) @log_ttl = args[:log_ttl] if args.key?(:log_ttl) @logging_sampling_strategy = args[:logging_sampling_strategy] if args.key?(:logging_sampling_strategy) @model_deployment_monitoring_objective_configs = args[:model_deployment_monitoring_objective_configs] if args.key?(:model_deployment_monitoring_objective_configs) @model_deployment_monitoring_schedule_config = args[:model_deployment_monitoring_schedule_config] if args.key?(:model_deployment_monitoring_schedule_config) @model_monitoring_alert_config = args[:model_monitoring_alert_config] if args.key?(:model_monitoring_alert_config) @name = args[:name] if args.key?(:name) @next_schedule_time = args[:next_schedule_time] if args.key?(:next_schedule_time) @predict_instance_schema_uri = args[:predict_instance_schema_uri] if args.key?(:predict_instance_schema_uri) @sample_predict_instance = args[:sample_predict_instance] if args.key?(:sample_predict_instance) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @schedule_state = args[:schedule_state] if args.key?(:schedule_state) @state = args[:state] if args.key?(:state) @stats_anomalies_base_directory = args[:stats_anomalies_base_directory] if args.key?(:stats_anomalies_base_directory) @update_time = args[:update_time] if args.key?(:update_time) end |