Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelDeploymentMonitoringJobLatestMonitoringPipelineMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelDeploymentMonitoringJobLatestMonitoringPipelineMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
All metadata of most recent monitoring pipelines.
Instance Attribute Summary collapse
-
#run_time ⇒ String
The time that most recent monitoring pipelines that is related to this run.
-
#status ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelDeploymentMonitoringJobLatestMonitoringPipelineMetadata
constructor
A new instance of GoogleCloudAiplatformV1ModelDeploymentMonitoringJobLatestMonitoringPipelineMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelDeploymentMonitoringJobLatestMonitoringPipelineMetadata
Returns a new instance of GoogleCloudAiplatformV1ModelDeploymentMonitoringJobLatestMonitoringPipelineMetadata.
25818 25819 25820 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25818 def initialize(**args) update!(**args) end |
Instance Attribute Details
#run_time ⇒ String
The time that most recent monitoring pipelines that is related to this run.
Corresponds to the JSON property runTime
25806 25807 25808 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25806 def run_time @run_time end |
#status ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property status
25816 25817 25818 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25816 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25823 25824 25825 25826 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25823 def update!(**args) @run_time = args[:run_time] if args.key?(:run_time) @status = args[:status] if args.key?(:status) end |