Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelDeploymentMonitoringJobLatestMonitoringPipelineMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelDeploymentMonitoringJobLatestMonitoringPipelineMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
All metadata of most recent monitoring pipelines.
Instance Attribute Summary collapse
-
#run_time ⇒ String
The time that most recent monitoring pipelines that is related to this run.
-
#status ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelDeploymentMonitoringJobLatestMonitoringPipelineMetadata
constructor
A new instance of GoogleCloudAiplatformV1ModelDeploymentMonitoringJobLatestMonitoringPipelineMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelDeploymentMonitoringJobLatestMonitoringPipelineMetadata
Returns a new instance of GoogleCloudAiplatformV1ModelDeploymentMonitoringJobLatestMonitoringPipelineMetadata.
23959 23960 23961 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23959 def initialize(**args) update!(**args) end |
Instance Attribute Details
#run_time ⇒ String
The time that most recent monitoring pipelines that is related to this run.
Corresponds to the JSON property runTime
23947 23948 23949 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23947 def run_time @run_time end |
#status ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property status
23957 23958 23959 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23957 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23964 23965 23966 23967 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23964 def update!(**args) @run_time = args[:run_time] if args.key?(:run_time) @status = args[:status] if args.key?(:status) end |