Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelDeploymentMonitoringJobLatestMonitoringPipelineMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

All metadata of most recent monitoring pipelines.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelDeploymentMonitoringJobLatestMonitoringPipelineMetadata

Returns a new instance of GoogleCloudAiplatformV1ModelDeploymentMonitoringJobLatestMonitoringPipelineMetadata.



13434
13435
13436
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13434

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#run_timeString

The time that most recent monitoring pipelines that is related to this run. Corresponds to the JSON property runTime

Returns:

  • (String)


13422
13423
13424
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13422

def run_time
  @run_time
end

#statusGoogle::Apis::AiplatformV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property status



13432
13433
13434
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13432

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13439
13440
13441
13442
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13439

def update!(**args)
  @run_time = args[:run_time] if args.key?(:run_time)
  @status = args[:status] if args.key?(:status)
end