Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelDeploymentMonitoringScheduleConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The config for scheduling monitoring job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelDeploymentMonitoringScheduleConfig

Returns a new instance of GoogleCloudAiplatformV1ModelDeploymentMonitoringScheduleConfig.



24131
24132
24133
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24131

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#monitor_intervalString

Required. The model monitoring job scheduling interval. It will be rounded up to next full hour. This defines how often the monitoring jobs are triggered. Corresponds to the JSON property monitorInterval

Returns:

  • (String)


24118
24119
24120
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24118

def monitor_interval
  @monitor_interval
end

#monitor_windowString

The time window of the prediction data being included in each prediction dataset. This window specifies how long the data should be collected from historical model results for each run. If not set, ModelDeploymentMonitoringScheduleConfig.monitor_interval will be used. e.g. If currently the cutoff time is 2022-01-08 14:30:00 and the monitor_window is set to be 3600, then data from 2022-01-08 13:30:00 to 2022-01-08 14:30:00 will be retrieved and aggregated to calculate the monitoring statistics. Corresponds to the JSON property monitorWindow

Returns:

  • (String)


24129
24130
24131
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24129

def monitor_window
  @monitor_window
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24136
24137
24138
24139
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24136

def update!(**args)
  @monitor_interval = args[:monitor_interval] if args.key?(:monitor_interval)
  @monitor_window = args[:monitor_window] if args.key?(:monitor_window)
end