Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelEvaluation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A collection of metrics calculated by comparing Model's predictions on all of the test data against annotations from the test data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelEvaluation

Returns a new instance of GoogleCloudAiplatformV1ModelEvaluation.



24110
24111
24112
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24110

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotation_schema_uriString

Points to a YAML file stored on Google Cloud Storage describing EvaluatedDataItemView.predictions, EvaluatedDataItemView.ground_truths, EvaluatedAnnotation.predictions, and EvaluatedAnnotation.ground_truths. The schema is defined as an OpenAPI 3.0.2 Schema Object. This field is not populated if there are neither EvaluatedDataItemViews nor EvaluatedAnnotations under this ModelEvaluation. Corresponds to the JSON property annotationSchemaUri

Returns:

  • (String)


24043
24044
24045
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24043

def annotation_schema_uri
  @annotation_schema_uri
end

#create_timeString

Output only. Timestamp when this ModelEvaluation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


24048
24049
24050
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24048

def create_time
  @create_time
end

#data_item_schema_uriString

Points to a YAML file stored on Google Cloud Storage describing EvaluatedDataItemView.data_item_payload and EvaluatedAnnotation. data_item_payload. The schema is defined as an OpenAPI 3.0.2 Schema Object. This field is not populated if there are neither EvaluatedDataItemViews nor EvaluatedAnnotations under this ModelEvaluation. Corresponds to the JSON property dataItemSchemaUri

Returns:

  • (String)


24058
24059
24060
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24058

def data_item_schema_uri
  @data_item_schema_uri
end

#display_nameString

The display name of the ModelEvaluation. Corresponds to the JSON property displayName

Returns:

  • (String)


24063
24064
24065
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24063

def display_name
  @display_name
end

#explanation_specsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelEvaluationModelEvaluationExplanationSpec>

Describes the values of ExplanationSpec that are used for explaining the predicted values on the evaluated data. Corresponds to the JSON property explanationSpecs



24069
24070
24071
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24069

def explanation_specs
  @explanation_specs
end

#metadataObject

The metadata of the ModelEvaluation. For the ModelEvaluation uploaded from Managed Pipeline, metadata contains a structured value with keys of " pipeline_job_id", "evaluation_dataset_type", "evaluation_dataset_path", " row_based_metrics_path". Corresponds to the JSON property metadata

Returns:

  • (Object)


24077
24078
24079
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24077

def 
  @metadata
end

#metricsObject

Evaluation metrics of the Model. The schema of the metrics is stored in metrics_schema_uri Corresponds to the JSON property metrics

Returns:

  • (Object)


24083
24084
24085
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24083

def metrics
  @metrics
end

#metrics_schema_uriString

Points to a YAML file stored on Google Cloud Storage describing the metrics of this ModelEvaluation. The schema is defined as an OpenAPI 3.0.2 Schema Object. Corresponds to the JSON property metricsSchemaUri

Returns:

  • (String)


24091
24092
24093
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24091

def metrics_schema_uri
  @metrics_schema_uri
end

#model_explanationGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelExplanation

Aggregated explanation metrics for a Model over a set of instances. Corresponds to the JSON property modelExplanation



24096
24097
24098
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24096

def model_explanation
  @model_explanation
end

#nameString

Output only. The resource name of the ModelEvaluation. Corresponds to the JSON property name

Returns:

  • (String)


24101
24102
24103
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24101

def name
  @name
end

#slice_dimensionsArray<String>

All possible dimensions of ModelEvaluationSlices. The dimensions can be used as the filter of the ModelService.ListModelEvaluationSlices request, in the form of slice.dimension =. Corresponds to the JSON property sliceDimensions

Returns:

  • (Array<String>)


24108
24109
24110
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24108

def slice_dimensions
  @slice_dimensions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24115
24116
24117
24118
24119
24120
24121
24122
24123
24124
24125
24126
24127
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24115

def update!(**args)
  @annotation_schema_uri = args[:annotation_schema_uri] if args.key?(:annotation_schema_uri)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_item_schema_uri = args[:data_item_schema_uri] if args.key?(:data_item_schema_uri)
  @display_name = args[:display_name] if args.key?(:display_name)
  @explanation_specs = args[:explanation_specs] if args.key?(:explanation_specs)
  @metadata = args[:metadata] if args.key?(:metadata)
  @metrics = args[:metrics] if args.key?(:metrics)
  @metrics_schema_uri = args[:metrics_schema_uri] if args.key?(:metrics_schema_uri)
  @model_explanation = args[:model_explanation] if args.key?(:model_explanation)
  @name = args[:name] if args.key?(:name)
  @slice_dimensions = args[:slice_dimensions] if args.key?(:slice_dimensions)
end