Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelEvaluation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A collection of metrics calculated by comparing Model's predictions on all of the test data against annotations from the test data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelEvaluation

Returns a new instance of GoogleCloudAiplatformV1ModelEvaluation.



18734
18735
18736
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18734

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotation_schema_uriString

Points to a YAML file stored on Google Cloud Storage describing EvaluatedDataItemView.predictions, EvaluatedDataItemView.ground_truths, EvaluatedAnnotation.predictions, and EvaluatedAnnotation.ground_truths. The schema is defined as an OpenAPI 3.0.2 Schema Object. This field is not populated if there are neither EvaluatedDataItemViews nor EvaluatedAnnotations under this ModelEvaluation. Corresponds to the JSON property annotationSchemaUri

Returns:

  • (String)


18667
18668
18669
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18667

def annotation_schema_uri
  @annotation_schema_uri
end

#create_timeString

Output only. Timestamp when this ModelEvaluation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


18672
18673
18674
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18672

def create_time
  @create_time
end

#data_item_schema_uriString

Points to a YAML file stored on Google Cloud Storage describing EvaluatedDataItemView.data_item_payload and EvaluatedAnnotation. data_item_payload. The schema is defined as an OpenAPI 3.0.2 Schema Object. This field is not populated if there are neither EvaluatedDataItemViews nor EvaluatedAnnotations under this ModelEvaluation. Corresponds to the JSON property dataItemSchemaUri

Returns:

  • (String)


18682
18683
18684
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18682

def data_item_schema_uri
  @data_item_schema_uri
end

#display_nameString

The display name of the ModelEvaluation. Corresponds to the JSON property displayName

Returns:

  • (String)


18687
18688
18689
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18687

def display_name
  @display_name
end

#explanation_specsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelEvaluationModelEvaluationExplanationSpec>

Describes the values of ExplanationSpec that are used for explaining the predicted values on the evaluated data. Corresponds to the JSON property explanationSpecs



18693
18694
18695
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18693

def explanation_specs
  @explanation_specs
end

#metadataObject

The metadata of the ModelEvaluation. For the ModelEvaluation uploaded from Managed Pipeline, metadata contains a structured value with keys of " pipeline_job_id", "evaluation_dataset_type", "evaluation_dataset_path", " row_based_metrics_path". Corresponds to the JSON property metadata

Returns:

  • (Object)


18701
18702
18703
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18701

def 
  @metadata
end

#metricsObject

Evaluation metrics of the Model. The schema of the metrics is stored in metrics_schema_uri Corresponds to the JSON property metrics

Returns:

  • (Object)


18707
18708
18709
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18707

def metrics
  @metrics
end

#metrics_schema_uriString

Points to a YAML file stored on Google Cloud Storage describing the metrics of this ModelEvaluation. The schema is defined as an OpenAPI 3.0.2 Schema Object. Corresponds to the JSON property metricsSchemaUri

Returns:

  • (String)


18715
18716
18717
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18715

def metrics_schema_uri
  @metrics_schema_uri
end

#model_explanationGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelExplanation

Aggregated explanation metrics for a Model over a set of instances. Corresponds to the JSON property modelExplanation



18720
18721
18722
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18720

def model_explanation
  @model_explanation
end

#nameString

Output only. The resource name of the ModelEvaluation. Corresponds to the JSON property name

Returns:

  • (String)


18725
18726
18727
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18725

def name
  @name
end

#slice_dimensionsArray<String>

All possible dimensions of ModelEvaluationSlices. The dimensions can be used as the filter of the ModelService.ListModelEvaluationSlices request, in the form of slice.dimension =. Corresponds to the JSON property sliceDimensions

Returns:

  • (Array<String>)


18732
18733
18734
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18732

def slice_dimensions
  @slice_dimensions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18739
18740
18741
18742
18743
18744
18745
18746
18747
18748
18749
18750
18751
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18739

def update!(**args)
  @annotation_schema_uri = args[:annotation_schema_uri] if args.key?(:annotation_schema_uri)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_item_schema_uri = args[:data_item_schema_uri] if args.key?(:data_item_schema_uri)
  @display_name = args[:display_name] if args.key?(:display_name)
  @explanation_specs = args[:explanation_specs] if args.key?(:explanation_specs)
  @metadata = args[:metadata] if args.key?(:metadata)
  @metrics = args[:metrics] if args.key?(:metrics)
  @metrics_schema_uri = args[:metrics_schema_uri] if args.key?(:metrics_schema_uri)
  @model_explanation = args[:model_explanation] if args.key?(:model_explanation)
  @name = args[:name] if args.key?(:name)
  @slice_dimensions = args[:slice_dimensions] if args.key?(:slice_dimensions)
end