Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelEvaluation
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelEvaluation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A collection of metrics calculated by comparing Model's predictions on all of the test data against annotations from the test data.
Instance Attribute Summary collapse
-
#annotation_schema_uri ⇒ String
Points to a YAML file stored on Google Cloud Storage describing EvaluatedDataItemView.predictions, EvaluatedDataItemView.ground_truths, EvaluatedAnnotation.predictions, and EvaluatedAnnotation.ground_truths.
-
#create_time ⇒ String
Output only.
-
#data_item_schema_uri ⇒ String
Points to a YAML file stored on Google Cloud Storage describing EvaluatedDataItemView.data_item_payload and EvaluatedAnnotation.
-
#display_name ⇒ String
The display name of the ModelEvaluation.
-
#explanation_specs ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelEvaluationModelEvaluationExplanationSpec>
Describes the values of ExplanationSpec that are used for explaining the predicted values on the evaluated data.
-
#metadata ⇒ Object
The metadata of the ModelEvaluation.
-
#metrics ⇒ Object
Evaluation metrics of the Model.
-
#metrics_schema_uri ⇒ String
Points to a YAML file stored on Google Cloud Storage describing the metrics of this ModelEvaluation.
-
#model_explanation ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelExplanation
Aggregated explanation metrics for a Model over a set of instances.
-
#name ⇒ String
Output only.
-
#slice_dimensions ⇒ Array<String>
All possible dimensions of ModelEvaluationSlices.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelEvaluation
constructor
A new instance of GoogleCloudAiplatformV1ModelEvaluation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelEvaluation
Returns a new instance of GoogleCloudAiplatformV1ModelEvaluation.
14342 14343 14344 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14342 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotation_schema_uri ⇒ String
Points to a YAML file stored on Google Cloud Storage describing
EvaluatedDataItemView.predictions, EvaluatedDataItemView.ground_truths,
EvaluatedAnnotation.predictions, and EvaluatedAnnotation.ground_truths. The
schema is defined as an OpenAPI 3.0.2 Schema Object. This field is
not populated if there are neither EvaluatedDataItemViews nor
EvaluatedAnnotations under this ModelEvaluation.
Corresponds to the JSON property annotationSchemaUri
14275 14276 14277 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14275 def annotation_schema_uri @annotation_schema_uri end |
#create_time ⇒ String
Output only. Timestamp when this ModelEvaluation was created.
Corresponds to the JSON property createTime
14280 14281 14282 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14280 def create_time @create_time end |
#data_item_schema_uri ⇒ String
Points to a YAML file stored on Google Cloud Storage describing
EvaluatedDataItemView.data_item_payload and EvaluatedAnnotation.
data_item_payload. The schema is defined as an OpenAPI 3.0.2 Schema Object. This field is not populated if there are neither
EvaluatedDataItemViews nor EvaluatedAnnotations under this ModelEvaluation.
Corresponds to the JSON property dataItemSchemaUri
14290 14291 14292 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14290 def data_item_schema_uri @data_item_schema_uri end |
#display_name ⇒ String
The display name of the ModelEvaluation.
Corresponds to the JSON property displayName
14295 14296 14297 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14295 def display_name @display_name end |
#explanation_specs ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelEvaluationModelEvaluationExplanationSpec>
Describes the values of ExplanationSpec that are used for explaining the
predicted values on the evaluated data.
Corresponds to the JSON property explanationSpecs
14301 14302 14303 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14301 def explanation_specs @explanation_specs end |
#metadata ⇒ Object
The metadata of the ModelEvaluation. For the ModelEvaluation uploaded from
Managed Pipeline, metadata contains a structured value with keys of "
pipeline_job_id", "evaluation_dataset_type", "evaluation_dataset_path", "
row_based_metrics_path".
Corresponds to the JSON property metadata
14309 14310 14311 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14309 def @metadata end |
#metrics ⇒ Object
Evaluation metrics of the Model. The schema of the metrics is stored in
metrics_schema_uri
Corresponds to the JSON property metrics
14315 14316 14317 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14315 def metrics @metrics end |
#metrics_schema_uri ⇒ String
Points to a YAML file stored on Google Cloud Storage describing the metrics of
this ModelEvaluation. The schema is defined as an OpenAPI 3.0.2 Schema Object.
Corresponds to the JSON property metricsSchemaUri
14323 14324 14325 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14323 def metrics_schema_uri @metrics_schema_uri end |
#model_explanation ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelExplanation
Aggregated explanation metrics for a Model over a set of instances.
Corresponds to the JSON property modelExplanation
14328 14329 14330 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14328 def model_explanation @model_explanation end |
#name ⇒ String
Output only. The resource name of the ModelEvaluation.
Corresponds to the JSON property name
14333 14334 14335 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14333 def name @name end |
#slice_dimensions ⇒ Array<String>
All possible dimensions of ModelEvaluationSlices. The dimensions can be used
as the filter of the ModelService.ListModelEvaluationSlices request, in the
form of slice.dimension =.
Corresponds to the JSON property sliceDimensions
14340 14341 14342 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14340 def slice_dimensions @slice_dimensions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14347 14348 14349 14350 14351 14352 14353 14354 14355 14356 14357 14358 14359 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14347 def update!(**args) @annotation_schema_uri = args[:annotation_schema_uri] if args.key?(:annotation_schema_uri) @create_time = args[:create_time] if args.key?(:create_time) @data_item_schema_uri = args[:data_item_schema_uri] if args.key?(:data_item_schema_uri) @display_name = args[:display_name] if args.key?(:display_name) @explanation_specs = args[:explanation_specs] if args.key?(:explanation_specs) @metadata = args[:metadata] if args.key?(:metadata) @metrics = args[:metrics] if args.key?(:metrics) @metrics_schema_uri = args[:metrics_schema_uri] if args.key?(:metrics_schema_uri) @model_explanation = args[:model_explanation] if args.key?(:model_explanation) @name = args[:name] if args.key?(:name) @slice_dimensions = args[:slice_dimensions] if args.key?(:slice_dimensions) end |