Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelEvaluation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A collection of metrics calculated by comparing Model's predictions on all of the test data against annotations from the test data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelEvaluation

Returns a new instance of GoogleCloudAiplatformV1ModelEvaluation.



13585
13586
13587
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13585

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotation_schema_uriString

Points to a YAML file stored on Google Cloud Storage describing EvaluatedDataItemView.predictions, EvaluatedDataItemView.ground_truths, EvaluatedAnnotation.predictions, and EvaluatedAnnotation.ground_truths. The schema is defined as an OpenAPI 3.0.2 Schema Object. This field is not populated if there are neither EvaluatedDataItemViews nor EvaluatedAnnotations under this ModelEvaluation. Corresponds to the JSON property annotationSchemaUri

Returns:

  • (String)


13518
13519
13520
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13518

def annotation_schema_uri
  @annotation_schema_uri
end

#create_timeString

Output only. Timestamp when this ModelEvaluation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


13523
13524
13525
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13523

def create_time
  @create_time
end

#data_item_schema_uriString

Points to a YAML file stored on Google Cloud Storage describing EvaluatedDataItemView.data_item_payload and EvaluatedAnnotation. data_item_payload. The schema is defined as an OpenAPI 3.0.2 Schema Object. This field is not populated if there are neither EvaluatedDataItemViews nor EvaluatedAnnotations under this ModelEvaluation. Corresponds to the JSON property dataItemSchemaUri

Returns:

  • (String)


13533
13534
13535
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13533

def data_item_schema_uri
  @data_item_schema_uri
end

#display_nameString

The display name of the ModelEvaluation. Corresponds to the JSON property displayName

Returns:

  • (String)


13538
13539
13540
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13538

def display_name
  @display_name
end

#explanation_specsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelEvaluationModelEvaluationExplanationSpec>

Describes the values of ExplanationSpec that are used for explaining the predicted values on the evaluated data. Corresponds to the JSON property explanationSpecs



13544
13545
13546
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13544

def explanation_specs
  @explanation_specs
end

#metadataObject

The metadata of the ModelEvaluation. For the ModelEvaluation uploaded from Managed Pipeline, metadata contains a structured value with keys of " pipeline_job_id", "evaluation_dataset_type", "evaluation_dataset_path", " row_based_metrics_path". Corresponds to the JSON property metadata

Returns:

  • (Object)


13552
13553
13554
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13552

def 
  @metadata
end

#metricsObject

Evaluation metrics of the Model. The schema of the metrics is stored in metrics_schema_uri Corresponds to the JSON property metrics

Returns:

  • (Object)


13558
13559
13560
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13558

def metrics
  @metrics
end

#metrics_schema_uriString

Points to a YAML file stored on Google Cloud Storage describing the metrics of this ModelEvaluation. The schema is defined as an OpenAPI 3.0.2 Schema Object. Corresponds to the JSON property metricsSchemaUri

Returns:

  • (String)


13566
13567
13568
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13566

def metrics_schema_uri
  @metrics_schema_uri
end

#model_explanationGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelExplanation

Aggregated explanation metrics for a Model over a set of instances. Corresponds to the JSON property modelExplanation



13571
13572
13573
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13571

def model_explanation
  @model_explanation
end

#nameString

Output only. The resource name of the ModelEvaluation. Corresponds to the JSON property name

Returns:

  • (String)


13576
13577
13578
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13576

def name
  @name
end

#slice_dimensionsArray<String>

All possible dimensions of ModelEvaluationSlices. The dimensions can be used as the filter of the ModelService.ListModelEvaluationSlices request, in the form of slice.dimension =. Corresponds to the JSON property sliceDimensions

Returns:

  • (Array<String>)


13583
13584
13585
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13583

def slice_dimensions
  @slice_dimensions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13590
13591
13592
13593
13594
13595
13596
13597
13598
13599
13600
13601
13602
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 13590

def update!(**args)
  @annotation_schema_uri = args[:annotation_schema_uri] if args.key?(:annotation_schema_uri)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_item_schema_uri = args[:data_item_schema_uri] if args.key?(:data_item_schema_uri)
  @display_name = args[:display_name] if args.key?(:display_name)
  @explanation_specs = args[:explanation_specs] if args.key?(:explanation_specs)
  @metadata = args[:metadata] if args.key?(:metadata)
  @metrics = args[:metrics] if args.key?(:metrics)
  @metrics_schema_uri = args[:metrics_schema_uri] if args.key?(:metrics_schema_uri)
  @model_explanation = args[:model_explanation] if args.key?(:model_explanation)
  @name = args[:name] if args.key?(:name)
  @slice_dimensions = args[:slice_dimensions] if args.key?(:slice_dimensions)
end