Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelEvaluationSlice

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A collection of metrics calculated by comparing Model's predictions on a slice of the test data against ground truth annotations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelEvaluationSlice

Returns a new instance of GoogleCloudAiplatformV1ModelEvaluationSlice.



24138
24139
24140
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24138

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this ModelEvaluationSlice was created. Corresponds to the JSON property createTime

Returns:

  • (String)


24107
24108
24109
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24107

def create_time
  @create_time
end

#metricsObject

Output only. Sliced evaluation metrics of the Model. The schema of the metrics is stored in metrics_schema_uri Corresponds to the JSON property metrics

Returns:

  • (Object)


24113
24114
24115
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24113

def metrics
  @metrics
end

#metrics_schema_uriString

Output only. Points to a YAML file stored on Google Cloud Storage describing the metrics of this ModelEvaluationSlice. The schema is defined as an OpenAPI 3.0.2 Schema Object. Corresponds to the JSON property metricsSchemaUri

Returns:

  • (String)


24121
24122
24123
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24121

def metrics_schema_uri
  @metrics_schema_uri
end

#model_explanationGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelExplanation

Aggregated explanation metrics for a Model over a set of instances. Corresponds to the JSON property modelExplanation



24126
24127
24128
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24126

def model_explanation
  @model_explanation
end

#nameString

Output only. The resource name of the ModelEvaluationSlice. Corresponds to the JSON property name

Returns:

  • (String)


24131
24132
24133
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24131

def name
  @name
end

#sliceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelEvaluationSliceSlice

Definition of a slice. Corresponds to the JSON property slice



24136
24137
24138
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24136

def slice
  @slice
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24143
24144
24145
24146
24147
24148
24149
24150
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24143

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @metrics = args[:metrics] if args.key?(:metrics)
  @metrics_schema_uri = args[:metrics_schema_uri] if args.key?(:metrics_schema_uri)
  @model_explanation = args[:model_explanation] if args.key?(:model_explanation)
  @name = args[:name] if args.key?(:name)
  @slice = args[:slice] if args.key?(:slice)
end