Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelEvaluationSlice

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A collection of metrics calculated by comparing Model's predictions on a slice of the test data against ground truth annotations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelEvaluationSlice

Returns a new instance of GoogleCloudAiplatformV1ModelEvaluationSlice.



18073
18074
18075
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18073

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this ModelEvaluationSlice was created. Corresponds to the JSON property createTime

Returns:

  • (String)


18042
18043
18044
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18042

def create_time
  @create_time
end

#metricsObject

Output only. Sliced evaluation metrics of the Model. The schema of the metrics is stored in metrics_schema_uri Corresponds to the JSON property metrics

Returns:

  • (Object)


18048
18049
18050
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18048

def metrics
  @metrics
end

#metrics_schema_uriString

Output only. Points to a YAML file stored on Google Cloud Storage describing the metrics of this ModelEvaluationSlice. The schema is defined as an OpenAPI 3.0.2 Schema Object. Corresponds to the JSON property metricsSchemaUri

Returns:

  • (String)


18056
18057
18058
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18056

def metrics_schema_uri
  @metrics_schema_uri
end

#model_explanationGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelExplanation

Aggregated explanation metrics for a Model over a set of instances. Corresponds to the JSON property modelExplanation



18061
18062
18063
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18061

def model_explanation
  @model_explanation
end

#nameString

Output only. The resource name of the ModelEvaluationSlice. Corresponds to the JSON property name

Returns:

  • (String)


18066
18067
18068
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18066

def name
  @name
end

#sliceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelEvaluationSliceSlice

Definition of a slice. Corresponds to the JSON property slice



18071
18072
18073
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18071

def slice
  @slice
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18078
18079
18080
18081
18082
18083
18084
18085
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18078

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @metrics = args[:metrics] if args.key?(:metrics)
  @metrics_schema_uri = args[:metrics_schema_uri] if args.key?(:metrics_schema_uri)
  @model_explanation = args[:model_explanation] if args.key?(:model_explanation)
  @name = args[:name] if args.key?(:name)
  @slice = args[:slice] if args.key?(:slice)
end