Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelEvaluationSlice
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelEvaluationSlice
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A collection of metrics calculated by comparing Model's predictions on a slice of the test data against ground truth annotations.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#metrics ⇒ Object
Output only.
-
#metrics_schema_uri ⇒ String
Output only.
-
#model_explanation ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelExplanation
Aggregated explanation metrics for a Model over a set of instances.
-
#name ⇒ String
Output only.
-
#slice ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelEvaluationSliceSlice
Definition of a slice.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelEvaluationSlice
constructor
A new instance of GoogleCloudAiplatformV1ModelEvaluationSlice.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelEvaluationSlice
Returns a new instance of GoogleCloudAiplatformV1ModelEvaluationSlice.
17510 17511 17512 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17510 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this ModelEvaluationSlice was created.
Corresponds to the JSON property createTime
17479 17480 17481 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17479 def create_time @create_time end |
#metrics ⇒ Object
Output only. Sliced evaluation metrics of the Model. The schema of the metrics
is stored in metrics_schema_uri
Corresponds to the JSON property metrics
17485 17486 17487 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17485 def metrics @metrics end |
#metrics_schema_uri ⇒ String
Output only. Points to a YAML file stored on Google Cloud Storage describing
the metrics of this ModelEvaluationSlice. The schema is defined as an OpenAPI
3.0.2 Schema Object.
Corresponds to the JSON property metricsSchemaUri
17493 17494 17495 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17493 def metrics_schema_uri @metrics_schema_uri end |
#model_explanation ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelExplanation
Aggregated explanation metrics for a Model over a set of instances.
Corresponds to the JSON property modelExplanation
17498 17499 17500 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17498 def model_explanation @model_explanation end |
#name ⇒ String
Output only. The resource name of the ModelEvaluationSlice.
Corresponds to the JSON property name
17503 17504 17505 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17503 def name @name end |
#slice ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelEvaluationSliceSlice
Definition of a slice.
Corresponds to the JSON property slice
17508 17509 17510 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17508 def slice @slice end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17515 17516 17517 17518 17519 17520 17521 17522 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17515 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @metrics = args[:metrics] if args.key?(:metrics) @metrics_schema_uri = args[:metrics_schema_uri] if args.key?(:metrics_schema_uri) @model_explanation = args[:model_explanation] if args.key?(:model_explanation) @name = args[:name] if args.key?(:name) @slice = args[:slice] if args.key?(:slice) end |