Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelEvaluationSlice

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A collection of metrics calculated by comparing Model's predictions on a slice of the test data against ground truth annotations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelEvaluationSlice

Returns a new instance of GoogleCloudAiplatformV1ModelEvaluationSlice.



15570
15571
15572
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15570

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this ModelEvaluationSlice was created. Corresponds to the JSON property createTime

Returns:

  • (String)


15539
15540
15541
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15539

def create_time
  @create_time
end

#metricsObject

Output only. Sliced evaluation metrics of the Model. The schema of the metrics is stored in metrics_schema_uri Corresponds to the JSON property metrics

Returns:

  • (Object)


15545
15546
15547
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15545

def metrics
  @metrics
end

#metrics_schema_uriString

Output only. Points to a YAML file stored on Google Cloud Storage describing the metrics of this ModelEvaluationSlice. The schema is defined as an OpenAPI 3.0.2 Schema Object. Corresponds to the JSON property metricsSchemaUri

Returns:

  • (String)


15553
15554
15555
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15553

def metrics_schema_uri
  @metrics_schema_uri
end

#model_explanationGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelExplanation

Aggregated explanation metrics for a Model over a set of instances. Corresponds to the JSON property modelExplanation



15558
15559
15560
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15558

def model_explanation
  @model_explanation
end

#nameString

Output only. The resource name of the ModelEvaluationSlice. Corresponds to the JSON property name

Returns:

  • (String)


15563
15564
15565
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15563

def name
  @name
end

#sliceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelEvaluationSliceSlice

Definition of a slice. Corresponds to the JSON property slice



15568
15569
15570
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15568

def slice
  @slice
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15575
15576
15577
15578
15579
15580
15581
15582
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15575

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @metrics = args[:metrics] if args.key?(:metrics)
  @metrics_schema_uri = args[:metrics_schema_uri] if args.key?(:metrics_schema_uri)
  @model_explanation = args[:model_explanation] if args.key?(:model_explanation)
  @name = args[:name] if args.key?(:name)
  @slice = args[:slice] if args.key?(:slice)
end