Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelEvaluationSliceSlice
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelEvaluationSliceSlice
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Definition of a slice.
Instance Attribute Summary collapse
-
#dimension ⇒ String
Output only.
-
#slice_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelEvaluationSliceSliceSliceSpec
Specification for how the data should be sliced.
-
#value ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelEvaluationSliceSlice
constructor
A new instance of GoogleCloudAiplatformV1ModelEvaluationSliceSlice.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelEvaluationSliceSlice
Returns a new instance of GoogleCloudAiplatformV1ModelEvaluationSliceSlice.
17523 17524 17525 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17523 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dimension ⇒ String
Output only. The dimension of the slice. Well-known dimensions are: *
annotationSpec: This slice is on the test data that has either ground truth
or prediction with AnnotationSpec.display_name equals to value. * slice:
This slice is a user customized slice defined by its SliceSpec.
Corresponds to the JSON property dimension
17511 17512 17513 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17511 def dimension @dimension end |
#slice_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelEvaluationSliceSliceSliceSpec
Specification for how the data should be sliced.
Corresponds to the JSON property sliceSpec
17516 17517 17518 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17516 def slice_spec @slice_spec end |
#value ⇒ String
Output only. The value of the dimension in this slice.
Corresponds to the JSON property value
17521 17522 17523 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17521 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17528 17529 17530 17531 17532 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17528 def update!(**args) @dimension = args[:dimension] if args.key?(:dimension) @slice_spec = args[:slice_spec] if args.key?(:slice_spec) @value = args[:value] if args.key?(:value) end |