Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelEvaluationSliceSlice

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Definition of a slice.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelEvaluationSliceSlice

Returns a new instance of GoogleCloudAiplatformV1ModelEvaluationSliceSlice.



14464
14465
14466
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14464

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dimensionString

Output only. The dimension of the slice. Well-known dimensions are: * annotationSpec: This slice is on the test data that has either ground truth or prediction with AnnotationSpec.display_name equals to value. * slice: This slice is a user customized slice defined by its SliceSpec. Corresponds to the JSON property dimension

Returns:

  • (String)


14452
14453
14454
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14452

def dimension
  @dimension
end

#slice_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelEvaluationSliceSliceSliceSpec

Specification for how the data should be sliced. Corresponds to the JSON property sliceSpec



14457
14458
14459
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14457

def slice_spec
  @slice_spec
end

#valueString

Output only. The value of the dimension in this slice. Corresponds to the JSON property value

Returns:

  • (String)


14462
14463
14464
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14462

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14469
14470
14471
14472
14473
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14469

def update!(**args)
  @dimension = args[:dimension] if args.key?(:dimension)
  @slice_spec = args[:slice_spec] if args.key?(:slice_spec)
  @value = args[:value] if args.key?(:value)
end