Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelGardenSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Contains information about the source of the models generated from Model Garden.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelGardenSource

Returns a new instance of GoogleCloudAiplatformV1ModelGardenSource.



19076
19077
19078
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19076

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#public_model_nameString

Required. The model garden source model resource name. Corresponds to the JSON property publicModelName

Returns:

  • (String)


19063
19064
19065
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19063

def public_model_name
  @public_model_name
end

#skip_hf_model_cacheBoolean Also known as: skip_hf_model_cache?

Optional. Whether to avoid pulling the model from the HF cache. Corresponds to the JSON property skipHfModelCache

Returns:

  • (Boolean)


19068
19069
19070
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19068

def skip_hf_model_cache
  @skip_hf_model_cache
end

#version_idString

Optional. The model garden source model version ID. Corresponds to the JSON property versionId

Returns:

  • (String)


19074
19075
19076
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19074

def version_id
  @version_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19081
19082
19083
19084
19085
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19081

def update!(**args)
  @public_model_name = args[:public_model_name] if args.key?(:public_model_name)
  @skip_hf_model_cache = args[:skip_hf_model_cache] if args.key?(:skip_hf_model_cache)
  @version_id = args[:version_id] if args.key?(:version_id)
end