Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelGardenSource
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelGardenSource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Contains information about the source of the models generated from Model Garden.
Instance Attribute Summary collapse
-
#public_model_name ⇒ String
Required.
-
#skip_hf_model_cache ⇒ Boolean
(also: #skip_hf_model_cache?)
Optional.
-
#version_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelGardenSource
constructor
A new instance of GoogleCloudAiplatformV1ModelGardenSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelGardenSource
Returns a new instance of GoogleCloudAiplatformV1ModelGardenSource.
18373 18374 18375 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18373 def initialize(**args) update!(**args) end |
Instance Attribute Details
#public_model_name ⇒ String
Required. The model garden source model resource name.
Corresponds to the JSON property publicModelName
18360 18361 18362 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18360 def public_model_name @public_model_name end |
#skip_hf_model_cache ⇒ Boolean Also known as: skip_hf_model_cache?
Optional. Whether to avoid pulling the model from the HF cache.
Corresponds to the JSON property skipHfModelCache
18365 18366 18367 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18365 def skip_hf_model_cache @skip_hf_model_cache end |
#version_id ⇒ String
Optional. The model garden source model version ID.
Corresponds to the JSON property versionId
18371 18372 18373 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18371 def version_id @version_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18378 18379 18380 18381 18382 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18378 def update!(**args) @public_model_name = args[:public_model_name] if args.key?(:public_model_name) @skip_hf_model_cache = args[:skip_hf_model_cache] if args.key?(:skip_hf_model_cache) @version_id = args[:version_id] if args.key?(:version_id) end |