Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelGardenSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Contains information about the source of the models generated from Model Garden.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelGardenSource

Returns a new instance of GoogleCloudAiplatformV1ModelGardenSource.



18292
18293
18294
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18292

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#public_model_nameString

Required. The model garden source model resource name. Corresponds to the JSON property publicModelName

Returns:

  • (String)


18279
18280
18281
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18279

def public_model_name
  @public_model_name
end

#skip_hf_model_cacheBoolean Also known as: skip_hf_model_cache?

Optional. Whether to avoid pulling the model from the HF cache. Corresponds to the JSON property skipHfModelCache

Returns:

  • (Boolean)


18284
18285
18286
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18284

def skip_hf_model_cache
  @skip_hf_model_cache
end

#version_idString

Optional. The model garden source model version ID. Corresponds to the JSON property versionId

Returns:

  • (String)


18290
18291
18292
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18290

def version_id
  @version_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18297
18298
18299
18300
18301
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18297

def update!(**args)
  @public_model_name = args[:public_model_name] if args.key?(:public_model_name)
  @skip_hf_model_cache = args[:skip_hf_model_cache] if args.key?(:skip_hf_model_cache)
  @version_id = args[:version_id] if args.key?(:version_id)
end