Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelGardenSource
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelGardenSource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Contains information about the source of the models generated from Model Garden.
Instance Attribute Summary collapse
-
#public_model_name ⇒ String
Required.
-
#skip_hf_model_cache ⇒ Boolean
(also: #skip_hf_model_cache?)
Optional.
-
#version_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelGardenSource
constructor
A new instance of GoogleCloudAiplatformV1ModelGardenSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelGardenSource
Returns a new instance of GoogleCloudAiplatformV1ModelGardenSource.
17906 17907 17908 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17906 def initialize(**args) update!(**args) end |
Instance Attribute Details
#public_model_name ⇒ String
Required. The model garden source model resource name.
Corresponds to the JSON property publicModelName
17893 17894 17895 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17893 def public_model_name @public_model_name end |
#skip_hf_model_cache ⇒ Boolean Also known as: skip_hf_model_cache?
Optional. Whether to avoid pulling the model from the HF cache.
Corresponds to the JSON property skipHfModelCache
17898 17899 17900 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17898 def skip_hf_model_cache @skip_hf_model_cache end |
#version_id ⇒ String
Optional. The model garden source model version ID.
Corresponds to the JSON property versionId
17904 17905 17906 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17904 def version_id @version_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17911 17912 17913 17914 17915 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17911 def update!(**args) @public_model_name = args[:public_model_name] if args.key?(:public_model_name) @skip_hf_model_cache = args[:skip_hf_model_cache] if args.key?(:skip_hf_model_cache) @version_id = args[:version_id] if args.key?(:version_id) end |