Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelGardenSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Contains information about the source of the models generated from Model Garden.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelGardenSource

Returns a new instance of GoogleCloudAiplatformV1ModelGardenSource.



17586
17587
17588
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17586

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#public_model_nameString

Required. The model garden source model resource name. Corresponds to the JSON property publicModelName

Returns:

  • (String)


17573
17574
17575
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17573

def public_model_name
  @public_model_name
end

#skip_hf_model_cacheBoolean Also known as: skip_hf_model_cache?

Optional. Whether to avoid pulling the model from the HF cache. Corresponds to the JSON property skipHfModelCache

Returns:

  • (Boolean)


17578
17579
17580
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17578

def skip_hf_model_cache
  @skip_hf_model_cache
end

#version_idString

Optional. The model garden source model version ID. Corresponds to the JSON property versionId

Returns:

  • (String)


17584
17585
17586
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17584

def version_id
  @version_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17591
17592
17593
17594
17595
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17591

def update!(**args)
  @public_model_name = args[:public_model_name] if args.key?(:public_model_name)
  @skip_hf_model_cache = args[:skip_hf_model_cache] if args.key?(:skip_hf_model_cache)
  @version_id = args[:version_id] if args.key?(:version_id)
end