Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelMonitoringAlertConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The alert config for model monitoring.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelMonitoringAlertConfig

Returns a new instance of GoogleCloudAiplatformV1ModelMonitoringAlertConfig.



17900
17901
17902
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17900

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#email_alert_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelMonitoringAlertConfigEmailAlertConfig

The config for email alert. Corresponds to the JSON property emailAlertConfig



17884
17885
17886
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17884

def email_alert_config
  @email_alert_config
end

#enable_loggingBoolean Also known as: enable_logging?

Dump the anomalies to Cloud Logging. The anomalies will be put to json payload encoded from proto ModelMonitoringStatsAnomalies. This can be further synced to Pub/Sub or any other services supported by Cloud Logging. Corresponds to the JSON property enableLogging

Returns:

  • (Boolean)


17891
17892
17893
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17891

def enable_logging
  @enable_logging
end

#notification_channelsArray<String>

Resource names of the NotificationChannels to send alert. Must be of the format projects//notificationChannels/ Corresponds to the JSON property notificationChannels

Returns:

  • (Array<String>)


17898
17899
17900
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17898

def notification_channels
  @notification_channels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17905
17906
17907
17908
17909
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17905

def update!(**args)
  @email_alert_config = args[:email_alert_config] if args.key?(:email_alert_config)
  @enable_logging = args[:enable_logging] if args.key?(:enable_logging)
  @notification_channels = args[:notification_channels] if args.key?(:notification_channels)
end