Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelMonitoringAlertConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The alert config for model monitoring.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelMonitoringAlertConfig

Returns a new instance of GoogleCloudAiplatformV1ModelMonitoringAlertConfig.



14640
14641
14642
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14640

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#email_alert_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelMonitoringAlertConfigEmailAlertConfig

The config for email alert. Corresponds to the JSON property emailAlertConfig



14623
14624
14625
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14623

def email_alert_config
  @email_alert_config
end

#enable_loggingBoolean Also known as: enable_logging?

Dump the anomalies to Cloud Logging. The anomalies will be put to json payload encoded from proto google.cloud.aiplatform.logging. ModelMonitoringAnomaliesLogEntry. This can be further sinked to Pub/Sub or any other services supported by Cloud Logging. Corresponds to the JSON property enableLogging

Returns:

  • (Boolean)


14631
14632
14633
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14631

def enable_logging
  @enable_logging
end

#notification_channelsArray<String>

Resource names of the NotificationChannels to send alert. Must be of the format projects//notificationChannels/ Corresponds to the JSON property notificationChannels

Returns:

  • (Array<String>)


14638
14639
14640
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14638

def notification_channels
  @notification_channels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14645
14646
14647
14648
14649
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14645

def update!(**args)
  @email_alert_config = args[:email_alert_config] if args.key?(:email_alert_config)
  @enable_logging = args[:enable_logging] if args.key?(:enable_logging)
  @notification_channels = args[:notification_channels] if args.key?(:notification_channels)
end