Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigExplanationConfigExplanationBaseline
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigExplanationConfigExplanationBaseline
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Output from BatchPredictionJob for Model Monitoring baseline dataset, which can be used to generate baseline attribution scores.
Instance Attribute Summary collapse
-
#bigquery ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQueryDestination
The BigQuery location for the output content.
-
#gcs ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsDestination
The Google Cloud Storage location where the output is to be written to.
-
#prediction_format ⇒ String
The storage format of the predictions generated BatchPrediction job.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigExplanationConfigExplanationBaseline
constructor
A new instance of GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigExplanationConfigExplanationBaseline.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigExplanationConfigExplanationBaseline
Returns a new instance of GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigExplanationConfigExplanationBaseline.
24551 24552 24553 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24551 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bigquery ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQueryDestination
The BigQuery location for the output content.
Corresponds to the JSON property bigquery
24539 24540 24541 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24539 def bigquery @bigquery end |
#gcs ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsDestination
The Google Cloud Storage location where the output is to be written to.
Corresponds to the JSON property gcs
24544 24545 24546 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24544 def gcs @gcs end |
#prediction_format ⇒ String
The storage format of the predictions generated BatchPrediction job.
Corresponds to the JSON property predictionFormat
24549 24550 24551 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24549 def prediction_format @prediction_format end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24556 24557 24558 24559 24560 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24556 def update!(**args) @bigquery = args[:bigquery] if args.key?(:bigquery) @gcs = args[:gcs] if args.key?(:gcs) @prediction_format = args[:prediction_format] if args.key?(:prediction_format) end |