Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigExplanationConfigExplanationBaseline

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Output from BatchPredictionJob for Model Monitoring baseline dataset, which can be used to generate baseline attribution scores.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigExplanationConfigExplanationBaseline

Returns a new instance of GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigExplanationConfigExplanationBaseline.



23107
23108
23109
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23107

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bigqueryGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQueryDestination

The BigQuery location for the output content. Corresponds to the JSON property bigquery



23095
23096
23097
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23095

def bigquery
  @bigquery
end

#gcsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsDestination

The Google Cloud Storage location where the output is to be written to. Corresponds to the JSON property gcs



23100
23101
23102
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23100

def gcs
  @gcs
end

#prediction_formatString

The storage format of the predictions generated BatchPrediction job. Corresponds to the JSON property predictionFormat

Returns:

  • (String)


23105
23106
23107
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23105

def prediction_format
  @prediction_format
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23112
23113
23114
23115
23116
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23112

def update!(**args)
  @bigquery = args[:bigquery] if args.key?(:bigquery)
  @gcs = args[:gcs] if args.key?(:gcs)
  @prediction_format = args[:prediction_format] if args.key?(:prediction_format)
end