Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigExplanationConfigExplanationBaseline

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Output from BatchPredictionJob for Model Monitoring baseline dataset, which can be used to generate baseline attribution scores.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigExplanationConfigExplanationBaseline

Returns a new instance of GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigExplanationConfigExplanationBaseline.



17923
17924
17925
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17923

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bigqueryGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQueryDestination

The BigQuery location for the output content. Corresponds to the JSON property bigquery



17911
17912
17913
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17911

def bigquery
  @bigquery
end

#gcsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsDestination

The Google Cloud Storage location where the output is to be written to. Corresponds to the JSON property gcs



17916
17917
17918
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17916

def gcs
  @gcs
end

#prediction_formatString

The storage format of the predictions generated BatchPrediction job. Corresponds to the JSON property predictionFormat

Returns:

  • (String)


17921
17922
17923
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17921

def prediction_format
  @prediction_format
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17928
17929
17930
17931
17932
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17928

def update!(**args)
  @bigquery = args[:bigquery] if args.key?(:bigquery)
  @gcs = args[:gcs] if args.key?(:gcs)
  @prediction_format = args[:prediction_format] if args.key?(:prediction_format)
end