Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigExplanationConfigExplanationBaseline

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Output from BatchPredictionJob for Model Monitoring baseline dataset, which can be used to generate baseline attribution scores.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigExplanationConfigExplanationBaseline

Returns a new instance of GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigExplanationConfigExplanationBaseline.



17887
17888
17889
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17887

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bigqueryGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQueryDestination

The BigQuery location for the output content. Corresponds to the JSON property bigquery



17875
17876
17877
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17875

def bigquery
  @bigquery
end

#gcsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsDestination

The Google Cloud Storage location where the output is to be written to. Corresponds to the JSON property gcs



17880
17881
17882
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17880

def gcs
  @gcs
end

#prediction_formatString

The storage format of the predictions generated BatchPrediction job. Corresponds to the JSON property predictionFormat

Returns:

  • (String)


17885
17886
17887
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17885

def prediction_format
  @prediction_format
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17892
17893
17894
17895
17896
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17892

def update!(**args)
  @bigquery = args[:bigquery] if args.key?(:bigquery)
  @gcs = args[:gcs] if args.key?(:gcs)
  @prediction_format = args[:prediction_format] if args.key?(:prediction_format)
end