Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigExplanationConfigExplanationBaseline
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigExplanationConfigExplanationBaseline
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Output from BatchPredictionJob for Model Monitoring baseline dataset, which can be used to generate baseline attribution scores.
Instance Attribute Summary collapse
-
#bigquery ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQueryDestination
The BigQuery location for the output content.
-
#gcs ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsDestination
The Google Cloud Storage location where the output is to be written to.
-
#prediction_format ⇒ String
The storage format of the predictions generated BatchPrediction job.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigExplanationConfigExplanationBaseline
constructor
A new instance of GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigExplanationConfigExplanationBaseline.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigExplanationConfigExplanationBaseline
Returns a new instance of GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigExplanationConfigExplanationBaseline.
17874 17875 17876 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17874 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bigquery ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQueryDestination
The BigQuery location for the output content.
Corresponds to the JSON property bigquery
17862 17863 17864 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17862 def bigquery @bigquery end |
#gcs ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsDestination
The Google Cloud Storage location where the output is to be written to.
Corresponds to the JSON property gcs
17867 17868 17869 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17867 def gcs @gcs end |
#prediction_format ⇒ String
The storage format of the predictions generated BatchPrediction job.
Corresponds to the JSON property predictionFormat
17872 17873 17874 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17872 def prediction_format @prediction_format end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17879 17880 17881 17882 17883 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17879 def update!(**args) @bigquery = args[:bigquery] if args.key?(:bigquery) @gcs = args[:gcs] if args.key?(:gcs) @prediction_format = args[:prediction_format] if args.key?(:prediction_format) end |