Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigPredictionDriftDetectionConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The config for Prediction data drift detection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigPredictionDriftDetectionConfig

Returns a new instance of GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigPredictionDriftDetectionConfig.



26120
26121
26122
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26120

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attribution_score_drift_thresholdsHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ThresholdConfig>

Key is the feature name and value is the threshold. The threshold here is against attribution score distance between different time windows. Corresponds to the JSON property attributionScoreDriftThresholds



26105
26106
26107
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26105

def attribution_score_drift_thresholds
  @attribution_score_drift_thresholds
end

#default_drift_thresholdGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ThresholdConfig

The config for feature monitoring threshold. Corresponds to the JSON property defaultDriftThreshold



26110
26111
26112
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26110

def default_drift_threshold
  @default_drift_threshold
end

#drift_thresholdsHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ThresholdConfig>

Key is the feature name and value is the threshold. If a feature needs to be monitored for drift, a value threshold must be configured for that feature. The threshold here is against feature distribution distance between different time windws. Corresponds to the JSON property driftThresholds



26118
26119
26120
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26118

def drift_thresholds
  @drift_thresholds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26125
26126
26127
26128
26129
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26125

def update!(**args)
  @attribution_score_drift_thresholds = args[:attribution_score_drift_thresholds] if args.key?(:attribution_score_drift_thresholds)
  @default_drift_threshold = args[:default_drift_threshold] if args.key?(:default_drift_threshold)
  @drift_thresholds = args[:drift_thresholds] if args.key?(:drift_thresholds)
end