Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigPredictionDriftDetectionConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigPredictionDriftDetectionConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The config for Prediction data drift detection.
Instance Attribute Summary collapse
-
#attribution_score_drift_thresholds ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ThresholdConfig>
Key is the feature name and value is the threshold.
-
#default_drift_threshold ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ThresholdConfig
The config for feature monitoring threshold.
-
#drift_thresholds ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ThresholdConfig>
Key is the feature name and value is the threshold.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigPredictionDriftDetectionConfig
constructor
A new instance of GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigPredictionDriftDetectionConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigPredictionDriftDetectionConfig
Returns a new instance of GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigPredictionDriftDetectionConfig.
24586 24587 24588 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24586 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attribution_score_drift_thresholds ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ThresholdConfig>
Key is the feature name and value is the threshold. The threshold here is
against attribution score distance between different time windows.
Corresponds to the JSON property attributionScoreDriftThresholds
24571 24572 24573 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24571 def attribution_score_drift_thresholds @attribution_score_drift_thresholds end |
#default_drift_threshold ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ThresholdConfig
The config for feature monitoring threshold.
Corresponds to the JSON property defaultDriftThreshold
24576 24577 24578 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24576 def default_drift_threshold @default_drift_threshold end |
#drift_thresholds ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ThresholdConfig>
Key is the feature name and value is the threshold. If a feature needs to be
monitored for drift, a value threshold must be configured for that feature.
The threshold here is against feature distribution distance between different
time windws.
Corresponds to the JSON property driftThresholds
24584 24585 24586 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24584 def drift_thresholds @drift_thresholds end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24591 24592 24593 24594 24595 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24591 def update!(**args) @attribution_score_drift_thresholds = args[:attribution_score_drift_thresholds] if args.key?(:attribution_score_drift_thresholds) @default_drift_threshold = args[:default_drift_threshold] if args.key?(:default_drift_threshold) @drift_thresholds = args[:drift_thresholds] if args.key?(:drift_thresholds) end |