Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigPredictionDriftDetectionConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigPredictionDriftDetectionConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The config for Prediction data drift detection.
Instance Attribute Summary collapse
-
#attribution_score_drift_thresholds ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ThresholdConfig>
Key is the feature name and value is the threshold.
-
#default_drift_threshold ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ThresholdConfig
The config for feature monitoring threshold.
-
#drift_thresholds ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ThresholdConfig>
Key is the feature name and value is the threshold.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigPredictionDriftDetectionConfig
constructor
A new instance of GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigPredictionDriftDetectionConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigPredictionDriftDetectionConfig
Returns a new instance of GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigPredictionDriftDetectionConfig.
15286 15287 15288 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15286 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attribution_score_drift_thresholds ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ThresholdConfig>
Key is the feature name and value is the threshold. The threshold here is
against attribution score distance between different time windows.
Corresponds to the JSON property attributionScoreDriftThresholds
15271 15272 15273 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15271 def attribution_score_drift_thresholds @attribution_score_drift_thresholds end |
#default_drift_threshold ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ThresholdConfig
The config for feature monitoring threshold.
Corresponds to the JSON property defaultDriftThreshold
15276 15277 15278 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15276 def default_drift_threshold @default_drift_threshold end |
#drift_thresholds ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ThresholdConfig>
Key is the feature name and value is the threshold. If a feature needs to be
monitored for drift, a value threshold must be configured for that feature.
The threshold here is against feature distribution distance between different
time windws.
Corresponds to the JSON property driftThresholds
15284 15285 15286 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15284 def drift_thresholds @drift_thresholds end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15291 15292 15293 15294 15295 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15291 def update!(**args) @attribution_score_drift_thresholds = args[:attribution_score_drift_thresholds] if args.key?(:attribution_score_drift_thresholds) @default_drift_threshold = args[:default_drift_threshold] if args.key?(:default_drift_threshold) @drift_thresholds = args[:drift_thresholds] if args.key?(:drift_thresholds) end |