Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingDataset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Training Dataset information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingDataset

Returns a new instance of GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingDataset.



26170
26171
26172
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26170

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bigquery_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQuerySource

The BigQuery location for the input content. Corresponds to the JSON property bigquerySource



26139
26140
26141
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26139

def bigquery_source
  @bigquery_source
end

#data_formatString

Data format of the dataset, only applicable if the input is from Google Cloud Storage. The possible formats are: "tf-record" The source file is a TFRecord file. "csv" The source file is a CSV file. "jsonl" The source file is a JSONL file. Corresponds to the JSON property dataFormat

Returns:

  • (String)


26147
26148
26149
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26147

def data_format
  @data_format
end

#datasetString

The resource name of the Dataset used to train this Model. Corresponds to the JSON property dataset

Returns:

  • (String)


26152
26153
26154
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26152

def dataset
  @dataset
end

#gcs_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsSource

The Google Cloud Storage location for the input content. Corresponds to the JSON property gcsSource



26157
26158
26159
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26157

def gcs_source
  @gcs_source
end

#logging_sampling_strategyGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SamplingStrategy

Sampling Strategy for logging, can be for both training and prediction dataset. Corresponds to the JSON property loggingSamplingStrategy



26162
26163
26164
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26162

def logging_sampling_strategy
  @logging_sampling_strategy
end

#target_fieldString

The target field name the model is to predict. This field will be excluded when doing Predict and (or) Explain for the training data. Corresponds to the JSON property targetField

Returns:

  • (String)


26168
26169
26170
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26168

def target_field
  @target_field
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26175
26176
26177
26178
26179
26180
26181
26182
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26175

def update!(**args)
  @bigquery_source = args[:bigquery_source] if args.key?(:bigquery_source)
  @data_format = args[:data_format] if args.key?(:data_format)
  @dataset = args[:dataset] if args.key?(:dataset)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @logging_sampling_strategy = args[:logging_sampling_strategy] if args.key?(:logging_sampling_strategy)
  @target_field = args[:target_field] if args.key?(:target_field)
end