Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingDataset
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingDataset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Training Dataset information.
Instance Attribute Summary collapse
-
#bigquery_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQuerySource
The BigQuery location for the input content.
-
#data_format ⇒ String
Data format of the dataset, only applicable if the input is from Google Cloud Storage.
-
#dataset ⇒ String
The resource name of the Dataset used to train this Model.
-
#gcs_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsSource
The Google Cloud Storage location for the input content.
-
#logging_sampling_strategy ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SamplingStrategy
Sampling Strategy for logging, can be for both training and prediction dataset.
-
#target_field ⇒ String
The target field name the model is to predict.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingDataset
constructor
A new instance of GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingDataset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingDataset
Returns a new instance of GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingDataset.
24806 24807 24808 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24806 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bigquery_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQuerySource
The BigQuery location for the input content.
Corresponds to the JSON property bigquerySource
24775 24776 24777 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24775 def bigquery_source @bigquery_source end |
#data_format ⇒ String
Data format of the dataset, only applicable if the input is from Google Cloud
Storage. The possible formats are: "tf-record" The source file is a TFRecord
file. "csv" The source file is a CSV file. "jsonl" The source file is a JSONL
file.
Corresponds to the JSON property dataFormat
24783 24784 24785 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24783 def data_format @data_format end |
#dataset ⇒ String
The resource name of the Dataset used to train this Model.
Corresponds to the JSON property dataset
24788 24789 24790 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24788 def dataset @dataset end |
#gcs_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsSource
The Google Cloud Storage location for the input content.
Corresponds to the JSON property gcsSource
24793 24794 24795 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24793 def gcs_source @gcs_source end |
#logging_sampling_strategy ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SamplingStrategy
Sampling Strategy for logging, can be for both training and prediction dataset.
Corresponds to the JSON property loggingSamplingStrategy
24798 24799 24800 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24798 def logging_sampling_strategy @logging_sampling_strategy end |
#target_field ⇒ String
The target field name the model is to predict. This field will be excluded
when doing Predict and (or) Explain for the training data.
Corresponds to the JSON property targetField
24804 24805 24806 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24804 def target_field @target_field end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24811 24812 24813 24814 24815 24816 24817 24818 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24811 def update!(**args) @bigquery_source = args[:bigquery_source] if args.key?(:bigquery_source) @data_format = args[:data_format] if args.key?(:data_format) @dataset = args[:dataset] if args.key?(:dataset) @gcs_source = args[:gcs_source] if args.key?(:gcs_source) @logging_sampling_strategy = args[:logging_sampling_strategy] if args.key?(:logging_sampling_strategy) @target_field = args[:target_field] if args.key?(:target_field) end |