Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingDataset
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingDataset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Training Dataset information.
Instance Attribute Summary collapse
-
#bigquery_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQuerySource
The BigQuery location for the input content.
-
#data_format ⇒ String
Data format of the dataset, only applicable if the input is from Google Cloud Storage.
-
#dataset ⇒ String
The resource name of the Dataset used to train this Model.
-
#gcs_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsSource
The Google Cloud Storage location for the input content.
-
#logging_sampling_strategy ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SamplingStrategy
Sampling Strategy for logging, can be for both training and prediction dataset.
-
#target_field ⇒ String
The target field name the model is to predict.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingDataset
constructor
A new instance of GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingDataset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingDataset
Returns a new instance of GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingDataset.
18571 18572 18573 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18571 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bigquery_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQuerySource
The BigQuery location for the input content.
Corresponds to the JSON property bigquerySource
18540 18541 18542 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18540 def bigquery_source @bigquery_source end |
#data_format ⇒ String
Data format of the dataset, only applicable if the input is from Google Cloud
Storage. The possible formats are: "tf-record" The source file is a TFRecord
file. "csv" The source file is a CSV file. "jsonl" The source file is a JSONL
file.
Corresponds to the JSON property dataFormat
18548 18549 18550 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18548 def data_format @data_format end |
#dataset ⇒ String
The resource name of the Dataset used to train this Model.
Corresponds to the JSON property dataset
18553 18554 18555 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18553 def dataset @dataset end |
#gcs_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsSource
The Google Cloud Storage location for the input content.
Corresponds to the JSON property gcsSource
18558 18559 18560 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18558 def gcs_source @gcs_source end |
#logging_sampling_strategy ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SamplingStrategy
Sampling Strategy for logging, can be for both training and prediction dataset.
Corresponds to the JSON property loggingSamplingStrategy
18563 18564 18565 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18563 def logging_sampling_strategy @logging_sampling_strategy end |
#target_field ⇒ String
The target field name the model is to predict. This field will be excluded
when doing Predict and (or) Explain for the training data.
Corresponds to the JSON property targetField
18569 18570 18571 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18569 def target_field @target_field end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18576 18577 18578 18579 18580 18581 18582 18583 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18576 def update!(**args) @bigquery_source = args[:bigquery_source] if args.key?(:bigquery_source) @data_format = args[:data_format] if args.key?(:data_format) @dataset = args[:dataset] if args.key?(:dataset) @gcs_source = args[:gcs_source] if args.key?(:gcs_source) @logging_sampling_strategy = args[:logging_sampling_strategy] if args.key?(:logging_sampling_strategy) @target_field = args[:target_field] if args.key?(:target_field) end |