Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingDataset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Training Dataset information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingDataset

Returns a new instance of GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingDataset.



15959
15960
15961
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15959

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bigquery_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQuerySource

The BigQuery location for the input content. Corresponds to the JSON property bigquerySource



15928
15929
15930
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15928

def bigquery_source
  @bigquery_source
end

#data_formatString

Data format of the dataset, only applicable if the input is from Google Cloud Storage. The possible formats are: "tf-record" The source file is a TFRecord file. "csv" The source file is a CSV file. "jsonl" The source file is a JSONL file. Corresponds to the JSON property dataFormat

Returns:

  • (String)


15936
15937
15938
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15936

def data_format
  @data_format
end

#datasetString

The resource name of the Dataset used to train this Model. Corresponds to the JSON property dataset

Returns:

  • (String)


15941
15942
15943
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15941

def dataset
  @dataset
end

#gcs_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsSource

The Google Cloud Storage location for the input content. Corresponds to the JSON property gcsSource



15946
15947
15948
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15946

def gcs_source
  @gcs_source
end

#logging_sampling_strategyGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SamplingStrategy

Sampling Strategy for logging, can be for both training and prediction dataset. Corresponds to the JSON property loggingSamplingStrategy



15951
15952
15953
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15951

def logging_sampling_strategy
  @logging_sampling_strategy
end

#target_fieldString

The target field name the model is to predict. This field will be excluded when doing Predict and (or) Explain for the training data. Corresponds to the JSON property targetField

Returns:

  • (String)


15957
15958
15959
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15957

def target_field
  @target_field
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15964
15965
15966
15967
15968
15969
15970
15971
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15964

def update!(**args)
  @bigquery_source = args[:bigquery_source] if args.key?(:bigquery_source)
  @data_format = args[:data_format] if args.key?(:data_format)
  @dataset = args[:dataset] if args.key?(:dataset)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @logging_sampling_strategy = args[:logging_sampling_strategy] if args.key?(:logging_sampling_strategy)
  @target_field = args[:target_field] if args.key?(:target_field)
end