Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingDataset
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingDataset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Training Dataset information.
Instance Attribute Summary collapse
-
#bigquery_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQuerySource
The BigQuery location for the input content.
-
#data_format ⇒ String
Data format of the dataset, only applicable if the input is from Google Cloud Storage.
-
#dataset ⇒ String
The resource name of the Dataset used to train this Model.
-
#gcs_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsSource
The Google Cloud Storage location for the input content.
-
#logging_sampling_strategy ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SamplingStrategy
Sampling Strategy for logging, can be for both training and prediction dataset.
-
#target_field ⇒ String
The target field name the model is to predict.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingDataset
constructor
A new instance of GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingDataset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingDataset
Returns a new instance of GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingDataset.
14840 14841 14842 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14840 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bigquery_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQuerySource
The BigQuery location for the input content.
Corresponds to the JSON property bigquerySource
14809 14810 14811 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14809 def bigquery_source @bigquery_source end |
#data_format ⇒ String
Data format of the dataset, only applicable if the input is from Google Cloud
Storage. The possible formats are: "tf-record" The source file is a TFRecord
file. "csv" The source file is a CSV file. "jsonl" The source file is a JSONL
file.
Corresponds to the JSON property dataFormat
14817 14818 14819 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14817 def data_format @data_format end |
#dataset ⇒ String
The resource name of the Dataset used to train this Model.
Corresponds to the JSON property dataset
14822 14823 14824 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14822 def dataset @dataset end |
#gcs_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsSource
The Google Cloud Storage location for the input content.
Corresponds to the JSON property gcsSource
14827 14828 14829 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14827 def gcs_source @gcs_source end |
#logging_sampling_strategy ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SamplingStrategy
Sampling Strategy for logging, can be for both training and prediction dataset.
Corresponds to the JSON property loggingSamplingStrategy
14832 14833 14834 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14832 def logging_sampling_strategy @logging_sampling_strategy end |
#target_field ⇒ String
The target field name the model is to predict. This field will be excluded
when doing Predict and (or) Explain for the training data.
Corresponds to the JSON property targetField
14838 14839 14840 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14838 def target_field @target_field end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14845 14846 14847 14848 14849 14850 14851 14852 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14845 def update!(**args) @bigquery_source = args[:bigquery_source] if args.key?(:bigquery_source) @data_format = args[:data_format] if args.key?(:data_format) @dataset = args[:dataset] if args.key?(:dataset) @gcs_source = args[:gcs_source] if args.key?(:gcs_source) @logging_sampling_strategy = args[:logging_sampling_strategy] if args.key?(:logging_sampling_strategy) @target_field = args[:target_field] if args.key?(:target_field) end |