Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingDataset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Training Dataset information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingDataset

Returns a new instance of GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingDataset.



14136
14137
14138
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14136

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bigquery_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1BigQuerySource

The BigQuery location for the input content. Corresponds to the JSON property bigquerySource



14105
14106
14107
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14105

def bigquery_source
  @bigquery_source
end

#data_formatString

Data format of the dataset, only applicable if the input is from Google Cloud Storage. The possible formats are: "tf-record" The source file is a TFRecord file. "csv" The source file is a CSV file. "jsonl" The source file is a JSONL file. Corresponds to the JSON property dataFormat

Returns:

  • (String)


14113
14114
14115
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14113

def data_format
  @data_format
end

#datasetString

The resource name of the Dataset used to train this Model. Corresponds to the JSON property dataset

Returns:

  • (String)


14118
14119
14120
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14118

def dataset
  @dataset
end

#gcs_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsSource

The Google Cloud Storage location for the input content. Corresponds to the JSON property gcsSource



14123
14124
14125
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14123

def gcs_source
  @gcs_source
end

#logging_sampling_strategyGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SamplingStrategy

Sampling Strategy for logging, can be for both training and prediction dataset. Corresponds to the JSON property loggingSamplingStrategy



14128
14129
14130
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14128

def logging_sampling_strategy
  @logging_sampling_strategy
end

#target_fieldString

The target field name the model is to predict. This field will be excluded when doing Predict and (or) Explain for the training data. Corresponds to the JSON property targetField

Returns:

  • (String)


14134
14135
14136
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14134

def target_field
  @target_field
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14141
14142
14143
14144
14145
14146
14147
14148
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 14141

def update!(**args)
  @bigquery_source = args[:bigquery_source] if args.key?(:bigquery_source)
  @data_format = args[:data_format] if args.key?(:data_format)
  @dataset = args[:dataset] if args.key?(:dataset)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @logging_sampling_strategy = args[:logging_sampling_strategy] if args.key?(:logging_sampling_strategy)
  @target_field = args[:target_field] if args.key?(:target_field)
end