Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingPredictionSkewDetectionConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The config for Training & Prediction data skew detection. It specifies the training dataset sources and the skew detection parameters.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingPredictionSkewDetectionConfig

Returns a new instance of GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingPredictionSkewDetectionConfig.



26591
26592
26593
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26591

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attribution_score_skew_thresholdsHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ThresholdConfig>

Key is the feature name and value is the threshold. The threshold here is against attribution score distance between the training and prediction feature. Corresponds to the JSON property attributionScoreSkewThresholds



26576
26577
26578
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26576

def attribution_score_skew_thresholds
  @attribution_score_skew_thresholds
end

#default_skew_thresholdGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ThresholdConfig

The config for feature monitoring threshold. Corresponds to the JSON property defaultSkewThreshold



26581
26582
26583
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26581

def default_skew_threshold
  @default_skew_threshold
end

#skew_thresholdsHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ThresholdConfig>

Key is the feature name and value is the threshold. If a feature needs to be monitored for skew, a value threshold must be configured for that feature. The threshold here is against feature distribution distance between the training and prediction feature. Corresponds to the JSON property skewThresholds



26589
26590
26591
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26589

def skew_thresholds
  @skew_thresholds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26596
26597
26598
26599
26600
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26596

def update!(**args)
  @attribution_score_skew_thresholds = args[:attribution_score_skew_thresholds] if args.key?(:attribution_score_skew_thresholds)
  @default_skew_threshold = args[:default_skew_threshold] if args.key?(:default_skew_threshold)
  @skew_thresholds = args[:skew_thresholds] if args.key?(:skew_thresholds)
end