Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingPredictionSkewDetectionConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The config for Training & Prediction data skew detection. It specifies the training dataset sources and the skew detection parameters.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingPredictionSkewDetectionConfig

Returns a new instance of GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingPredictionSkewDetectionConfig.



24732
24733
24734
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24732

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attribution_score_skew_thresholdsHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ThresholdConfig>

Key is the feature name and value is the threshold. The threshold here is against attribution score distance between the training and prediction feature. Corresponds to the JSON property attributionScoreSkewThresholds



24717
24718
24719
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24717

def attribution_score_skew_thresholds
  @attribution_score_skew_thresholds
end

#default_skew_thresholdGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ThresholdConfig

The config for feature monitoring threshold. Corresponds to the JSON property defaultSkewThreshold



24722
24723
24724
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24722

def default_skew_threshold
  @default_skew_threshold
end

#skew_thresholdsHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ThresholdConfig>

Key is the feature name and value is the threshold. If a feature needs to be monitored for skew, a value threshold must be configured for that feature. The threshold here is against feature distribution distance between the training and prediction feature. Corresponds to the JSON property skewThresholds



24730
24731
24732
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24730

def skew_thresholds
  @skew_thresholds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24737
24738
24739
24740
24741
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24737

def update!(**args)
  @attribution_score_skew_thresholds = args[:attribution_score_skew_thresholds] if args.key?(:attribution_score_skew_thresholds)
  @default_skew_threshold = args[:default_skew_threshold] if args.key?(:default_skew_threshold)
  @skew_thresholds = args[:skew_thresholds] if args.key?(:skew_thresholds)
end