Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingPredictionSkewDetectionConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingPredictionSkewDetectionConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The config for Training & Prediction data skew detection. It specifies the training dataset sources and the skew detection parameters.
Instance Attribute Summary collapse
-
#attribution_score_skew_thresholds ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ThresholdConfig>
Key is the feature name and value is the threshold.
-
#default_skew_threshold ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ThresholdConfig
The config for feature monitoring threshold.
-
#skew_thresholds ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ThresholdConfig>
Key is the feature name and value is the threshold.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingPredictionSkewDetectionConfig
constructor
A new instance of GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingPredictionSkewDetectionConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingPredictionSkewDetectionConfig
Returns a new instance of GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingPredictionSkewDetectionConfig.
18231 18232 18233 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18231 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attribution_score_skew_thresholds ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ThresholdConfig>
Key is the feature name and value is the threshold. The threshold here is
against attribution score distance between the training and prediction feature.
Corresponds to the JSON property attributionScoreSkewThresholds
18216 18217 18218 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18216 def attribution_score_skew_thresholds @attribution_score_skew_thresholds end |
#default_skew_threshold ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ThresholdConfig
The config for feature monitoring threshold.
Corresponds to the JSON property defaultSkewThreshold
18221 18222 18223 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18221 def default_skew_threshold @default_skew_threshold end |
#skew_thresholds ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ThresholdConfig>
Key is the feature name and value is the threshold. If a feature needs to be
monitored for skew, a value threshold must be configured for that feature. The
threshold here is against feature distribution distance between the training
and prediction feature.
Corresponds to the JSON property skewThresholds
18229 18230 18231 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18229 def skew_thresholds @skew_thresholds end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18236 18237 18238 18239 18240 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18236 def update!(**args) @attribution_score_skew_thresholds = args[:attribution_score_skew_thresholds] if args.key?(:attribution_score_skew_thresholds) @default_skew_threshold = args[:default_skew_threshold] if args.key?(:default_skew_threshold) @skew_thresholds = args[:skew_thresholds] if args.key?(:skew_thresholds) end |