Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingPredictionSkewDetectionConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingPredictionSkewDetectionConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The config for Training & Prediction data skew detection. It specifies the training dataset sources and the skew detection parameters.
Instance Attribute Summary collapse
-
#attribution_score_skew_thresholds ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ThresholdConfig>
Key is the feature name and value is the threshold.
-
#default_skew_threshold ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ThresholdConfig
The config for feature monitoring threshold.
-
#skew_thresholds ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ThresholdConfig>
Key is the feature name and value is the threshold.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingPredictionSkewDetectionConfig
constructor
A new instance of GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingPredictionSkewDetectionConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingPredictionSkewDetectionConfig
Returns a new instance of GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingPredictionSkewDetectionConfig.
18186 18187 18188 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18186 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attribution_score_skew_thresholds ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ThresholdConfig>
Key is the feature name and value is the threshold. The threshold here is
against attribution score distance between the training and prediction feature.
Corresponds to the JSON property attributionScoreSkewThresholds
18171 18172 18173 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18171 def attribution_score_skew_thresholds @attribution_score_skew_thresholds end |
#default_skew_threshold ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ThresholdConfig
The config for feature monitoring threshold.
Corresponds to the JSON property defaultSkewThreshold
18176 18177 18178 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18176 def default_skew_threshold @default_skew_threshold end |
#skew_thresholds ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ThresholdConfig>
Key is the feature name and value is the threshold. If a feature needs to be
monitored for skew, a value threshold must be configured for that feature. The
threshold here is against feature distribution distance between the training
and prediction feature.
Corresponds to the JSON property skewThresholds
18184 18185 18186 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18184 def skew_thresholds @skew_thresholds end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18191 18192 18193 18194 18195 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18191 def update!(**args) @attribution_score_skew_thresholds = args[:attribution_score_skew_thresholds] if args.key?(:attribution_score_skew_thresholds) @default_skew_threshold = args[:default_skew_threshold] if args.key?(:default_skew_threshold) @skew_thresholds = args[:skew_thresholds] if args.key?(:skew_thresholds) end |