Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingPredictionSkewDetectionConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingPredictionSkewDetectionConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The config for Training & Prediction data skew detection. It specifies the training dataset sources and the skew detection parameters.
Instance Attribute Summary collapse
-
#attribution_score_skew_thresholds ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ThresholdConfig>
Key is the feature name and value is the threshold.
-
#default_skew_threshold ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ThresholdConfig
The config for feature monitoring threshold.
-
#skew_thresholds ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ThresholdConfig>
Key is the feature name and value is the threshold.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingPredictionSkewDetectionConfig
constructor
A new instance of GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingPredictionSkewDetectionConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingPredictionSkewDetectionConfig
Returns a new instance of GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingPredictionSkewDetectionConfig.
17437 17438 17439 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17437 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attribution_score_skew_thresholds ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ThresholdConfig>
Key is the feature name and value is the threshold. The threshold here is
against attribution score distance between the training and prediction feature.
Corresponds to the JSON property attributionScoreSkewThresholds
17422 17423 17424 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17422 def attribution_score_skew_thresholds @attribution_score_skew_thresholds end |
#default_skew_threshold ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ThresholdConfig
The config for feature monitoring threshold.
Corresponds to the JSON property defaultSkewThreshold
17427 17428 17429 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17427 def default_skew_threshold @default_skew_threshold end |
#skew_thresholds ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ThresholdConfig>
Key is the feature name and value is the threshold. If a feature needs to be
monitored for skew, a value threshold must be configured for that feature. The
threshold here is against feature distribution distance between the training
and prediction feature.
Corresponds to the JSON property skewThresholds
17435 17436 17437 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17435 def skew_thresholds @skew_thresholds end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17442 17443 17444 17445 17446 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17442 def update!(**args) @attribution_score_skew_thresholds = args[:attribution_score_skew_thresholds] if args.key?(:attribution_score_skew_thresholds) @default_skew_threshold = args[:default_skew_threshold] if args.key?(:default_skew_threshold) @skew_thresholds = args[:skew_thresholds] if args.key?(:skew_thresholds) end |