Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelMonitoringStatsAnomalies
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelMonitoringStatsAnomalies
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Statistics and anomalies generated by Model Monitoring.
Instance Attribute Summary collapse
-
#anomaly_count ⇒ Fixnum
Number of anomalies within all stats.
-
#deployed_model_id ⇒ String
Deployed Model ID.
-
#feature_stats ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelMonitoringStatsAnomaliesFeatureHistoricStatsAnomalies>
A list of historical Stats and Anomalies generated for all Features.
-
#objective ⇒ String
Model Monitoring Objective those stats and anomalies belonging to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelMonitoringStatsAnomalies
constructor
A new instance of GoogleCloudAiplatformV1ModelMonitoringStatsAnomalies.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelMonitoringStatsAnomalies
Returns a new instance of GoogleCloudAiplatformV1ModelMonitoringStatsAnomalies.
24711 24712 24713 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24711 def initialize(**args) update!(**args) end |
Instance Attribute Details
#anomaly_count ⇒ Fixnum
Number of anomalies within all stats.
Corresponds to the JSON property anomalyCount
24694 24695 24696 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24694 def anomaly_count @anomaly_count end |
#deployed_model_id ⇒ String
Deployed Model ID.
Corresponds to the JSON property deployedModelId
24699 24700 24701 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24699 def deployed_model_id @deployed_model_id end |
#feature_stats ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelMonitoringStatsAnomaliesFeatureHistoricStatsAnomalies>
A list of historical Stats and Anomalies generated for all Features.
Corresponds to the JSON property featureStats
24704 24705 24706 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24704 def feature_stats @feature_stats end |
#objective ⇒ String
Model Monitoring Objective those stats and anomalies belonging to.
Corresponds to the JSON property objective
24709 24710 24711 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24709 def objective @objective end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24716 24717 24718 24719 24720 24721 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24716 def update!(**args) @anomaly_count = args[:anomaly_count] if args.key?(:anomaly_count) @deployed_model_id = args[:deployed_model_id] if args.key?(:deployed_model_id) @feature_stats = args[:feature_stats] if args.key?(:feature_stats) @objective = args[:objective] if args.key?(:objective) end |