Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelMonitoringStatsAnomalies
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelMonitoringStatsAnomalies
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Statistics and anomalies generated by Model Monitoring.
Instance Attribute Summary collapse
-
#anomaly_count ⇒ Fixnum
Number of anomalies within all stats.
-
#deployed_model_id ⇒ String
Deployed Model ID.
-
#feature_stats ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelMonitoringStatsAnomaliesFeatureHistoricStatsAnomalies>
A list of historical Stats and Anomalies generated for all Features.
-
#objective ⇒ String
Model Monitoring Objective those stats and anomalies belonging to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelMonitoringStatsAnomalies
constructor
A new instance of GoogleCloudAiplatformV1ModelMonitoringStatsAnomalies.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelMonitoringStatsAnomalies
Returns a new instance of GoogleCloudAiplatformV1ModelMonitoringStatsAnomalies.
18608 18609 18610 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18608 def initialize(**args) update!(**args) end |
Instance Attribute Details
#anomaly_count ⇒ Fixnum
Number of anomalies within all stats.
Corresponds to the JSON property anomalyCount
18591 18592 18593 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18591 def anomaly_count @anomaly_count end |
#deployed_model_id ⇒ String
Deployed Model ID.
Corresponds to the JSON property deployedModelId
18596 18597 18598 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18596 def deployed_model_id @deployed_model_id end |
#feature_stats ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelMonitoringStatsAnomaliesFeatureHistoricStatsAnomalies>
A list of historical Stats and Anomalies generated for all Features.
Corresponds to the JSON property featureStats
18601 18602 18603 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18601 def feature_stats @feature_stats end |
#objective ⇒ String
Model Monitoring Objective those stats and anomalies belonging to.
Corresponds to the JSON property objective
18606 18607 18608 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18606 def objective @objective end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18613 18614 18615 18616 18617 18618 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18613 def update!(**args) @anomaly_count = args[:anomaly_count] if args.key?(:anomaly_count) @deployed_model_id = args[:deployed_model_id] if args.key?(:deployed_model_id) @feature_stats = args[:feature_stats] if args.key?(:feature_stats) @objective = args[:objective] if args.key?(:objective) end |