Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelMonitoringStatsAnomalies

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Statistics and anomalies generated by Model Monitoring.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelMonitoringStatsAnomalies

Returns a new instance of GoogleCloudAiplatformV1ModelMonitoringStatsAnomalies.



18059
18060
18061
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18059

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#anomaly_countFixnum

Number of anomalies within all stats. Corresponds to the JSON property anomalyCount

Returns:

  • (Fixnum)


18042
18043
18044
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18042

def anomaly_count
  @anomaly_count
end

#deployed_model_idString

Deployed Model ID. Corresponds to the JSON property deployedModelId

Returns:

  • (String)


18047
18048
18049
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18047

def deployed_model_id
  @deployed_model_id
end

#feature_statsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelMonitoringStatsAnomaliesFeatureHistoricStatsAnomalies>

A list of historical Stats and Anomalies generated for all Features. Corresponds to the JSON property featureStats



18052
18053
18054
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18052

def feature_stats
  @feature_stats
end

#objectiveString

Model Monitoring Objective those stats and anomalies belonging to. Corresponds to the JSON property objective

Returns:

  • (String)


18057
18058
18059
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18057

def objective
  @objective
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18064
18065
18066
18067
18068
18069
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18064

def update!(**args)
  @anomaly_count = args[:anomaly_count] if args.key?(:anomaly_count)
  @deployed_model_id = args[:deployed_model_id] if args.key?(:deployed_model_id)
  @feature_stats = args[:feature_stats] if args.key?(:feature_stats)
  @objective = args[:objective] if args.key?(:objective)
end