Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelMonitoringStatsAnomaliesFeatureHistoricStatsAnomalies

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Historical Stats (and Anomalies) for a specific Feature.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ModelMonitoringStatsAnomaliesFeatureHistoricStatsAnomalies

Returns a new instance of GoogleCloudAiplatformV1ModelMonitoringStatsAnomaliesFeatureHistoricStatsAnomalies.



26303
26304
26305
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26303

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#feature_display_nameString

Display Name of the Feature. Corresponds to the JSON property featureDisplayName

Returns:

  • (String)


26278
26279
26280
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26278

def feature_display_name
  @feature_display_name
end

#prediction_statsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureStatsAnomaly>

A list of historical stats generated by different time window's Prediction Dataset. Corresponds to the JSON property predictionStats



26284
26285
26286
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26284

def prediction_stats
  @prediction_stats
end

#thresholdGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ThresholdConfig

The config for feature monitoring threshold. Corresponds to the JSON property threshold



26289
26290
26291
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26289

def threshold
  @threshold
end

#training_statsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureStatsAnomaly

Stats and Anomaly generated at specific timestamp for specific Feature. The start_time and end_time are used to define the time range of the dataset that current stats belongs to, e.g. prediction traffic is bucketed into prediction datasets by time window. If the Dataset is not defined by time window, start_time = end_time. Timestamp of the stats and anomalies always refers to end_time. Raw stats and anomalies are stored in stats_uri or anomaly_uri in the tensorflow defined protos. Field data_stats contains almost identical information with the raw stats in Vertex AI defined proto, for UI to display. Corresponds to the JSON property trainingStats



26301
26302
26303
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26301

def training_stats
  @training_stats
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26308
26309
26310
26311
26312
26313
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26308

def update!(**args)
  @feature_display_name = args[:feature_display_name] if args.key?(:feature_display_name)
  @prediction_stats = args[:prediction_stats] if args.key?(:prediction_stats)
  @threshold = args[:threshold] if args.key?(:threshold)
  @training_stats = args[:training_stats] if args.key?(:training_stats)
end