Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NasJob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents a Neural Architecture Search (NAS) job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1NasJob

Returns a new instance of GoogleCloudAiplatformV1NasJob.



18987
18988
18989
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18987

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Time when the NasJob was created. Corresponds to the JSON property createTime

Returns:

  • (String)


18898
18899
18900
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18898

def create_time
  @create_time
end

#display_nameString

Required. The display name of the NasJob. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


18904
18905
18906
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18904

def display_name
  @display_name
end

#enable_restricted_image_trainingBoolean Also known as: enable_restricted_image_training?

Optional. Enable a separation of Custom model training and restricted image training for tenant project. Corresponds to the JSON property enableRestrictedImageTraining

Returns:

  • (Boolean)


18910
18911
18912
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18910

def enable_restricted_image_training
  @enable_restricted_image_training
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key spec that can be applied to a top- level resource. Corresponds to the JSON property encryptionSpec



18917
18918
18919
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18917

def encryption_spec
  @encryption_spec
end

#end_timeString

Output only. Time when the NasJob entered any of the following states: JOB_STATE_SUCCEEDED, JOB_STATE_FAILED, JOB_STATE_CANCELLED. Corresponds to the JSON property endTime

Returns:

  • (String)


18923
18924
18925
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18923

def end_time
  @end_time
end

#errorGoogle::Apis::AiplatformV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



18933
18934
18935
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18933

def error
  @error
end

#labelsHash<String,String>

The labels with user-defined metadata to organize NasJobs. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


18942
18943
18944
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18942

def labels
  @labels
end

#nameString

Output only. Resource name of the NasJob. Corresponds to the JSON property name

Returns:

  • (String)


18947
18948
18949
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18947

def name
  @name
end

#nas_job_outputGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1NasJobOutput

Represents a uCAIP NasJob output. Corresponds to the JSON property nasJobOutput



18952
18953
18954
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18952

def nas_job_output
  @nas_job_output
end

#nas_job_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1NasJobSpec

Represents the spec of a NasJob. Corresponds to the JSON property nasJobSpec



18957
18958
18959
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18957

def nas_job_spec
  @nas_job_spec
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


18962
18963
18964
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18962

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


18968
18969
18970
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18968

def satisfies_pzs
  @satisfies_pzs
end

#start_timeString

Output only. Time when the NasJob for the first time entered the JOB_STATE_RUNNING state. Corresponds to the JSON property startTime

Returns:

  • (String)


18975
18976
18977
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18975

def start_time
  @start_time
end

#stateString

Output only. The detailed state of the job. Corresponds to the JSON property state

Returns:

  • (String)


18980
18981
18982
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18980

def state
  @state
end

#update_timeString

Output only. Time when the NasJob was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


18985
18986
18987
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18985

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18992
18993
18994
18995
18996
18997
18998
18999
19000
19001
19002
19003
19004
19005
19006
19007
19008
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18992

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @enable_restricted_image_training = args[:enable_restricted_image_training] if args.key?(:enable_restricted_image_training)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @end_time = args[:end_time] if args.key?(:end_time)
  @error = args[:error] if args.key?(:error)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @nas_job_output = args[:nas_job_output] if args.key?(:nas_job_output)
  @nas_job_spec = args[:nas_job_spec] if args.key?(:nas_job_spec)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end