Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NasJob
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NasJob
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Represents a Neural Architecture Search (NAS) job.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Required.
-
#enable_restricted_image_training ⇒ Boolean
(also: #enable_restricted_image_training?)
Optional.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top- level resource.
-
#end_time ⇒ String
Output only.
-
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize NasJobs.
-
#name ⇒ String
Output only.
-
#nas_job_output ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NasJobOutput
Represents a uCAIP NasJob output.
-
#nas_job_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NasJobSpec
Represents the spec of a NasJob.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1NasJob
constructor
A new instance of GoogleCloudAiplatformV1NasJob.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1NasJob
Returns a new instance of GoogleCloudAiplatformV1NasJob.
18571 18572 18573 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18571 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Time when the NasJob was created.
Corresponds to the JSON property createTime
18482 18483 18484 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18482 def create_time @create_time end |
#display_name ⇒ String
Required. The display name of the NasJob. The name can be up to 128 characters
long and can consist of any UTF-8 characters.
Corresponds to the JSON property displayName
18488 18489 18490 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18488 def display_name @display_name end |
#enable_restricted_image_training ⇒ Boolean Also known as: enable_restricted_image_training?
Optional. Enable a separation of Custom model training and restricted image
training for tenant project.
Corresponds to the JSON property enableRestrictedImageTraining
18494 18495 18496 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18494 def enable_restricted_image_training @enable_restricted_image_training end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top-
level resource.
Corresponds to the JSON property encryptionSpec
18501 18502 18503 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18501 def encryption_spec @encryption_spec end |
#end_time ⇒ String
Output only. Time when the NasJob entered any of the following states:
JOB_STATE_SUCCEEDED, JOB_STATE_FAILED, JOB_STATE_CANCELLED.
Corresponds to the JSON property endTime
18507 18508 18509 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18507 def end_time @end_time end |
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
18517 18518 18519 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18517 def error @error end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize NasJobs. Label keys and
values can be no longer than 64 characters (Unicode codepoints), can only
contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. See https://goo.gl/xmQnxf for more
information and examples of labels.
Corresponds to the JSON property labels
18526 18527 18528 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18526 def labels @labels end |
#name ⇒ String
Output only. Resource name of the NasJob.
Corresponds to the JSON property name
18531 18532 18533 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18531 def name @name end |
#nas_job_output ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NasJobOutput
Represents a uCAIP NasJob output.
Corresponds to the JSON property nasJobOutput
18536 18537 18538 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18536 def nas_job_output @nas_job_output end |
#nas_job_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NasJobSpec
Represents the spec of a NasJob.
Corresponds to the JSON property nasJobSpec
18541 18542 18543 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18541 def nas_job_spec @nas_job_spec end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
18546 18547 18548 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18546 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
18552 18553 18554 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18552 def satisfies_pzs @satisfies_pzs end |
#start_time ⇒ String
Output only. Time when the NasJob for the first time entered the
JOB_STATE_RUNNING state.
Corresponds to the JSON property startTime
18559 18560 18561 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18559 def start_time @start_time end |
#state ⇒ String
Output only. The detailed state of the job.
Corresponds to the JSON property state
18564 18565 18566 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18564 def state @state end |
#update_time ⇒ String
Output only. Time when the NasJob was most recently updated.
Corresponds to the JSON property updateTime
18569 18570 18571 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18569 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18576 18577 18578 18579 18580 18581 18582 18583 18584 18585 18586 18587 18588 18589 18590 18591 18592 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18576 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @enable_restricted_image_training = args[:enable_restricted_image_training] if args.key?(:enable_restricted_image_training) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @end_time = args[:end_time] if args.key?(:end_time) @error = args[:error] if args.key?(:error) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @nas_job_output = args[:nas_job_output] if args.key?(:nas_job_output) @nas_job_spec = args[:nas_job_spec] if args.key?(:nas_job_spec) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |