Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NasJob
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NasJob
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Represents a Neural Architecture Search (NAS) job.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Required.
-
#enable_restricted_image_training ⇒ Boolean
(also: #enable_restricted_image_training?)
Optional.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top- level resource.
-
#end_time ⇒ String
Output only.
-
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize NasJobs.
-
#name ⇒ String
Output only.
-
#nas_job_output ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NasJobOutput
Represents a uCAIP NasJob output.
-
#nas_job_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NasJobSpec
Represents the spec of a NasJob.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1NasJob
constructor
A new instance of GoogleCloudAiplatformV1NasJob.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1NasJob
Returns a new instance of GoogleCloudAiplatformV1NasJob.
15450 15451 15452 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15450 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Time when the NasJob was created.
Corresponds to the JSON property createTime
15373 15374 15375 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15373 def create_time @create_time end |
#display_name ⇒ String
Required. The display name of the NasJob. The name can be up to 128 characters
long and can consist of any UTF-8 characters.
Corresponds to the JSON property displayName
15379 15380 15381 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15379 def display_name @display_name end |
#enable_restricted_image_training ⇒ Boolean Also known as: enable_restricted_image_training?
Optional. Enable a separation of Custom model training and restricted image
training for tenant project.
Corresponds to the JSON property enableRestrictedImageTraining
15385 15386 15387 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15385 def enable_restricted_image_training @enable_restricted_image_training end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top-
level resource.
Corresponds to the JSON property encryptionSpec
15392 15393 15394 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15392 def encryption_spec @encryption_spec end |
#end_time ⇒ String
Output only. Time when the NasJob entered any of the following states:
JOB_STATE_SUCCEEDED, JOB_STATE_FAILED, JOB_STATE_CANCELLED.
Corresponds to the JSON property endTime
15398 15399 15400 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15398 def end_time @end_time end |
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
15408 15409 15410 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15408 def error @error end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize NasJobs. Label keys and
values can be no longer than 64 characters (Unicode codepoints), can only
contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. See https://goo.gl/xmQnxf for more
information and examples of labels.
Corresponds to the JSON property labels
15417 15418 15419 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15417 def labels @labels end |
#name ⇒ String
Output only. Resource name of the NasJob.
Corresponds to the JSON property name
15422 15423 15424 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15422 def name @name end |
#nas_job_output ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NasJobOutput
Represents a uCAIP NasJob output.
Corresponds to the JSON property nasJobOutput
15427 15428 15429 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15427 def nas_job_output @nas_job_output end |
#nas_job_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NasJobSpec
Represents the spec of a NasJob.
Corresponds to the JSON property nasJobSpec
15432 15433 15434 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15432 def nas_job_spec @nas_job_spec end |
#start_time ⇒ String
Output only. Time when the NasJob for the first time entered the
JOB_STATE_RUNNING state.
Corresponds to the JSON property startTime
15438 15439 15440 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15438 def start_time @start_time end |
#state ⇒ String
Output only. The detailed state of the job.
Corresponds to the JSON property state
15443 15444 15445 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15443 def state @state end |
#update_time ⇒ String
Output only. Time when the NasJob was most recently updated.
Corresponds to the JSON property updateTime
15448 15449 15450 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15448 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15455 15456 15457 15458 15459 15460 15461 15462 15463 15464 15465 15466 15467 15468 15469 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15455 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @enable_restricted_image_training = args[:enable_restricted_image_training] if args.key?(:enable_restricted_image_training) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @end_time = args[:end_time] if args.key?(:end_time) @error = args[:error] if args.key?(:error) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @nas_job_output = args[:nas_job_output] if args.key?(:nas_job_output) @nas_job_spec = args[:nas_job_spec] if args.key?(:nas_job_spec) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |