Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NasJob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents a Neural Architecture Search (NAS) job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1NasJob

Returns a new instance of GoogleCloudAiplatformV1NasJob.



15219
15220
15221
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15219

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Time when the NasJob was created. Corresponds to the JSON property createTime

Returns:

  • (String)


15142
15143
15144
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15142

def create_time
  @create_time
end

#display_nameString

Required. The display name of the NasJob. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


15148
15149
15150
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15148

def display_name
  @display_name
end

#enable_restricted_image_trainingBoolean Also known as: enable_restricted_image_training?

Optional. Enable a separation of Custom model training and restricted image training for tenant project. Corresponds to the JSON property enableRestrictedImageTraining

Returns:

  • (Boolean)


15154
15155
15156
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15154

def enable_restricted_image_training
  @enable_restricted_image_training
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key spec that can be applied to a top- level resource. Corresponds to the JSON property encryptionSpec



15161
15162
15163
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15161

def encryption_spec
  @encryption_spec
end

#end_timeString

Output only. Time when the NasJob entered any of the following states: JOB_STATE_SUCCEEDED, JOB_STATE_FAILED, JOB_STATE_CANCELLED. Corresponds to the JSON property endTime

Returns:

  • (String)


15167
15168
15169
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15167

def end_time
  @end_time
end

#errorGoogle::Apis::AiplatformV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



15177
15178
15179
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15177

def error
  @error
end

#labelsHash<String,String>

The labels with user-defined metadata to organize NasJobs. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


15186
15187
15188
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15186

def labels
  @labels
end

#nameString

Output only. Resource name of the NasJob. Corresponds to the JSON property name

Returns:

  • (String)


15191
15192
15193
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15191

def name
  @name
end

#nas_job_outputGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1NasJobOutput

Represents a uCAIP NasJob output. Corresponds to the JSON property nasJobOutput



15196
15197
15198
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15196

def nas_job_output
  @nas_job_output
end

#nas_job_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1NasJobSpec

Represents the spec of a NasJob. Corresponds to the JSON property nasJobSpec



15201
15202
15203
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15201

def nas_job_spec
  @nas_job_spec
end

#start_timeString

Output only. Time when the NasJob for the first time entered the JOB_STATE_RUNNING state. Corresponds to the JSON property startTime

Returns:

  • (String)


15207
15208
15209
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15207

def start_time
  @start_time
end

#stateString

Output only. The detailed state of the job. Corresponds to the JSON property state

Returns:

  • (String)


15212
15213
15214
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15212

def state
  @state
end

#update_timeString

Output only. Time when the NasJob was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


15217
15218
15219
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15217

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15224
15225
15226
15227
15228
15229
15230
15231
15232
15233
15234
15235
15236
15237
15238
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15224

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @enable_restricted_image_training = args[:enable_restricted_image_training] if args.key?(:enable_restricted_image_training)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @end_time = args[:end_time] if args.key?(:end_time)
  @error = args[:error] if args.key?(:error)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @nas_job_output = args[:nas_job_output] if args.key?(:nas_job_output)
  @nas_job_spec = args[:nas_job_spec] if args.key?(:nas_job_spec)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end