Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpecSearchTrialSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represent spec for search trials.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpecSearchTrialSpec

Returns a new instance of GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpecSearchTrialSpec.



27621
27622
27623
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27621

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_failed_trial_countFixnum

The number of failed trials that need to be seen before failing the NasJob. If set to 0, Vertex AI decides how many trials must fail before the whole job fails. Corresponds to the JSON property maxFailedTrialCount

Returns:

  • (Fixnum)


27604
27605
27606
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27604

def max_failed_trial_count
  @max_failed_trial_count
end

#max_parallel_trial_countFixnum

Required. The maximum number of trials to run in parallel. Corresponds to the JSON property maxParallelTrialCount

Returns:

  • (Fixnum)


27609
27610
27611
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27609

def max_parallel_trial_count
  @max_parallel_trial_count
end

#max_trial_countFixnum

Required. The maximum number of Neural Architecture Search (NAS) trials to run. Corresponds to the JSON property maxTrialCount

Returns:

  • (Fixnum)


27614
27615
27616
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27614

def max_trial_count
  @max_trial_count
end

#search_trial_job_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1CustomJobSpec

Represents the spec of a CustomJob. Corresponds to the JSON property searchTrialJobSpec



27619
27620
27621
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27619

def search_trial_job_spec
  @search_trial_job_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27626
27627
27628
27629
27630
27631
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27626

def update!(**args)
  @max_failed_trial_count = args[:max_failed_trial_count] if args.key?(:max_failed_trial_count)
  @max_parallel_trial_count = args[:max_parallel_trial_count] if args.key?(:max_parallel_trial_count)
  @max_trial_count = args[:max_trial_count] if args.key?(:max_trial_count)
  @search_trial_job_spec = args[:search_trial_job_spec] if args.key?(:search_trial_job_spec)
end