Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpecSearchTrialSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpecSearchTrialSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Represent spec for search trials.
Instance Attribute Summary collapse
-
#max_failed_trial_count ⇒ Fixnum
The number of failed trials that need to be seen before failing the NasJob.
-
#max_parallel_trial_count ⇒ Fixnum
Required.
-
#max_trial_count ⇒ Fixnum
Required.
-
#search_trial_job_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CustomJobSpec
Represents the spec of a CustomJob.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpecSearchTrialSpec
constructor
A new instance of GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpecSearchTrialSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpecSearchTrialSpec
Returns a new instance of GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpecSearchTrialSpec.
27178 27179 27180 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27178 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_failed_trial_count ⇒ Fixnum
The number of failed trials that need to be seen before failing the NasJob. If
set to 0, Vertex AI decides how many trials must fail before the whole job
fails.
Corresponds to the JSON property maxFailedTrialCount
27161 27162 27163 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27161 def max_failed_trial_count @max_failed_trial_count end |
#max_parallel_trial_count ⇒ Fixnum
Required. The maximum number of trials to run in parallel.
Corresponds to the JSON property maxParallelTrialCount
27166 27167 27168 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27166 def max_parallel_trial_count @max_parallel_trial_count end |
#max_trial_count ⇒ Fixnum
Required. The maximum number of Neural Architecture Search (NAS) trials to run.
Corresponds to the JSON property maxTrialCount
27171 27172 27173 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27171 def max_trial_count @max_trial_count end |
#search_trial_job_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CustomJobSpec
Represents the spec of a CustomJob.
Corresponds to the JSON property searchTrialJobSpec
27176 27177 27178 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27176 def search_trial_job_spec @search_trial_job_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27183 27184 27185 27186 27187 27188 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27183 def update!(**args) @max_failed_trial_count = args[:max_failed_trial_count] if args.key?(:max_failed_trial_count) @max_parallel_trial_count = args[:max_parallel_trial_count] if args.key?(:max_parallel_trial_count) @max_trial_count = args[:max_trial_count] if args.key?(:max_trial_count) @search_trial_job_spec = args[:search_trial_job_spec] if args.key?(:search_trial_job_spec) end |