Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpecSearchTrialSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpecSearchTrialSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Represent spec for search trials.
Instance Attribute Summary collapse
-
#max_failed_trial_count ⇒ Fixnum
The number of failed trials that need to be seen before failing the NasJob.
-
#max_parallel_trial_count ⇒ Fixnum
Required.
-
#max_trial_count ⇒ Fixnum
Required.
-
#search_trial_job_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CustomJobSpec
Represents the spec of a CustomJob.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpecSearchTrialSpec
constructor
A new instance of GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpecSearchTrialSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpecSearchTrialSpec
Returns a new instance of GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpecSearchTrialSpec.
26392 26393 26394 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26392 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_failed_trial_count ⇒ Fixnum
The number of failed trials that need to be seen before failing the NasJob. If
set to 0, Vertex AI decides how many trials must fail before the whole job
fails.
Corresponds to the JSON property maxFailedTrialCount
26375 26376 26377 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26375 def max_failed_trial_count @max_failed_trial_count end |
#max_parallel_trial_count ⇒ Fixnum
Required. The maximum number of trials to run in parallel.
Corresponds to the JSON property maxParallelTrialCount
26380 26381 26382 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26380 def max_parallel_trial_count @max_parallel_trial_count end |
#max_trial_count ⇒ Fixnum
Required. The maximum number of Neural Architecture Search (NAS) trials to run.
Corresponds to the JSON property maxTrialCount
26385 26386 26387 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26385 def max_trial_count @max_trial_count end |
#search_trial_job_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CustomJobSpec
Represents the spec of a CustomJob.
Corresponds to the JSON property searchTrialJobSpec
26390 26391 26392 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26390 def search_trial_job_spec @search_trial_job_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26397 26398 26399 26400 26401 26402 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26397 def update!(**args) @max_failed_trial_count = args[:max_failed_trial_count] if args.key?(:max_failed_trial_count) @max_parallel_trial_count = args[:max_parallel_trial_count] if args.key?(:max_parallel_trial_count) @max_trial_count = args[:max_trial_count] if args.key?(:max_trial_count) @search_trial_job_spec = args[:search_trial_job_spec] if args.key?(:search_trial_job_spec) end |