Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpecSearchTrialSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represent spec for search trials.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpecSearchTrialSpec

Returns a new instance of GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpecSearchTrialSpec.



19139
19140
19141
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19139

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_failed_trial_countFixnum

The number of failed trials that need to be seen before failing the NasJob. If set to 0, Vertex AI decides how many trials must fail before the whole job fails. Corresponds to the JSON property maxFailedTrialCount

Returns:

  • (Fixnum)


19122
19123
19124
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19122

def max_failed_trial_count
  @max_failed_trial_count
end

#max_parallel_trial_countFixnum

Required. The maximum number of trials to run in parallel. Corresponds to the JSON property maxParallelTrialCount

Returns:

  • (Fixnum)


19127
19128
19129
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19127

def max_parallel_trial_count
  @max_parallel_trial_count
end

#max_trial_countFixnum

Required. The maximum number of Neural Architecture Search (NAS) trials to run. Corresponds to the JSON property maxTrialCount

Returns:

  • (Fixnum)


19132
19133
19134
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19132

def max_trial_count
  @max_trial_count
end

#search_trial_job_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1CustomJobSpec

Represents the spec of a CustomJob. Corresponds to the JSON property searchTrialJobSpec



19137
19138
19139
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19137

def search_trial_job_spec
  @search_trial_job_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19144
19145
19146
19147
19148
19149
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19144

def update!(**args)
  @max_failed_trial_count = args[:max_failed_trial_count] if args.key?(:max_failed_trial_count)
  @max_parallel_trial_count = args[:max_parallel_trial_count] if args.key?(:max_parallel_trial_count)
  @max_trial_count = args[:max_trial_count] if args.key?(:max_trial_count)
  @search_trial_job_spec = args[:search_trial_job_spec] if args.key?(:search_trial_job_spec)
end