Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpecSearchTrialSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represent spec for search trials.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpecSearchTrialSpec

Returns a new instance of GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpecSearchTrialSpec.



18798
18799
18800
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18798

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_failed_trial_countFixnum

The number of failed trials that need to be seen before failing the NasJob. If set to 0, Vertex AI decides how many trials must fail before the whole job fails. Corresponds to the JSON property maxFailedTrialCount

Returns:

  • (Fixnum)


18781
18782
18783
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18781

def max_failed_trial_count
  @max_failed_trial_count
end

#max_parallel_trial_countFixnum

Required. The maximum number of trials to run in parallel. Corresponds to the JSON property maxParallelTrialCount

Returns:

  • (Fixnum)


18786
18787
18788
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18786

def max_parallel_trial_count
  @max_parallel_trial_count
end

#max_trial_countFixnum

Required. The maximum number of Neural Architecture Search (NAS) trials to run. Corresponds to the JSON property maxTrialCount

Returns:

  • (Fixnum)


18791
18792
18793
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18791

def max_trial_count
  @max_trial_count
end

#search_trial_job_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1CustomJobSpec

Represents the spec of a CustomJob. Corresponds to the JSON property searchTrialJobSpec



18796
18797
18798
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18796

def search_trial_job_spec
  @search_trial_job_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18803
18804
18805
18806
18807
18808
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18803

def update!(**args)
  @max_failed_trial_count = args[:max_failed_trial_count] if args.key?(:max_failed_trial_count)
  @max_parallel_trial_count = args[:max_parallel_trial_count] if args.key?(:max_parallel_trial_count)
  @max_trial_count = args[:max_trial_count] if args.key?(:max_trial_count)
  @search_trial_job_spec = args[:search_trial_job_spec] if args.key?(:search_trial_job_spec)
end