Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpecSearchTrialSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpecSearchTrialSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Represent spec for search trials.
Instance Attribute Summary collapse
-
#max_failed_trial_count ⇒ Fixnum
The number of failed trials that need to be seen before failing the NasJob.
-
#max_parallel_trial_count ⇒ Fixnum
Required.
-
#max_trial_count ⇒ Fixnum
Required.
-
#search_trial_job_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CustomJobSpec
Represents the spec of a CustomJob.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpecSearchTrialSpec
constructor
A new instance of GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpecSearchTrialSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpecSearchTrialSpec
Returns a new instance of GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpecSearchTrialSpec.
18441 18442 18443 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18441 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_failed_trial_count ⇒ Fixnum
The number of failed trials that need to be seen before failing the NasJob. If
set to 0, Vertex AI decides how many trials must fail before the whole job
fails.
Corresponds to the JSON property maxFailedTrialCount
18424 18425 18426 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18424 def max_failed_trial_count @max_failed_trial_count end |
#max_parallel_trial_count ⇒ Fixnum
Required. The maximum number of trials to run in parallel.
Corresponds to the JSON property maxParallelTrialCount
18429 18430 18431 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18429 def max_parallel_trial_count @max_parallel_trial_count end |
#max_trial_count ⇒ Fixnum
Required. The maximum number of Neural Architecture Search (NAS) trials to run.
Corresponds to the JSON property maxTrialCount
18434 18435 18436 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18434 def max_trial_count @max_trial_count end |
#search_trial_job_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CustomJobSpec
Represents the spec of a CustomJob.
Corresponds to the JSON property searchTrialJobSpec
18439 18440 18441 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18439 def search_trial_job_spec @search_trial_job_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18446 18447 18448 18449 18450 18451 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18446 def update!(**args) @max_failed_trial_count = args[:max_failed_trial_count] if args.key?(:max_failed_trial_count) @max_parallel_trial_count = args[:max_parallel_trial_count] if args.key?(:max_parallel_trial_count) @max_trial_count = args[:max_trial_count] if args.key?(:max_trial_count) @search_trial_job_spec = args[:search_trial_job_spec] if args.key?(:search_trial_job_spec) end |