Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpecSearchTrialSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represent spec for search trials.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpecSearchTrialSpec

Returns a new instance of GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpecSearchTrialSpec.



15638
15639
15640
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15638

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_failed_trial_countFixnum

The number of failed trials that need to be seen before failing the NasJob. If set to 0, Vertex AI decides how many trials must fail before the whole job fails. Corresponds to the JSON property maxFailedTrialCount

Returns:

  • (Fixnum)


15621
15622
15623
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15621

def max_failed_trial_count
  @max_failed_trial_count
end

#max_parallel_trial_countFixnum

Required. The maximum number of trials to run in parallel. Corresponds to the JSON property maxParallelTrialCount

Returns:

  • (Fixnum)


15626
15627
15628
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15626

def max_parallel_trial_count
  @max_parallel_trial_count
end

#max_trial_countFixnum

Required. The maximum number of Neural Architecture Search (NAS) trials to run. Corresponds to the JSON property maxTrialCount

Returns:

  • (Fixnum)


15631
15632
15633
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15631

def max_trial_count
  @max_trial_count
end

#search_trial_job_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1CustomJobSpec

Represents the spec of a CustomJob. Corresponds to the JSON property searchTrialJobSpec



15636
15637
15638
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15636

def search_trial_job_spec
  @search_trial_job_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15643
15644
15645
15646
15647
15648
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15643

def update!(**args)
  @max_failed_trial_count = args[:max_failed_trial_count] if args.key?(:max_failed_trial_count)
  @max_parallel_trial_count = args[:max_parallel_trial_count] if args.key?(:max_parallel_trial_count)
  @max_trial_count = args[:max_trial_count] if args.key?(:max_trial_count)
  @search_trial_job_spec = args[:search_trial_job_spec] if args.key?(:search_trial_job_spec)
end