Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborQuery
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborQuery
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A query to find a number of similar entities.
Instance Attribute Summary collapse
-
#embedding ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborQueryEmbedding
The embedding vector.
-
#entity_id ⇒ String
Optional.
-
#neighbor_count ⇒ Fixnum
Optional.
-
#numeric_filters ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborQueryNumericFilter>
Optional.
-
#parameters ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborQueryParameters
Parameters that can be overrided in each query to tune query latency and recall.
-
#per_crowding_attribute_neighbor_count ⇒ Fixnum
Optional.
-
#string_filters ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborQueryStringFilter>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1NearestNeighborQuery
constructor
A new instance of GoogleCloudAiplatformV1NearestNeighborQuery.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1NearestNeighborQuery
Returns a new instance of GoogleCloudAiplatformV1NearestNeighborQuery.
24199 24200 24201 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24199 def initialize(**args) update!(**args) end |
Instance Attribute Details
#embedding ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborQueryEmbedding
The embedding vector.
Corresponds to the JSON property embedding
24161 24162 24163 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24161 def @embedding end |
#entity_id ⇒ String
Optional. The entity id whose similar entities should be searched for. If
embedding is set, search will use embedding instead of entity_id.
Corresponds to the JSON property entityId
24167 24168 24169 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24167 def entity_id @entity_id end |
#neighbor_count ⇒ Fixnum
Optional. The number of similar entities to be retrieved from feature view for
each query.
Corresponds to the JSON property neighborCount
24173 24174 24175 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24173 def neighbor_count @neighbor_count end |
#numeric_filters ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborQueryNumericFilter>
Optional. The list of numeric filters.
Corresponds to the JSON property numericFilters
24178 24179 24180 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24178 def numeric_filters @numeric_filters end |
#parameters ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborQueryParameters
Parameters that can be overrided in each query to tune query latency and
recall.
Corresponds to the JSON property parameters
24184 24185 24186 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24184 def parameters @parameters end |
#per_crowding_attribute_neighbor_count ⇒ Fixnum
Optional. Crowding is a constraint on a neighbor list produced by nearest
neighbor search requiring that no more than
sper_crowding_attribute_neighbor_count of the k neighbors returned have the
same value of crowding_attribute. It's used for improving result diversity.
Corresponds to the JSON property perCrowdingAttributeNeighborCount
24192 24193 24194 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24192 def per_crowding_attribute_neighbor_count @per_crowding_attribute_neighbor_count end |
#string_filters ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborQueryStringFilter>
Optional. The list of string filters.
Corresponds to the JSON property stringFilters
24197 24198 24199 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24197 def string_filters @string_filters end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24204 24205 24206 24207 24208 24209 24210 24211 24212 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24204 def update!(**args) @embedding = args[:embedding] if args.key?(:embedding) @entity_id = args[:entity_id] if args.key?(:entity_id) @neighbor_count = args[:neighbor_count] if args.key?(:neighbor_count) @numeric_filters = args[:numeric_filters] if args.key?(:numeric_filters) @parameters = args[:parameters] if args.key?(:parameters) @per_crowding_attribute_neighbor_count = args[:per_crowding_attribute_neighbor_count] if args.key?(:per_crowding_attribute_neighbor_count) @string_filters = args[:string_filters] if args.key?(:string_filters) end |