Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborQuery
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborQuery
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A query to find a number of similar entities.
Instance Attribute Summary collapse
-
#embedding ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborQueryEmbedding
The embedding vector.
-
#entity_id ⇒ String
Optional.
-
#neighbor_count ⇒ Fixnum
Optional.
-
#numeric_filters ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborQueryNumericFilter>
Optional.
-
#parameters ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborQueryParameters
Parameters that can be overrided in each query to tune query latency and recall.
-
#per_crowding_attribute_neighbor_count ⇒ Fixnum
Optional.
-
#string_filters ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborQueryStringFilter>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1NearestNeighborQuery
constructor
A new instance of GoogleCloudAiplatformV1NearestNeighborQuery.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1NearestNeighborQuery
Returns a new instance of GoogleCloudAiplatformV1NearestNeighborQuery.
23992 23993 23994 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23992 def initialize(**args) update!(**args) end |
Instance Attribute Details
#embedding ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborQueryEmbedding
The embedding vector.
Corresponds to the JSON property embedding
23954 23955 23956 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23954 def @embedding end |
#entity_id ⇒ String
Optional. The entity id whose similar entities should be searched for. If
embedding is set, search will use embedding instead of entity_id.
Corresponds to the JSON property entityId
23960 23961 23962 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23960 def entity_id @entity_id end |
#neighbor_count ⇒ Fixnum
Optional. The number of similar entities to be retrieved from feature view for
each query.
Corresponds to the JSON property neighborCount
23966 23967 23968 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23966 def neighbor_count @neighbor_count end |
#numeric_filters ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborQueryNumericFilter>
Optional. The list of numeric filters.
Corresponds to the JSON property numericFilters
23971 23972 23973 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23971 def numeric_filters @numeric_filters end |
#parameters ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborQueryParameters
Parameters that can be overrided in each query to tune query latency and
recall.
Corresponds to the JSON property parameters
23977 23978 23979 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23977 def parameters @parameters end |
#per_crowding_attribute_neighbor_count ⇒ Fixnum
Optional. Crowding is a constraint on a neighbor list produced by nearest
neighbor search requiring that no more than
sper_crowding_attribute_neighbor_count of the k neighbors returned have the
same value of crowding_attribute. It's used for improving result diversity.
Corresponds to the JSON property perCrowdingAttributeNeighborCount
23985 23986 23987 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23985 def per_crowding_attribute_neighbor_count @per_crowding_attribute_neighbor_count end |
#string_filters ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborQueryStringFilter>
Optional. The list of string filters.
Corresponds to the JSON property stringFilters
23990 23991 23992 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23990 def string_filters @string_filters end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23997 23998 23999 24000 24001 24002 24003 24004 24005 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23997 def update!(**args) @embedding = args[:embedding] if args.key?(:embedding) @entity_id = args[:entity_id] if args.key?(:entity_id) @neighbor_count = args[:neighbor_count] if args.key?(:neighbor_count) @numeric_filters = args[:numeric_filters] if args.key?(:numeric_filters) @parameters = args[:parameters] if args.key?(:parameters) @per_crowding_attribute_neighbor_count = args[:per_crowding_attribute_neighbor_count] if args.key?(:per_crowding_attribute_neighbor_count) @string_filters = args[:string_filters] if args.key?(:string_filters) end |