Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborQuery

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A query to find a number of similar entities.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1NearestNeighborQuery

Returns a new instance of GoogleCloudAiplatformV1NearestNeighborQuery.



19751
19752
19753
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19751

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#embeddingGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborQueryEmbedding

The embedding vector. Corresponds to the JSON property embedding



19713
19714
19715
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19713

def embedding
  @embedding
end

#entity_idString

Optional. The entity id whose similar entities should be searched for. If embedding is set, search will use embedding instead of entity_id. Corresponds to the JSON property entityId

Returns:

  • (String)


19719
19720
19721
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19719

def entity_id
  @entity_id
end

#neighbor_countFixnum

Optional. The number of similar entities to be retrieved from feature view for each query. Corresponds to the JSON property neighborCount

Returns:

  • (Fixnum)


19725
19726
19727
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19725

def neighbor_count
  @neighbor_count
end

#numeric_filtersArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborQueryNumericFilter>

Optional. The list of numeric filters. Corresponds to the JSON property numericFilters



19730
19731
19732
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19730

def numeric_filters
  @numeric_filters
end

#parametersGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborQueryParameters

Parameters that can be overrided in each query to tune query latency and recall. Corresponds to the JSON property parameters



19736
19737
19738
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19736

def parameters
  @parameters
end

#per_crowding_attribute_neighbor_countFixnum

Optional. Crowding is a constraint on a neighbor list produced by nearest neighbor search requiring that no more than sper_crowding_attribute_neighbor_count of the k neighbors returned have the same value of crowding_attribute. It's used for improving result diversity. Corresponds to the JSON property perCrowdingAttributeNeighborCount

Returns:

  • (Fixnum)


19744
19745
19746
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19744

def per_crowding_attribute_neighbor_count
  @per_crowding_attribute_neighbor_count
end

#string_filtersArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborQueryStringFilter>

Optional. The list of string filters. Corresponds to the JSON property stringFilters



19749
19750
19751
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19749

def string_filters
  @string_filters
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19756
19757
19758
19759
19760
19761
19762
19763
19764
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19756

def update!(**args)
  @embedding = args[:embedding] if args.key?(:embedding)
  @entity_id = args[:entity_id] if args.key?(:entity_id)
  @neighbor_count = args[:neighbor_count] if args.key?(:neighbor_count)
  @numeric_filters = args[:numeric_filters] if args.key?(:numeric_filters)
  @parameters = args[:parameters] if args.key?(:parameters)
  @per_crowding_attribute_neighbor_count = args[:per_crowding_attribute_neighbor_count] if args.key?(:per_crowding_attribute_neighbor_count)
  @string_filters = args[:string_filters] if args.key?(:string_filters)
end