Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborQuery

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A query to find a number of similar entities.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1NearestNeighborQuery

Returns a new instance of GoogleCloudAiplatformV1NearestNeighborQuery.



15807
15808
15809
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15807

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#embeddingGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborQueryEmbedding

The embedding vector. Corresponds to the JSON property embedding



15774
15775
15776
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15774

def embedding
  @embedding
end

#entity_idString

Optional. The entity id whose similar entities should be searched for. If embedding is set, search will use embedding instead of entity_id. Corresponds to the JSON property entityId

Returns:

  • (String)


15780
15781
15782
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15780

def entity_id
  @entity_id
end

#neighbor_countFixnum

Optional. The number of similar entities to be retrieved from feature view for each query. Corresponds to the JSON property neighborCount

Returns:

  • (Fixnum)


15786
15787
15788
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15786

def neighbor_count
  @neighbor_count
end

#parametersGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborQueryParameters

Parameters that can be overrided in each query to tune query latency and recall. Corresponds to the JSON property parameters



15792
15793
15794
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15792

def parameters
  @parameters
end

#per_crowding_attribute_neighbor_countFixnum

Optional. Crowding is a constraint on a neighbor list produced by nearest neighbor search requiring that no more than sper_crowding_attribute_neighbor_count of the k neighbors returned have the same value of crowding_attribute. It's used for improving result diversity. Corresponds to the JSON property perCrowdingAttributeNeighborCount

Returns:

  • (Fixnum)


15800
15801
15802
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15800

def per_crowding_attribute_neighbor_count
  @per_crowding_attribute_neighbor_count
end

#string_filtersArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborQueryStringFilter>

Optional. The list of string filters. Corresponds to the JSON property stringFilters



15805
15806
15807
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15805

def string_filters
  @string_filters
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15812
15813
15814
15815
15816
15817
15818
15819
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15812

def update!(**args)
  @embedding = args[:embedding] if args.key?(:embedding)
  @entity_id = args[:entity_id] if args.key?(:entity_id)
  @neighbor_count = args[:neighbor_count] if args.key?(:neighbor_count)
  @parameters = args[:parameters] if args.key?(:parameters)
  @per_crowding_attribute_neighbor_count = args[:per_crowding_attribute_neighbor_count] if args.key?(:per_crowding_attribute_neighbor_count)
  @string_filters = args[:string_filters] if args.key?(:string_filters)
end