Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborQueryParameters
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborQueryParameters
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Parameters that can be overrided in each query to tune query latency and recall.
Instance Attribute Summary collapse
-
#approximate_neighbor_candidates ⇒ Fixnum
Optional.
-
#leaf_nodes_search_fraction ⇒ Float
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1NearestNeighborQueryParameters
constructor
A new instance of GoogleCloudAiplatformV1NearestNeighborQueryParameters.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1NearestNeighborQueryParameters
Returns a new instance of GoogleCloudAiplatformV1NearestNeighborQueryParameters.
18863 18864 18865 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18863 def initialize(**args) update!(**args) end |
Instance Attribute Details
#approximate_neighbor_candidates ⇒ Fixnum
Optional. The number of neighbors to find via approximate search before exact
reordering is performed; if set, this value must be > neighbor_count.
Corresponds to the JSON property approximateNeighborCandidates
18854 18855 18856 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18854 def approximate_neighbor_candidates @approximate_neighbor_candidates end |
#leaf_nodes_search_fraction ⇒ Float
Optional. The fraction of the number of leaves to search, set at query time
allows user to tune search performance. This value increase result in both
search accuracy and latency increase. The value should be between 0.0 and 1.0.
Corresponds to the JSON property leafNodesSearchFraction
18861 18862 18863 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18861 def leaf_nodes_search_fraction @leaf_nodes_search_fraction end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18868 18869 18870 18871 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18868 def update!(**args) @approximate_neighbor_candidates = args[:approximate_neighbor_candidates] if args.key?(:approximate_neighbor_candidates) @leaf_nodes_search_fraction = args[:leaf_nodes_search_fraction] if args.key?(:leaf_nodes_search_fraction) end |