Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborQueryParameters

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Parameters that can be overrided in each query to tune query latency and recall.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1NearestNeighborQueryParameters

Returns a new instance of GoogleCloudAiplatformV1NearestNeighborQueryParameters.



16811
16812
16813
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16811

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#approximate_neighbor_candidatesFixnum

Optional. The number of neighbors to find via approximate search before exact reordering is performed; if set, this value must be > neighbor_count. Corresponds to the JSON property approximateNeighborCandidates

Returns:

  • (Fixnum)


16802
16803
16804
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16802

def approximate_neighbor_candidates
  @approximate_neighbor_candidates
end

#leaf_nodes_search_fractionFloat

Optional. The fraction of the number of leaves to search, set at query time allows user to tune search performance. This value increase result in both search accuracy and latency increase. The value should be between 0.0 and 1.0. Corresponds to the JSON property leafNodesSearchFraction

Returns:

  • (Float)


16809
16810
16811
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16809

def leaf_nodes_search_fraction
  @leaf_nodes_search_fraction
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16816
16817
16818
16819
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16816

def update!(**args)
  @approximate_neighbor_candidates = args[:approximate_neighbor_candidates] if args.key?(:approximate_neighbor_candidates)
  @leaf_nodes_search_fraction = args[:leaf_nodes_search_fraction] if args.key?(:leaf_nodes_search_fraction)
end