Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborSearchOperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Runtime operation metadata with regard to Matching Engine Index.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1NearestNeighborSearchOperationMetadata

Returns a new instance of GoogleCloudAiplatformV1NearestNeighborSearchOperationMetadata.



26735
26736
26737
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26735

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#content_validation_statsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborSearchOperationMetadataContentValidationStats>

The validation stats of the content (per file) to be inserted or updated on the Matching Engine Index resource. Populated if contentsDeltaUri is provided as part of Index.metadata. Please note that, currently for those files that are broken or has unsupported file format, we will not have the stats for those files. Corresponds to the JSON property contentValidationStats



26728
26729
26730
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26728

def content_validation_stats
  @content_validation_stats
end

#data_bytes_countFixnum

The ingested data size in bytes. Corresponds to the JSON property dataBytesCount

Returns:

  • (Fixnum)


26733
26734
26735
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26733

def data_bytes_count
  @data_bytes_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26740
26741
26742
26743
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26740

def update!(**args)
  @content_validation_stats = args[:content_validation_stats] if args.key?(:content_validation_stats)
  @data_bytes_count = args[:data_bytes_count] if args.key?(:data_bytes_count)
end