Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborSearchOperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborSearchOperationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Runtime operation metadata with regard to Matching Engine Index.
Instance Attribute Summary collapse
-
#content_validation_stats ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborSearchOperationMetadataContentValidationStats>
The validation stats of the content (per file) to be inserted or updated on the Matching Engine Index resource.
-
#data_bytes_count ⇒ Fixnum
The ingested data size in bytes.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1NearestNeighborSearchOperationMetadata
constructor
A new instance of GoogleCloudAiplatformV1NearestNeighborSearchOperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1NearestNeighborSearchOperationMetadata
Returns a new instance of GoogleCloudAiplatformV1NearestNeighborSearchOperationMetadata.
24368 24369 24370 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24368 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content_validation_stats ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborSearchOperationMetadataContentValidationStats>
The validation stats of the content (per file) to be inserted or updated on
the Matching Engine Index resource. Populated if contentsDeltaUri is provided
as part of Index.metadata. Please note that, currently for those files that
are broken or has unsupported file format, we will not have the stats for
those files.
Corresponds to the JSON property contentValidationStats
24361 24362 24363 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24361 def content_validation_stats @content_validation_stats end |
#data_bytes_count ⇒ Fixnum
The ingested data size in bytes.
Corresponds to the JSON property dataBytesCount
24366 24367 24368 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24366 def data_bytes_count @data_bytes_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24373 24374 24375 24376 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24373 def update!(**args) @content_validation_stats = args[:content_validation_stats] if args.key?(:content_validation_stats) @data_bytes_count = args[:data_bytes_count] if args.key?(:data_bytes_count) end |