Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborSearchOperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Runtime operation metadata with regard to Matching Engine Index.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1NearestNeighborSearchOperationMetadata

Returns a new instance of GoogleCloudAiplatformV1NearestNeighborSearchOperationMetadata.



19482
19483
19484
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19482

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#content_validation_statsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborSearchOperationMetadataContentValidationStats>

The validation stats of the content (per file) to be inserted or updated on the Matching Engine Index resource. Populated if contentsDeltaUri is provided as part of Index.metadata. Please note that, currently for those files that are broken or has unsupported file format, we will not have the stats for those files. Corresponds to the JSON property contentValidationStats



19475
19476
19477
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19475

def content_validation_stats
  @content_validation_stats
end

#data_bytes_countFixnum

The ingested data size in bytes. Corresponds to the JSON property dataBytesCount

Returns:

  • (Fixnum)


19480
19481
19482
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19480

def data_bytes_count
  @data_bytes_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19487
19488
19489
19490
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19487

def update!(**args)
  @content_validation_stats = args[:content_validation_stats] if args.key?(:content_validation_stats)
  @data_bytes_count = args[:data_bytes_count] if args.key?(:data_bytes_count)
end