Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborSearchOperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Runtime operation metadata with regard to Matching Engine Index.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1NearestNeighborSearchOperationMetadata

Returns a new instance of GoogleCloudAiplatformV1NearestNeighborSearchOperationMetadata.



15925
15926
15927
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15925

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#content_validation_statsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborSearchOperationMetadataContentValidationStats>

The validation stats of the content (per file) to be inserted or updated on the Matching Engine Index resource. Populated if contentsDeltaUri is provided as part of Index.metadata. Please note that, currently for those files that are broken or has unsupported file format, we will not have the stats for those files. Corresponds to the JSON property contentValidationStats



15918
15919
15920
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15918

def content_validation_stats
  @content_validation_stats
end

#data_bytes_countFixnum

The ingested data size in bytes. Corresponds to the JSON property dataBytesCount

Returns:

  • (Fixnum)


15923
15924
15925
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15923

def data_bytes_count
  @data_bytes_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15930
15931
15932
15933
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15930

def update!(**args)
  @content_validation_stats = args[:content_validation_stats] if args.key?(:content_validation_stats)
  @data_bytes_count = args[:data_bytes_count] if args.key?(:data_bytes_count)
end