Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NetworkSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NetworkSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Network spec.
Instance Attribute Summary collapse
-
#enable_internet_access ⇒ Boolean
(also: #enable_internet_access?)
Whether to enable public internet access.
-
#network ⇒ String
The full name of the Google Compute Engine network Corresponds to the JSON property
network. -
#subnetwork ⇒ String
The name of the subnet that this instance is in.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1NetworkSpec
constructor
A new instance of GoogleCloudAiplatformV1NetworkSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1NetworkSpec
Returns a new instance of GoogleCloudAiplatformV1NetworkSpec.
20123 20124 20125 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20123 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable_internet_access ⇒ Boolean Also known as: enable_internet_access?
Whether to enable public internet access. Default false.
Corresponds to the JSON property enableInternetAccess
20108 20109 20110 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20108 def enable_internet_access @enable_internet_access end |
#network ⇒ String
The full name of the Google Compute Engine network
Corresponds to the JSON property network
20115 20116 20117 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20115 def network @network end |
#subnetwork ⇒ String
The name of the subnet that this instance is in. Format: projects/
project_id_or_number/regions/region/subnetworks/subnetwork_id`
Corresponds to the JSON propertysubnetwork`
20121 20122 20123 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20121 def subnetwork @subnetwork end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20128 20129 20130 20131 20132 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20128 def update!(**args) @enable_internet_access = args[:enable_internet_access] if args.key?(:enable_internet_access) @network = args[:network] if args.key?(:network) @subnetwork = args[:subnetwork] if args.key?(:subnetwork) end |