Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NetworkSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Network spec.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1NetworkSpec

Returns a new instance of GoogleCloudAiplatformV1NetworkSpec.



16443
16444
16445
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16443

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_internet_accessBoolean Also known as: enable_internet_access?

Whether to enable public internet access. Default false. Corresponds to the JSON property enableInternetAccess

Returns:

  • (Boolean)


16428
16429
16430
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16428

def enable_internet_access
  @enable_internet_access
end

#networkString

The full name of the Google Compute Engine network Corresponds to the JSON property network

Returns:

  • (String)


16435
16436
16437
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16435

def network
  @network
end

#subnetworkString

The name of the subnet that this instance is in. Format: projects/ project_id_or_number/regions/region/subnetworks/subnetwork_id` Corresponds to the JSON propertysubnetwork`

Returns:

  • (String)


16441
16442
16443
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16441

def subnetwork
  @subnetwork
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16448
16449
16450
16451
16452
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16448

def update!(**args)
  @enable_internet_access = args[:enable_internet_access] if args.key?(:enable_internet_access)
  @network = args[:network] if args.key?(:network)
  @subnetwork = args[:subnetwork] if args.key?(:subnetwork)
end