Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NfsMount
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NfsMount
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Represents a mount configuration for Network File System (NFS) to mount.
Instance Attribute Summary collapse
-
#mount_point ⇒ String
Required.
-
#path ⇒ String
Required.
-
#server ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1NfsMount
constructor
A new instance of GoogleCloudAiplatformV1NfsMount.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1NfsMount
Returns a new instance of GoogleCloudAiplatformV1NfsMount.
24398 24399 24400 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24398 def initialize(**args) update!(**args) end |
Instance Attribute Details
#mount_point ⇒ String
Required. Destination mount path. The NFS will be mounted for the user under /
mnt/nfs/
Corresponds to the JSON property mountPoint
24384 24385 24386 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24384 def mount_point @mount_point end |
#path ⇒ String
Required. Source path exported from NFS server. Has to start with '/', and
combined with the ip address, it indicates the source mount path in the form
of server:path
Corresponds to the JSON property path
24391 24392 24393 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24391 def path @path end |
#server ⇒ String
Required. IP address of the NFS server.
Corresponds to the JSON property server
24396 24397 24398 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24396 def server @server end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24403 24404 24405 24406 24407 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24403 def update!(**args) @mount_point = args[:mount_point] if args.key?(:mount_point) @path = args[:path] if args.key?(:path) @server = args[:server] if args.key?(:server) end |