Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NfsMount

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents a mount configuration for Network File System (NFS) to mount.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1NfsMount

Returns a new instance of GoogleCloudAiplatformV1NfsMount.



19800
19801
19802
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19800

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#mount_pointString

Required. Destination mount path. The NFS will be mounted for the user under / mnt/nfs/ Corresponds to the JSON property mountPoint

Returns:

  • (String)


19786
19787
19788
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19786

def mount_point
  @mount_point
end

#pathString

Required. Source path exported from NFS server. Has to start with '/', and combined with the ip address, it indicates the source mount path in the form of server:path Corresponds to the JSON property path

Returns:

  • (String)


19793
19794
19795
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19793

def path
  @path
end

#serverString

Required. IP address of the NFS server. Corresponds to the JSON property server

Returns:

  • (String)


19798
19799
19800
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19798

def server
  @server
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19805
19806
19807
19808
19809
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19805

def update!(**args)
  @mount_point = args[:mount_point] if args.key?(:mount_point)
  @path = args[:path] if args.key?(:path)
  @server = args[:server] if args.key?(:server)
end