Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NfsMount
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NfsMount
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Represents a mount configuration for Network File System (NFS) to mount.
Instance Attribute Summary collapse
-
#mount_point ⇒ String
Required.
-
#path ⇒ String
Required.
-
#server ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1NfsMount
constructor
A new instance of GoogleCloudAiplatformV1NfsMount.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1NfsMount
Returns a new instance of GoogleCloudAiplatformV1NfsMount.
19341 19342 19343 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19341 def initialize(**args) update!(**args) end |
Instance Attribute Details
#mount_point ⇒ String
Required. Destination mount path. The NFS will be mounted for the user under /
mnt/nfs/
Corresponds to the JSON property mountPoint
19327 19328 19329 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19327 def mount_point @mount_point end |
#path ⇒ String
Required. Source path exported from NFS server. Has to start with '/', and
combined with the ip address, it indicates the source mount path in the form
of server:path
Corresponds to the JSON property path
19334 19335 19336 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19334 def path @path end |
#server ⇒ String
Required. IP address of the NFS server.
Corresponds to the JSON property server
19339 19340 19341 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19339 def server @server end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19346 19347 19348 19349 19350 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19346 def update!(**args) @mount_point = args[:mount_point] if args.key?(:mount_point) @path = args[:path] if args.key?(:path) @server = args[:server] if args.key?(:server) end |