Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookEucConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookEucConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The euc configuration of NotebookRuntimeTemplate.
Instance Attribute Summary collapse
-
#bypass_actas_check ⇒ Boolean
(also: #bypass_actas_check?)
Output only.
-
#euc_disabled ⇒ Boolean
(also: #euc_disabled?)
Input only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1NotebookEucConfig
constructor
A new instance of GoogleCloudAiplatformV1NotebookEucConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1NotebookEucConfig
Returns a new instance of GoogleCloudAiplatformV1NotebookEucConfig.
20539 20540 20541 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20539 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bypass_actas_check ⇒ Boolean Also known as: bypass_actas_check?
Output only. Whether ActAs check is bypassed for service account attached to
the VM. If false, we need ActAs check for the default Compute Engine Service
account. When a Runtime is created, a VM is allocated using Default Compute
Engine Service Account. Any user requesting to use this Runtime requires
Service Account User (ActAs) permission over this SA. If true, Runtime owner
is using EUC and does not require the above permission as VM no longer use
default Compute Engine SA, but a P4SA.
Corresponds to the JSON property bypassActasCheck
20528 20529 20530 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20528 def bypass_actas_check @bypass_actas_check end |
#euc_disabled ⇒ Boolean Also known as: euc_disabled?
Input only. Whether EUC is disabled in this NotebookRuntimeTemplate. In proto3,
the default value of a boolean is false. In this way, by default EUC will be
enabled for NotebookRuntimeTemplate.
Corresponds to the JSON property eucDisabled
20536 20537 20538 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20536 def euc_disabled @euc_disabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20544 20545 20546 20547 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20544 def update!(**args) @bypass_actas_check = args[:bypass_actas_check] if args.key?(:bypass_actas_check) @euc_disabled = args[:euc_disabled] if args.key?(:euc_disabled) end |