Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookEucConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The euc configuration of NotebookRuntimeTemplate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1NotebookEucConfig

Returns a new instance of GoogleCloudAiplatformV1NotebookEucConfig.



15104
15105
15106
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15104

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bypass_actas_checkBoolean Also known as: bypass_actas_check?

Output only. Whether ActAs check is bypassed for service account attached to the VM. If false, we need ActAs check for the default Compute Engine Service account. When a Runtime is created, a VM is allocated using Default Compute Engine Service Account. Any user requesting to use this Runtime requires Service Account User (ActAs) permission over this SA. If true, Runtime owner is using EUC and does not require the above permission as VM no longer use default Compute Engine SA, but a P4SA. Corresponds to the JSON property bypassActasCheck

Returns:

  • (Boolean)


15093
15094
15095
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15093

def bypass_actas_check
  @bypass_actas_check
end

#euc_disabledBoolean Also known as: euc_disabled?

Input only. Whether EUC is disabled in this NotebookRuntimeTemplate. In proto3, the default value of a boolean is false. In this way, by default EUC will be enabled for NotebookRuntimeTemplate. Corresponds to the JSON property eucDisabled

Returns:

  • (Boolean)


15101
15102
15103
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15101

def euc_disabled
  @euc_disabled
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15109
15110
15111
15112
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15109

def update!(**args)
  @bypass_actas_check = args[:bypass_actas_check] if args.key?(:bypass_actas_check)
  @euc_disabled = args[:euc_disabled] if args.key?(:euc_disabled)
end