Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookExecutionJob
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookExecutionJob
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
NotebookExecutionJob represents an instance of a notebook execution.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#custom_environment_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookExecutionJobCustomEnvironmentSpec
Compute configuration to use for an execution job.
-
#dataform_repository_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookExecutionJobDataformRepositorySource
The Dataform Repository containing the input notebook.
-
#direct_notebook_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookExecutionJobDirectNotebookSource
The content of the input notebook in ipynb format.
-
#display_name ⇒ String
The display name of the NotebookExecutionJob.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.
-
#execution_timeout ⇒ String
Max running time of the execution job in seconds (default 86400s / 24 hrs).
-
#execution_user ⇒ String
The user email to run the execution as.
-
#gcs_notebook_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookExecutionJobGcsNotebookSource
The Cloud Storage uri for the input notebook.
-
#gcs_output_uri ⇒ String
The Cloud Storage location to upload the result to.
-
#job_state ⇒ String
Output only.
-
#kernel_name ⇒ String
The name of the kernel to use during notebook execution.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize NotebookExecutionJobs.
-
#name ⇒ String
Output only.
-
#notebook_runtime_template_resource_name ⇒ String
The NotebookRuntimeTemplate to source compute configuration from.
-
#schedule_resource_name ⇒ String
The Schedule resource name if this job is triggered by one.
-
#service_account ⇒ String
The service account to run the execution as.
-
#status ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#update_time ⇒ String
Output only.
-
#workbench_runtime ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookExecutionJobWorkbenchRuntime
Configuration for a Workbench Instances-based environment.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1NotebookExecutionJob
constructor
A new instance of GoogleCloudAiplatformV1NotebookExecutionJob.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1NotebookExecutionJob
Returns a new instance of GoogleCloudAiplatformV1NotebookExecutionJob.
27139 27140 27141 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27139 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this NotebookExecutionJob was created.
Corresponds to the JSON property createTime
27026 27027 27028 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27026 def create_time @create_time end |
#custom_environment_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookExecutionJobCustomEnvironmentSpec
Compute configuration to use for an execution job.
Corresponds to the JSON property customEnvironmentSpec
27031 27032 27033 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27031 def custom_environment_spec @custom_environment_spec end |
#dataform_repository_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookExecutionJobDataformRepositorySource
The Dataform Repository containing the input notebook.
Corresponds to the JSON property dataformRepositorySource
27036 27037 27038 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27036 def dataform_repository_source @dataform_repository_source end |
#direct_notebook_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookExecutionJobDirectNotebookSource
The content of the input notebook in ipynb format.
Corresponds to the JSON property directNotebookSource
27041 27042 27043 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27041 def direct_notebook_source @direct_notebook_source end |
#display_name ⇒ String
The display name of the NotebookExecutionJob. The name can be up to 128
characters long and can consist of any UTF-8 characters.
Corresponds to the JSON property displayName
27047 27048 27049 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27047 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied
to a Vertex AI resource.
Corresponds to the JSON property encryptionSpec
27053 27054 27055 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27053 def encryption_spec @encryption_spec end |
#execution_timeout ⇒ String
Max running time of the execution job in seconds (default 86400s / 24 hrs).
Corresponds to the JSON property executionTimeout
27058 27059 27060 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27058 def execution_timeout @execution_timeout end |
#execution_user ⇒ String
The user email to run the execution as. Only supported by Colab runtimes.
Corresponds to the JSON property executionUser
27063 27064 27065 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27063 def execution_user @execution_user end |
#gcs_notebook_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookExecutionJobGcsNotebookSource
The Cloud Storage uri for the input notebook.
Corresponds to the JSON property gcsNotebookSource
27068 27069 27070 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27068 def gcs_notebook_source @gcs_notebook_source end |
#gcs_output_uri ⇒ String
The Cloud Storage location to upload the result to. Format: gs://bucket-name
Corresponds to the JSON property gcsOutputUri
27073 27074 27075 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27073 def gcs_output_uri @gcs_output_uri end |
#job_state ⇒ String
Output only. The state of the NotebookExecutionJob.
Corresponds to the JSON property jobState
27078 27079 27080 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27078 def job_state @job_state end |
#kernel_name ⇒ String
The name of the kernel to use during notebook execution. If unset, the default
kernel is used.
Corresponds to the JSON property kernelName
27084 27085 27086 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27084 def kernel_name @kernel_name end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize NotebookExecutionJobs. Label
keys and values can be no longer than 64 characters (Unicode codepoints), can
only contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. See https://goo.gl/xmQnxf for more
information and examples of labels. System reserved label keys are prefixed
with "aiplatform.googleapis.com/" and are immutable.
Corresponds to the JSON property labels
27094 27095 27096 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27094 def labels @labels end |
#name ⇒ String
Output only. The resource name of this NotebookExecutionJob. Format: projects/
project_id/locations/location/notebookExecutionJobs/job_id`
Corresponds to the JSON propertyname`
27100 27101 27102 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27100 def name @name end |
#notebook_runtime_template_resource_name ⇒ String
The NotebookRuntimeTemplate to source compute configuration from.
Corresponds to the JSON property notebookRuntimeTemplateResourceName
27105 27106 27107 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27105 def notebook_runtime_template_resource_name @notebook_runtime_template_resource_name end |
#schedule_resource_name ⇒ String
The Schedule resource name if this job is triggered by one. Format: projects/
project_id/locations/location/schedules/schedule_id`
Corresponds to the JSON propertyscheduleResourceName`
27111 27112 27113 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27111 def schedule_resource_name @schedule_resource_name end |
#service_account ⇒ String
The service account to run the execution as.
Corresponds to the JSON property serviceAccount
27116 27117 27118 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27116 def service_account @service_account end |
#status ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property status
27126 27127 27128 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27126 def status @status end |
#update_time ⇒ String
Output only. Timestamp when this NotebookExecutionJob was most recently
updated.
Corresponds to the JSON property updateTime
27132 27133 27134 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27132 def update_time @update_time end |
#workbench_runtime ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookExecutionJobWorkbenchRuntime
Configuration for a Workbench Instances-based environment.
Corresponds to the JSON property workbenchRuntime
27137 27138 27139 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27137 def workbench_runtime @workbench_runtime end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27144 27145 27146 27147 27148 27149 27150 27151 27152 27153 27154 27155 27156 27157 27158 27159 27160 27161 27162 27163 27164 27165 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27144 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @custom_environment_spec = args[:custom_environment_spec] if args.key?(:custom_environment_spec) @dataform_repository_source = args[:dataform_repository_source] if args.key?(:dataform_repository_source) @direct_notebook_source = args[:direct_notebook_source] if args.key?(:direct_notebook_source) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @execution_timeout = args[:execution_timeout] if args.key?(:execution_timeout) @execution_user = args[:execution_user] if args.key?(:execution_user) @gcs_notebook_source = args[:gcs_notebook_source] if args.key?(:gcs_notebook_source) @gcs_output_uri = args[:gcs_output_uri] if args.key?(:gcs_output_uri) @job_state = args[:job_state] if args.key?(:job_state) @kernel_name = args[:kernel_name] if args.key?(:kernel_name) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @notebook_runtime_template_resource_name = args[:notebook_runtime_template_resource_name] if args.key?(:notebook_runtime_template_resource_name) @schedule_resource_name = args[:schedule_resource_name] if args.key?(:schedule_resource_name) @service_account = args[:service_account] if args.key?(:service_account) @status = args[:status] if args.key?(:status) @update_time = args[:update_time] if args.key?(:update_time) @workbench_runtime = args[:workbench_runtime] if args.key?(:workbench_runtime) end |