Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookExecutionJob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

NotebookExecutionJob represents an instance of a notebook execution.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1NotebookExecutionJob

Returns a new instance of GoogleCloudAiplatformV1NotebookExecutionJob.



25962
25963
25964
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25962

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this NotebookExecutionJob was created. Corresponds to the JSON property createTime

Returns:

  • (String)


25849
25850
25851
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25849

def create_time
  @create_time
end

#custom_environment_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookExecutionJobCustomEnvironmentSpec

Compute configuration to use for an execution job. Corresponds to the JSON property customEnvironmentSpec



25854
25855
25856
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25854

def custom_environment_spec
  @custom_environment_spec
end

#dataform_repository_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookExecutionJobDataformRepositorySource

The Dataform Repository containing the input notebook. Corresponds to the JSON property dataformRepositorySource



25859
25860
25861
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25859

def dataform_repository_source
  @dataform_repository_source
end

#direct_notebook_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookExecutionJobDirectNotebookSource

The content of the input notebook in ipynb format. Corresponds to the JSON property directNotebookSource



25864
25865
25866
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25864

def direct_notebook_source
  @direct_notebook_source
end

#display_nameString

The display name of the NotebookExecutionJob. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


25870
25871
25872
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25870

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



25876
25877
25878
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25876

def encryption_spec
  @encryption_spec
end

#execution_timeoutString

Max running time of the execution job in seconds (default 86400s / 24 hrs). Corresponds to the JSON property executionTimeout

Returns:

  • (String)


25881
25882
25883
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25881

def execution_timeout
  @execution_timeout
end

#execution_userString

The user email to run the execution as. Only supported by Colab runtimes. Corresponds to the JSON property executionUser

Returns:

  • (String)


25886
25887
25888
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25886

def execution_user
  @execution_user
end

#gcs_notebook_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookExecutionJobGcsNotebookSource

The Cloud Storage uri for the input notebook. Corresponds to the JSON property gcsNotebookSource



25891
25892
25893
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25891

def gcs_notebook_source
  @gcs_notebook_source
end

#gcs_output_uriString

The Cloud Storage location to upload the result to. Format: gs://bucket-name Corresponds to the JSON property gcsOutputUri

Returns:

  • (String)


25896
25897
25898
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25896

def gcs_output_uri
  @gcs_output_uri
end

#job_stateString

Output only. The state of the NotebookExecutionJob. Corresponds to the JSON property jobState

Returns:

  • (String)


25901
25902
25903
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25901

def job_state
  @job_state
end

#kernel_nameString

The name of the kernel to use during notebook execution. If unset, the default kernel is used. Corresponds to the JSON property kernelName

Returns:

  • (String)


25907
25908
25909
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25907

def kernel_name
  @kernel_name
end

#labelsHash<String,String>

The labels with user-defined metadata to organize NotebookExecutionJobs. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


25917
25918
25919
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25917

def labels
  @labels
end

#nameString

Output only. The resource name of this NotebookExecutionJob. Format: projects/ project_id/locations/location/notebookExecutionJobs/job_id` Corresponds to the JSON propertyname`

Returns:

  • (String)


25923
25924
25925
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25923

def name
  @name
end

#notebook_runtime_template_resource_nameString

The NotebookRuntimeTemplate to source compute configuration from. Corresponds to the JSON property notebookRuntimeTemplateResourceName

Returns:

  • (String)


25928
25929
25930
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25928

def notebook_runtime_template_resource_name
  @notebook_runtime_template_resource_name
end

#schedule_resource_nameString

The Schedule resource name if this job is triggered by one. Format: projects/ project_id/locations/location/schedules/schedule_id` Corresponds to the JSON propertyscheduleResourceName`

Returns:

  • (String)


25934
25935
25936
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25934

def schedule_resource_name
  @schedule_resource_name
end

#service_accountString

The service account to run the execution as. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


25939
25940
25941
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25939

def 
  @service_account
end

#statusGoogle::Apis::AiplatformV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property status



25949
25950
25951
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25949

def status
  @status
end

#update_timeString

Output only. Timestamp when this NotebookExecutionJob was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


25955
25956
25957
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25955

def update_time
  @update_time
end

#workbench_runtimeGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookExecutionJobWorkbenchRuntime

Configuration for a Workbench Instances-based environment. Corresponds to the JSON property workbenchRuntime



25960
25961
25962
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25960

def workbench_runtime
  @workbench_runtime
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25967
25968
25969
25970
25971
25972
25973
25974
25975
25976
25977
25978
25979
25980
25981
25982
25983
25984
25985
25986
25987
25988
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25967

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @custom_environment_spec = args[:custom_environment_spec] if args.key?(:custom_environment_spec)
  @dataform_repository_source = args[:dataform_repository_source] if args.key?(:dataform_repository_source)
  @direct_notebook_source = args[:direct_notebook_source] if args.key?(:direct_notebook_source)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @execution_timeout = args[:execution_timeout] if args.key?(:execution_timeout)
  @execution_user = args[:execution_user] if args.key?(:execution_user)
  @gcs_notebook_source = args[:gcs_notebook_source] if args.key?(:gcs_notebook_source)
  @gcs_output_uri = args[:gcs_output_uri] if args.key?(:gcs_output_uri)
  @job_state = args[:job_state] if args.key?(:job_state)
  @kernel_name = args[:kernel_name] if args.key?(:kernel_name)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @notebook_runtime_template_resource_name = args[:notebook_runtime_template_resource_name] if args.key?(:notebook_runtime_template_resource_name)
  @schedule_resource_name = args[:schedule_resource_name] if args.key?(:schedule_resource_name)
  @service_account = args[:service_account] if args.key?(:service_account)
  @status = args[:status] if args.key?(:status)
  @update_time = args[:update_time] if args.key?(:update_time)
  @workbench_runtime = args[:workbench_runtime] if args.key?(:workbench_runtime)
end