Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookExecutionJob
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookExecutionJob
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
NotebookExecutionJob represents an instance of a notebook execution.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#dataform_repository_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookExecutionJobDataformRepositorySource
The Dataform Repository containing the input notebook.
-
#direct_notebook_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookExecutionJobDirectNotebookSource
The content of the input notebook in ipynb format.
-
#display_name ⇒ String
The display name of the NotebookExecutionJob.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top- level resource.
-
#execution_timeout ⇒ String
Max running time of the execution job in seconds (default 86400s / 24 hrs).
-
#execution_user ⇒ String
The user email to run the execution as.
-
#gcs_notebook_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookExecutionJobGcsNotebookSource
The Cloud Storage uri for the input notebook.
-
#gcs_output_uri ⇒ String
The Cloud Storage location to upload the result to.
-
#job_state ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize NotebookExecutionJobs.
-
#name ⇒ String
Output only.
-
#notebook_runtime_template_resource_name ⇒ String
The NotebookRuntimeTemplate to source compute configuration from.
-
#schedule_resource_name ⇒ String
Output only.
-
#service_account ⇒ String
The service account to run the execution as.
-
#status ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1NotebookExecutionJob
constructor
A new instance of GoogleCloudAiplatformV1NotebookExecutionJob.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1NotebookExecutionJob
Returns a new instance of GoogleCloudAiplatformV1NotebookExecutionJob.
17362 17363 17364 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17362 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this NotebookExecutionJob was created.
Corresponds to the JSON property createTime
17265 17266 17267 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17265 def create_time @create_time end |
#dataform_repository_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookExecutionJobDataformRepositorySource
The Dataform Repository containing the input notebook.
Corresponds to the JSON property dataformRepositorySource
17270 17271 17272 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17270 def dataform_repository_source @dataform_repository_source end |
#direct_notebook_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookExecutionJobDirectNotebookSource
The content of the input notebook in ipynb format.
Corresponds to the JSON property directNotebookSource
17275 17276 17277 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17275 def direct_notebook_source @direct_notebook_source end |
#display_name ⇒ String
The display name of the NotebookExecutionJob. The name can be up to 128
characters long and can consist of any UTF-8 characters.
Corresponds to the JSON property displayName
17281 17282 17283 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17281 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top-
level resource.
Corresponds to the JSON property encryptionSpec
17287 17288 17289 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17287 def encryption_spec @encryption_spec end |
#execution_timeout ⇒ String
Max running time of the execution job in seconds (default 86400s / 24 hrs).
Corresponds to the JSON property executionTimeout
17292 17293 17294 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17292 def execution_timeout @execution_timeout end |
#execution_user ⇒ String
The user email to run the execution as. Only supported by Colab runtimes.
Corresponds to the JSON property executionUser
17297 17298 17299 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17297 def execution_user @execution_user end |
#gcs_notebook_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookExecutionJobGcsNotebookSource
The Cloud Storage uri for the input notebook.
Corresponds to the JSON property gcsNotebookSource
17302 17303 17304 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17302 def gcs_notebook_source @gcs_notebook_source end |
#gcs_output_uri ⇒ String
The Cloud Storage location to upload the result to. Format: gs://bucket-name
Corresponds to the JSON property gcsOutputUri
17307 17308 17309 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17307 def gcs_output_uri @gcs_output_uri end |
#job_state ⇒ String
Output only. The state of the NotebookExecutionJob.
Corresponds to the JSON property jobState
17312 17313 17314 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17312 def job_state @job_state end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize NotebookExecutionJobs. Label
keys and values can be no longer than 64 characters (Unicode codepoints), can
only contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. See https://goo.gl/xmQnxf for more
information and examples of labels. System reserved label keys are prefixed
with "aiplatform.googleapis.com/" and are immutable.
Corresponds to the JSON property labels
17322 17323 17324 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17322 def labels @labels end |
#name ⇒ String
Output only. The resource name of this NotebookExecutionJob. Format: projects/
project_id/locations/location/notebookExecutionJobs/job_id`
Corresponds to the JSON propertyname`
17328 17329 17330 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17328 def name @name end |
#notebook_runtime_template_resource_name ⇒ String
The NotebookRuntimeTemplate to source compute configuration from.
Corresponds to the JSON property notebookRuntimeTemplateResourceName
17333 17334 17335 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17333 def notebook_runtime_template_resource_name @notebook_runtime_template_resource_name end |
#schedule_resource_name ⇒ String
Output only. The Schedule resource name if this job is triggered by one.
Format: projects/project_id/locations/location/schedules/schedule_id`
Corresponds to the JSON propertyscheduleResourceName`
17339 17340 17341 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17339 def schedule_resource_name @schedule_resource_name end |
#service_account ⇒ String
The service account to run the execution as.
Corresponds to the JSON property serviceAccount
17344 17345 17346 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17344 def service_account @service_account end |
#status ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property status
17354 17355 17356 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17354 def status @status end |
#update_time ⇒ String
Output only. Timestamp when this NotebookExecutionJob was most recently
updated.
Corresponds to the JSON property updateTime
17360 17361 17362 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17360 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17367 17368 17369 17370 17371 17372 17373 17374 17375 17376 17377 17378 17379 17380 17381 17382 17383 17384 17385 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17367 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @dataform_repository_source = args[:dataform_repository_source] if args.key?(:dataform_repository_source) @direct_notebook_source = args[:direct_notebook_source] if args.key?(:direct_notebook_source) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @execution_timeout = args[:execution_timeout] if args.key?(:execution_timeout) @execution_user = args[:execution_user] if args.key?(:execution_user) @gcs_notebook_source = args[:gcs_notebook_source] if args.key?(:gcs_notebook_source) @gcs_output_uri = args[:gcs_output_uri] if args.key?(:gcs_output_uri) @job_state = args[:job_state] if args.key?(:job_state) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @notebook_runtime_template_resource_name = args[:notebook_runtime_template_resource_name] if args.key?(:notebook_runtime_template_resource_name) @schedule_resource_name = args[:schedule_resource_name] if args.key?(:schedule_resource_name) @service_account = args[:service_account] if args.key?(:service_account) @status = args[:status] if args.key?(:status) @update_time = args[:update_time] if args.key?(:update_time) end |