Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookExecutionJobCustomEnvironmentSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookExecutionJobCustomEnvironmentSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Compute configuration to use for an execution job.
Instance Attribute Summary collapse
-
#machine_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MachineSpec
Specification of a single machine.
-
#network_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NetworkSpec
Network spec.
-
#persistent_disk_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PersistentDiskSpec
Represents the spec of persistent disk and hyperdisk options.
-
#shielded_instance_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookExecutionJobCustomEnvironmentSpecShieldedInstanceConfig
A set of Shielded VM options for the execution VM.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1NotebookExecutionJobCustomEnvironmentSpec
constructor
A new instance of GoogleCloudAiplatformV1NotebookExecutionJobCustomEnvironmentSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1NotebookExecutionJobCustomEnvironmentSpec
Returns a new instance of GoogleCloudAiplatformV1NotebookExecutionJobCustomEnvironmentSpec.
27980 27981 27982 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27980 def initialize(**args) update!(**args) end |
Instance Attribute Details
#machine_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MachineSpec
Specification of a single machine.
Corresponds to the JSON property machineSpec
27961 27962 27963 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27961 def machine_spec @machine_spec end |
#network_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NetworkSpec
Network spec.
Corresponds to the JSON property networkSpec
27966 27967 27968 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27966 def network_spec @network_spec end |
#persistent_disk_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PersistentDiskSpec
Represents the spec of persistent disk and hyperdisk options.
Corresponds to the JSON property persistentDiskSpec
27971 27972 27973 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27971 def persistent_disk_spec @persistent_disk_spec end |
#shielded_instance_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookExecutionJobCustomEnvironmentSpecShieldedInstanceConfig
A set of Shielded VM options for the execution VM. Mirrors google.cloud.
notebooks.v2.ShieldedInstanceConfig. See https://cloud.google.com/compute/
docs/instances/modifying-shielded-vm.
Corresponds to the JSON property shieldedInstanceConfig
27978 27979 27980 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27978 def shielded_instance_config @shielded_instance_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27985 27986 27987 27988 27989 27990 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27985 def update!(**args) @machine_spec = args[:machine_spec] if args.key?(:machine_spec) @network_spec = args[:network_spec] if args.key?(:network_spec) @persistent_disk_spec = args[:persistent_disk_spec] if args.key?(:persistent_disk_spec) @shielded_instance_config = args[:shielded_instance_config] if args.key?(:shielded_instance_config) end |