Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookExecutionJobGcsNotebookSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The Cloud Storage uri for the input notebook.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1NotebookExecutionJobGcsNotebookSource

Returns a new instance of GoogleCloudAiplatformV1NotebookExecutionJobGcsNotebookSource.



19312
19313
19314
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19312

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#generationString

The version of the Cloud Storage object to read. If unset, the current version of the object is read. See https://cloud.google.com/storage/docs/metadata# generation-number. Corresponds to the JSON property generation

Returns:

  • (String)


19304
19305
19306
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19304

def generation
  @generation
end

#uriString

The Cloud Storage uri pointing to the ipynb file. Format: gs://bucket/ notebook_file.ipynb Corresponds to the JSON property uri

Returns:

  • (String)


19310
19311
19312
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19310

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19317
19318
19319
19320
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19317

def update!(**args)
  @generation = args[:generation] if args.key?(:generation)
  @uri = args[:uri] if args.key?(:uri)
end