Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookReservationAffinity
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookReservationAffinity
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Notebook Reservation Affinity for consuming Zonal reservation.
Instance Attribute Summary collapse
-
#consume_reservation_type ⇒ String
Required.
-
#key ⇒ String
Optional.
-
#values ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1NotebookReservationAffinity
constructor
A new instance of GoogleCloudAiplatformV1NotebookReservationAffinity.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1NotebookReservationAffinity
Returns a new instance of GoogleCloudAiplatformV1NotebookReservationAffinity.
20469 20470 20471 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20469 def initialize(**args) update!(**args) end |
Instance Attribute Details
#consume_reservation_type ⇒ String
Required. Specifies the type of reservation from which this instance can
consume resources: RESERVATION_ANY (default), RESERVATION_SPECIFIC, or
RESERVATION_NONE. See Consuming reserved instances for examples.
Corresponds to the JSON property consumeReservationType
20454 20455 20456 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20454 def consume_reservation_type @consume_reservation_type end |
#key ⇒ String
Optional. Corresponds to the label key of a reservation resource. To target a
RESERVATION_SPECIFIC by name, use compute.googleapis.com/reservation-name as
the key and specify the name of your reservation as its value.
Corresponds to the JSON property key
20461 20462 20463 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20461 def key @key end |
#values ⇒ Array<String>
Optional. Corresponds to the label values of a reservation resource. This must
be the full path name of Reservation.
Corresponds to the JSON property values
20467 20468 20469 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20467 def values @values end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20474 20475 20476 20477 20478 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20474 def update!(**args) @consume_reservation_type = args[:consume_reservation_type] if args.key?(:consume_reservation_type) @key = args[:key] if args.key?(:key) @values = args[:values] if args.key?(:values) end |