Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookRuntime
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookRuntime
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A runtime is a virtual machine allocated to a particular user for a particular Notebook file on temporary basis with lifetime. Default runtimes have a lifetime of 18 hours, while custom runtimes last for 6 months from their creation or last upgrade.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#data_persistent_disk_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PersistentDiskSpec
Represents the spec of persistent disk and hyperdisk options.
-
#description ⇒ String
The description of the NotebookRuntime.
-
#display_name ⇒ String
Required.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.
-
#euc_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookEucConfig
The euc configuration of NotebookRuntimeTemplate.
-
#expiration_time ⇒ String
Output only.
-
#health_state ⇒ String
Output only.
-
#idle_shutdown_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookIdleShutdownConfig
The idle shutdown configuration of NotebookRuntimeTemplate, which contains the idle_timeout as required field.
-
#is_upgradable ⇒ Boolean
(also: #is_upgradable?)
Output only.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your NotebookRuntime.
-
#machine_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MachineSpec
Specification of a single machine.
-
#name ⇒ String
Output only.
-
#network_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NetworkSpec
Network spec.
-
#network_tags ⇒ Array<String>
Optional.
-
#notebook_runtime_template_ref ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookRuntimeTemplateRef
Points to a NotebookRuntimeTemplateRef.
-
#notebook_runtime_type ⇒ String
Output only.
-
#proxy_uri ⇒ String
Output only.
-
#reservation_affinity ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookReservationAffinity
Notebook Reservation Affinity for consuming Zonal reservation.
-
#runtime_state ⇒ String
Output only.
-
#runtime_user ⇒ String
Required.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#service_account ⇒ String
Output only.
-
#shielded_vm_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ShieldedVmConfig
A set of Shielded Instance options.
-
#software_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookSoftwareConfig
Notebook Software Config.
-
#update_time ⇒ String
Output only.
-
#version ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1NotebookRuntime
constructor
A new instance of GoogleCloudAiplatformV1NotebookRuntime.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1NotebookRuntime
Returns a new instance of GoogleCloudAiplatformV1NotebookRuntime.
27947 27948 27949 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27947 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this NotebookRuntime was created.
Corresponds to the JSON property createTime
27779 27780 27781 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27779 def create_time @create_time end |
#data_persistent_disk_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PersistentDiskSpec
Represents the spec of persistent disk and hyperdisk options.
Corresponds to the JSON property dataPersistentDiskSpec
27784 27785 27786 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27784 def data_persistent_disk_spec @data_persistent_disk_spec end |
#description ⇒ String
The description of the NotebookRuntime.
Corresponds to the JSON property description
27789 27790 27791 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27789 def description @description end |
#display_name ⇒ String
Required. The display name of the NotebookRuntime. The name can be up to 128
characters long and can consist of any UTF-8 characters.
Corresponds to the JSON property displayName
27795 27796 27797 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27795 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied
to a Vertex AI resource.
Corresponds to the JSON property encryptionSpec
27801 27802 27803 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27801 def encryption_spec @encryption_spec end |
#euc_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookEucConfig
The euc configuration of NotebookRuntimeTemplate.
Corresponds to the JSON property eucConfig
27806 27807 27808 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27806 def euc_config @euc_config end |
#expiration_time ⇒ String
Output only. Timestamp when this NotebookRuntime will be expired: 1. System
Predefined NotebookRuntime: 24 hours after creation. After expiration, system
predifined runtime will be deleted. 2. User created NotebookRuntime: 6 months
after last upgrade. After expiration, user created runtime will be stopped and
allowed for upgrade.
Corresponds to the JSON property expirationTime
27815 27816 27817 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27815 def expiration_time @expiration_time end |
#health_state ⇒ String
Output only. The health state of the NotebookRuntime.
Corresponds to the JSON property healthState
27820 27821 27822 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27820 def health_state @health_state end |
#idle_shutdown_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookIdleShutdownConfig
The idle shutdown configuration of NotebookRuntimeTemplate, which contains the
idle_timeout as required field.
Corresponds to the JSON property idleShutdownConfig
27826 27827 27828 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27826 def idle_shutdown_config @idle_shutdown_config end |
#is_upgradable ⇒ Boolean Also known as: is_upgradable?
Output only. Whether NotebookRuntime is upgradable.
Corresponds to the JSON property isUpgradable
27831 27832 27833 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27831 def is_upgradable @is_upgradable end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your NotebookRuntime. Label
keys and values can be no longer than 64 characters (Unicode codepoints), can
only contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. No more than 64 user labels can be
associated with one NotebookRuntime (System labels are excluded). See https://
goo.gl/xmQnxf for more information and examples of labels. System reserved
label keys are prefixed with "aiplatform.googleapis.com/" and are immutable.
Following system labels exist for NotebookRuntime: * "aiplatform.googleapis.
com/notebook_runtime_gce_instance_id": output only, its value is the Compute
Engine instance id. * "aiplatform.googleapis.com/
colab_enterprise_entry_service": its value is either "bigquery" or "vertex";
if absent, it should be "vertex". This is to describe the entry service,
either BigQuery or Vertex.
Corresponds to the JSON property labels
27849 27850 27851 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27849 def labels @labels end |
#machine_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MachineSpec
Specification of a single machine.
Corresponds to the JSON property machineSpec
27854 27855 27856 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27854 def machine_spec @machine_spec end |
#name ⇒ String
Output only. The resource name of the NotebookRuntime.
Corresponds to the JSON property name
27859 27860 27861 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27859 def name @name end |
#network_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NetworkSpec
Network spec.
Corresponds to the JSON property networkSpec
27864 27865 27866 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27864 def network_spec @network_spec end |
#network_tags ⇒ Array<String>
Optional. The Compute Engine tags to add to runtime (see Tagging instances).
Corresponds to the JSON property networkTags
27870 27871 27872 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27870 def @network_tags end |
#notebook_runtime_template_ref ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookRuntimeTemplateRef
Points to a NotebookRuntimeTemplateRef.
Corresponds to the JSON property notebookRuntimeTemplateRef
27875 27876 27877 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27875 def notebook_runtime_template_ref @notebook_runtime_template_ref end |
#notebook_runtime_type ⇒ String
Output only. The type of the notebook runtime.
Corresponds to the JSON property notebookRuntimeType
27880 27881 27882 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27880 def notebook_runtime_type @notebook_runtime_type end |
#proxy_uri ⇒ String
Output only. The proxy endpoint used to access the NotebookRuntime.
Corresponds to the JSON property proxyUri
27885 27886 27887 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27885 def proxy_uri @proxy_uri end |
#reservation_affinity ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookReservationAffinity
Notebook Reservation Affinity for consuming Zonal reservation.
Corresponds to the JSON property reservationAffinity
27890 27891 27892 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27890 def reservation_affinity @reservation_affinity end |
#runtime_state ⇒ String
Output only. The runtime (instance) state of the NotebookRuntime.
Corresponds to the JSON property runtimeState
27895 27896 27897 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27895 def runtime_state @runtime_state end |
#runtime_user ⇒ String
Required. The user email of the NotebookRuntime.
Corresponds to the JSON property runtimeUser
27900 27901 27902 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27900 def runtime_user @runtime_user end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
27905 27906 27907 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27905 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
27911 27912 27913 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27911 def satisfies_pzs @satisfies_pzs end |
#service_account ⇒ String
Output only. Deprecated: This field is no longer used and the "Vertex AI
Notebook Service Account" (service-PROJECT_NUMBER@gcp-sa-aiplatform-vm.iam.
gserviceaccount.com) is used for the runtime workload identity. See https://
cloud.google.com/iam/docs/service-agents#vertex-ai-notebook-service-account
for more details. The service account that the NotebookRuntime workload runs
as.
Corresponds to the JSON property serviceAccount
27922 27923 27924 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27922 def service_account @service_account end |
#shielded_vm_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ShieldedVmConfig
A set of Shielded Instance options. See Images using supported Shielded VM
features.
Corresponds to the JSON property shieldedVmConfig
27929 27930 27931 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27929 def shielded_vm_config @shielded_vm_config end |
#software_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookSoftwareConfig
Notebook Software Config. This is passed to the backend when user makes
software configurations in UI.
Corresponds to the JSON property softwareConfig
27935 27936 27937 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27935 def software_config @software_config end |
#update_time ⇒ String
Output only. Timestamp when this NotebookRuntime was most recently updated.
Corresponds to the JSON property updateTime
27940 27941 27942 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27940 def update_time @update_time end |
#version ⇒ String
Output only. The VM os image version of NotebookRuntime.
Corresponds to the JSON property version
27945 27946 27947 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27945 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27952 27953 27954 27955 27956 27957 27958 27959 27960 27961 27962 27963 27964 27965 27966 27967 27968 27969 27970 27971 27972 27973 27974 27975 27976 27977 27978 27979 27980 27981 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27952 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @data_persistent_disk_spec = args[:data_persistent_disk_spec] if args.key?(:data_persistent_disk_spec) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @euc_config = args[:euc_config] if args.key?(:euc_config) @expiration_time = args[:expiration_time] if args.key?(:expiration_time) @health_state = args[:health_state] if args.key?(:health_state) @idle_shutdown_config = args[:idle_shutdown_config] if args.key?(:idle_shutdown_config) @is_upgradable = args[:is_upgradable] if args.key?(:is_upgradable) @labels = args[:labels] if args.key?(:labels) @machine_spec = args[:machine_spec] if args.key?(:machine_spec) @name = args[:name] if args.key?(:name) @network_spec = args[:network_spec] if args.key?(:network_spec) @network_tags = args[:network_tags] if args.key?(:network_tags) @notebook_runtime_template_ref = args[:notebook_runtime_template_ref] if args.key?(:notebook_runtime_template_ref) @notebook_runtime_type = args[:notebook_runtime_type] if args.key?(:notebook_runtime_type) @proxy_uri = args[:proxy_uri] if args.key?(:proxy_uri) @reservation_affinity = args[:reservation_affinity] if args.key?(:reservation_affinity) @runtime_state = args[:runtime_state] if args.key?(:runtime_state) @runtime_user = args[:runtime_user] if args.key?(:runtime_user) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @service_account = args[:service_account] if args.key?(:service_account) @shielded_vm_config = args[:shielded_vm_config] if args.key?(:shielded_vm_config) @software_config = args[:software_config] if args.key?(:software_config) @update_time = args[:update_time] if args.key?(:update_time) @version = args[:version] if args.key?(:version) end |