Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookRuntime
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookRuntime
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A runtime is a virtual machine allocated to a particular user for a particular Notebook file on temporary basis with lifetime limited to 24 hours.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#data_persistent_disk_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PersistentDiskSpec
Represents the spec of persistent disk options.
-
#description ⇒ String
The description of the NotebookRuntime.
-
#display_name ⇒ String
Required.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top- level resource.
-
#euc_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookEucConfig
The euc configuration of NotebookRuntimeTemplate.
-
#expiration_time ⇒ String
Output only.
-
#health_state ⇒ String
Output only.
-
#idle_shutdown_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookIdleShutdownConfig
The idle shutdown configuration of NotebookRuntimeTemplate, which contains the idle_timeout as required field.
-
#is_upgradable ⇒ Boolean
(also: #is_upgradable?)
Output only.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your NotebookRuntime.
-
#machine_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MachineSpec
Specification of a single machine.
-
#name ⇒ String
Output only.
-
#network_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NetworkSpec
Network spec.
-
#network_tags ⇒ Array<String>
Optional.
-
#notebook_runtime_template_ref ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookRuntimeTemplateRef
Points to a NotebookRuntimeTemplateRef.
-
#notebook_runtime_type ⇒ String
Output only.
-
#proxy_uri ⇒ String
Output only.
-
#reservation_affinity ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookReservationAffinity
Notebook Reservation Affinity for consuming Zonal reservation.
-
#runtime_state ⇒ String
Output only.
-
#runtime_user ⇒ String
Required.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#service_account ⇒ String
Output only.
-
#shielded_vm_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ShieldedVmConfig
A set of Shielded Instance options.
-
#software_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookSoftwareConfig
Notebook Software Config.
-
#update_time ⇒ String
Output only.
-
#version ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1NotebookRuntime
constructor
A new instance of GoogleCloudAiplatformV1NotebookRuntime.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1NotebookRuntime
Returns a new instance of GoogleCloudAiplatformV1NotebookRuntime.
19896 19897 19898 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19896 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this NotebookRuntime was created.
Corresponds to the JSON property createTime
19729 19730 19731 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19729 def create_time @create_time end |
#data_persistent_disk_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PersistentDiskSpec
Represents the spec of persistent disk options.
Corresponds to the JSON property dataPersistentDiskSpec
19734 19735 19736 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19734 def data_persistent_disk_spec @data_persistent_disk_spec end |
#description ⇒ String
The description of the NotebookRuntime.
Corresponds to the JSON property description
19739 19740 19741 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19739 def description @description end |
#display_name ⇒ String
Required. The display name of the NotebookRuntime. The name can be up to 128
characters long and can consist of any UTF-8 characters.
Corresponds to the JSON property displayName
19745 19746 19747 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19745 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top-
level resource.
Corresponds to the JSON property encryptionSpec
19751 19752 19753 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19751 def encryption_spec @encryption_spec end |
#euc_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookEucConfig
The euc configuration of NotebookRuntimeTemplate.
Corresponds to the JSON property eucConfig
19756 19757 19758 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19756 def euc_config @euc_config end |
#expiration_time ⇒ String
Output only. Timestamp when this NotebookRuntime will be expired: 1. System
Predefined NotebookRuntime: 24 hours after creation. After expiration, system
predifined runtime will be deleted. 2. User created NotebookRuntime: 6 months
after last upgrade. After expiration, user created runtime will be stopped and
allowed for upgrade.
Corresponds to the JSON property expirationTime
19765 19766 19767 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19765 def expiration_time @expiration_time end |
#health_state ⇒ String
Output only. The health state of the NotebookRuntime.
Corresponds to the JSON property healthState
19770 19771 19772 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19770 def health_state @health_state end |
#idle_shutdown_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookIdleShutdownConfig
The idle shutdown configuration of NotebookRuntimeTemplate, which contains the
idle_timeout as required field.
Corresponds to the JSON property idleShutdownConfig
19776 19777 19778 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19776 def idle_shutdown_config @idle_shutdown_config end |
#is_upgradable ⇒ Boolean Also known as: is_upgradable?
Output only. Whether NotebookRuntime is upgradable.
Corresponds to the JSON property isUpgradable
19781 19782 19783 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19781 def is_upgradable @is_upgradable end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your NotebookRuntime. Label
keys and values can be no longer than 64 characters (Unicode codepoints), can
only contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. No more than 64 user labels can be
associated with one NotebookRuntime (System labels are excluded). See https://
goo.gl/xmQnxf for more information and examples of labels. System reserved
label keys are prefixed with "aiplatform.googleapis.com/" and are immutable.
Following system labels exist for NotebookRuntime: * "aiplatform.googleapis.
com/notebook_runtime_gce_instance_id": output only, its value is the Compute
Engine instance id. * "aiplatform.googleapis.com/
colab_enterprise_entry_service": its value is either "bigquery" or "vertex";
if absent, it should be "vertex". This is to describe the entry service,
either BigQuery or Vertex.
Corresponds to the JSON property labels
19799 19800 19801 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19799 def labels @labels end |
#machine_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MachineSpec
Specification of a single machine.
Corresponds to the JSON property machineSpec
19804 19805 19806 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19804 def machine_spec @machine_spec end |
#name ⇒ String
Output only. The resource name of the NotebookRuntime.
Corresponds to the JSON property name
19809 19810 19811 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19809 def name @name end |
#network_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NetworkSpec
Network spec.
Corresponds to the JSON property networkSpec
19814 19815 19816 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19814 def network_spec @network_spec end |
#network_tags ⇒ Array<String>
Optional. The Compute Engine tags to add to runtime (see Tagging instances).
Corresponds to the JSON property networkTags
19820 19821 19822 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19820 def @network_tags end |
#notebook_runtime_template_ref ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookRuntimeTemplateRef
Points to a NotebookRuntimeTemplateRef.
Corresponds to the JSON property notebookRuntimeTemplateRef
19825 19826 19827 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19825 def notebook_runtime_template_ref @notebook_runtime_template_ref end |
#notebook_runtime_type ⇒ String
Output only. The type of the notebook runtime.
Corresponds to the JSON property notebookRuntimeType
19830 19831 19832 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19830 def notebook_runtime_type @notebook_runtime_type end |
#proxy_uri ⇒ String
Output only. The proxy endpoint used to access the NotebookRuntime.
Corresponds to the JSON property proxyUri
19835 19836 19837 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19835 def proxy_uri @proxy_uri end |
#reservation_affinity ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookReservationAffinity
Notebook Reservation Affinity for consuming Zonal reservation.
Corresponds to the JSON property reservationAffinity
19840 19841 19842 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19840 def reservation_affinity @reservation_affinity end |
#runtime_state ⇒ String
Output only. The runtime (instance) state of the NotebookRuntime.
Corresponds to the JSON property runtimeState
19845 19846 19847 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19845 def runtime_state @runtime_state end |
#runtime_user ⇒ String
Required. The user email of the NotebookRuntime.
Corresponds to the JSON property runtimeUser
19850 19851 19852 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19850 def runtime_user @runtime_user end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
19855 19856 19857 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19855 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
19861 19862 19863 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19861 def satisfies_pzs @satisfies_pzs end |
#service_account ⇒ String
Output only. Deprecated: This field is no longer used and the "Vertex AI
Notebook Service Account" (service-PROJECT_NUMBER@gcp-sa-aiplatform-vm.iam.
gserviceaccount.com) is used for the runtime workload identity. See https://
cloud.google.com/iam/docs/service-agents#vertex-ai-notebook-service-account
for more details. The service account that the NotebookRuntime workload runs
as.
Corresponds to the JSON property serviceAccount
19872 19873 19874 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19872 def service_account @service_account end |
#shielded_vm_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ShieldedVmConfig
A set of Shielded Instance options. See Images using supported Shielded VM
features.
Corresponds to the JSON property shieldedVmConfig
19879 19880 19881 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19879 def shielded_vm_config @shielded_vm_config end |
#software_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookSoftwareConfig
Notebook Software Config.
Corresponds to the JSON property softwareConfig
19884 19885 19886 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19884 def software_config @software_config end |
#update_time ⇒ String
Output only. Timestamp when this NotebookRuntime was most recently updated.
Corresponds to the JSON property updateTime
19889 19890 19891 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19889 def update_time @update_time end |
#version ⇒ String
Output only. The VM os image version of NotebookRuntime.
Corresponds to the JSON property version
19894 19895 19896 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19894 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19901 19902 19903 19904 19905 19906 19907 19908 19909 19910 19911 19912 19913 19914 19915 19916 19917 19918 19919 19920 19921 19922 19923 19924 19925 19926 19927 19928 19929 19930 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19901 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @data_persistent_disk_spec = args[:data_persistent_disk_spec] if args.key?(:data_persistent_disk_spec) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @euc_config = args[:euc_config] if args.key?(:euc_config) @expiration_time = args[:expiration_time] if args.key?(:expiration_time) @health_state = args[:health_state] if args.key?(:health_state) @idle_shutdown_config = args[:idle_shutdown_config] if args.key?(:idle_shutdown_config) @is_upgradable = args[:is_upgradable] if args.key?(:is_upgradable) @labels = args[:labels] if args.key?(:labels) @machine_spec = args[:machine_spec] if args.key?(:machine_spec) @name = args[:name] if args.key?(:name) @network_spec = args[:network_spec] if args.key?(:network_spec) @network_tags = args[:network_tags] if args.key?(:network_tags) @notebook_runtime_template_ref = args[:notebook_runtime_template_ref] if args.key?(:notebook_runtime_template_ref) @notebook_runtime_type = args[:notebook_runtime_type] if args.key?(:notebook_runtime_type) @proxy_uri = args[:proxy_uri] if args.key?(:proxy_uri) @reservation_affinity = args[:reservation_affinity] if args.key?(:reservation_affinity) @runtime_state = args[:runtime_state] if args.key?(:runtime_state) @runtime_user = args[:runtime_user] if args.key?(:runtime_user) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @service_account = args[:service_account] if args.key?(:service_account) @shielded_vm_config = args[:shielded_vm_config] if args.key?(:shielded_vm_config) @software_config = args[:software_config] if args.key?(:software_config) @update_time = args[:update_time] if args.key?(:update_time) @version = args[:version] if args.key?(:version) end |