Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookRuntime
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookRuntime
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A runtime is a virtual machine allocated to a particular user for a particular Notebook file on temporary basis with lifetime limited to 24 hours.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#data_persistent_disk_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PersistentDiskSpec
Represents the spec of persistent disk options.
-
#description ⇒ String
The description of the NotebookRuntime.
-
#display_name ⇒ String
Required.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top- level resource.
-
#euc_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookEucConfig
The euc configuration of NotebookRuntimeTemplate.
-
#expiration_time ⇒ String
Output only.
-
#health_state ⇒ String
Output only.
-
#idle_shutdown_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookIdleShutdownConfig
The idle shutdown configuration of NotebookRuntimeTemplate, which contains the idle_timeout as required field.
-
#is_upgradable ⇒ Boolean
(also: #is_upgradable?)
Output only.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your NotebookRuntime.
-
#machine_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MachineSpec
Specification of a single machine.
-
#name ⇒ String
Output only.
-
#network_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NetworkSpec
Network spec.
-
#network_tags ⇒ Array<String>
Optional.
-
#notebook_runtime_template_ref ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookRuntimeTemplateRef
Points to a NotebookRuntimeTemplateRef.
-
#notebook_runtime_type ⇒ String
Output only.
-
#proxy_uri ⇒ String
Output only.
-
#runtime_state ⇒ String
Output only.
-
#runtime_user ⇒ String
Required.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#service_account ⇒ String
Output only.
-
#shielded_vm_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ShieldedVmConfig
A set of Shielded Instance options.
-
#software_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookSoftwareConfig
Notebook Software Config.
-
#update_time ⇒ String
Output only.
-
#version ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1NotebookRuntime
constructor
A new instance of GoogleCloudAiplatformV1NotebookRuntime.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1NotebookRuntime
Returns a new instance of GoogleCloudAiplatformV1NotebookRuntime.
19667 19668 19669 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19667 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this NotebookRuntime was created.
Corresponds to the JSON property createTime
19505 19506 19507 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19505 def create_time @create_time end |
#data_persistent_disk_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PersistentDiskSpec
Represents the spec of persistent disk options.
Corresponds to the JSON property dataPersistentDiskSpec
19510 19511 19512 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19510 def data_persistent_disk_spec @data_persistent_disk_spec end |
#description ⇒ String
The description of the NotebookRuntime.
Corresponds to the JSON property description
19515 19516 19517 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19515 def description @description end |
#display_name ⇒ String
Required. The display name of the NotebookRuntime. The name can be up to 128
characters long and can consist of any UTF-8 characters.
Corresponds to the JSON property displayName
19521 19522 19523 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19521 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top-
level resource.
Corresponds to the JSON property encryptionSpec
19527 19528 19529 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19527 def encryption_spec @encryption_spec end |
#euc_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookEucConfig
The euc configuration of NotebookRuntimeTemplate.
Corresponds to the JSON property eucConfig
19532 19533 19534 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19532 def euc_config @euc_config end |
#expiration_time ⇒ String
Output only. Timestamp when this NotebookRuntime will be expired: 1. System
Predefined NotebookRuntime: 24 hours after creation. After expiration, system
predifined runtime will be deleted. 2. User created NotebookRuntime: 6 months
after last upgrade. After expiration, user created runtime will be stopped and
allowed for upgrade.
Corresponds to the JSON property expirationTime
19541 19542 19543 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19541 def expiration_time @expiration_time end |
#health_state ⇒ String
Output only. The health state of the NotebookRuntime.
Corresponds to the JSON property healthState
19546 19547 19548 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19546 def health_state @health_state end |
#idle_shutdown_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookIdleShutdownConfig
The idle shutdown configuration of NotebookRuntimeTemplate, which contains the
idle_timeout as required field.
Corresponds to the JSON property idleShutdownConfig
19552 19553 19554 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19552 def idle_shutdown_config @idle_shutdown_config end |
#is_upgradable ⇒ Boolean Also known as: is_upgradable?
Output only. Whether NotebookRuntime is upgradable.
Corresponds to the JSON property isUpgradable
19557 19558 19559 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19557 def is_upgradable @is_upgradable end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your NotebookRuntime. Label
keys and values can be no longer than 64 characters (Unicode codepoints), can
only contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. No more than 64 user labels can be
associated with one NotebookRuntime (System labels are excluded). See https://
goo.gl/xmQnxf for more information and examples of labels. System reserved
label keys are prefixed with "aiplatform.googleapis.com/" and are immutable.
Following system labels exist for NotebookRuntime: * "aiplatform.googleapis.
com/notebook_runtime_gce_instance_id": output only, its value is the Compute
Engine instance id. * "aiplatform.googleapis.com/
colab_enterprise_entry_service": its value is either "bigquery" or "vertex";
if absent, it should be "vertex". This is to describe the entry service,
either BigQuery or Vertex.
Corresponds to the JSON property labels
19575 19576 19577 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19575 def labels @labels end |
#machine_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MachineSpec
Specification of a single machine.
Corresponds to the JSON property machineSpec
19580 19581 19582 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19580 def machine_spec @machine_spec end |
#name ⇒ String
Output only. The resource name of the NotebookRuntime.
Corresponds to the JSON property name
19585 19586 19587 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19585 def name @name end |
#network_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NetworkSpec
Network spec.
Corresponds to the JSON property networkSpec
19590 19591 19592 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19590 def network_spec @network_spec end |
#network_tags ⇒ Array<String>
Optional. The Compute Engine tags to add to runtime (see Tagging instances).
Corresponds to the JSON property networkTags
19596 19597 19598 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19596 def @network_tags end |
#notebook_runtime_template_ref ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookRuntimeTemplateRef
Points to a NotebookRuntimeTemplateRef.
Corresponds to the JSON property notebookRuntimeTemplateRef
19601 19602 19603 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19601 def notebook_runtime_template_ref @notebook_runtime_template_ref end |
#notebook_runtime_type ⇒ String
Output only. The type of the notebook runtime.
Corresponds to the JSON property notebookRuntimeType
19606 19607 19608 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19606 def notebook_runtime_type @notebook_runtime_type end |
#proxy_uri ⇒ String
Output only. The proxy endpoint used to access the NotebookRuntime.
Corresponds to the JSON property proxyUri
19611 19612 19613 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19611 def proxy_uri @proxy_uri end |
#runtime_state ⇒ String
Output only. The runtime (instance) state of the NotebookRuntime.
Corresponds to the JSON property runtimeState
19616 19617 19618 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19616 def runtime_state @runtime_state end |
#runtime_user ⇒ String
Required. The user email of the NotebookRuntime.
Corresponds to the JSON property runtimeUser
19621 19622 19623 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19621 def runtime_user @runtime_user end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
19626 19627 19628 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19626 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
19632 19633 19634 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19632 def satisfies_pzs @satisfies_pzs end |
#service_account ⇒ String
Output only. Deprecated: This field is no longer used and the "Vertex AI
Notebook Service Account" (service-PROJECT_NUMBER@gcp-sa-aiplatform-vm.iam.
gserviceaccount.com) is used for the runtime workload identity. See https://
cloud.google.com/iam/docs/service-agents#vertex-ai-notebook-service-account
for more details. The service account that the NotebookRuntime workload runs
as.
Corresponds to the JSON property serviceAccount
19643 19644 19645 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19643 def service_account @service_account end |
#shielded_vm_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ShieldedVmConfig
A set of Shielded Instance options. See Images using supported Shielded VM
features.
Corresponds to the JSON property shieldedVmConfig
19650 19651 19652 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19650 def shielded_vm_config @shielded_vm_config end |
#software_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookSoftwareConfig
Notebook Software Config.
Corresponds to the JSON property softwareConfig
19655 19656 19657 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19655 def software_config @software_config end |
#update_time ⇒ String
Output only. Timestamp when this NotebookRuntime was most recently updated.
Corresponds to the JSON property updateTime
19660 19661 19662 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19660 def update_time @update_time end |
#version ⇒ String
Output only. The VM os image version of NotebookRuntime.
Corresponds to the JSON property version
19665 19666 19667 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19665 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19672 19673 19674 19675 19676 19677 19678 19679 19680 19681 19682 19683 19684 19685 19686 19687 19688 19689 19690 19691 19692 19693 19694 19695 19696 19697 19698 19699 19700 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19672 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @data_persistent_disk_spec = args[:data_persistent_disk_spec] if args.key?(:data_persistent_disk_spec) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @euc_config = args[:euc_config] if args.key?(:euc_config) @expiration_time = args[:expiration_time] if args.key?(:expiration_time) @health_state = args[:health_state] if args.key?(:health_state) @idle_shutdown_config = args[:idle_shutdown_config] if args.key?(:idle_shutdown_config) @is_upgradable = args[:is_upgradable] if args.key?(:is_upgradable) @labels = args[:labels] if args.key?(:labels) @machine_spec = args[:machine_spec] if args.key?(:machine_spec) @name = args[:name] if args.key?(:name) @network_spec = args[:network_spec] if args.key?(:network_spec) @network_tags = args[:network_tags] if args.key?(:network_tags) @notebook_runtime_template_ref = args[:notebook_runtime_template_ref] if args.key?(:notebook_runtime_template_ref) @notebook_runtime_type = args[:notebook_runtime_type] if args.key?(:notebook_runtime_type) @proxy_uri = args[:proxy_uri] if args.key?(:proxy_uri) @runtime_state = args[:runtime_state] if args.key?(:runtime_state) @runtime_user = args[:runtime_user] if args.key?(:runtime_user) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @service_account = args[:service_account] if args.key?(:service_account) @shielded_vm_config = args[:shielded_vm_config] if args.key?(:shielded_vm_config) @software_config = args[:software_config] if args.key?(:software_config) @update_time = args[:update_time] if args.key?(:update_time) @version = args[:version] if args.key?(:version) end |