Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookRuntime

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A runtime is a virtual machine allocated to a particular user for a particular Notebook file on temporary basis with lifetime limited to 24 hours.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1NotebookRuntime

Returns a new instance of GoogleCloudAiplatformV1NotebookRuntime.



17528
17529
17530
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17528

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this NotebookRuntime was created. Corresponds to the JSON property createTime

Returns:

  • (String)


17403
17404
17405
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17403

def create_time
  @create_time
end

#descriptionString

The description of the NotebookRuntime. Corresponds to the JSON property description

Returns:

  • (String)


17408
17409
17410
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17408

def description
  @description
end

#display_nameString

Required. The display name of the NotebookRuntime. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


17414
17415
17416
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17414

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key spec that can be applied to a top- level resource. Corresponds to the JSON property encryptionSpec



17420
17421
17422
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17420

def encryption_spec
  @encryption_spec
end

#expiration_timeString

Output only. Timestamp when this NotebookRuntime will be expired: 1. System Predefined NotebookRuntime: 24 hours after creation. After expiration, system predifined runtime will be deleted. 2. User created NotebookRuntime: 6 months after last upgrade. After expiration, user created runtime will be stopped and allowed for upgrade. Corresponds to the JSON property expirationTime

Returns:

  • (String)


17429
17430
17431
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17429

def expiration_time
  @expiration_time
end

#health_stateString

Output only. The health state of the NotebookRuntime. Corresponds to the JSON property healthState

Returns:

  • (String)


17434
17435
17436
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17434

def health_state
  @health_state
end

#idle_shutdown_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookIdleShutdownConfig

The idle shutdown configuration of NotebookRuntimeTemplate, which contains the idle_timeout as required field. Corresponds to the JSON property idleShutdownConfig



17440
17441
17442
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17440

def idle_shutdown_config
  @idle_shutdown_config
end

#is_upgradableBoolean Also known as: is_upgradable?

Output only. Whether NotebookRuntime is upgradable. Corresponds to the JSON property isUpgradable

Returns:

  • (Boolean)


17445
17446
17447
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17445

def is_upgradable
  @is_upgradable
end

#labelsHash<String,String>

The labels with user-defined metadata to organize your NotebookRuntime. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. No more than 64 user labels can be associated with one NotebookRuntime (System labels are excluded). See https:// goo.gl/xmQnxf for more information and examples of labels. System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable. Following system labels exist for NotebookRuntime: * "aiplatform.googleapis. com/notebook_runtime_gce_instance_id": output only, its value is the Compute Engine instance id. * "aiplatform.googleapis.com/ colab_enterprise_entry_service": its value is either "bigquery" or "vertex"; if absent, it should be "vertex". This is to describe the entry service, either BigQuery or Vertex. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


17463
17464
17465
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17463

def labels
  @labels
end

#nameString

Output only. The resource name of the NotebookRuntime. Corresponds to the JSON property name

Returns:

  • (String)


17468
17469
17470
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17468

def name
  @name
end

#network_tagsArray<String>

Optional. The Compute Engine tags to add to runtime (see Tagging instances). Corresponds to the JSON property networkTags

Returns:

  • (Array<String>)


17474
17475
17476
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17474

def network_tags
  @network_tags
end

#notebook_runtime_template_refGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookRuntimeTemplateRef

Points to a NotebookRuntimeTemplateRef. Corresponds to the JSON property notebookRuntimeTemplateRef



17479
17480
17481
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17479

def notebook_runtime_template_ref
  @notebook_runtime_template_ref
end

#notebook_runtime_typeString

Output only. The type of the notebook runtime. Corresponds to the JSON property notebookRuntimeType

Returns:

  • (String)


17484
17485
17486
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17484

def notebook_runtime_type
  @notebook_runtime_type
end

#proxy_uriString

Output only. The proxy endpoint used to access the NotebookRuntime. Corresponds to the JSON property proxyUri

Returns:

  • (String)


17489
17490
17491
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17489

def proxy_uri
  @proxy_uri
end

#runtime_stateString

Output only. The runtime (instance) state of the NotebookRuntime. Corresponds to the JSON property runtimeState

Returns:

  • (String)


17494
17495
17496
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17494

def runtime_state
  @runtime_state
end

#runtime_userString

Required. The user email of the NotebookRuntime. Corresponds to the JSON property runtimeUser

Returns:

  • (String)


17499
17500
17501
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17499

def runtime_user
  @runtime_user
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


17504
17505
17506
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17504

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


17510
17511
17512
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17510

def satisfies_pzs
  @satisfies_pzs
end

#service_accountString

Output only. The service account that the NotebookRuntime workload runs as. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


17516
17517
17518
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17516

def 
  @service_account
end

#update_timeString

Output only. Timestamp when this NotebookRuntime was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


17521
17522
17523
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17521

def update_time
  @update_time
end

#versionString

Output only. The VM os image version of NotebookRuntime. Corresponds to the JSON property version

Returns:

  • (String)


17526
17527
17528
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17526

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17533
17534
17535
17536
17537
17538
17539
17540
17541
17542
17543
17544
17545
17546
17547
17548
17549
17550
17551
17552
17553
17554
17555
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17533

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @expiration_time = args[:expiration_time] if args.key?(:expiration_time)
  @health_state = args[:health_state] if args.key?(:health_state)
  @idle_shutdown_config = args[:idle_shutdown_config] if args.key?(:idle_shutdown_config)
  @is_upgradable = args[:is_upgradable] if args.key?(:is_upgradable)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @network_tags = args[:network_tags] if args.key?(:network_tags)
  @notebook_runtime_template_ref = args[:notebook_runtime_template_ref] if args.key?(:notebook_runtime_template_ref)
  @notebook_runtime_type = args[:notebook_runtime_type] if args.key?(:notebook_runtime_type)
  @proxy_uri = args[:proxy_uri] if args.key?(:proxy_uri)
  @runtime_state = args[:runtime_state] if args.key?(:runtime_state)
  @runtime_user = args[:runtime_user] if args.key?(:runtime_user)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @service_account = args[:service_account] if args.key?(:service_account)
  @update_time = args[:update_time] if args.key?(:update_time)
  @version = args[:version] if args.key?(:version)
end