Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookRuntime
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookRuntime
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A runtime is a virtual machine allocated to a particular user for a particular Notebook file on temporary basis with lifetime limited to 24 hours.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
The description of the NotebookRuntime.
-
#display_name ⇒ String
Required.
-
#expiration_time ⇒ String
Output only.
-
#health_state ⇒ String
Output only.
-
#is_upgradable ⇒ Boolean
(also: #is_upgradable?)
Output only.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your NotebookRuntime.
-
#name ⇒ String
Output only.
-
#network_tags ⇒ Array<String>
Optional.
-
#notebook_runtime_template_ref ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookRuntimeTemplateRef
Points to a NotebookRuntimeTemplateRef.
-
#notebook_runtime_type ⇒ String
Output only.
-
#proxy_uri ⇒ String
Output only.
-
#reservation_affinity ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookReservationAffinity
Notebook Reservation Affinity for consuming Zonal reservation.
-
#runtime_state ⇒ String
Output only.
-
#runtime_user ⇒ String
Required.
-
#service_account ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
-
#version ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1NotebookRuntime
constructor
A new instance of GoogleCloudAiplatformV1NotebookRuntime.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1NotebookRuntime
Returns a new instance of GoogleCloudAiplatformV1NotebookRuntime.
15435 15436 15437 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15435 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this NotebookRuntime was created.
Corresponds to the JSON property createTime
15329 15330 15331 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15329 def create_time @create_time end |
#description ⇒ String
The description of the NotebookRuntime.
Corresponds to the JSON property description
15334 15335 15336 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15334 def description @description end |
#display_name ⇒ String
Required. The display name of the NotebookRuntime. The name can be up to 128
characters long and can consist of any UTF-8 characters.
Corresponds to the JSON property displayName
15340 15341 15342 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15340 def display_name @display_name end |
#expiration_time ⇒ String
Output only. Timestamp when this NotebookRuntime will be expired: 1. System
Predefined NotebookRuntime: 24 hours after creation. After expiration, system
predifined runtime will be deleted. 2. User created NotebookRuntime: 6 months
after last upgrade. After expiration, user created runtime will be stopped and
allowed for upgrade.
Corresponds to the JSON property expirationTime
15349 15350 15351 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15349 def expiration_time @expiration_time end |
#health_state ⇒ String
Output only. The health state of the NotebookRuntime.
Corresponds to the JSON property healthState
15354 15355 15356 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15354 def health_state @health_state end |
#is_upgradable ⇒ Boolean Also known as: is_upgradable?
Output only. Whether NotebookRuntime is upgradable.
Corresponds to the JSON property isUpgradable
15359 15360 15361 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15359 def is_upgradable @is_upgradable end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your NotebookRuntime. Label
keys and values can be no longer than 64 characters (Unicode codepoints), can
only contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. No more than 64 user labels can be
associated with one NotebookRuntime (System labels are excluded). See https://
goo.gl/xmQnxf for more information and examples of labels. System reserved
label keys are prefixed with "aiplatform.googleapis.com/" and are immutable.
Following system labels exist for NotebookRuntime: * "aiplatform.googleapis.
com/notebook_runtime_gce_instance_id": output only, its value is the Compute
Engine instance id. * "aiplatform.googleapis.com/
colab_enterprise_entry_service": its value is either "bigquery" or "vertex";
if absent, it should be "vertex". This is to describe the entry service,
either BigQuery or Vertex.
Corresponds to the JSON property labels
15377 15378 15379 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15377 def labels @labels end |
#name ⇒ String
Output only. The resource name of the NotebookRuntime.
Corresponds to the JSON property name
15382 15383 15384 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15382 def name @name end |
#network_tags ⇒ Array<String>
Optional. The Compute Engine tags to add to runtime (see Tagging instances).
Corresponds to the JSON property networkTags
15388 15389 15390 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15388 def @network_tags end |
#notebook_runtime_template_ref ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookRuntimeTemplateRef
Points to a NotebookRuntimeTemplateRef.
Corresponds to the JSON property notebookRuntimeTemplateRef
15393 15394 15395 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15393 def notebook_runtime_template_ref @notebook_runtime_template_ref end |
#notebook_runtime_type ⇒ String
Output only. The type of the notebook runtime.
Corresponds to the JSON property notebookRuntimeType
15398 15399 15400 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15398 def notebook_runtime_type @notebook_runtime_type end |
#proxy_uri ⇒ String
Output only. The proxy endpoint used to access the NotebookRuntime.
Corresponds to the JSON property proxyUri
15403 15404 15405 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15403 def proxy_uri @proxy_uri end |
#reservation_affinity ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookReservationAffinity
Notebook Reservation Affinity for consuming Zonal reservation.
Corresponds to the JSON property reservationAffinity
15408 15409 15410 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15408 def reservation_affinity @reservation_affinity end |
#runtime_state ⇒ String
Output only. The runtime (instance) state of the NotebookRuntime.
Corresponds to the JSON property runtimeState
15413 15414 15415 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15413 def runtime_state @runtime_state end |
#runtime_user ⇒ String
Required. The user email of the NotebookRuntime.
Corresponds to the JSON property runtimeUser
15418 15419 15420 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15418 def runtime_user @runtime_user end |
#service_account ⇒ String
Output only. The service account that the NotebookRuntime workload runs as.
Corresponds to the JSON property serviceAccount
15423 15424 15425 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15423 def service_account @service_account end |
#update_time ⇒ String
Output only. Timestamp when this NotebookRuntime was most recently updated.
Corresponds to the JSON property updateTime
15428 15429 15430 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15428 def update_time @update_time end |
#version ⇒ String
Output only. The VM os image version of NotebookRuntime.
Corresponds to the JSON property version
15433 15434 15435 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15433 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15440 15441 15442 15443 15444 15445 15446 15447 15448 15449 15450 15451 15452 15453 15454 15455 15456 15457 15458 15459 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15440 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @expiration_time = args[:expiration_time] if args.key?(:expiration_time) @health_state = args[:health_state] if args.key?(:health_state) @is_upgradable = args[:is_upgradable] if args.key?(:is_upgradable) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @network_tags = args[:network_tags] if args.key?(:network_tags) @notebook_runtime_template_ref = args[:notebook_runtime_template_ref] if args.key?(:notebook_runtime_template_ref) @notebook_runtime_type = args[:notebook_runtime_type] if args.key?(:notebook_runtime_type) @proxy_uri = args[:proxy_uri] if args.key?(:proxy_uri) @reservation_affinity = args[:reservation_affinity] if args.key?(:reservation_affinity) @runtime_state = args[:runtime_state] if args.key?(:runtime_state) @runtime_user = args[:runtime_user] if args.key?(:runtime_user) @service_account = args[:service_account] if args.key?(:service_account) @update_time = args[:update_time] if args.key?(:update_time) @version = args[:version] if args.key?(:version) end |