Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookRuntimeTemplate

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A template that specifies runtime configurations such as machine type, runtime version, network configurations, etc. Multiple runtimes can be created from a runtime template.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1NotebookRuntimeTemplate

Returns a new instance of GoogleCloudAiplatformV1NotebookRuntimeTemplate.



28101
28102
28103
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28101

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this NotebookRuntimeTemplate was created. Corresponds to the JSON property createTime

Returns:

  • (String)


27980
27981
27982
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27980

def create_time
  @create_time
end

#data_persistent_disk_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PersistentDiskSpec

Represents the spec of persistent disk and hyperdisk options. Corresponds to the JSON property dataPersistentDiskSpec



27985
27986
27987
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27985

def data_persistent_disk_spec
  @data_persistent_disk_spec
end

#descriptionString

The description of the NotebookRuntimeTemplate. Corresponds to the JSON property description

Returns:

  • (String)


27990
27991
27992
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27990

def description
  @description
end

#display_nameString

Required. The display name of the NotebookRuntimeTemplate. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


27996
27997
27998
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27996

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



28002
28003
28004
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28002

def encryption_spec
  @encryption_spec
end

#etagString

Used to perform consistent read-modify-write updates. If not set, a blind " overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


28008
28009
28010
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28008

def etag
  @etag
end

#euc_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookEucConfig

The euc configuration of NotebookRuntimeTemplate. Corresponds to the JSON property eucConfig



28013
28014
28015
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28013

def euc_config
  @euc_config
end

#idle_shutdown_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookIdleShutdownConfig

The idle shutdown configuration of NotebookRuntimeTemplate, which contains the idle_timeout as required field. Corresponds to the JSON property idleShutdownConfig



28019
28020
28021
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28019

def idle_shutdown_config
  @idle_shutdown_config
end

#is_defaultBoolean Also known as: is_default?

Output only. Deprecated: This field has no behavior. Use notebook_runtime_type = 'ONE_CLICK' instead. The default template to use if not specified. Corresponds to the JSON property isDefault

Returns:

  • (Boolean)


28025
28026
28027
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28025

def is_default
  @is_default
end

#labelsHash<String,String>

The labels with user-defined metadata to organize the NotebookRuntimeTemplates. Label keys and values can be no longer than 64 characters (Unicode codepoints) , can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


28035
28036
28037
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28035

def labels
  @labels
end

#machine_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1MachineSpec

Specification of a single machine. Corresponds to the JSON property machineSpec



28040
28041
28042
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28040

def machine_spec
  @machine_spec
end

#nameString

The resource name of the NotebookRuntimeTemplate. Corresponds to the JSON property name

Returns:

  • (String)


28045
28046
28047
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28045

def name
  @name
end

#network_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1NetworkSpec

Network spec. Corresponds to the JSON property networkSpec



28050
28051
28052
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28050

def network_spec
  @network_spec
end

#network_tagsArray<String>

Optional. The Compute Engine tags to add to runtime (see Tagging instances). Corresponds to the JSON property networkTags

Returns:

  • (Array<String>)


28056
28057
28058
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28056

def network_tags
  @network_tags
end

#notebook_runtime_typeString

Optional. Immutable. The type of the notebook runtime template. Corresponds to the JSON property notebookRuntimeType

Returns:

  • (String)


28061
28062
28063
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28061

def notebook_runtime_type
  @notebook_runtime_type
end

#reservation_affinityGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookReservationAffinity

Notebook Reservation Affinity for consuming Zonal reservation. Corresponds to the JSON property reservationAffinity



28066
28067
28068
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28066

def reservation_affinity
  @reservation_affinity
end

#service_accountString

Deprecated: This field is ignored and the "Vertex AI Notebook Service Account" (service-PROJECT_NUMBER@gcp-sa-aiplatform-vm.iam.gserviceaccount.com) is used for the runtime workload identity. See https://cloud.google.com/iam/docs/ service-agents#vertex-ai-notebook-service-account for more details. For NotebookExecutionJob, use NotebookExecutionJob.service_account instead. The service account that the runtime workload runs as. You can use any service account within the same project, but you must have the service account user permission to use the instance. If not specified, the Compute Engine default service account is used. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


28080
28081
28082
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28080

def 
  @service_account
end

#shielded_vm_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ShieldedVmConfig

A set of Shielded Instance options. See Images using supported Shielded VM features. Corresponds to the JSON property shieldedVmConfig



28087
28088
28089
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28087

def shielded_vm_config
  @shielded_vm_config
end

#software_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookSoftwareConfig

Notebook Software Config. This is passed to the backend when user makes software configurations in UI. Corresponds to the JSON property softwareConfig



28093
28094
28095
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28093

def software_config
  @software_config
end

#update_timeString

Output only. Timestamp when this NotebookRuntimeTemplate was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


28099
28100
28101
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28099

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28106
28107
28108
28109
28110
28111
28112
28113
28114
28115
28116
28117
28118
28119
28120
28121
28122
28123
28124
28125
28126
28127
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28106

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_persistent_disk_spec = args[:data_persistent_disk_spec] if args.key?(:data_persistent_disk_spec)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @etag = args[:etag] if args.key?(:etag)
  @euc_config = args[:euc_config] if args.key?(:euc_config)
  @idle_shutdown_config = args[:idle_shutdown_config] if args.key?(:idle_shutdown_config)
  @is_default = args[:is_default] if args.key?(:is_default)
  @labels = args[:labels] if args.key?(:labels)
  @machine_spec = args[:machine_spec] if args.key?(:machine_spec)
  @name = args[:name] if args.key?(:name)
  @network_spec = args[:network_spec] if args.key?(:network_spec)
  @network_tags = args[:network_tags] if args.key?(:network_tags)
  @notebook_runtime_type = args[:notebook_runtime_type] if args.key?(:notebook_runtime_type)
  @reservation_affinity = args[:reservation_affinity] if args.key?(:reservation_affinity)
  @service_account = args[:service_account] if args.key?(:service_account)
  @shielded_vm_config = args[:shielded_vm_config] if args.key?(:shielded_vm_config)
  @software_config = args[:software_config] if args.key?(:software_config)
  @update_time = args[:update_time] if args.key?(:update_time)
end