Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookRuntimeTemplate
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookRuntimeTemplate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A template that specifies runtime configurations such as machine type, runtime version, network configurations, etc. Multiple runtimes can be created from a runtime template.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#data_persistent_disk_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PersistentDiskSpec
Represents the spec of persistent disk and hyperdisk options.
-
#description ⇒ String
The description of the NotebookRuntimeTemplate.
-
#display_name ⇒ String
Required.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.
-
#etag ⇒ String
Used to perform consistent read-modify-write updates.
-
#euc_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookEucConfig
The euc configuration of NotebookRuntimeTemplate.
-
#idle_shutdown_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookIdleShutdownConfig
The idle shutdown configuration of NotebookRuntimeTemplate, which contains the idle_timeout as required field.
-
#is_default ⇒ Boolean
(also: #is_default?)
Output only.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize the NotebookRuntimeTemplates.
-
#machine_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MachineSpec
Specification of a single machine.
-
#name ⇒ String
The resource name of the NotebookRuntimeTemplate.
-
#network_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NetworkSpec
Network spec.
-
#network_tags ⇒ Array<String>
Optional.
-
#notebook_runtime_type ⇒ String
Optional.
-
#reservation_affinity ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookReservationAffinity
Notebook Reservation Affinity for consuming Zonal reservation.
-
#service_account ⇒ String
Deprecated: This field is ignored and the "Vertex AI Notebook Service Account" (service-PROJECT_NUMBER@gcp-sa-aiplatform-vm.iam.gserviceaccount.com) is used for the runtime workload identity.
-
#shielded_vm_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ShieldedVmConfig
A set of Shielded Instance options.
-
#software_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookSoftwareConfig
Notebook Software Config.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1NotebookRuntimeTemplate
constructor
A new instance of GoogleCloudAiplatformV1NotebookRuntimeTemplate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1NotebookRuntimeTemplate
Returns a new instance of GoogleCloudAiplatformV1NotebookRuntimeTemplate.
26737 26738 26739 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26737 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this NotebookRuntimeTemplate was created.
Corresponds to the JSON property createTime
26616 26617 26618 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26616 def create_time @create_time end |
#data_persistent_disk_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PersistentDiskSpec
Represents the spec of persistent disk and hyperdisk options.
Corresponds to the JSON property dataPersistentDiskSpec
26621 26622 26623 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26621 def data_persistent_disk_spec @data_persistent_disk_spec end |
#description ⇒ String
The description of the NotebookRuntimeTemplate.
Corresponds to the JSON property description
26626 26627 26628 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26626 def description @description end |
#display_name ⇒ String
Required. The display name of the NotebookRuntimeTemplate. The name can be up
to 128 characters long and can consist of any UTF-8 characters.
Corresponds to the JSON property displayName
26632 26633 26634 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26632 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied
to a Vertex AI resource.
Corresponds to the JSON property encryptionSpec
26638 26639 26640 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26638 def encryption_spec @encryption_spec end |
#etag ⇒ String
Used to perform consistent read-modify-write updates. If not set, a blind "
overwrite" update happens.
Corresponds to the JSON property etag
26644 26645 26646 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26644 def etag @etag end |
#euc_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookEucConfig
The euc configuration of NotebookRuntimeTemplate.
Corresponds to the JSON property eucConfig
26649 26650 26651 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26649 def euc_config @euc_config end |
#idle_shutdown_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookIdleShutdownConfig
The idle shutdown configuration of NotebookRuntimeTemplate, which contains the
idle_timeout as required field.
Corresponds to the JSON property idleShutdownConfig
26655 26656 26657 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26655 def idle_shutdown_config @idle_shutdown_config end |
#is_default ⇒ Boolean Also known as: is_default?
Output only. Deprecated: This field has no behavior. Use notebook_runtime_type
= 'ONE_CLICK' instead. The default template to use if not specified.
Corresponds to the JSON property isDefault
26661 26662 26663 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26661 def is_default @is_default end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize the NotebookRuntimeTemplates.
Label keys and values can be no longer than 64 characters (Unicode codepoints)
, can only contain lowercase letters, numeric characters, underscores and
dashes. International characters are allowed. See https://goo.gl/xmQnxf for
more information and examples of labels.
Corresponds to the JSON property labels
26671 26672 26673 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26671 def labels @labels end |
#machine_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MachineSpec
Specification of a single machine.
Corresponds to the JSON property machineSpec
26676 26677 26678 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26676 def machine_spec @machine_spec end |
#name ⇒ String
The resource name of the NotebookRuntimeTemplate.
Corresponds to the JSON property name
26681 26682 26683 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26681 def name @name end |
#network_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NetworkSpec
Network spec.
Corresponds to the JSON property networkSpec
26686 26687 26688 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26686 def network_spec @network_spec end |
#network_tags ⇒ Array<String>
Optional. The Compute Engine tags to add to runtime (see Tagging instances).
Corresponds to the JSON property networkTags
26692 26693 26694 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26692 def @network_tags end |
#notebook_runtime_type ⇒ String
Optional. Immutable. The type of the notebook runtime template.
Corresponds to the JSON property notebookRuntimeType
26697 26698 26699 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26697 def notebook_runtime_type @notebook_runtime_type end |
#reservation_affinity ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookReservationAffinity
Notebook Reservation Affinity for consuming Zonal reservation.
Corresponds to the JSON property reservationAffinity
26702 26703 26704 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26702 def reservation_affinity @reservation_affinity end |
#service_account ⇒ String
Deprecated: This field is ignored and the "Vertex AI Notebook Service Account"
(service-PROJECT_NUMBER@gcp-sa-aiplatform-vm.iam.gserviceaccount.com) is used
for the runtime workload identity. See https://cloud.google.com/iam/docs/
service-agents#vertex-ai-notebook-service-account for more details. For
NotebookExecutionJob, use NotebookExecutionJob.service_account instead. The
service account that the runtime workload runs as. You can use any service
account within the same project, but you must have the service account user
permission to use the instance. If not specified, the Compute Engine default
service account is used.
Corresponds to the JSON property serviceAccount
26716 26717 26718 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26716 def service_account @service_account end |
#shielded_vm_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ShieldedVmConfig
A set of Shielded Instance options. See Images using supported Shielded VM
features.
Corresponds to the JSON property shieldedVmConfig
26723 26724 26725 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26723 def shielded_vm_config @shielded_vm_config end |
#software_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookSoftwareConfig
Notebook Software Config. This is passed to the backend when user makes
software configurations in UI.
Corresponds to the JSON property softwareConfig
26729 26730 26731 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26729 def software_config @software_config end |
#update_time ⇒ String
Output only. Timestamp when this NotebookRuntimeTemplate was most recently
updated.
Corresponds to the JSON property updateTime
26735 26736 26737 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26735 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26742 26743 26744 26745 26746 26747 26748 26749 26750 26751 26752 26753 26754 26755 26756 26757 26758 26759 26760 26761 26762 26763 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26742 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @data_persistent_disk_spec = args[:data_persistent_disk_spec] if args.key?(:data_persistent_disk_spec) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @etag = args[:etag] if args.key?(:etag) @euc_config = args[:euc_config] if args.key?(:euc_config) @idle_shutdown_config = args[:idle_shutdown_config] if args.key?(:idle_shutdown_config) @is_default = args[:is_default] if args.key?(:is_default) @labels = args[:labels] if args.key?(:labels) @machine_spec = args[:machine_spec] if args.key?(:machine_spec) @name = args[:name] if args.key?(:name) @network_spec = args[:network_spec] if args.key?(:network_spec) @network_tags = args[:network_tags] if args.key?(:network_tags) @notebook_runtime_type = args[:notebook_runtime_type] if args.key?(:notebook_runtime_type) @reservation_affinity = args[:reservation_affinity] if args.key?(:reservation_affinity) @service_account = args[:service_account] if args.key?(:service_account) @shielded_vm_config = args[:shielded_vm_config] if args.key?(:shielded_vm_config) @software_config = args[:software_config] if args.key?(:software_config) @update_time = args[:update_time] if args.key?(:update_time) end |