Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookRuntimeTemplate
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookRuntimeTemplate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A template that specifies runtime configurations such as machine type, runtime version, network configurations, etc. Multiple runtimes can be created from a runtime template.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#data_persistent_disk_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PersistentDiskSpec
Represents the spec of persistent disk options.
-
#description ⇒ String
The description of the NotebookRuntimeTemplate.
-
#display_name ⇒ String
Required.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.
-
#etag ⇒ String
Used to perform consistent read-modify-write updates.
-
#euc_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookEucConfig
The euc configuration of NotebookRuntimeTemplate.
-
#idle_shutdown_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookIdleShutdownConfig
The idle shutdown configuration of NotebookRuntimeTemplate, which contains the idle_timeout as required field.
-
#is_default ⇒ Boolean
(also: #is_default?)
Output only.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize the NotebookRuntimeTemplates.
-
#machine_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MachineSpec
Specification of a single machine.
-
#name ⇒ String
The resource name of the NotebookRuntimeTemplate.
-
#network_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NetworkSpec
Network spec.
-
#network_tags ⇒ Array<String>
Optional.
-
#notebook_runtime_type ⇒ String
Optional.
-
#reservation_affinity ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookReservationAffinity
Notebook Reservation Affinity for consuming Zonal reservation.
-
#service_account ⇒ String
Deprecated: This field is ignored and the "Vertex AI Notebook Service Account" (service-PROJECT_NUMBER@gcp-sa-aiplatform-vm.iam.gserviceaccount.com) is used for the runtime workload identity.
-
#shielded_vm_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ShieldedVmConfig
A set of Shielded Instance options.
-
#software_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookSoftwareConfig
Notebook Software Config.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1NotebookRuntimeTemplate
constructor
A new instance of GoogleCloudAiplatformV1NotebookRuntimeTemplate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1NotebookRuntimeTemplate
Returns a new instance of GoogleCloudAiplatformV1NotebookRuntimeTemplate.
25123 25124 25125 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25123 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this NotebookRuntimeTemplate was created.
Corresponds to the JSON property createTime
25002 25003 25004 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25002 def create_time @create_time end |
#data_persistent_disk_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PersistentDiskSpec
Represents the spec of persistent disk options.
Corresponds to the JSON property dataPersistentDiskSpec
25007 25008 25009 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25007 def data_persistent_disk_spec @data_persistent_disk_spec end |
#description ⇒ String
The description of the NotebookRuntimeTemplate.
Corresponds to the JSON property description
25012 25013 25014 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25012 def description @description end |
#display_name ⇒ String
Required. The display name of the NotebookRuntimeTemplate. The name can be up
to 128 characters long and can consist of any UTF-8 characters.
Corresponds to the JSON property displayName
25018 25019 25020 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25018 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied
to a Vertex AI resource.
Corresponds to the JSON property encryptionSpec
25024 25025 25026 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25024 def encryption_spec @encryption_spec end |
#etag ⇒ String
Used to perform consistent read-modify-write updates. If not set, a blind "
overwrite" update happens.
Corresponds to the JSON property etag
25030 25031 25032 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25030 def etag @etag end |
#euc_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookEucConfig
The euc configuration of NotebookRuntimeTemplate.
Corresponds to the JSON property eucConfig
25035 25036 25037 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25035 def euc_config @euc_config end |
#idle_shutdown_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookIdleShutdownConfig
The idle shutdown configuration of NotebookRuntimeTemplate, which contains the
idle_timeout as required field.
Corresponds to the JSON property idleShutdownConfig
25041 25042 25043 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25041 def idle_shutdown_config @idle_shutdown_config end |
#is_default ⇒ Boolean Also known as: is_default?
Output only. Deprecated: This field has no behavior. Use notebook_runtime_type
= 'ONE_CLICK' instead. The default template to use if not specified.
Corresponds to the JSON property isDefault
25047 25048 25049 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25047 def is_default @is_default end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize the NotebookRuntimeTemplates.
Label keys and values can be no longer than 64 characters (Unicode codepoints)
, can only contain lowercase letters, numeric characters, underscores and
dashes. International characters are allowed. See https://goo.gl/xmQnxf for
more information and examples of labels.
Corresponds to the JSON property labels
25057 25058 25059 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25057 def labels @labels end |
#machine_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MachineSpec
Specification of a single machine.
Corresponds to the JSON property machineSpec
25062 25063 25064 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25062 def machine_spec @machine_spec end |
#name ⇒ String
The resource name of the NotebookRuntimeTemplate.
Corresponds to the JSON property name
25067 25068 25069 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25067 def name @name end |
#network_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NetworkSpec
Network spec.
Corresponds to the JSON property networkSpec
25072 25073 25074 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25072 def network_spec @network_spec end |
#network_tags ⇒ Array<String>
Optional. The Compute Engine tags to add to runtime (see Tagging instances).
Corresponds to the JSON property networkTags
25078 25079 25080 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25078 def @network_tags end |
#notebook_runtime_type ⇒ String
Optional. Immutable. The type of the notebook runtime template.
Corresponds to the JSON property notebookRuntimeType
25083 25084 25085 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25083 def notebook_runtime_type @notebook_runtime_type end |
#reservation_affinity ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookReservationAffinity
Notebook Reservation Affinity for consuming Zonal reservation.
Corresponds to the JSON property reservationAffinity
25088 25089 25090 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25088 def reservation_affinity @reservation_affinity end |
#service_account ⇒ String
Deprecated: This field is ignored and the "Vertex AI Notebook Service Account"
(service-PROJECT_NUMBER@gcp-sa-aiplatform-vm.iam.gserviceaccount.com) is used
for the runtime workload identity. See https://cloud.google.com/iam/docs/
service-agents#vertex-ai-notebook-service-account for more details. For
NotebookExecutionJob, use NotebookExecutionJob.service_account instead. The
service account that the runtime workload runs as. You can use any service
account within the same project, but you must have the service account user
permission to use the instance. If not specified, the Compute Engine default
service account is used.
Corresponds to the JSON property serviceAccount
25102 25103 25104 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25102 def service_account @service_account end |
#shielded_vm_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ShieldedVmConfig
A set of Shielded Instance options. See Images using supported Shielded VM
features.
Corresponds to the JSON property shieldedVmConfig
25109 25110 25111 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25109 def shielded_vm_config @shielded_vm_config end |
#software_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookSoftwareConfig
Notebook Software Config. This is passed to the backend when user makes
software configurations in UI.
Corresponds to the JSON property softwareConfig
25115 25116 25117 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25115 def software_config @software_config end |
#update_time ⇒ String
Output only. Timestamp when this NotebookRuntimeTemplate was most recently
updated.
Corresponds to the JSON property updateTime
25121 25122 25123 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25121 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25128 25129 25130 25131 25132 25133 25134 25135 25136 25137 25138 25139 25140 25141 25142 25143 25144 25145 25146 25147 25148 25149 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25128 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @data_persistent_disk_spec = args[:data_persistent_disk_spec] if args.key?(:data_persistent_disk_spec) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @etag = args[:etag] if args.key?(:etag) @euc_config = args[:euc_config] if args.key?(:euc_config) @idle_shutdown_config = args[:idle_shutdown_config] if args.key?(:idle_shutdown_config) @is_default = args[:is_default] if args.key?(:is_default) @labels = args[:labels] if args.key?(:labels) @machine_spec = args[:machine_spec] if args.key?(:machine_spec) @name = args[:name] if args.key?(:name) @network_spec = args[:network_spec] if args.key?(:network_spec) @network_tags = args[:network_tags] if args.key?(:network_tags) @notebook_runtime_type = args[:notebook_runtime_type] if args.key?(:notebook_runtime_type) @reservation_affinity = args[:reservation_affinity] if args.key?(:reservation_affinity) @service_account = args[:service_account] if args.key?(:service_account) @shielded_vm_config = args[:shielded_vm_config] if args.key?(:shielded_vm_config) @software_config = args[:software_config] if args.key?(:software_config) @update_time = args[:update_time] if args.key?(:update_time) end |