Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookRuntimeTemplate
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookRuntimeTemplate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A template that specifies runtime configurations such as machine type, runtime version, network configurations, etc. Multiple runtimes can be created from a runtime template.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#data_persistent_disk_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PersistentDiskSpec
Represents the spec of persistent disk options.
-
#description ⇒ String
The description of the NotebookRuntimeTemplate.
-
#display_name ⇒ String
Required.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top- level resource.
-
#etag ⇒ String
Used to perform consistent read-modify-write updates.
-
#euc_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookEucConfig
The euc configuration of NotebookRuntimeTemplate.
-
#idle_shutdown_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookIdleShutdownConfig
The idle shutdown configuration of NotebookRuntimeTemplate, which contains the idle_timeout as required field.
-
#is_default ⇒ Boolean
(also: #is_default?)
Output only.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize the NotebookRuntimeTemplates.
-
#machine_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MachineSpec
Specification of a single machine.
-
#name ⇒ String
The resource name of the NotebookRuntimeTemplate.
-
#network_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NetworkSpec
Network spec.
-
#network_tags ⇒ Array<String>
Optional.
-
#notebook_runtime_type ⇒ String
Optional.
-
#reservation_affinity ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookReservationAffinity
Notebook Reservation Affinity for consuming Zonal reservation.
-
#service_account ⇒ String
Deprecated: This field is ignored and the "Vertex AI Notebook Service Account" (service-PROJECT_NUMBER@gcp-sa-aiplatform-vm.iam.gserviceaccount.com) is used for the runtime workload identity.
-
#shielded_vm_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ShieldedVmConfig
A set of Shielded Instance options.
-
#software_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookSoftwareConfig
Notebook Software Config.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1NotebookRuntimeTemplate
constructor
A new instance of GoogleCloudAiplatformV1NotebookRuntimeTemplate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1NotebookRuntimeTemplate
Returns a new instance of GoogleCloudAiplatformV1NotebookRuntimeTemplate.
20482 20483 20484 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20482 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this NotebookRuntimeTemplate was created.
Corresponds to the JSON property createTime
20361 20362 20363 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20361 def create_time @create_time end |
#data_persistent_disk_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PersistentDiskSpec
Represents the spec of persistent disk options.
Corresponds to the JSON property dataPersistentDiskSpec
20366 20367 20368 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20366 def data_persistent_disk_spec @data_persistent_disk_spec end |
#description ⇒ String
The description of the NotebookRuntimeTemplate.
Corresponds to the JSON property description
20371 20372 20373 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20371 def description @description end |
#display_name ⇒ String
Required. The display name of the NotebookRuntimeTemplate. The name can be up
to 128 characters long and can consist of any UTF-8 characters.
Corresponds to the JSON property displayName
20377 20378 20379 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20377 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top-
level resource.
Corresponds to the JSON property encryptionSpec
20383 20384 20385 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20383 def encryption_spec @encryption_spec end |
#etag ⇒ String
Used to perform consistent read-modify-write updates. If not set, a blind "
overwrite" update happens.
Corresponds to the JSON property etag
20389 20390 20391 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20389 def etag @etag end |
#euc_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookEucConfig
The euc configuration of NotebookRuntimeTemplate.
Corresponds to the JSON property eucConfig
20394 20395 20396 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20394 def euc_config @euc_config end |
#idle_shutdown_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookIdleShutdownConfig
The idle shutdown configuration of NotebookRuntimeTemplate, which contains the
idle_timeout as required field.
Corresponds to the JSON property idleShutdownConfig
20400 20401 20402 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20400 def idle_shutdown_config @idle_shutdown_config end |
#is_default ⇒ Boolean Also known as: is_default?
Output only. Deprecated: This field has no behavior. Use notebook_runtime_type
= 'ONE_CLICK' instead. The default template to use if not specified.
Corresponds to the JSON property isDefault
20406 20407 20408 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20406 def is_default @is_default end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize the NotebookRuntimeTemplates.
Label keys and values can be no longer than 64 characters (Unicode codepoints)
, can only contain lowercase letters, numeric characters, underscores and
dashes. International characters are allowed. See https://goo.gl/xmQnxf for
more information and examples of labels.
Corresponds to the JSON property labels
20416 20417 20418 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20416 def labels @labels end |
#machine_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MachineSpec
Specification of a single machine.
Corresponds to the JSON property machineSpec
20421 20422 20423 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20421 def machine_spec @machine_spec end |
#name ⇒ String
The resource name of the NotebookRuntimeTemplate.
Corresponds to the JSON property name
20426 20427 20428 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20426 def name @name end |
#network_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NetworkSpec
Network spec.
Corresponds to the JSON property networkSpec
20431 20432 20433 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20431 def network_spec @network_spec end |
#network_tags ⇒ Array<String>
Optional. The Compute Engine tags to add to runtime (see Tagging instances).
Corresponds to the JSON property networkTags
20437 20438 20439 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20437 def @network_tags end |
#notebook_runtime_type ⇒ String
Optional. Immutable. The type of the notebook runtime template.
Corresponds to the JSON property notebookRuntimeType
20442 20443 20444 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20442 def notebook_runtime_type @notebook_runtime_type end |
#reservation_affinity ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookReservationAffinity
Notebook Reservation Affinity for consuming Zonal reservation.
Corresponds to the JSON property reservationAffinity
20447 20448 20449 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20447 def reservation_affinity @reservation_affinity end |
#service_account ⇒ String
Deprecated: This field is ignored and the "Vertex AI Notebook Service Account"
(service-PROJECT_NUMBER@gcp-sa-aiplatform-vm.iam.gserviceaccount.com) is used
for the runtime workload identity. See https://cloud.google.com/iam/docs/
service-agents#vertex-ai-notebook-service-account for more details. For
NotebookExecutionJob, use NotebookExecutionJob.service_account instead. The
service account that the runtime workload runs as. You can use any service
account within the same project, but you must have the service account user
permission to use the instance. If not specified, the Compute Engine default
service account is used.
Corresponds to the JSON property serviceAccount
20461 20462 20463 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20461 def service_account @service_account end |
#shielded_vm_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ShieldedVmConfig
A set of Shielded Instance options. See Images using supported Shielded VM
features.
Corresponds to the JSON property shieldedVmConfig
20468 20469 20470 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20468 def shielded_vm_config @shielded_vm_config end |
#software_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookSoftwareConfig
Notebook Software Config. This is passed to the backend when user makes
software configurations in UI.
Corresponds to the JSON property softwareConfig
20474 20475 20476 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20474 def software_config @software_config end |
#update_time ⇒ String
Output only. Timestamp when this NotebookRuntimeTemplate was most recently
updated.
Corresponds to the JSON property updateTime
20480 20481 20482 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20480 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20487 20488 20489 20490 20491 20492 20493 20494 20495 20496 20497 20498 20499 20500 20501 20502 20503 20504 20505 20506 20507 20508 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20487 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @data_persistent_disk_spec = args[:data_persistent_disk_spec] if args.key?(:data_persistent_disk_spec) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @etag = args[:etag] if args.key?(:etag) @euc_config = args[:euc_config] if args.key?(:euc_config) @idle_shutdown_config = args[:idle_shutdown_config] if args.key?(:idle_shutdown_config) @is_default = args[:is_default] if args.key?(:is_default) @labels = args[:labels] if args.key?(:labels) @machine_spec = args[:machine_spec] if args.key?(:machine_spec) @name = args[:name] if args.key?(:name) @network_spec = args[:network_spec] if args.key?(:network_spec) @network_tags = args[:network_tags] if args.key?(:network_tags) @notebook_runtime_type = args[:notebook_runtime_type] if args.key?(:notebook_runtime_type) @reservation_affinity = args[:reservation_affinity] if args.key?(:reservation_affinity) @service_account = args[:service_account] if args.key?(:service_account) @shielded_vm_config = args[:shielded_vm_config] if args.key?(:shielded_vm_config) @software_config = args[:software_config] if args.key?(:software_config) @update_time = args[:update_time] if args.key?(:update_time) end |