Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookRuntimeTemplate

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A template that specifies runtime configurations such as machine type, runtime version, network configurations, etc. Multiple runtimes can be created from a runtime template.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1NotebookRuntimeTemplate

Returns a new instance of GoogleCloudAiplatformV1NotebookRuntimeTemplate.



20444
20445
20446
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20444

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this NotebookRuntimeTemplate was created. Corresponds to the JSON property createTime

Returns:

  • (String)


20323
20324
20325
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20323

def create_time
  @create_time
end

#data_persistent_disk_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PersistentDiskSpec

Represents the spec of persistent disk options. Corresponds to the JSON property dataPersistentDiskSpec



20328
20329
20330
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20328

def data_persistent_disk_spec
  @data_persistent_disk_spec
end

#descriptionString

The description of the NotebookRuntimeTemplate. Corresponds to the JSON property description

Returns:

  • (String)


20333
20334
20335
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20333

def description
  @description
end

#display_nameString

Required. The display name of the NotebookRuntimeTemplate. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


20339
20340
20341
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20339

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key spec that can be applied to a top- level resource. Corresponds to the JSON property encryptionSpec



20345
20346
20347
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20345

def encryption_spec
  @encryption_spec
end

#etagString

Used to perform consistent read-modify-write updates. If not set, a blind " overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


20351
20352
20353
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20351

def etag
  @etag
end

#euc_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookEucConfig

The euc configuration of NotebookRuntimeTemplate. Corresponds to the JSON property eucConfig



20356
20357
20358
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20356

def euc_config
  @euc_config
end

#idle_shutdown_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookIdleShutdownConfig

The idle shutdown configuration of NotebookRuntimeTemplate, which contains the idle_timeout as required field. Corresponds to the JSON property idleShutdownConfig



20362
20363
20364
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20362

def idle_shutdown_config
  @idle_shutdown_config
end

#is_defaultBoolean Also known as: is_default?

Output only. Deprecated: This field has no behavior. Use notebook_runtime_type = 'ONE_CLICK' instead. The default template to use if not specified. Corresponds to the JSON property isDefault

Returns:

  • (Boolean)


20368
20369
20370
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20368

def is_default
  @is_default
end

#labelsHash<String,String>

The labels with user-defined metadata to organize the NotebookRuntimeTemplates. Label keys and values can be no longer than 64 characters (Unicode codepoints) , can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


20378
20379
20380
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20378

def labels
  @labels
end

#machine_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1MachineSpec

Specification of a single machine. Corresponds to the JSON property machineSpec



20383
20384
20385
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20383

def machine_spec
  @machine_spec
end

#nameString

The resource name of the NotebookRuntimeTemplate. Corresponds to the JSON property name

Returns:

  • (String)


20388
20389
20390
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20388

def name
  @name
end

#network_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1NetworkSpec

Network spec. Corresponds to the JSON property networkSpec



20393
20394
20395
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20393

def network_spec
  @network_spec
end

#network_tagsArray<String>

Optional. The Compute Engine tags to add to runtime (see Tagging instances). Corresponds to the JSON property networkTags

Returns:

  • (Array<String>)


20399
20400
20401
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20399

def network_tags
  @network_tags
end

#notebook_runtime_typeString

Optional. Immutable. The type of the notebook runtime template. Corresponds to the JSON property notebookRuntimeType

Returns:

  • (String)


20404
20405
20406
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20404

def notebook_runtime_type
  @notebook_runtime_type
end

#reservation_affinityGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookReservationAffinity

Notebook Reservation Affinity for consuming Zonal reservation. Corresponds to the JSON property reservationAffinity



20409
20410
20411
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20409

def reservation_affinity
  @reservation_affinity
end

#service_accountString

Deprecated: This field is ignored and the "Vertex AI Notebook Service Account" (service-PROJECT_NUMBER@gcp-sa-aiplatform-vm.iam.gserviceaccount.com) is used for the runtime workload identity. See https://cloud.google.com/iam/docs/ service-agents#vertex-ai-notebook-service-account for more details. For NotebookExecutionJob, use NotebookExecutionJob.service_account instead. The service account that the runtime workload runs as. You can use any service account within the same project, but you must have the service account user permission to use the instance. If not specified, the Compute Engine default service account is used. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


20423
20424
20425
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20423

def 
  @service_account
end

#shielded_vm_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ShieldedVmConfig

A set of Shielded Instance options. See Images using supported Shielded VM features. Corresponds to the JSON property shieldedVmConfig



20430
20431
20432
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20430

def shielded_vm_config
  @shielded_vm_config
end

#software_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1NotebookSoftwareConfig

Notebook Software Config. This is passed to the backend when user makes software configurations in UI. Corresponds to the JSON property softwareConfig



20436
20437
20438
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20436

def software_config
  @software_config
end

#update_timeString

Output only. Timestamp when this NotebookRuntimeTemplate was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


20442
20443
20444
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20442

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20449
20450
20451
20452
20453
20454
20455
20456
20457
20458
20459
20460
20461
20462
20463
20464
20465
20466
20467
20468
20469
20470
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20449

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_persistent_disk_spec = args[:data_persistent_disk_spec] if args.key?(:data_persistent_disk_spec)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @etag = args[:etag] if args.key?(:etag)
  @euc_config = args[:euc_config] if args.key?(:euc_config)
  @idle_shutdown_config = args[:idle_shutdown_config] if args.key?(:idle_shutdown_config)
  @is_default = args[:is_default] if args.key?(:is_default)
  @labels = args[:labels] if args.key?(:labels)
  @machine_spec = args[:machine_spec] if args.key?(:machine_spec)
  @name = args[:name] if args.key?(:name)
  @network_spec = args[:network_spec] if args.key?(:network_spec)
  @network_tags = args[:network_tags] if args.key?(:network_tags)
  @notebook_runtime_type = args[:notebook_runtime_type] if args.key?(:notebook_runtime_type)
  @reservation_affinity = args[:reservation_affinity] if args.key?(:reservation_affinity)
  @service_account = args[:service_account] if args.key?(:service_account)
  @shielded_vm_config = args[:shielded_vm_config] if args.key?(:shielded_vm_config)
  @software_config = args[:software_config] if args.key?(:software_config)
  @update_time = args[:update_time] if args.key?(:update_time)
end