Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1OnlineEvaluator

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

An OnlineEvaluator contains the configuration for an Online Evaluation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1OnlineEvaluator

Returns a new instance of GoogleCloudAiplatformV1OnlineEvaluator.



27847
27848
27849
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27847

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_resourceString

Required. Immutable. The name of the agent that the OnlineEvaluator evaluates periodically. This value is used to filter the traces with a matching cloud. resource_id and link the evaluation results with relevant dashboards/UIs. This field is immutable. Once set, it cannot be changed. Corresponds to the JSON property agentResource

Returns:

  • (String)


27788
27789
27790
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27788

def agent_resource
  @agent_resource
end

#cloud_observabilityGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1OnlineEvaluatorCloudObservability

Data source for the OnlineEvaluator, based on Google Cloud Observability stack (Cloud Trace & Cloud Logging). Corresponds to the JSON property cloudObservability



27794
27795
27796
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27794

def cloud_observability
  @cloud_observability
end

#configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1OnlineEvaluatorConfig

Configuration for sampling behavior of the OnlineEvaluator. The OnlineEvaluator runs at a fixed interval of 10 minutes. Corresponds to the JSON property config



27800
27801
27802
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27800

def config
  @config
end

#create_timeString

Output only. Timestamp when the OnlineEvaluator was created. Corresponds to the JSON property createTime

Returns:

  • (String)


27805
27806
27807
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27805

def create_time
  @create_time
end

#display_nameString

Optional. Human-readable name for the OnlineEvaluator. The name doesn't have to be unique. The name can consist of any UTF-8 characters. The maximum length is 63 characters. If the display name exceeds max characters, an INVALID_ARGUMENT error is returned. Corresponds to the JSON property displayName

Returns:

  • (String)


27813
27814
27815
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27813

def display_name
  @display_name
end

#metric_sourcesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MetricSource>

Required. A list of metric sources to be used for evaluating samples. At least one MetricSource must be provided. Right now, only predefined metrics and registered metrics are supported. Every registered metric must have display_name (or title) and score_range defined. Otherwise, the evaluations will fail. The maximum number of metric_sources is 25. Corresponds to the JSON property metricSources



27822
27823
27824
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27822

def metric_sources
  @metric_sources
end

#nameString

Identifier. The resource name of the OnlineEvaluator. Format: projects/ project/locations/location/onlineEvaluators/id. Corresponds to the JSON property name

Returns:

  • (String)


27828
27829
27830
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27828

def name
  @name
end

#stateString

Output only. The state of the OnlineEvaluator. Corresponds to the JSON property state

Returns:

  • (String)


27833
27834
27835
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27833

def state
  @state
end

#state_detailsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1OnlineEvaluatorStateDetails>

Output only. Contains additional information about the state of the OnlineEvaluator. This is used to provide more details in the event of a failure. Corresponds to the JSON property stateDetails



27840
27841
27842
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27840

def state_details
  @state_details
end

#update_timeString

Output only. Timestamp when the OnlineEvaluator was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


27845
27846
27847
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27845

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27852
27853
27854
27855
27856
27857
27858
27859
27860
27861
27862
27863
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27852

def update!(**args)
  @agent_resource = args[:agent_resource] if args.key?(:agent_resource)
  @cloud_observability = args[:cloud_observability] if args.key?(:cloud_observability)
  @config = args[:config] if args.key?(:config)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @metric_sources = args[:metric_sources] if args.key?(:metric_sources)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @state_details = args[:state_details] if args.key?(:state_details)
  @update_time = args[:update_time] if args.key?(:update_time)
end