Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1OnlineEvaluatorCloudObservability

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Data source for the OnlineEvaluator, based on Google Cloud Observability stack (Cloud Trace & Cloud Logging).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1OnlineEvaluatorCloudObservability

Returns a new instance of GoogleCloudAiplatformV1OnlineEvaluatorCloudObservability.



28800
28801
28802
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28800

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#log_viewString

Optional. Optional log view that will be used to query logs. If empty, the _Default view will be used. Corresponds to the JSON property logView

Returns:

  • (String)


28780
28781
28782
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28780

def log_view
  @log_view
end

#open_telemetryGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1OnlineEvaluatorCloudObservabilityOpenTelemetry

Configuration for data source following OpenTelemetry. Corresponds to the JSON property openTelemetry



28785
28786
28787
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28785

def open_telemetry
  @open_telemetry
end

#trace_scopeGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1OnlineEvaluatorCloudObservabilityTraceScope

If chosen, the online evaluator will evaluate single traces matching specified filter. Corresponds to the JSON property traceScope



28791
28792
28793
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28791

def trace_scope
  @trace_scope
end

#trace_viewString

Optional. Optional trace view that will be used to query traces. If empty, the _Default view will be used. NOTE: This field is not supported yet and will be ignored if set. Corresponds to the JSON property traceView

Returns:

  • (String)


28798
28799
28800
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28798

def trace_view
  @trace_view
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28805
28806
28807
28808
28809
28810
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28805

def update!(**args)
  @log_view = args[:log_view] if args.key?(:log_view)
  @open_telemetry = args[:open_telemetry] if args.key?(:open_telemetry)
  @trace_scope = args[:trace_scope] if args.key?(:trace_scope)
  @trace_view = args[:trace_view] if args.key?(:trace_view)
end