Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1OnlineEvaluatorCloudObservability
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1OnlineEvaluatorCloudObservability
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Data source for the OnlineEvaluator, based on Google Cloud Observability stack (Cloud Trace & Cloud Logging).
Instance Attribute Summary collapse
-
#log_view ⇒ String
Optional.
-
#open_telemetry ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1OnlineEvaluatorCloudObservabilityOpenTelemetry
Configuration for data source following OpenTelemetry.
-
#trace_scope ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1OnlineEvaluatorCloudObservabilityTraceScope
If chosen, the online evaluator will evaluate single traces matching specified
filter. -
#trace_view ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1OnlineEvaluatorCloudObservability
constructor
A new instance of GoogleCloudAiplatformV1OnlineEvaluatorCloudObservability.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1OnlineEvaluatorCloudObservability
Returns a new instance of GoogleCloudAiplatformV1OnlineEvaluatorCloudObservability.
28299 28300 28301 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28299 def initialize(**args) update!(**args) end |
Instance Attribute Details
#log_view ⇒ String
Optional. Optional log view that will be used to query logs. If empty, the
_Default view will be used.
Corresponds to the JSON property logView
28279 28280 28281 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28279 def log_view @log_view end |
#open_telemetry ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1OnlineEvaluatorCloudObservabilityOpenTelemetry
Configuration for data source following OpenTelemetry.
Corresponds to the JSON property openTelemetry
28284 28285 28286 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28284 def open_telemetry @open_telemetry end |
#trace_scope ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1OnlineEvaluatorCloudObservabilityTraceScope
If chosen, the online evaluator will evaluate single traces matching specified
filter.
Corresponds to the JSON property traceScope
28290 28291 28292 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28290 def trace_scope @trace_scope end |
#trace_view ⇒ String
Optional. Optional trace view that will be used to query traces. If empty, the
_Default view will be used. NOTE: This field is not supported yet and will
be ignored if set.
Corresponds to the JSON property traceView
28297 28298 28299 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28297 def trace_view @trace_view end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28304 28305 28306 28307 28308 28309 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28304 def update!(**args) @log_view = args[:log_view] if args.key?(:log_view) @open_telemetry = args[:open_telemetry] if args.key?(:open_telemetry) @trace_scope = args[:trace_scope] if args.key?(:trace_scope) @trace_view = args[:trace_view] if args.key?(:trace_view) end |