Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1OnlineEvaluatorCloudObservability

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Data source for the OnlineEvaluator, based on Google Cloud Observability stack (Cloud Trace & Cloud Logging).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1OnlineEvaluatorCloudObservability

Returns a new instance of GoogleCloudAiplatformV1OnlineEvaluatorCloudObservability.



27895
27896
27897
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27895

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#log_viewString

Optional. Optional log view that will be used to query logs. If empty, the _Default view will be used. Corresponds to the JSON property logView

Returns:

  • (String)


27875
27876
27877
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27875

def log_view
  @log_view
end

#open_telemetryGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1OnlineEvaluatorCloudObservabilityOpenTelemetry

Configuration for data source following OpenTelemetry. Corresponds to the JSON property openTelemetry



27880
27881
27882
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27880

def open_telemetry
  @open_telemetry
end

#trace_scopeGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1OnlineEvaluatorCloudObservabilityTraceScope

If chosen, the online evaluator will evaluate single traces matching specified filter. Corresponds to the JSON property traceScope



27886
27887
27888
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27886

def trace_scope
  @trace_scope
end

#trace_viewString

Optional. Optional trace view that will be used to query traces. If empty, the _Default view will be used. NOTE: This field is not supported yet and will be ignored if set. Corresponds to the JSON property traceView

Returns:

  • (String)


27893
27894
27895
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27893

def trace_view
  @trace_view
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27900
27901
27902
27903
27904
27905
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27900

def update!(**args)
  @log_view = args[:log_view] if args.key?(:log_view)
  @open_telemetry = args[:open_telemetry] if args.key?(:open_telemetry)
  @trace_scope = args[:trace_scope] if args.key?(:trace_scope)
  @trace_view = args[:trace_view] if args.key?(:trace_view)
end