Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1OnlineEvaluatorCloudObservabilitySessionScopeInactivityTrigger
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1OnlineEvaluatorCloudObservabilitySessionScopeInactivityTrigger
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Configuration for inactivity based session completion.
Instance Attribute Summary collapse
-
#threshold ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1OnlineEvaluatorCloudObservabilitySessionScopeInactivityTrigger
constructor
A new instance of GoogleCloudAiplatformV1OnlineEvaluatorCloudObservabilitySessionScopeInactivityTrigger.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1OnlineEvaluatorCloudObservabilitySessionScopeInactivityTrigger
Returns a new instance of GoogleCloudAiplatformV1OnlineEvaluatorCloudObservabilitySessionScopeInactivityTrigger.
29367 29368 29369 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29367 def initialize(**args) update!(**args) end |
Instance Attribute Details
#threshold ⇒ String
Required. The amount of time that must pass with no new traces before a
session is considered ready for evaluation. This is a required field if
InactivityTrigger is used. The value must be a positive duration no greater
than 7 days (604800 seconds).
Corresponds to the JSON property threshold
29365 29366 29367 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29365 def threshold @threshold end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29372 29373 29374 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29372 def update!(**args) @threshold = args[:threshold] if args.key?(:threshold) end |