Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1OnlineEvaluatorCloudObservabilityTraceScopePredicate
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1OnlineEvaluatorCloudObservabilityTraceScopePredicate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Defines a single filter predicate.
Instance Attribute Summary collapse
-
#duration ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1OnlineEvaluatorCloudObservabilityNumericPredicate
Defines a predicate for filtering based on a numeric value.
-
#total_token_usage ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1OnlineEvaluatorCloudObservabilityNumericPredicate
Defines a predicate for filtering based on a numeric value.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1OnlineEvaluatorCloudObservabilityTraceScopePredicate
constructor
A new instance of GoogleCloudAiplatformV1OnlineEvaluatorCloudObservabilityTraceScopePredicate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1OnlineEvaluatorCloudObservabilityTraceScopePredicate
Returns a new instance of GoogleCloudAiplatformV1OnlineEvaluatorCloudObservabilityTraceScopePredicate.
28392 28393 28394 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28392 def initialize(**args) update!(**args) end |
Instance Attribute Details
#duration ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1OnlineEvaluatorCloudObservabilityNumericPredicate
Defines a predicate for filtering based on a numeric value.
Corresponds to the JSON property duration
28385 28386 28387 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28385 def duration @duration end |
#total_token_usage ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1OnlineEvaluatorCloudObservabilityNumericPredicate
Defines a predicate for filtering based on a numeric value.
Corresponds to the JSON property totalTokenUsage
28390 28391 28392 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28390 def total_token_usage @total_token_usage end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28397 28398 28399 28400 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28397 def update!(**args) @duration = args[:duration] if args.key?(:duration) @total_token_usage = args[:total_token_usage] if args.key?(:total_token_usage) end |