Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1OnlineEvaluatorCloudObservabilityTraceScopePredicate
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1OnlineEvaluatorCloudObservabilityTraceScopePredicate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Defines a single filter predicate.
Instance Attribute Summary collapse
-
#duration ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1OnlineEvaluatorCloudObservabilityNumericPredicate
Defines a predicate for filtering based on a numeric value.
-
#total_token_usage ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1OnlineEvaluatorCloudObservabilityNumericPredicate
Defines a predicate for filtering based on a numeric value.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1OnlineEvaluatorCloudObservabilityTraceScopePredicate
constructor
A new instance of GoogleCloudAiplatformV1OnlineEvaluatorCloudObservabilityTraceScopePredicate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1OnlineEvaluatorCloudObservabilityTraceScopePredicate
Returns a new instance of GoogleCloudAiplatformV1OnlineEvaluatorCloudObservabilityTraceScopePredicate.
27988 27989 27990 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27988 def initialize(**args) update!(**args) end |
Instance Attribute Details
#duration ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1OnlineEvaluatorCloudObservabilityNumericPredicate
Defines a predicate for filtering based on a numeric value.
Corresponds to the JSON property duration
27981 27982 27983 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27981 def duration @duration end |
#total_token_usage ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1OnlineEvaluatorCloudObservabilityNumericPredicate
Defines a predicate for filtering based on a numeric value.
Corresponds to the JSON property totalTokenUsage
27986 27987 27988 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27986 def total_token_usage @total_token_usage end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27993 27994 27995 27996 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27993 def update!(**args) @duration = args[:duration] if args.key?(:duration) @total_token_usage = args[:total_token_usage] if args.key?(:total_token_usage) end |