Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1OutputFieldSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1OutputFieldSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Specifies the properties of a single field that are included in each generated synthetic example. This helps the model understand what kind of data to generate for each field.
Instance Attribute Summary collapse
-
#field_name ⇒ String
Required.
-
#field_type ⇒ String
Optional.
-
#guidance ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1OutputFieldSpec
constructor
A new instance of GoogleCloudAiplatformV1OutputFieldSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1OutputFieldSpec
Returns a new instance of GoogleCloudAiplatformV1OutputFieldSpec.
29016 29017 29018 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29016 def initialize(**args) update!(**args) end |
Instance Attribute Details
#field_name ⇒ String
Required. The name of this field in the generated synthetic data, such as "
email_subject" or "customer_review".
Corresponds to the JSON property fieldName
29000 29001 29002 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29000 def field_name @field_name end |
#field_type ⇒ String
Optional. The data type of the field. Defaults to CONTENT if not set.
Corresponds to the JSON property fieldType
29005 29006 29007 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29005 def field_type @field_type end |
#guidance ⇒ String
Optional. Specific instructions for the large language model on how to
generate content for this particular field. While the LLM can sometimes infer
content from the field name, providing explicit guidance is preferred. For
example, for a field named "review", the guidance could be "A positive review
about a coffee maker."
Corresponds to the JSON property guidance
29014 29015 29016 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29014 def guidance @guidance end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29021 29022 29023 29024 29025 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29021 def update!(**args) @field_name = args[:field_name] if args.key?(:field_name) @field_type = args[:field_type] if args.key?(:field_type) @guidance = args[:guidance] if args.key?(:guidance) end |