Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1OutputFieldSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Specifies the properties of a single field that are included in each generated synthetic example. This helps the model understand what kind of data to generate for each field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1OutputFieldSpec

Returns a new instance of GoogleCloudAiplatformV1OutputFieldSpec.



26646
26647
26648
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26646

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#field_nameString

Required. The name of this field in the generated synthetic data, such as " email_subject" or "customer_review". Corresponds to the JSON property fieldName

Returns:

  • (String)


26630
26631
26632
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26630

def field_name
  @field_name
end

#field_typeString

Optional. The data type of the field. Defaults to CONTENT if not set. Corresponds to the JSON property fieldType

Returns:

  • (String)


26635
26636
26637
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26635

def field_type
  @field_type
end

#guidanceString

Optional. Specific instructions for the large language model on how to generate content for this particular field. While the LLM can sometimes infer content from the field name, providing explicit guidance is preferred. For example, for a field named "review", the guidance could be "A positive review about a coffee maker." Corresponds to the JSON property guidance

Returns:

  • (String)


26644
26645
26646
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26644

def guidance
  @guidance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26651
26652
26653
26654
26655
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26651

def update!(**args)
  @field_name = args[:field_name] if args.key?(:field_name)
  @field_type = args[:field_type] if args.key?(:field_type)
  @guidance = args[:guidance] if args.key?(:guidance)
end