Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1OutputFieldSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Defines a specification for a single output field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1OutputFieldSpec

Returns a new instance of GoogleCloudAiplatformV1OutputFieldSpec.



25452
25453
25454
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25452

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#field_nameString

Required. The name of the output field. Corresponds to the JSON property fieldName

Returns:

  • (String)


25437
25438
25439
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25437

def field_name
  @field_name
end

#field_typeString

Optional. The data type of the field. Defaults to CONTENT if not set. Corresponds to the JSON property fieldType

Returns:

  • (String)


25442
25443
25444
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25442

def field_type
  @field_type
end

#guidanceString

Optional. Optional, but recommended. Additional guidance specific to this field to provide targeted instructions for the LLM to generate the content of a single output field. While the LLM can sometimes infer content from the field name, providing explicit guidance is preferred. Corresponds to the JSON property guidance

Returns:

  • (String)


25450
25451
25452
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25450

def guidance
  @guidance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25457
25458
25459
25460
25461
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25457

def update!(**args)
  @field_name = args[:field_name] if args.key?(:field_name)
  @field_type = args[:field_type] if args.key?(:field_type)
  @guidance = args[:guidance] if args.key?(:guidance)
end