Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1OutputFieldSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Defines a specification for a single output field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1OutputFieldSpec

Returns a new instance of GoogleCloudAiplatformV1OutputFieldSpec.



25245
25246
25247
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25245

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#field_nameString

Required. The name of the output field. Corresponds to the JSON property fieldName

Returns:

  • (String)


25230
25231
25232
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25230

def field_name
  @field_name
end

#field_typeString

Optional. The data type of the field. Defaults to CONTENT if not set. Corresponds to the JSON property fieldType

Returns:

  • (String)


25235
25236
25237
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25235

def field_type
  @field_type
end

#guidanceString

Optional. Optional, but recommended. Additional guidance specific to this field to provide targeted instructions for the LLM to generate the content of a single output field. While the LLM can sometimes infer content from the field name, providing explicit guidance is preferred. Corresponds to the JSON property guidance

Returns:

  • (String)


25243
25244
25245
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25243

def guidance
  @guidance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25250
25251
25252
25253
25254
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25250

def update!(**args)
  @field_name = args[:field_name] if args.key?(:field_name)
  @field_type = args[:field_type] if args.key?(:field_type)
  @guidance = args[:guidance] if args.key?(:guidance)
end