Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1OutputInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Describes the info for output of EvaluationService.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1OutputInfo

Returns a new instance of GoogleCloudAiplatformV1OutputInfo.



25474
25475
25476
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25474

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gcs_output_directoryString

Output only. The full path of the Cloud Storage directory created, into which the evaluation results and aggregation results are written. Corresponds to the JSON property gcsOutputDirectory

Returns:

  • (String)


25472
25473
25474
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25472

def gcs_output_directory
  @gcs_output_directory
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25479
25480
25481
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25479

def update!(**args)
  @gcs_output_directory = args[:gcs_output_directory] if args.key?(:gcs_output_directory)
end