Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Part

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A datatype containing media that is part of a multi-part Content message. A Part consists of data which has an associated datatype. A Part can only contain one of the accepted types in Part.data. For media types that are not text, Part must have a fixed IANA MIME type identifying the type and subtype of the media if inline_data or file_data field is filled with raw bytes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Part

Returns a new instance of GoogleCloudAiplatformV1Part.



29075
29076
29077
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29075

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#code_execution_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1CodeExecutionResult

Result of executing the ExecutableCode. Generated only when the CodeExecution tool is used. Corresponds to the JSON property codeExecutionResult



29004
29005
29006
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29004

def code_execution_result
  @code_execution_result
end

#executable_codeGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ExecutableCode

Code generated by the model that is meant to be executed, and the result returned to the model. Generated when using the CodeExecution tool, in which the code will be automatically executed, and a corresponding CodeExecutionResult will also be generated. Corresponds to the JSON property executableCode



29012
29013
29014
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29012

def executable_code
  @executable_code
end

#file_dataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FileData

URI-based data. A FileData message contains a URI pointing to data of a specific media type. It is used to represent images, audio, and video stored in Google Cloud Storage. Corresponds to the JSON property fileData



29019
29020
29021
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29019

def file_data
  @file_data
end

#function_callGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FunctionCall

A predicted FunctionCall returned from the model that contains a string representing the FunctionDeclaration.name and a structured JSON object containing the parameters and their values. Corresponds to the JSON property functionCall



29026
29027
29028
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29026

def function_call
  @function_call
end

#function_responseGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FunctionResponse

The result output from a FunctionCall that contains a string representing the FunctionDeclaration.name and a structured JSON object containing any output from the function is used as context to the model. This should contain the result of a FunctionCall made based on model prediction. Corresponds to the JSON property functionResponse



29034
29035
29036
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29034

def function_response
  @function_response
end

#inline_dataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Blob

A content blob. A Blob contains data of a specific media type. It is used to represent images, audio, and video. Corresponds to the JSON property inlineData



29040
29041
29042
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29040

def inline_data
  @inline_data
end

#media_resolutionGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PartMediaResolution

per part media resolution. Media resolution for the input media. Corresponds to the JSON property mediaResolution



29045
29046
29047
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29045

def media_resolution
  @media_resolution
end

#textString

Optional. The text content of the part. When sent from the VSCode Gemini Code Assist extension, references to @mentioned items will be converted to markdown boldface text. For example @my-repo will be converted to and sent as **my- repo** by the IDE agent. Corresponds to the JSON property text

Returns:

  • (String)


29053
29054
29055
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29053

def text
  @text
end

#thoughtBoolean Also known as: thought?

Optional. Indicates whether the part represents the model's thought process or reasoning. Corresponds to the JSON property thought

Returns:

  • (Boolean)


29059
29060
29061
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29059

def thought
  @thought
end

#thought_signatureString

Optional. An opaque signature for the thought so it can be reused in subsequent requests. Corresponds to the JSON property thoughtSignature NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


29067
29068
29069
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29067

def thought_signature
  @thought_signature
end

#video_metadataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1VideoMetadata

Provides metadata for a video, including the start and end offsets for clipping and the frame rate. Corresponds to the JSON property videoMetadata



29073
29074
29075
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29073

def 
  @video_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29080
29081
29082
29083
29084
29085
29086
29087
29088
29089
29090
29091
29092
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29080

def update!(**args)
  @code_execution_result = args[:code_execution_result] if args.key?(:code_execution_result)
  @executable_code = args[:executable_code] if args.key?(:executable_code)
  @file_data = args[:file_data] if args.key?(:file_data)
  @function_call = args[:function_call] if args.key?(:function_call)
  @function_response = args[:function_response] if args.key?(:function_response)
  @inline_data = args[:inline_data] if args.key?(:inline_data)
  @media_resolution = args[:media_resolution] if args.key?(:media_resolution)
  @text = args[:text] if args.key?(:text)
  @thought = args[:thought] if args.key?(:thought)
  @thought_signature = args[:thought_signature] if args.key?(:thought_signature)
  @video_metadata = args[:video_metadata] if args.key?(:video_metadata)
end