Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Part

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A datatype containing media that is part of a multi-part Content message. A Part consists of data which has an associated datatype. A Part can only contain one of the accepted types in Part.data. A Part must have a fixed IANA MIME type identifying the type and subtype of the media if inline_data or file_data field is filled with raw bytes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Part

Returns a new instance of GoogleCloudAiplatformV1Part.



21485
21486
21487
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21485

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#code_execution_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1CodeExecutionResult

Result of executing the [ExecutableCode]. Only generated when using the [ CodeExecution] tool, and always follows a part containing the [ ExecutableCode]. Corresponds to the JSON property codeExecutionResult



21427
21428
21429
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21427

def code_execution_result
  @code_execution_result
end

#executable_codeGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ExecutableCode

Code generated by the model that is meant to be executed, and the result returned to the model. Generated when using the [CodeExecution] tool, in which the code will be automatically executed, and a corresponding [ CodeExecutionResult] will also be generated. Corresponds to the JSON property executableCode



21435
21436
21437
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21435

def executable_code
  @executable_code
end

#file_dataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FileData

URI based data. Corresponds to the JSON property fileData



21440
21441
21442
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21440

def file_data
  @file_data
end

#function_callGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FunctionCall

A predicted [FunctionCall] returned from the model that contains a string representing the [FunctionDeclaration.name] and a structured JSON object containing the parameters and their values. Corresponds to the JSON property functionCall



21447
21448
21449
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21447

def function_call
  @function_call
end

#function_responseGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FunctionResponse

The result output from a [FunctionCall] that contains a string representing the [FunctionDeclaration.name] and a structured JSON object containing any output from the function is used as context to the model. This should contain the result of a [FunctionCall] made based on model prediction. Corresponds to the JSON property functionResponse



21455
21456
21457
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21455

def function_response
  @function_response
end

#inline_dataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Blob

Content blob. Corresponds to the JSON property inlineData



21460
21461
21462
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21460

def inline_data
  @inline_data
end

#textString

Optional. Text part (can be code). Corresponds to the JSON property text

Returns:

  • (String)


21465
21466
21467
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21465

def text
  @text
end

#thoughtBoolean Also known as: thought?

Optional. Indicates if the part is thought from the model. Corresponds to the JSON property thought

Returns:

  • (Boolean)


21470
21471
21472
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21470

def thought
  @thought
end

#thought_signatureString

Optional. An opaque signature for the thought so it can be reused in subsequent requests. Corresponds to the JSON property thoughtSignature NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


21478
21479
21480
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21478

def thought_signature
  @thought_signature
end

#video_metadataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1VideoMetadata

Metadata describes the input video content. Corresponds to the JSON property videoMetadata



21483
21484
21485
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21483

def 
  @video_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21490
21491
21492
21493
21494
21495
21496
21497
21498
21499
21500
21501
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21490

def update!(**args)
  @code_execution_result = args[:code_execution_result] if args.key?(:code_execution_result)
  @executable_code = args[:executable_code] if args.key?(:executable_code)
  @file_data = args[:file_data] if args.key?(:file_data)
  @function_call = args[:function_call] if args.key?(:function_call)
  @function_response = args[:function_response] if args.key?(:function_response)
  @inline_data = args[:inline_data] if args.key?(:inline_data)
  @text = args[:text] if args.key?(:text)
  @thought = args[:thought] if args.key?(:thought)
  @thought_signature = args[:thought_signature] if args.key?(:thought_signature)
  @video_metadata = args[:video_metadata] if args.key?(:video_metadata)
end