Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Part
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Part
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A datatype containing media that is part of a multi-part Content message. A
Part consists of data which has an associated datatype. A Part can only
contain one of the accepted types in Part.data. A Part must have a fixed
IANA MIME type identifying the type and subtype of the media if inline_data
or file_data field is filled with raw bytes.
Instance Attribute Summary collapse
-
#code_execution_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CodeExecutionResult
Result of executing the [ExecutableCode].
-
#executable_code ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExecutableCode
Code generated by the model that is meant to be executed, and the result returned to the model.
-
#file_data ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FileData
URI based data.
-
#function_call ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FunctionCall
A predicted [FunctionCall] returned from the model that contains a string representing the [FunctionDeclaration.name] and a structured JSON object containing the parameters and their values.
-
#function_response ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FunctionResponse
The result output from a [FunctionCall] that contains a string representing the [FunctionDeclaration.name] and a structured JSON object containing any output from the function is used as context to the model.
-
#inline_data ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Blob
Content blob.
-
#text ⇒ String
Optional.
-
#thought ⇒ Boolean
(also: #thought?)
Output only.
-
#video_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VideoMetadata
Metadata describes the input video content.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Part
constructor
A new instance of GoogleCloudAiplatformV1Part.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Part
Returns a new instance of GoogleCloudAiplatformV1Part.
21112 21113 21114 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21112 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code_execution_result ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CodeExecutionResult
Result of executing the [ExecutableCode]. Only generated when using the [
CodeExecution] tool, and always follows a part containing the [
ExecutableCode].
Corresponds to the JSON property codeExecutionResult
21061 21062 21063 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21061 def code_execution_result @code_execution_result end |
#executable_code ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExecutableCode
Code generated by the model that is meant to be executed, and the result
returned to the model. Generated when using the [CodeExecution] tool, in which
the code will be automatically executed, and a corresponding [
CodeExecutionResult] will also be generated.
Corresponds to the JSON property executableCode
21069 21070 21071 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21069 def executable_code @executable_code end |
#file_data ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FileData
URI based data.
Corresponds to the JSON property fileData
21074 21075 21076 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21074 def file_data @file_data end |
#function_call ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FunctionCall
A predicted [FunctionCall] returned from the model that contains a string
representing the [FunctionDeclaration.name] and a structured JSON object
containing the parameters and their values.
Corresponds to the JSON property functionCall
21081 21082 21083 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21081 def function_call @function_call end |
#function_response ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FunctionResponse
The result output from a [FunctionCall] that contains a string representing
the [FunctionDeclaration.name] and a structured JSON object containing any
output from the function is used as context to the model. This should contain
the result of a [FunctionCall] made based on model prediction.
Corresponds to the JSON property functionResponse
21089 21090 21091 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21089 def function_response @function_response end |
#inline_data ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Blob
Content blob.
Corresponds to the JSON property inlineData
21094 21095 21096 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21094 def inline_data @inline_data end |
#text ⇒ String
Optional. Text part (can be code).
Corresponds to the JSON property text
21099 21100 21101 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21099 def text @text end |
#thought ⇒ Boolean Also known as: thought?
Output only. Indicates if the part is thought from the model.
Corresponds to the JSON property thought
21104 21105 21106 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21104 def thought @thought end |
#video_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VideoMetadata
Metadata describes the input video content.
Corresponds to the JSON property videoMetadata
21110 21111 21112 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21110 def @video_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21117 21118 21119 21120 21121 21122 21123 21124 21125 21126 21127 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21117 def update!(**args) @code_execution_result = args[:code_execution_result] if args.key?(:code_execution_result) @executable_code = args[:executable_code] if args.key?(:executable_code) @file_data = args[:file_data] if args.key?(:file_data) @function_call = args[:function_call] if args.key?(:function_call) @function_response = args[:function_response] if args.key?(:function_response) @inline_data = args[:inline_data] if args.key?(:inline_data) @text = args[:text] if args.key?(:text) @thought = args[:thought] if args.key?(:thought) @video_metadata = args[:video_metadata] if args.key?(:video_metadata) end |