Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Part

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A datatype containing media that is part of a multi-part Content message. A Part consists of data which has an associated datatype. A Part can only contain one of the accepted types in Part.data. A Part must have a fixed IANA MIME type identifying the type and subtype of the media if inline_data or file_data field is filled with raw bytes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Part

Returns a new instance of GoogleCloudAiplatformV1Part.



21009
21010
21011
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21009

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#code_execution_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1CodeExecutionResult

Result of executing the [ExecutableCode]. Always follows a part containing the [ExecutableCode]. Corresponds to the JSON property codeExecutionResult



20959
20960
20961
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20959

def code_execution_result
  @code_execution_result
end

#executable_codeGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ExecutableCode

Code generated by the model that is meant to be executed, and the result returned to the model. Generated when using the [FunctionDeclaration] tool and [FunctionCallingConfig] mode is set to [Mode.CODE]. Corresponds to the JSON property executableCode



20966
20967
20968
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20966

def executable_code
  @executable_code
end

#file_dataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FileData

URI based data. Corresponds to the JSON property fileData



20971
20972
20973
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20971

def file_data
  @file_data
end

#function_callGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FunctionCall

A predicted [FunctionCall] returned from the model that contains a string representing the [FunctionDeclaration.name] and a structured JSON object containing the parameters and their values. Corresponds to the JSON property functionCall



20978
20979
20980
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20978

def function_call
  @function_call
end

#function_responseGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FunctionResponse

The result output from a [FunctionCall] that contains a string representing the [FunctionDeclaration.name] and a structured JSON object containing any output from the function is used as context to the model. This should contain the result of a [FunctionCall] made based on model prediction. Corresponds to the JSON property functionResponse



20986
20987
20988
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20986

def function_response
  @function_response
end

#inline_dataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Blob

Content blob. Corresponds to the JSON property inlineData



20991
20992
20993
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20991

def inline_data
  @inline_data
end

#textString

Optional. Text part (can be code). Corresponds to the JSON property text

Returns:

  • (String)


20996
20997
20998
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20996

def text
  @text
end

#thoughtBoolean Also known as: thought?

Output only. Indicates if the part is thought from the model. Corresponds to the JSON property thought

Returns:

  • (Boolean)


21001
21002
21003
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21001

def thought
  @thought
end

#video_metadataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1VideoMetadata

Metadata describes the input video content. Corresponds to the JSON property videoMetadata



21007
21008
21009
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21007

def 
  @video_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21014
21015
21016
21017
21018
21019
21020
21021
21022
21023
21024
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21014

def update!(**args)
  @code_execution_result = args[:code_execution_result] if args.key?(:code_execution_result)
  @executable_code = args[:executable_code] if args.key?(:executable_code)
  @file_data = args[:file_data] if args.key?(:file_data)
  @function_call = args[:function_call] if args.key?(:function_call)
  @function_response = args[:function_response] if args.key?(:function_response)
  @inline_data = args[:inline_data] if args.key?(:inline_data)
  @text = args[:text] if args.key?(:text)
  @thought = args[:thought] if args.key?(:thought)
  @video_metadata = args[:video_metadata] if args.key?(:video_metadata)
end