Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Part

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A datatype containing media that is part of a multi-part Content message. A Part consists of data which has an associated datatype. A Part can only contain one of the accepted types in Part.data. A Part must have a fixed IANA MIME type identifying the type and subtype of the media if inline_data or file_data field is filled with raw bytes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Part

Returns a new instance of GoogleCloudAiplatformV1Part.



20234
20235
20236
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20234

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#code_execution_resultGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1CodeExecutionResult

Result of executing the [ExecutableCode]. Always follows a part containing the [ExecutableCode]. Corresponds to the JSON property codeExecutionResult



20190
20191
20192
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20190

def code_execution_result
  @code_execution_result
end

#executable_codeGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ExecutableCode

Code generated by the model that is meant to be executed, and the result returned to the model. Generated when using the [FunctionDeclaration] tool and [FunctionCallingConfig] mode is set to [Mode.CODE]. Corresponds to the JSON property executableCode



20197
20198
20199
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20197

def executable_code
  @executable_code
end

#file_dataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FileData

URI based data. Corresponds to the JSON property fileData



20202
20203
20204
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20202

def file_data
  @file_data
end

#function_callGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FunctionCall

A predicted [FunctionCall] returned from the model that contains a string representing the [FunctionDeclaration.name] and a structured JSON object containing the parameters and their values. Corresponds to the JSON property functionCall



20209
20210
20211
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20209

def function_call
  @function_call
end

#function_responseGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FunctionResponse

The result output from a [FunctionCall] that contains a string representing the [FunctionDeclaration.name] and a structured JSON object containing any output from the function is used as context to the model. This should contain the result of a [FunctionCall] made based on model prediction. Corresponds to the JSON property functionResponse



20217
20218
20219
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20217

def function_response
  @function_response
end

#inline_dataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Blob

Content blob. Corresponds to the JSON property inlineData



20222
20223
20224
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20222

def inline_data
  @inline_data
end

#textString

Optional. Text part (can be code). Corresponds to the JSON property text

Returns:

  • (String)


20227
20228
20229
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20227

def text
  @text
end

#video_metadataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1VideoMetadata

Metadata describes the input video content. Corresponds to the JSON property videoMetadata



20232
20233
20234
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20232

def 
  @video_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20239
20240
20241
20242
20243
20244
20245
20246
20247
20248
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20239

def update!(**args)
  @code_execution_result = args[:code_execution_result] if args.key?(:code_execution_result)
  @executable_code = args[:executable_code] if args.key?(:executable_code)
  @file_data = args[:file_data] if args.key?(:file_data)
  @function_call = args[:function_call] if args.key?(:function_call)
  @function_response = args[:function_response] if args.key?(:function_response)
  @inline_data = args[:inline_data] if args.key?(:inline_data)
  @text = args[:text] if args.key?(:text)
  @video_metadata = args[:video_metadata] if args.key?(:video_metadata)
end