Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PersistentResource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents long-lasting resources that are dedicated to users to runs custom workloads. A PersistentResource can have multiple node pools and each node pool can have its own machine spec.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1PersistentResource

Returns a new instance of GoogleCloudAiplatformV1PersistentResource.



21624
21625
21626
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21624

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Time when the PersistentResource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


21514
21515
21516
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21514

def create_time
  @create_time
end

#display_nameString

Optional. The display name of the PersistentResource. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


21520
21521
21522
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21520

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key spec that can be applied to a top- level resource. Corresponds to the JSON property encryptionSpec



21526
21527
21528
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21526

def encryption_spec
  @encryption_spec
end

#errorGoogle::Apis::AiplatformV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



21536
21537
21538
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21536

def error
  @error
end

#labelsHash<String,String>

Optional. The labels with user-defined metadata to organize PersistentResource. Label keys and values can be no longer than 64 characters (Unicode codepoints) , can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


21545
21546
21547
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21545

def labels
  @labels
end

#nameString

Immutable. Resource name of a PersistentResource. Corresponds to the JSON property name

Returns:

  • (String)


21550
21551
21552
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21550

def name
  @name
end

#networkString

Optional. The full name of the Compute Engine network to peered with Vertex AI to host the persistent resources. For example, projects/12345/global/networks/myVPC. Format is of the form projects/ project/global/networks/network`. Whereprojectis a project number, as in12345, andnetworkis a network name. To specify this field, you must have already [configured VPC Network Peering for Vertex AI](https://cloud. google.com/vertex-ai/docs/general/vpc-peering). If this field is left unspecified, the resources aren't peered with any network. Corresponds to the JSON propertynetwork`

Returns:

  • (String)


21563
21564
21565
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21563

def network
  @network
end

#psc_interface_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PscInterfaceConfig

Configuration for PSC-I. Corresponds to the JSON property pscInterfaceConfig



21568
21569
21570
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21568

def psc_interface_config
  @psc_interface_config
end

#reserved_ip_rangesArray<String>

Optional. A list of names for the reserved IP ranges under the VPC network that can be used for this persistent resource. If set, we will deploy the persistent resource within the provided IP ranges. Otherwise, the persistent resource is deployed to any IP ranges under the provided VPC network. Example: ['vertex-ai-ip-range']. Corresponds to the JSON property reservedIpRanges

Returns:

  • (Array<String>)


21577
21578
21579
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21577

def reserved_ip_ranges
  @reserved_ip_ranges
end

#resource_poolsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ResourcePool>

Required. The spec of the pools of different resources. Corresponds to the JSON property resourcePools



21582
21583
21584
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21582

def resource_pools
  @resource_pools
end

#resource_runtimeGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ResourceRuntime

Persistent Cluster runtime information as output Corresponds to the JSON property resourceRuntime



21587
21588
21589
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21587

def resource_runtime
  @resource_runtime
end

#resource_runtime_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ResourceRuntimeSpec

Configuration for the runtime on a PersistentResource instance, including but not limited to: * Service accounts used to run the workloads. * Whether to make it a dedicated Ray Cluster. Corresponds to the JSON property resourceRuntimeSpec



21594
21595
21596
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21594

def resource_runtime_spec
  @resource_runtime_spec
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


21599
21600
21601
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21599

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


21605
21606
21607
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21605

def satisfies_pzs
  @satisfies_pzs
end

#start_timeString

Output only. Time when the PersistentResource for the first time entered the RUNNING state. Corresponds to the JSON property startTime

Returns:

  • (String)


21612
21613
21614
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21612

def start_time
  @start_time
end

#stateString

Output only. The detailed state of a Study. Corresponds to the JSON property state

Returns:

  • (String)


21617
21618
21619
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21617

def state
  @state
end

#update_timeString

Output only. Time when the PersistentResource was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


21622
21623
21624
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21622

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21629
21630
21631
21632
21633
21634
21635
21636
21637
21638
21639
21640
21641
21642
21643
21644
21645
21646
21647
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21629

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @error = args[:error] if args.key?(:error)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @psc_interface_config = args[:psc_interface_config] if args.key?(:psc_interface_config)
  @reserved_ip_ranges = args[:reserved_ip_ranges] if args.key?(:reserved_ip_ranges)
  @resource_pools = args[:resource_pools] if args.key?(:resource_pools)
  @resource_runtime = args[:resource_runtime] if args.key?(:resource_runtime)
  @resource_runtime_spec = args[:resource_runtime_spec] if args.key?(:resource_runtime_spec)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end