Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PersistentResource
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PersistentResource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Represents long-lasting resources that are dedicated to users to runs custom workloads. A PersistentResource can have multiple node pools and each node pool can have its own machine spec.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Optional.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top- level resource.
-
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Immutable.
-
#network ⇒ String
Optional.
-
#psc_interface_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PscInterfaceConfig
Configuration for PSC-I.
-
#reserved_ip_ranges ⇒ Array<String>
Optional.
-
#resource_pools ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ResourcePool>
Required.
-
#resource_runtime ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ResourceRuntime
Persistent Cluster runtime information as output Corresponds to the JSON property
resourceRuntime. -
#resource_runtime_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ResourceRuntimeSpec
Configuration for the runtime on a PersistentResource instance, including but not limited to: * Service accounts used to run the workloads.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1PersistentResource
constructor
A new instance of GoogleCloudAiplatformV1PersistentResource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1PersistentResource
Returns a new instance of GoogleCloudAiplatformV1PersistentResource.
21622 21623 21624 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21622 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Time when the PersistentResource was created.
Corresponds to the JSON property createTime
21512 21513 21514 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21512 def create_time @create_time end |
#display_name ⇒ String
Optional. The display name of the PersistentResource. The name can be up to
128 characters long and can consist of any UTF-8 characters.
Corresponds to the JSON property displayName
21518 21519 21520 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21518 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top-
level resource.
Corresponds to the JSON property encryptionSpec
21524 21525 21526 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21524 def encryption_spec @encryption_spec end |
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
21534 21535 21536 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21534 def error @error end |
#labels ⇒ Hash<String,String>
Optional. The labels with user-defined metadata to organize PersistentResource.
Label keys and values can be no longer than 64 characters (Unicode codepoints)
, can only contain lowercase letters, numeric characters, underscores and
dashes. International characters are allowed. See https://goo.gl/xmQnxf for
more information and examples of labels.
Corresponds to the JSON property labels
21543 21544 21545 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21543 def labels @labels end |
#name ⇒ String
Immutable. Resource name of a PersistentResource.
Corresponds to the JSON property name
21548 21549 21550 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21548 def name @name end |
#network ⇒ String
Optional. The full name of the Compute Engine network to peered with Vertex AI to host the persistent
resources. For example, projects/12345/global/networks/myVPC. Format is of the form projects/
project/global/networks/network`. Whereprojectis a project number, as
in12345, andnetworkis a network name. To specify this field, you must
have already [configured VPC Network Peering for Vertex AI](https://cloud.
google.com/vertex-ai/docs/general/vpc-peering). If this field is left
unspecified, the resources aren't peered with any network.
Corresponds to the JSON propertynetwork`
21561 21562 21563 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21561 def network @network end |
#psc_interface_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PscInterfaceConfig
Configuration for PSC-I.
Corresponds to the JSON property pscInterfaceConfig
21566 21567 21568 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21566 def psc_interface_config @psc_interface_config end |
#reserved_ip_ranges ⇒ Array<String>
Optional. A list of names for the reserved IP ranges under the VPC network
that can be used for this persistent resource. If set, we will deploy the
persistent resource within the provided IP ranges. Otherwise, the persistent
resource is deployed to any IP ranges under the provided VPC network. Example:
['vertex-ai-ip-range'].
Corresponds to the JSON property reservedIpRanges
21575 21576 21577 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21575 def reserved_ip_ranges @reserved_ip_ranges end |
#resource_pools ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ResourcePool>
Required. The spec of the pools of different resources.
Corresponds to the JSON property resourcePools
21580 21581 21582 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21580 def resource_pools @resource_pools end |
#resource_runtime ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ResourceRuntime
Persistent Cluster runtime information as output
Corresponds to the JSON property resourceRuntime
21585 21586 21587 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21585 def resource_runtime @resource_runtime end |
#resource_runtime_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ResourceRuntimeSpec
Configuration for the runtime on a PersistentResource instance, including but
not limited to: * Service accounts used to run the workloads. * Whether to
make it a dedicated Ray Cluster.
Corresponds to the JSON property resourceRuntimeSpec
21592 21593 21594 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21592 def resource_runtime_spec @resource_runtime_spec end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
21597 21598 21599 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21597 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
21603 21604 21605 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21603 def satisfies_pzs @satisfies_pzs end |
#start_time ⇒ String
Output only. Time when the PersistentResource for the first time entered the
RUNNING state.
Corresponds to the JSON property startTime
21610 21611 21612 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21610 def start_time @start_time end |
#state ⇒ String
Output only. The detailed state of a Study.
Corresponds to the JSON property state
21615 21616 21617 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21615 def state @state end |
#update_time ⇒ String
Output only. Time when the PersistentResource was most recently updated.
Corresponds to the JSON property updateTime
21620 21621 21622 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21620 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21627 21628 21629 21630 21631 21632 21633 21634 21635 21636 21637 21638 21639 21640 21641 21642 21643 21644 21645 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21627 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @error = args[:error] if args.key?(:error) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @psc_interface_config = args[:psc_interface_config] if args.key?(:psc_interface_config) @reserved_ip_ranges = args[:reserved_ip_ranges] if args.key?(:reserved_ip_ranges) @resource_pools = args[:resource_pools] if args.key?(:resource_pools) @resource_runtime = args[:resource_runtime] if args.key?(:resource_runtime) @resource_runtime_spec = args[:resource_runtime_spec] if args.key?(:resource_runtime_spec) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |