Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PersistentResource
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PersistentResource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Represents long-lasting resources that are dedicated to users to runs custom workloads. A PersistentResource can have multiple node pools and each node pool can have its own machine spec.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Optional.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top- level resource.
-
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Immutable.
-
#network ⇒ String
Optional.
-
#reserved_ip_ranges ⇒ Array<String>
Optional.
-
#resource_pools ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ResourcePool>
Required.
-
#resource_runtime ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ResourceRuntime
Persistent Cluster runtime information as output Corresponds to the JSON property
resourceRuntime. -
#resource_runtime_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ResourceRuntimeSpec
Configuration for the runtime on a PersistentResource instance, including but not limited to: * Service accounts used to run the workloads.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1PersistentResource
constructor
A new instance of GoogleCloudAiplatformV1PersistentResource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1PersistentResource
Returns a new instance of GoogleCloudAiplatformV1PersistentResource.
21255 21256 21257 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21255 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Time when the PersistentResource was created.
Corresponds to the JSON property createTime
21150 21151 21152 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21150 def create_time @create_time end |
#display_name ⇒ String
Optional. The display name of the PersistentResource. The name can be up to
128 characters long and can consist of any UTF-8 characters.
Corresponds to the JSON property displayName
21156 21157 21158 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21156 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top-
level resource.
Corresponds to the JSON property encryptionSpec
21162 21163 21164 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21162 def encryption_spec @encryption_spec end |
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
21172 21173 21174 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21172 def error @error end |
#labels ⇒ Hash<String,String>
Optional. The labels with user-defined metadata to organize PersistentResource.
Label keys and values can be no longer than 64 characters (Unicode codepoints)
, can only contain lowercase letters, numeric characters, underscores and
dashes. International characters are allowed. See https://goo.gl/xmQnxf for
more information and examples of labels.
Corresponds to the JSON property labels
21181 21182 21183 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21181 def labels @labels end |
#name ⇒ String
Immutable. Resource name of a PersistentResource.
Corresponds to the JSON property name
21186 21187 21188 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21186 def name @name end |
#network ⇒ String
Optional. The full name of the Compute Engine network to peered with Vertex AI to host the persistent
resources. For example, projects/12345/global/networks/myVPC. Format is of the form projects/
project/global/networks/network`. Whereprojectis a project number, as
in12345, andnetworkis a network name. To specify this field, you must
have already [configured VPC Network Peering for Vertex AI](https://cloud.
google.com/vertex-ai/docs/general/vpc-peering). If this field is left
unspecified, the resources aren't peered with any network.
Corresponds to the JSON propertynetwork`
21199 21200 21201 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21199 def network @network end |
#reserved_ip_ranges ⇒ Array<String>
Optional. A list of names for the reserved IP ranges under the VPC network
that can be used for this persistent resource. If set, we will deploy the
persistent resource within the provided IP ranges. Otherwise, the persistent
resource is deployed to any IP ranges under the provided VPC network. Example:
['vertex-ai-ip-range'].
Corresponds to the JSON property reservedIpRanges
21208 21209 21210 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21208 def reserved_ip_ranges @reserved_ip_ranges end |
#resource_pools ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ResourcePool>
Required. The spec of the pools of different resources.
Corresponds to the JSON property resourcePools
21213 21214 21215 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21213 def resource_pools @resource_pools end |
#resource_runtime ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ResourceRuntime
Persistent Cluster runtime information as output
Corresponds to the JSON property resourceRuntime
21218 21219 21220 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21218 def resource_runtime @resource_runtime end |
#resource_runtime_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ResourceRuntimeSpec
Configuration for the runtime on a PersistentResource instance, including but
not limited to: * Service accounts used to run the workloads. * Whether to
make it a dedicated Ray Cluster.
Corresponds to the JSON property resourceRuntimeSpec
21225 21226 21227 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21225 def resource_runtime_spec @resource_runtime_spec end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
21230 21231 21232 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21230 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
21236 21237 21238 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21236 def satisfies_pzs @satisfies_pzs end |
#start_time ⇒ String
Output only. Time when the PersistentResource for the first time entered the
RUNNING state.
Corresponds to the JSON property startTime
21243 21244 21245 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21243 def start_time @start_time end |
#state ⇒ String
Output only. The detailed state of a Study.
Corresponds to the JSON property state
21248 21249 21250 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21248 def state @state end |
#update_time ⇒ String
Output only. Time when the PersistentResource was most recently updated.
Corresponds to the JSON property updateTime
21253 21254 21255 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21253 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21260 21261 21262 21263 21264 21265 21266 21267 21268 21269 21270 21271 21272 21273 21274 21275 21276 21277 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21260 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @error = args[:error] if args.key?(:error) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @reserved_ip_ranges = args[:reserved_ip_ranges] if args.key?(:reserved_ip_ranges) @resource_pools = args[:resource_pools] if args.key?(:resource_pools) @resource_runtime = args[:resource_runtime] if args.key?(:resource_runtime) @resource_runtime_spec = args[:resource_runtime_spec] if args.key?(:resource_runtime_spec) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |