Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PersistentResource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents long-lasting resources that are dedicated to users to runs custom workloads. A PersistentResource can have multiple node pools and each node pool can have its own machine spec.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1PersistentResource

Returns a new instance of GoogleCloudAiplatformV1PersistentResource.



20847
20848
20849
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20847

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Time when the PersistentResource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


20742
20743
20744
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20742

def create_time
  @create_time
end

#display_nameString

Optional. The display name of the PersistentResource. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


20748
20749
20750
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20748

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key spec that can be applied to a top- level resource. Corresponds to the JSON property encryptionSpec



20754
20755
20756
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20754

def encryption_spec
  @encryption_spec
end

#errorGoogle::Apis::AiplatformV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



20764
20765
20766
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20764

def error
  @error
end

#labelsHash<String,String>

Optional. The labels with user-defined metadata to organize PersistentResource. Label keys and values can be no longer than 64 characters (Unicode codepoints) , can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


20773
20774
20775
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20773

def labels
  @labels
end

#nameString

Immutable. Resource name of a PersistentResource. Corresponds to the JSON property name

Returns:

  • (String)


20778
20779
20780
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20778

def name
  @name
end

#networkString

Optional. The full name of the Compute Engine network to peered with Vertex AI to host the persistent resources. For example, projects/12345/global/networks/myVPC. Format is of the form projects/ project/global/networks/network`. Whereprojectis a project number, as in12345, andnetworkis a network name. To specify this field, you must have already [configured VPC Network Peering for Vertex AI](https://cloud. google.com/vertex-ai/docs/general/vpc-peering). If this field is left unspecified, the resources aren't peered with any network. Corresponds to the JSON propertynetwork`

Returns:

  • (String)


20791
20792
20793
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20791

def network
  @network
end

#reserved_ip_rangesArray<String>

Optional. A list of names for the reserved IP ranges under the VPC network that can be used for this persistent resource. If set, we will deploy the persistent resource within the provided IP ranges. Otherwise, the persistent resource is deployed to any IP ranges under the provided VPC network. Example: ['vertex-ai-ip-range']. Corresponds to the JSON property reservedIpRanges

Returns:

  • (Array<String>)


20800
20801
20802
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20800

def reserved_ip_ranges
  @reserved_ip_ranges
end

#resource_poolsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ResourcePool>

Required. The spec of the pools of different resources. Corresponds to the JSON property resourcePools



20805
20806
20807
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20805

def resource_pools
  @resource_pools
end

#resource_runtimeGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ResourceRuntime

Persistent Cluster runtime information as output Corresponds to the JSON property resourceRuntime



20810
20811
20812
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20810

def resource_runtime
  @resource_runtime
end

#resource_runtime_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ResourceRuntimeSpec

Configuration for the runtime on a PersistentResource instance, including but not limited to: * Service accounts used to run the workloads. * Whether to make it a dedicated Ray Cluster. Corresponds to the JSON property resourceRuntimeSpec



20817
20818
20819
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20817

def resource_runtime_spec
  @resource_runtime_spec
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


20822
20823
20824
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20822

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


20828
20829
20830
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20828

def satisfies_pzs
  @satisfies_pzs
end

#start_timeString

Output only. Time when the PersistentResource for the first time entered the RUNNING state. Corresponds to the JSON property startTime

Returns:

  • (String)


20835
20836
20837
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20835

def start_time
  @start_time
end

#stateString

Output only. The detailed state of a Study. Corresponds to the JSON property state

Returns:

  • (String)


20840
20841
20842
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20840

def state
  @state
end

#update_timeString

Output only. Time when the PersistentResource was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


20845
20846
20847
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20845

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20852
20853
20854
20855
20856
20857
20858
20859
20860
20861
20862
20863
20864
20865
20866
20867
20868
20869
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20852

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @error = args[:error] if args.key?(:error)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @reserved_ip_ranges = args[:reserved_ip_ranges] if args.key?(:reserved_ip_ranges)
  @resource_pools = args[:resource_pools] if args.key?(:resource_pools)
  @resource_runtime = args[:resource_runtime] if args.key?(:resource_runtime)
  @resource_runtime_spec = args[:resource_runtime_spec] if args.key?(:resource_runtime_spec)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end