Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PersistentResource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents long-lasting resources that are dedicated to users to runs custom workloads. A PersistentResource can have multiple node pools and each node pool can have its own machine spec.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1PersistentResource

Returns a new instance of GoogleCloudAiplatformV1PersistentResource.



18316
18317
18318
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18316

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Time when the PersistentResource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


18211
18212
18213
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18211

def create_time
  @create_time
end

#display_nameString

Optional. The display name of the PersistentResource. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


18217
18218
18219
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18217

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key spec that can be applied to a top- level resource. Corresponds to the JSON property encryptionSpec



18223
18224
18225
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18223

def encryption_spec
  @encryption_spec
end

#errorGoogle::Apis::AiplatformV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



18233
18234
18235
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18233

def error
  @error
end

#labelsHash<String,String>

Optional. The labels with user-defined metadata to organize PersistentResource. Label keys and values can be no longer than 64 characters (Unicode codepoints) , can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


18242
18243
18244
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18242

def labels
  @labels
end

#nameString

Immutable. Resource name of a PersistentResource. Corresponds to the JSON property name

Returns:

  • (String)


18247
18248
18249
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18247

def name
  @name
end

#networkString

Optional. The full name of the Compute Engine network to peered with Vertex AI to host the persistent resources. For example, projects/12345/global/networks/myVPC. Format is of the form projects/ project/global/networks/network`. Whereprojectis a project number, as in12345, andnetworkis a network name. To specify this field, you must have already [configured VPC Network Peering for Vertex AI](https://cloud. google.com/vertex-ai/docs/general/vpc-peering). If this field is left unspecified, the resources aren't peered with any network. Corresponds to the JSON propertynetwork`

Returns:

  • (String)


18260
18261
18262
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18260

def network
  @network
end

#reserved_ip_rangesArray<String>

Optional. A list of names for the reserved IP ranges under the VPC network that can be used for this persistent resource. If set, we will deploy the persistent resource within the provided IP ranges. Otherwise, the persistent resource is deployed to any IP ranges under the provided VPC network. Example: ['vertex-ai-ip-range']. Corresponds to the JSON property reservedIpRanges

Returns:

  • (Array<String>)


18269
18270
18271
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18269

def reserved_ip_ranges
  @reserved_ip_ranges
end

#resource_poolsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ResourcePool>

Required. The spec of the pools of different resources. Corresponds to the JSON property resourcePools



18274
18275
18276
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18274

def resource_pools
  @resource_pools
end

#resource_runtimeGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ResourceRuntime

Persistent Cluster runtime information as output Corresponds to the JSON property resourceRuntime



18279
18280
18281
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18279

def resource_runtime
  @resource_runtime
end

#resource_runtime_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ResourceRuntimeSpec

Configuration for the runtime on a PersistentResource instance, including but not limited to: * Service accounts used to run the workloads. * Whether to make it a dedicated Ray Cluster. Corresponds to the JSON property resourceRuntimeSpec



18286
18287
18288
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18286

def resource_runtime_spec
  @resource_runtime_spec
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


18291
18292
18293
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18291

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


18297
18298
18299
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18297

def satisfies_pzs
  @satisfies_pzs
end

#start_timeString

Output only. Time when the PersistentResource for the first time entered the RUNNING state. Corresponds to the JSON property startTime

Returns:

  • (String)


18304
18305
18306
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18304

def start_time
  @start_time
end

#stateString

Output only. The detailed state of a Study. Corresponds to the JSON property state

Returns:

  • (String)


18309
18310
18311
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18309

def state
  @state
end

#update_timeString

Output only. Time when the PersistentResource was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


18314
18315
18316
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18314

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18321
18322
18323
18324
18325
18326
18327
18328
18329
18330
18331
18332
18333
18334
18335
18336
18337
18338
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18321

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @error = args[:error] if args.key?(:error)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @reserved_ip_ranges = args[:reserved_ip_ranges] if args.key?(:reserved_ip_ranges)
  @resource_pools = args[:resource_pools] if args.key?(:resource_pools)
  @resource_runtime = args[:resource_runtime] if args.key?(:resource_runtime)
  @resource_runtime_spec = args[:resource_runtime_spec] if args.key?(:resource_runtime_spec)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end