Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PersistentResource
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PersistentResource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Represents long-lasting resources that are dedicated to users to runs custom workloads. A PersistentResource can have multiple node pools and each node pool can have its own machine spec.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Optional.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top- level resource.
-
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Immutable.
-
#network ⇒ String
Optional.
-
#reserved_ip_ranges ⇒ Array<String>
Optional.
-
#resource_pools ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ResourcePool>
Required.
-
#resource_runtime ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ResourceRuntime
Persistent Cluster runtime information as output Corresponds to the JSON property
resourceRuntime. -
#resource_runtime_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ResourceRuntimeSpec
Configuration for the runtime on a PersistentResource instance, including but not limited to: * Service accounts used to run the workloads.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1PersistentResource
constructor
A new instance of GoogleCloudAiplatformV1PersistentResource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1PersistentResource
Returns a new instance of GoogleCloudAiplatformV1PersistentResource.
17026 17027 17028 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17026 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Time when the PersistentResource was created.
Corresponds to the JSON property createTime
16933 16934 16935 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16933 def create_time @create_time end |
#display_name ⇒ String
Optional. The display name of the PersistentResource. The name can be up to
128 characters long and can consist of any UTF-8 characters.
Corresponds to the JSON property displayName
16939 16940 16941 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16939 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top-
level resource.
Corresponds to the JSON property encryptionSpec
16945 16946 16947 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16945 def encryption_spec @encryption_spec end |
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
16955 16956 16957 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16955 def error @error end |
#labels ⇒ Hash<String,String>
Optional. The labels with user-defined metadata to organize PersistentResource.
Label keys and values can be no longer than 64 characters (Unicode codepoints)
, can only contain lowercase letters, numeric characters, underscores and
dashes. International characters are allowed. See https://goo.gl/xmQnxf for
more information and examples of labels.
Corresponds to the JSON property labels
16964 16965 16966 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16964 def labels @labels end |
#name ⇒ String
Immutable. Resource name of a PersistentResource.
Corresponds to the JSON property name
16969 16970 16971 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16969 def name @name end |
#network ⇒ String
Optional. The full name of the Compute Engine network to peered with Vertex AI to host the persistent
resources. For example, projects/12345/global/networks/myVPC. Format is of the form projects/
project/global/networks/network`. Whereprojectis a project number, as
in12345, andnetworkis a network name. To specify this field, you must
have already [configured VPC Network Peering for Vertex AI](https://cloud.
google.com/vertex-ai/docs/general/vpc-peering). If this field is left
unspecified, the resources aren't peered with any network.
Corresponds to the JSON propertynetwork`
16982 16983 16984 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16982 def network @network end |
#reserved_ip_ranges ⇒ Array<String>
Optional. A list of names for the reserved IP ranges under the VPC network
that can be used for this persistent resource. If set, we will deploy the
persistent resource within the provided IP ranges. Otherwise, the persistent
resource is deployed to any IP ranges under the provided VPC network. Example:
['vertex-ai-ip-range'].
Corresponds to the JSON property reservedIpRanges
16991 16992 16993 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16991 def reserved_ip_ranges @reserved_ip_ranges end |
#resource_pools ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ResourcePool>
Required. The spec of the pools of different resources.
Corresponds to the JSON property resourcePools
16996 16997 16998 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16996 def resource_pools @resource_pools end |
#resource_runtime ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ResourceRuntime
Persistent Cluster runtime information as output
Corresponds to the JSON property resourceRuntime
17001 17002 17003 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17001 def resource_runtime @resource_runtime end |
#resource_runtime_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ResourceRuntimeSpec
Configuration for the runtime on a PersistentResource instance, including but
not limited to: * Service accounts used to run the workloads. * Whether to
make it a dedicated Ray Cluster.
Corresponds to the JSON property resourceRuntimeSpec
17008 17009 17010 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17008 def resource_runtime_spec @resource_runtime_spec end |
#start_time ⇒ String
Output only. Time when the PersistentResource for the first time entered the
RUNNING state.
Corresponds to the JSON property startTime
17014 17015 17016 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17014 def start_time @start_time end |
#state ⇒ String
Output only. The detailed state of a Study.
Corresponds to the JSON property state
17019 17020 17021 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17019 def state @state end |
#update_time ⇒ String
Output only. Time when the PersistentResource was most recently updated.
Corresponds to the JSON property updateTime
17024 17025 17026 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17024 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17031 17032 17033 17034 17035 17036 17037 17038 17039 17040 17041 17042 17043 17044 17045 17046 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17031 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @error = args[:error] if args.key?(:error) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @reserved_ip_ranges = args[:reserved_ip_ranges] if args.key?(:reserved_ip_ranges) @resource_pools = args[:resource_pools] if args.key?(:resource_pools) @resource_runtime = args[:resource_runtime] if args.key?(:resource_runtime) @resource_runtime_spec = args[:resource_runtime_spec] if args.key?(:resource_runtime_spec) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |