Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineJob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

An instance of a machine learning PipelineJob.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1PipelineJob

Returns a new instance of GoogleCloudAiplatformV1PipelineJob.



29530
29531
29532
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29530

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Pipeline creation time. Corresponds to the JSON property createTime

Returns:

  • (String)


29389
29390
29391
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29389

def create_time
  @create_time
end

#display_nameString

The display name of the Pipeline. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


29395
29396
29397
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29395

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



29401
29402
29403
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29401

def encryption_spec
  @encryption_spec
end

#end_timeString

Output only. Pipeline end time. Corresponds to the JSON property endTime

Returns:

  • (String)


29406
29407
29408
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29406

def end_time
  @end_time
end

#errorGoogle::Apis::AiplatformV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



29416
29417
29418
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29416

def error
  @error
end

#job_detailGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineJobDetail

The runtime detail of PipelineJob. Corresponds to the JSON property jobDetail



29421
29422
29423
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29421

def job_detail
  @job_detail
end

#labelsHash<String,String>

The labels with user-defined metadata to organize PipelineJob. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. Note there is some reserved label key for Vertex AI Pipelines. - vertex-ai-pipelines-run-billing-id, user set value will get overrided. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


29432
29433
29434
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29432

def labels
  @labels
end

#nameString

Output only. The resource name of the PipelineJob. Corresponds to the JSON property name

Returns:

  • (String)


29437
29438
29439
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29437

def name
  @name
end

#networkString

The full name of the Compute Engine network to which the Pipeline Job's workload should be peered. For example, projects/12345/global/networks/myVPC. Format is of the form projects/project/global/ networks/network`. Whereprojectis a project number, as in12345, and networkis a network name. Private services access must already be configured for the network. Pipeline job will apply the network configuration to the Google Cloud resources being launched, if applied, such as Vertex AI Training or Dataflow job. If left unspecified, the workload is not peered with any network. Corresponds to the JSON propertynetwork`

Returns:

  • (String)


29451
29452
29453
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29451

def network
  @network
end

#pipeline_specHash<String,Object>

A compiled definition of a pipeline, represented as a JSON object. Defines the structure of the pipeline, including its components, tasks, and parameters. This specification is generated by compiling a pipeline function defined in Python using the Kubeflow Pipelines SDK. Corresponds to the JSON property pipelineSpec

Returns:

  • (Hash<String,Object>)


29459
29460
29461
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29459

def pipeline_spec
  @pipeline_spec
end

#preflight_validationsBoolean Also known as: preflight_validations?

Optional. Whether to do component level validations before job creation. Corresponds to the JSON property preflightValidations

Returns:

  • (Boolean)


29464
29465
29466
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29464

def preflight_validations
  @preflight_validations
end

#psc_interface_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PscInterfaceConfig

Configuration for PSC-I. Corresponds to the JSON property pscInterfaceConfig



29470
29471
29472
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29470

def psc_interface_config
  @psc_interface_config
end

#reserved_ip_rangesArray<String>

A list of names for the reserved ip ranges under the VPC network that can be used for this Pipeline Job's workload. If set, we will deploy the Pipeline Job' s workload within the provided ip ranges. Otherwise, the job will be deployed to any ip ranges under the provided VPC network. Example: ['vertex-ai-ip-range' ]. Corresponds to the JSON property reservedIpRanges

Returns:

  • (Array<String>)


29479
29480
29481
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29479

def reserved_ip_ranges
  @reserved_ip_ranges
end

#runtime_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineJobRuntimeConfig

The runtime config of a PipelineJob. Corresponds to the JSON property runtimeConfig



29484
29485
29486
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29484

def runtime_config
  @runtime_config
end

#schedule_nameString

Output only. The schedule resource name. Only returned if the Pipeline is created by Schedule API. Corresponds to the JSON property scheduleName

Returns:

  • (String)


29490
29491
29492
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29490

def schedule_name
  @schedule_name
end

#service_accountString

The service account that the pipeline workload runs as. If not specified, the Compute Engine default service account in the project will be used. See https:/ /cloud.google.com/compute/docs/access/service-accounts#default_service_account Users starting the pipeline must have the iam.serviceAccounts.actAs permission on this service account. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


29499
29500
29501
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29499

def 
  @service_account
end

#start_timeString

Output only. Pipeline start time. Corresponds to the JSON property startTime

Returns:

  • (String)


29504
29505
29506
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29504

def start_time
  @start_time
end

#stateString

Output only. The detailed state of the job. Corresponds to the JSON property state

Returns:

  • (String)


29509
29510
29511
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29509

def state
  @state
end

#template_metadataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTemplateMetadata

Pipeline template metadata if PipelineJob.template_uri is from supported template registry. Currently, the only supported registry is Artifact Registry. Corresponds to the JSON property templateMetadata



29515
29516
29517
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29515

def 
  @template_metadata
end

#template_uriString

A template uri from where the PipelineJob.pipeline_spec, if empty, will be downloaded. Currently, only uri from Vertex Template Registry & Gallery is supported. Reference to https://cloud.google.com/vertex-ai/docs/pipelines/ create-pipeline-template. Corresponds to the JSON property templateUri

Returns:

  • (String)


29523
29524
29525
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29523

def template_uri
  @template_uri
end

#update_timeString

Output only. Timestamp when this PipelineJob was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


29528
29529
29530
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29528

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29535
29536
29537
29538
29539
29540
29541
29542
29543
29544
29545
29546
29547
29548
29549
29550
29551
29552
29553
29554
29555
29556
29557
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29535

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @end_time = args[:end_time] if args.key?(:end_time)
  @error = args[:error] if args.key?(:error)
  @job_detail = args[:job_detail] if args.key?(:job_detail)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @pipeline_spec = args[:pipeline_spec] if args.key?(:pipeline_spec)
  @preflight_validations = args[:preflight_validations] if args.key?(:preflight_validations)
  @psc_interface_config = args[:psc_interface_config] if args.key?(:psc_interface_config)
  @reserved_ip_ranges = args[:reserved_ip_ranges] if args.key?(:reserved_ip_ranges)
  @runtime_config = args[:runtime_config] if args.key?(:runtime_config)
  @schedule_name = args[:schedule_name] if args.key?(:schedule_name)
  @service_account = args[:service_account] if args.key?(:service_account)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @template_metadata = args[:template_metadata] if args.key?(:template_metadata)
  @template_uri = args[:template_uri] if args.key?(:template_uri)
  @update_time = args[:update_time] if args.key?(:update_time)
end