Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineJob
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineJob
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
An instance of a machine learning PipelineJob.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
The display name of the Pipeline.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top- level resource.
-
#end_time ⇒ String
Output only.
-
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#job_detail ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineJobDetail
The runtime detail of PipelineJob.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize PipelineJob.
-
#name ⇒ String
Output only.
-
#network ⇒ String
The full name of the Compute Engine network to which the Pipeline Job's workload should be peered.
-
#pipeline_spec ⇒ Hash<String,Object>
The spec of the pipeline.
-
#preflight_validations ⇒ Boolean
(also: #preflight_validations?)
Optional.
-
#reserved_ip_ranges ⇒ Array<String>
A list of names for the reserved ip ranges under the VPC network that can be used for this Pipeline Job's workload.
-
#runtime_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineJobRuntimeConfig
The runtime config of a PipelineJob.
-
#schedule_name ⇒ String
Output only.
-
#service_account ⇒ String
The service account that the pipeline workload runs as.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#template_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTemplateMetadata
Pipeline template metadata if PipelineJob.template_uri is from supported template registry.
-
#template_uri ⇒ String
A template uri from where the PipelineJob.pipeline_spec, if empty, will be downloaded.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1PipelineJob
constructor
A new instance of GoogleCloudAiplatformV1PipelineJob.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1PipelineJob
Returns a new instance of GoogleCloudAiplatformV1PipelineJob.
17189 17190 17191 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17189 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Pipeline creation time.
Corresponds to the JSON property createTime
17056 17057 17058 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17056 def create_time @create_time end |
#display_name ⇒ String
The display name of the Pipeline. The name can be up to 128 characters long
and can consist of any UTF-8 characters.
Corresponds to the JSON property displayName
17062 17063 17064 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17062 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top-
level resource.
Corresponds to the JSON property encryptionSpec
17068 17069 17070 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17068 def encryption_spec @encryption_spec end |
#end_time ⇒ String
Output only. Pipeline end time.
Corresponds to the JSON property endTime
17073 17074 17075 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17073 def end_time @end_time end |
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
17083 17084 17085 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17083 def error @error end |
#job_detail ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineJobDetail
The runtime detail of PipelineJob.
Corresponds to the JSON property jobDetail
17088 17089 17090 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17088 def job_detail @job_detail end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize PipelineJob. Label keys and
values can be no longer than 64 characters (Unicode codepoints), can only
contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. See https://goo.gl/xmQnxf for more
information and examples of labels. Note there is some reserved label key for
Vertex AI Pipelines. - vertex-ai-pipelines-run-billing-id, user set value
will get overrided.
Corresponds to the JSON property labels
17099 17100 17101 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17099 def labels @labels end |
#name ⇒ String
Output only. The resource name of the PipelineJob.
Corresponds to the JSON property name
17104 17105 17106 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17104 def name @name end |
#network ⇒ String
The full name of the Compute Engine network to which the Pipeline Job's workload should be peered. For
example, projects/12345/global/networks/myVPC. Format is of the form projects/project/global/
networks/network`. Whereprojectis a project number, as in12345, and
networkis a network name. Private services access must already be configured
for the network. Pipeline job will apply the network configuration to the
Google Cloud resources being launched, if applied, such as Vertex AI Training
or Dataflow job. If left unspecified, the workload is not peered with any
network.
Corresponds to the JSON propertynetwork`
17118 17119 17120 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17118 def network @network end |
#pipeline_spec ⇒ Hash<String,Object>
The spec of the pipeline.
Corresponds to the JSON property pipelineSpec
17123 17124 17125 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17123 def pipeline_spec @pipeline_spec end |
#preflight_validations ⇒ Boolean Also known as: preflight_validations?
Optional. Whether to do component level validations before job creation.
Corresponds to the JSON property preflightValidations
17128 17129 17130 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17128 def preflight_validations @preflight_validations end |
#reserved_ip_ranges ⇒ Array<String>
A list of names for the reserved ip ranges under the VPC network that can be
used for this Pipeline Job's workload. If set, we will deploy the Pipeline Job'
s workload within the provided ip ranges. Otherwise, the job will be deployed
to any ip ranges under the provided VPC network. Example: ['vertex-ai-ip-range'
].
Corresponds to the JSON property reservedIpRanges
17138 17139 17140 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17138 def reserved_ip_ranges @reserved_ip_ranges end |
#runtime_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineJobRuntimeConfig
The runtime config of a PipelineJob.
Corresponds to the JSON property runtimeConfig
17143 17144 17145 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17143 def runtime_config @runtime_config end |
#schedule_name ⇒ String
Output only. The schedule resource name. Only returned if the Pipeline is
created by Schedule API.
Corresponds to the JSON property scheduleName
17149 17150 17151 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17149 def schedule_name @schedule_name end |
#service_account ⇒ String
The service account that the pipeline workload runs as. If not specified, the
Compute Engine default service account in the project will be used. See https:/
/cloud.google.com/compute/docs/access/service-accounts#default_service_account
Users starting the pipeline must have the iam.serviceAccounts.actAs
permission on this service account.
Corresponds to the JSON property serviceAccount
17158 17159 17160 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17158 def service_account @service_account end |
#start_time ⇒ String
Output only. Pipeline start time.
Corresponds to the JSON property startTime
17163 17164 17165 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17163 def start_time @start_time end |
#state ⇒ String
Output only. The detailed state of the job.
Corresponds to the JSON property state
17168 17169 17170 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17168 def state @state end |
#template_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTemplateMetadata
Pipeline template metadata if PipelineJob.template_uri is from supported
template registry. Currently, the only supported registry is Artifact Registry.
Corresponds to the JSON property templateMetadata
17174 17175 17176 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17174 def @template_metadata end |
#template_uri ⇒ String
A template uri from where the PipelineJob.pipeline_spec, if empty, will be
downloaded. Currently, only uri from Vertex Template Registry & Gallery is
supported. Reference to https://cloud.google.com/vertex-ai/docs/pipelines/
create-pipeline-template.
Corresponds to the JSON property templateUri
17182 17183 17184 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17182 def template_uri @template_uri end |
#update_time ⇒ String
Output only. Timestamp when this PipelineJob was most recently updated.
Corresponds to the JSON property updateTime
17187 17188 17189 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17187 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17194 17195 17196 17197 17198 17199 17200 17201 17202 17203 17204 17205 17206 17207 17208 17209 17210 17211 17212 17213 17214 17215 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17194 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @end_time = args[:end_time] if args.key?(:end_time) @error = args[:error] if args.key?(:error) @job_detail = args[:job_detail] if args.key?(:job_detail) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @pipeline_spec = args[:pipeline_spec] if args.key?(:pipeline_spec) @preflight_validations = args[:preflight_validations] if args.key?(:preflight_validations) @reserved_ip_ranges = args[:reserved_ip_ranges] if args.key?(:reserved_ip_ranges) @runtime_config = args[:runtime_config] if args.key?(:runtime_config) @schedule_name = args[:schedule_name] if args.key?(:schedule_name) @service_account = args[:service_account] if args.key?(:service_account) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @template_metadata = args[:template_metadata] if args.key?(:template_metadata) @template_uri = args[:template_uri] if args.key?(:template_uri) @update_time = args[:update_time] if args.key?(:update_time) end |