Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineJobRuntimeConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The runtime config of a PipelineJob.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1PipelineJobRuntimeConfig

Returns a new instance of GoogleCloudAiplatformV1PipelineJobRuntimeConfig.



27845
27846
27847
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27845

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#failure_policyString

Represents the failure policy of a pipeline. Currently, the default of a pipeline is that the pipeline will continue to run until no more tasks can be executed, also known as PIPELINE_FAILURE_POLICY_FAIL_SLOW. However, if a pipeline is set to PIPELINE_FAILURE_POLICY_FAIL_FAST, it will stop scheduling any new tasks when a task has failed. Any scheduled tasks will continue to completion. Corresponds to the JSON property failurePolicy

Returns:

  • (String)


27809
27810
27811
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27809

def failure_policy
  @failure_policy
end

#gcs_output_directoryString

Required. A path in a Cloud Storage bucket, which will be treated as the root output directory of the pipeline. It is used by the system to generate the paths of output artifacts. The artifact paths are generated with a sub-path pattern job_id`/`task_id`/`output_key under the specified output directory. The service account specified in this pipeline must have the storage.objects. get and storage.objects.create permissions for this bucket. Corresponds to the JSON property gcsOutputDirectory

Returns:

  • (String)


27819
27820
27821
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27819

def gcs_output_directory
  @gcs_output_directory
end

#input_artifactsHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineJobRuntimeConfigInputArtifact>

The runtime artifacts of the PipelineJob. The key will be the input artifact name and the value would be one of the InputArtifact. Corresponds to the JSON property inputArtifacts



27825
27826
27827
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27825

def input_artifacts
  @input_artifacts
end

#parameter_valuesHash<String,Object>

The runtime parameters of the PipelineJob. The parameters will be passed into PipelineJob.pipeline_spec to replace the placeholders at runtime. This field is used by pipelines built using PipelineJob.pipeline_spec.schema_version 2. 1.0, such as pipelines built using Kubeflow Pipelines SDK 1.9 or higher and the v2 DSL. Corresponds to the JSON property parameterValues

Returns:

  • (Hash<String,Object>)


27834
27835
27836
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27834

def parameter_values
  @parameter_values
end

#parametersHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Value>

Deprecated. Use RuntimeConfig.parameter_values instead. The runtime parameters of the PipelineJob. The parameters will be passed into PipelineJob. pipeline_spec to replace the placeholders at runtime. This field is used by pipelines built using PipelineJob.pipeline_spec.schema_version 2.0.0 or lower, such as pipelines built using Kubeflow Pipelines SDK 1.8 or lower. Corresponds to the JSON property parameters



27843
27844
27845
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27843

def parameters
  @parameters
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27850
27851
27852
27853
27854
27855
27856
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27850

def update!(**args)
  @failure_policy = args[:failure_policy] if args.key?(:failure_policy)
  @gcs_output_directory = args[:gcs_output_directory] if args.key?(:gcs_output_directory)
  @input_artifacts = args[:input_artifacts] if args.key?(:input_artifacts)
  @parameter_values = args[:parameter_values] if args.key?(:parameter_values)
  @parameters = args[:parameters] if args.key?(:parameters)
end