Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetail
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetail
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The runtime detail of a task execution.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#execution ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Execution
Instance of a general execution.
-
#executor_detail ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskExecutorDetail
The runtime detail of a pipeline executor.
-
#inputs ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetailArtifactList>
Output only.
-
#outputs ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetailArtifactList>
Output only.
-
#parent_task_id ⇒ Fixnum
Output only.
-
#pipeline_task_status ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetailPipelineTaskStatus>
Output only.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#task_id ⇒ Fixnum
Output only.
-
#task_name ⇒ String
Output only.
-
#task_unique_name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1PipelineTaskDetail
constructor
A new instance of GoogleCloudAiplatformV1PipelineTaskDetail.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1PipelineTaskDetail
Returns a new instance of GoogleCloudAiplatformV1PipelineTaskDetail.
29762 29763 29764 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29762 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Task create time.
Corresponds to the JSON property createTime
29682 29683 29684 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29682 def create_time @create_time end |
#end_time ⇒ String
Output only. Task end time.
Corresponds to the JSON property endTime
29687 29688 29689 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29687 def end_time @end_time end |
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
29697 29698 29699 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29697 def error @error end |
#execution ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Execution
Instance of a general execution.
Corresponds to the JSON property execution
29702 29703 29704 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29702 def execution @execution end |
#executor_detail ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskExecutorDetail
The runtime detail of a pipeline executor.
Corresponds to the JSON property executorDetail
29707 29708 29709 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29707 def executor_detail @executor_detail end |
#inputs ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetailArtifactList>
Output only. The runtime input artifacts of the task.
Corresponds to the JSON property inputs
29712 29713 29714 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29712 def inputs @inputs end |
#outputs ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetailArtifactList>
Output only. The runtime output artifacts of the task.
Corresponds to the JSON property outputs
29717 29718 29719 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29717 def outputs @outputs end |
#parent_task_id ⇒ Fixnum
Output only. The id of the parent task if the task is within a component scope.
Empty if the task is at the root level.
Corresponds to the JSON property parentTaskId
29723 29724 29725 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29723 def parent_task_id @parent_task_id end |
#pipeline_task_status ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetailPipelineTaskStatus>
Output only. A list of task status. This field keeps a record of task status
evolving over time.
Corresponds to the JSON property pipelineTaskStatus
29729 29730 29731 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29729 def pipeline_task_status @pipeline_task_status end |
#start_time ⇒ String
Output only. Task start time.
Corresponds to the JSON property startTime
29734 29735 29736 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29734 def start_time @start_time end |
#state ⇒ String
Output only. State of the task.
Corresponds to the JSON property state
29739 29740 29741 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29739 def state @state end |
#task_id ⇒ Fixnum
Output only. The system generated ID of the task.
Corresponds to the JSON property taskId
29744 29745 29746 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29744 def task_id @task_id end |
#task_name ⇒ String
Output only. The user specified name of the task that is defined in
pipeline_spec.
Corresponds to the JSON property taskName
29750 29751 29752 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29750 def task_name @task_name end |
#task_unique_name ⇒ String
Output only. The unique name of a task. This field is used by rerun pipeline
job. Console UI and Vertex AI SDK will support triggering pipeline job reruns.
The name is constructed by concatenating all the parent tasks name with the
task name. For example, if a task named "child_task" has a parent task named "
parent_task_1" and parent task 1 has a parent task named "parent_task_2", the
task unique name will be "parent_task_2.parent_task_1.child_task".
Corresponds to the JSON property taskUniqueName
29760 29761 29762 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29760 def task_unique_name @task_unique_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29767 29768 29769 29770 29771 29772 29773 29774 29775 29776 29777 29778 29779 29780 29781 29782 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29767 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @error = args[:error] if args.key?(:error) @execution = args[:execution] if args.key?(:execution) @executor_detail = args[:executor_detail] if args.key?(:executor_detail) @inputs = args[:inputs] if args.key?(:inputs) @outputs = args[:outputs] if args.key?(:outputs) @parent_task_id = args[:parent_task_id] if args.key?(:parent_task_id) @pipeline_task_status = args[:pipeline_task_status] if args.key?(:pipeline_task_status) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @task_id = args[:task_id] if args.key?(:task_id) @task_name = args[:task_name] if args.key?(:task_name) @task_unique_name = args[:task_unique_name] if args.key?(:task_unique_name) end |