Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetail

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The runtime detail of a task execution.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1PipelineTaskDetail

Returns a new instance of GoogleCloudAiplatformV1PipelineTaskDetail.



29345
29346
29347
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29345

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Task create time. Corresponds to the JSON property createTime

Returns:

  • (String)


29265
29266
29267
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29265

def create_time
  @create_time
end

#end_timeString

Output only. Task end time. Corresponds to the JSON property endTime

Returns:

  • (String)


29270
29271
29272
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29270

def end_time
  @end_time
end

#errorGoogle::Apis::AiplatformV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



29280
29281
29282
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29280

def error
  @error
end

#executionGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Execution

Instance of a general execution. Corresponds to the JSON property execution



29285
29286
29287
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29285

def execution
  @execution
end

#executor_detailGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskExecutorDetail

The runtime detail of a pipeline executor. Corresponds to the JSON property executorDetail



29290
29291
29292
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29290

def executor_detail
  @executor_detail
end

#inputsHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetailArtifactList>

Output only. The runtime input artifacts of the task. Corresponds to the JSON property inputs



29295
29296
29297
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29295

def inputs
  @inputs
end

#outputsHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetailArtifactList>

Output only. The runtime output artifacts of the task. Corresponds to the JSON property outputs



29300
29301
29302
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29300

def outputs
  @outputs
end

#parent_task_idFixnum

Output only. The id of the parent task if the task is within a component scope. Empty if the task is at the root level. Corresponds to the JSON property parentTaskId

Returns:

  • (Fixnum)


29306
29307
29308
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29306

def parent_task_id
  @parent_task_id
end

#pipeline_task_statusArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetailPipelineTaskStatus>

Output only. A list of task status. This field keeps a record of task status evolving over time. Corresponds to the JSON property pipelineTaskStatus



29312
29313
29314
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29312

def pipeline_task_status
  @pipeline_task_status
end

#start_timeString

Output only. Task start time. Corresponds to the JSON property startTime

Returns:

  • (String)


29317
29318
29319
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29317

def start_time
  @start_time
end

#stateString

Output only. State of the task. Corresponds to the JSON property state

Returns:

  • (String)


29322
29323
29324
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29322

def state
  @state
end

#task_idFixnum

Output only. The system generated ID of the task. Corresponds to the JSON property taskId

Returns:

  • (Fixnum)


29327
29328
29329
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29327

def task_id
  @task_id
end

#task_nameString

Output only. The user specified name of the task that is defined in pipeline_spec. Corresponds to the JSON property taskName

Returns:

  • (String)


29333
29334
29335
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29333

def task_name
  @task_name
end

#task_unique_nameString

Output only. The unique name of a task. This field is used by rerun pipeline job. Console UI and Vertex AI SDK will support triggering pipeline job reruns. The name is constructed by concatenating all the parent tasks name with the task name. For example, if a task named "child_task" has a parent task named " parent_task_1" and parent task 1 has a parent task named "parent_task_2", the task unique name will be "parent_task_2.parent_task_1.child_task". Corresponds to the JSON property taskUniqueName

Returns:

  • (String)


29343
29344
29345
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29343

def task_unique_name
  @task_unique_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29350
29351
29352
29353
29354
29355
29356
29357
29358
29359
29360
29361
29362
29363
29364
29365
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29350

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @error = args[:error] if args.key?(:error)
  @execution = args[:execution] if args.key?(:execution)
  @executor_detail = args[:executor_detail] if args.key?(:executor_detail)
  @inputs = args[:inputs] if args.key?(:inputs)
  @outputs = args[:outputs] if args.key?(:outputs)
  @parent_task_id = args[:parent_task_id] if args.key?(:parent_task_id)
  @pipeline_task_status = args[:pipeline_task_status] if args.key?(:pipeline_task_status)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @task_id = args[:task_id] if args.key?(:task_id)
  @task_name = args[:task_name] if args.key?(:task_name)
  @task_unique_name = args[:task_unique_name] if args.key?(:task_unique_name)
end