Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetail

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The runtime detail of a task execution.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1PipelineTaskDetail

Returns a new instance of GoogleCloudAiplatformV1PipelineTaskDetail.



22026
22027
22028
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22026

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Task create time. Corresponds to the JSON property createTime

Returns:

  • (String)


21946
21947
21948
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21946

def create_time
  @create_time
end

#end_timeString

Output only. Task end time. Corresponds to the JSON property endTime

Returns:

  • (String)


21951
21952
21953
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21951

def end_time
  @end_time
end

#errorGoogle::Apis::AiplatformV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



21961
21962
21963
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21961

def error
  @error
end

#executionGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Execution

Instance of a general execution. Corresponds to the JSON property execution



21966
21967
21968
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21966

def execution
  @execution
end

#executor_detailGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskExecutorDetail

The runtime detail of a pipeline executor. Corresponds to the JSON property executorDetail



21971
21972
21973
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21971

def executor_detail
  @executor_detail
end

#inputsHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetailArtifactList>

Output only. The runtime input artifacts of the task. Corresponds to the JSON property inputs



21976
21977
21978
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21976

def inputs
  @inputs
end

#outputsHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetailArtifactList>

Output only. The runtime output artifacts of the task. Corresponds to the JSON property outputs



21981
21982
21983
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21981

def outputs
  @outputs
end

#parent_task_idFixnum

Output only. The id of the parent task if the task is within a component scope. Empty if the task is at the root level. Corresponds to the JSON property parentTaskId

Returns:

  • (Fixnum)


21987
21988
21989
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21987

def parent_task_id
  @parent_task_id
end

#pipeline_task_statusArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetailPipelineTaskStatus>

Output only. A list of task status. This field keeps a record of task status evolving over time. Corresponds to the JSON property pipelineTaskStatus



21993
21994
21995
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21993

def pipeline_task_status
  @pipeline_task_status
end

#start_timeString

Output only. Task start time. Corresponds to the JSON property startTime

Returns:

  • (String)


21998
21999
22000
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21998

def start_time
  @start_time
end

#stateString

Output only. State of the task. Corresponds to the JSON property state

Returns:

  • (String)


22003
22004
22005
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22003

def state
  @state
end

#task_idFixnum

Output only. The system generated ID of the task. Corresponds to the JSON property taskId

Returns:

  • (Fixnum)


22008
22009
22010
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22008

def task_id
  @task_id
end

#task_nameString

Output only. The user specified name of the task that is defined in pipeline_spec. Corresponds to the JSON property taskName

Returns:

  • (String)


22014
22015
22016
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22014

def task_name
  @task_name
end

#task_unique_nameString

Output only. The unique name of a task. This field is used by rerun pipeline job. Console UI and Vertex AI SDK will support triggering pipeline job reruns. The name is constructed by concatenating all the parent tasks name with the task name. For example, if a task named "child_task" has a parent task named " parent_task_1" and parent task 1 has a parent task named "parent_task_2", the task unique name will be "parent_task_2.parent_task_1.child_task". Corresponds to the JSON property taskUniqueName

Returns:

  • (String)


22024
22025
22026
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22024

def task_unique_name
  @task_unique_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22031
22032
22033
22034
22035
22036
22037
22038
22039
22040
22041
22042
22043
22044
22045
22046
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22031

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @error = args[:error] if args.key?(:error)
  @execution = args[:execution] if args.key?(:execution)
  @executor_detail = args[:executor_detail] if args.key?(:executor_detail)
  @inputs = args[:inputs] if args.key?(:inputs)
  @outputs = args[:outputs] if args.key?(:outputs)
  @parent_task_id = args[:parent_task_id] if args.key?(:parent_task_id)
  @pipeline_task_status = args[:pipeline_task_status] if args.key?(:pipeline_task_status)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @task_id = args[:task_id] if args.key?(:task_id)
  @task_name = args[:task_name] if args.key?(:task_name)
  @task_unique_name = args[:task_unique_name] if args.key?(:task_unique_name)
end