Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetail
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetail
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The runtime detail of a task execution.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#execution ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Execution
Instance of a general execution.
-
#executor_detail ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskExecutorDetail
The runtime detail of a pipeline executor.
-
#inputs ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetailArtifactList>
Output only.
-
#outputs ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetailArtifactList>
Output only.
-
#parent_task_id ⇒ Fixnum
Output only.
-
#pipeline_task_status ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetailPipelineTaskStatus>
Output only.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#task_id ⇒ Fixnum
Output only.
-
#task_name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1PipelineTaskDetail
constructor
A new instance of GoogleCloudAiplatformV1PipelineTaskDetail.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1PipelineTaskDetail
Returns a new instance of GoogleCloudAiplatformV1PipelineTaskDetail.
21641 21642 21643 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21641 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Task create time.
Corresponds to the JSON property createTime
21571 21572 21573 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21571 def create_time @create_time end |
#end_time ⇒ String
Output only. Task end time.
Corresponds to the JSON property endTime
21576 21577 21578 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21576 def end_time @end_time end |
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
21586 21587 21588 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21586 def error @error end |
#execution ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Execution
Instance of a general execution.
Corresponds to the JSON property execution
21591 21592 21593 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21591 def execution @execution end |
#executor_detail ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskExecutorDetail
The runtime detail of a pipeline executor.
Corresponds to the JSON property executorDetail
21596 21597 21598 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21596 def executor_detail @executor_detail end |
#inputs ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetailArtifactList>
Output only. The runtime input artifacts of the task.
Corresponds to the JSON property inputs
21601 21602 21603 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21601 def inputs @inputs end |
#outputs ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetailArtifactList>
Output only. The runtime output artifacts of the task.
Corresponds to the JSON property outputs
21606 21607 21608 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21606 def outputs @outputs end |
#parent_task_id ⇒ Fixnum
Output only. The id of the parent task if the task is within a component scope.
Empty if the task is at the root level.
Corresponds to the JSON property parentTaskId
21612 21613 21614 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21612 def parent_task_id @parent_task_id end |
#pipeline_task_status ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetailPipelineTaskStatus>
Output only. A list of task status. This field keeps a record of task status
evolving over time.
Corresponds to the JSON property pipelineTaskStatus
21618 21619 21620 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21618 def pipeline_task_status @pipeline_task_status end |
#start_time ⇒ String
Output only. Task start time.
Corresponds to the JSON property startTime
21623 21624 21625 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21623 def start_time @start_time end |
#state ⇒ String
Output only. State of the task.
Corresponds to the JSON property state
21628 21629 21630 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21628 def state @state end |
#task_id ⇒ Fixnum
Output only. The system generated ID of the task.
Corresponds to the JSON property taskId
21633 21634 21635 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21633 def task_id @task_id end |
#task_name ⇒ String
Output only. The user specified name of the task that is defined in
pipeline_spec.
Corresponds to the JSON property taskName
21639 21640 21641 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21639 def task_name @task_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21646 21647 21648 21649 21650 21651 21652 21653 21654 21655 21656 21657 21658 21659 21660 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21646 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @error = args[:error] if args.key?(:error) @execution = args[:execution] if args.key?(:execution) @executor_detail = args[:executor_detail] if args.key?(:executor_detail) @inputs = args[:inputs] if args.key?(:inputs) @outputs = args[:outputs] if args.key?(:outputs) @parent_task_id = args[:parent_task_id] if args.key?(:parent_task_id) @pipeline_task_status = args[:pipeline_task_status] if args.key?(:pipeline_task_status) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @task_id = args[:task_id] if args.key?(:task_id) @task_name = args[:task_name] if args.key?(:task_name) end |