Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetail
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetail
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The runtime detail of a task execution.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#execution ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Execution
Instance of a general execution.
-
#executor_detail ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskExecutorDetail
The runtime detail of a pipeline executor.
-
#inputs ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetailArtifactList>
Output only.
-
#outputs ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetailArtifactList>
Output only.
-
#parent_task_id ⇒ Fixnum
Output only.
-
#pipeline_task_status ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetailPipelineTaskStatus>
Output only.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#task_id ⇒ Fixnum
Output only.
-
#task_name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1PipelineTaskDetail
constructor
A new instance of GoogleCloudAiplatformV1PipelineTaskDetail.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1PipelineTaskDetail
Returns a new instance of GoogleCloudAiplatformV1PipelineTaskDetail.
21254 21255 21256 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21254 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Task create time.
Corresponds to the JSON property createTime
21184 21185 21186 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21184 def create_time @create_time end |
#end_time ⇒ String
Output only. Task end time.
Corresponds to the JSON property endTime
21189 21190 21191 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21189 def end_time @end_time end |
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
21199 21200 21201 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21199 def error @error end |
#execution ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Execution
Instance of a general execution.
Corresponds to the JSON property execution
21204 21205 21206 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21204 def execution @execution end |
#executor_detail ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskExecutorDetail
The runtime detail of a pipeline executor.
Corresponds to the JSON property executorDetail
21209 21210 21211 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21209 def executor_detail @executor_detail end |
#inputs ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetailArtifactList>
Output only. The runtime input artifacts of the task.
Corresponds to the JSON property inputs
21214 21215 21216 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21214 def inputs @inputs end |
#outputs ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetailArtifactList>
Output only. The runtime output artifacts of the task.
Corresponds to the JSON property outputs
21219 21220 21221 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21219 def outputs @outputs end |
#parent_task_id ⇒ Fixnum
Output only. The id of the parent task if the task is within a component scope.
Empty if the task is at the root level.
Corresponds to the JSON property parentTaskId
21225 21226 21227 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21225 def parent_task_id @parent_task_id end |
#pipeline_task_status ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetailPipelineTaskStatus>
Output only. A list of task status. This field keeps a record of task status
evolving over time.
Corresponds to the JSON property pipelineTaskStatus
21231 21232 21233 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21231 def pipeline_task_status @pipeline_task_status end |
#start_time ⇒ String
Output only. Task start time.
Corresponds to the JSON property startTime
21236 21237 21238 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21236 def start_time @start_time end |
#state ⇒ String
Output only. State of the task.
Corresponds to the JSON property state
21241 21242 21243 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21241 def state @state end |
#task_id ⇒ Fixnum
Output only. The system generated ID of the task.
Corresponds to the JSON property taskId
21246 21247 21248 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21246 def task_id @task_id end |
#task_name ⇒ String
Output only. The user specified name of the task that is defined in
pipeline_spec.
Corresponds to the JSON property taskName
21252 21253 21254 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21252 def task_name @task_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21259 21260 21261 21262 21263 21264 21265 21266 21267 21268 21269 21270 21271 21272 21273 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21259 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @error = args[:error] if args.key?(:error) @execution = args[:execution] if args.key?(:execution) @executor_detail = args[:executor_detail] if args.key?(:executor_detail) @inputs = args[:inputs] if args.key?(:inputs) @outputs = args[:outputs] if args.key?(:outputs) @parent_task_id = args[:parent_task_id] if args.key?(:parent_task_id) @pipeline_task_status = args[:pipeline_task_status] if args.key?(:pipeline_task_status) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @task_id = args[:task_id] if args.key?(:task_id) @task_name = args[:task_name] if args.key?(:task_name) end |