Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetail

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The runtime detail of a task execution.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1PipelineTaskDetail

Returns a new instance of GoogleCloudAiplatformV1PipelineTaskDetail.



20962
20963
20964
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20962

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Task create time. Corresponds to the JSON property createTime

Returns:

  • (String)


20892
20893
20894
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20892

def create_time
  @create_time
end

#end_timeString

Output only. Task end time. Corresponds to the JSON property endTime

Returns:

  • (String)


20897
20898
20899
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20897

def end_time
  @end_time
end

#errorGoogle::Apis::AiplatformV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



20907
20908
20909
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20907

def error
  @error
end

#executionGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Execution

Instance of a general execution. Corresponds to the JSON property execution



20912
20913
20914
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20912

def execution
  @execution
end

#executor_detailGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskExecutorDetail

The runtime detail of a pipeline executor. Corresponds to the JSON property executorDetail



20917
20918
20919
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20917

def executor_detail
  @executor_detail
end

#inputsHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetailArtifactList>

Output only. The runtime input artifacts of the task. Corresponds to the JSON property inputs



20922
20923
20924
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20922

def inputs
  @inputs
end

#outputsHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetailArtifactList>

Output only. The runtime output artifacts of the task. Corresponds to the JSON property outputs



20927
20928
20929
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20927

def outputs
  @outputs
end

#parent_task_idFixnum

Output only. The id of the parent task if the task is within a component scope. Empty if the task is at the root level. Corresponds to the JSON property parentTaskId

Returns:

  • (Fixnum)


20933
20934
20935
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20933

def parent_task_id
  @parent_task_id
end

#pipeline_task_statusArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetailPipelineTaskStatus>

Output only. A list of task status. This field keeps a record of task status evolving over time. Corresponds to the JSON property pipelineTaskStatus



20939
20940
20941
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20939

def pipeline_task_status
  @pipeline_task_status
end

#start_timeString

Output only. Task start time. Corresponds to the JSON property startTime

Returns:

  • (String)


20944
20945
20946
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20944

def start_time
  @start_time
end

#stateString

Output only. State of the task. Corresponds to the JSON property state

Returns:

  • (String)


20949
20950
20951
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20949

def state
  @state
end

#task_idFixnum

Output only. The system generated ID of the task. Corresponds to the JSON property taskId

Returns:

  • (Fixnum)


20954
20955
20956
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20954

def task_id
  @task_id
end

#task_nameString

Output only. The user specified name of the task that is defined in pipeline_spec. Corresponds to the JSON property taskName

Returns:

  • (String)


20960
20961
20962
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20960

def task_name
  @task_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20967
20968
20969
20970
20971
20972
20973
20974
20975
20976
20977
20978
20979
20980
20981
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20967

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @error = args[:error] if args.key?(:error)
  @execution = args[:execution] if args.key?(:execution)
  @executor_detail = args[:executor_detail] if args.key?(:executor_detail)
  @inputs = args[:inputs] if args.key?(:inputs)
  @outputs = args[:outputs] if args.key?(:outputs)
  @parent_task_id = args[:parent_task_id] if args.key?(:parent_task_id)
  @pipeline_task_status = args[:pipeline_task_status] if args.key?(:pipeline_task_status)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @task_id = args[:task_id] if args.key?(:task_id)
  @task_name = args[:task_name] if args.key?(:task_name)
end