Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetail
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetail
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The runtime detail of a task execution.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#execution ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Execution
Instance of a general execution.
-
#executor_detail ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskExecutorDetail
The runtime detail of a pipeline executor.
-
#inputs ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetailArtifactList>
Output only.
-
#outputs ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetailArtifactList>
Output only.
-
#parent_task_id ⇒ Fixnum
Output only.
-
#pipeline_task_status ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetailPipelineTaskStatus>
Output only.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#task_id ⇒ Fixnum
Output only.
-
#task_name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1PipelineTaskDetail
constructor
A new instance of GoogleCloudAiplatformV1PipelineTaskDetail.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1PipelineTaskDetail
Returns a new instance of GoogleCloudAiplatformV1PipelineTaskDetail.
20805 20806 20807 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20805 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Task create time.
Corresponds to the JSON property createTime
20735 20736 20737 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20735 def create_time @create_time end |
#end_time ⇒ String
Output only. Task end time.
Corresponds to the JSON property endTime
20740 20741 20742 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20740 def end_time @end_time end |
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
20750 20751 20752 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20750 def error @error end |
#execution ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Execution
Instance of a general execution.
Corresponds to the JSON property execution
20755 20756 20757 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20755 def execution @execution end |
#executor_detail ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskExecutorDetail
The runtime detail of a pipeline executor.
Corresponds to the JSON property executorDetail
20760 20761 20762 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20760 def executor_detail @executor_detail end |
#inputs ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetailArtifactList>
Output only. The runtime input artifacts of the task.
Corresponds to the JSON property inputs
20765 20766 20767 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20765 def inputs @inputs end |
#outputs ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetailArtifactList>
Output only. The runtime output artifacts of the task.
Corresponds to the JSON property outputs
20770 20771 20772 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20770 def outputs @outputs end |
#parent_task_id ⇒ Fixnum
Output only. The id of the parent task if the task is within a component scope.
Empty if the task is at the root level.
Corresponds to the JSON property parentTaskId
20776 20777 20778 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20776 def parent_task_id @parent_task_id end |
#pipeline_task_status ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetailPipelineTaskStatus>
Output only. A list of task status. This field keeps a record of task status
evolving over time.
Corresponds to the JSON property pipelineTaskStatus
20782 20783 20784 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20782 def pipeline_task_status @pipeline_task_status end |
#start_time ⇒ String
Output only. Task start time.
Corresponds to the JSON property startTime
20787 20788 20789 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20787 def start_time @start_time end |
#state ⇒ String
Output only. State of the task.
Corresponds to the JSON property state
20792 20793 20794 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20792 def state @state end |
#task_id ⇒ Fixnum
Output only. The system generated ID of the task.
Corresponds to the JSON property taskId
20797 20798 20799 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20797 def task_id @task_id end |
#task_name ⇒ String
Output only. The user specified name of the task that is defined in
pipeline_spec.
Corresponds to the JSON property taskName
20803 20804 20805 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20803 def task_name @task_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20810 20811 20812 20813 20814 20815 20816 20817 20818 20819 20820 20821 20822 20823 20824 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20810 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @error = args[:error] if args.key?(:error) @execution = args[:execution] if args.key?(:execution) @executor_detail = args[:executor_detail] if args.key?(:executor_detail) @inputs = args[:inputs] if args.key?(:inputs) @outputs = args[:outputs] if args.key?(:outputs) @parent_task_id = args[:parent_task_id] if args.key?(:parent_task_id) @pipeline_task_status = args[:pipeline_task_status] if args.key?(:pipeline_task_status) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @task_id = args[:task_id] if args.key?(:task_id) @task_name = args[:task_name] if args.key?(:task_name) end |