Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetail

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The runtime detail of a task execution.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1PipelineTaskDetail

Returns a new instance of GoogleCloudAiplatformV1PipelineTaskDetail.



17929
17930
17931
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17929

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Task create time. Corresponds to the JSON property createTime

Returns:

  • (String)


17859
17860
17861
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17859

def create_time
  @create_time
end

#end_timeString

Output only. Task end time. Corresponds to the JSON property endTime

Returns:

  • (String)


17864
17865
17866
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17864

def end_time
  @end_time
end

#errorGoogle::Apis::AiplatformV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



17874
17875
17876
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17874

def error
  @error
end

#executionGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Execution

Instance of a general execution. Corresponds to the JSON property execution



17879
17880
17881
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17879

def execution
  @execution
end

#executor_detailGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskExecutorDetail

The runtime detail of a pipeline executor. Corresponds to the JSON property executorDetail



17884
17885
17886
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17884

def executor_detail
  @executor_detail
end

#inputsHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetailArtifactList>

Output only. The runtime input artifacts of the task. Corresponds to the JSON property inputs



17889
17890
17891
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17889

def inputs
  @inputs
end

#outputsHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetailArtifactList>

Output only. The runtime output artifacts of the task. Corresponds to the JSON property outputs



17894
17895
17896
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17894

def outputs
  @outputs
end

#parent_task_idFixnum

Output only. The id of the parent task if the task is within a component scope. Empty if the task is at the root level. Corresponds to the JSON property parentTaskId

Returns:

  • (Fixnum)


17900
17901
17902
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17900

def parent_task_id
  @parent_task_id
end

#pipeline_task_statusArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetailPipelineTaskStatus>

Output only. A list of task status. This field keeps a record of task status evolving over time. Corresponds to the JSON property pipelineTaskStatus



17906
17907
17908
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17906

def pipeline_task_status
  @pipeline_task_status
end

#start_timeString

Output only. Task start time. Corresponds to the JSON property startTime

Returns:

  • (String)


17911
17912
17913
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17911

def start_time
  @start_time
end

#stateString

Output only. State of the task. Corresponds to the JSON property state

Returns:

  • (String)


17916
17917
17918
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17916

def state
  @state
end

#task_idFixnum

Output only. The system generated ID of the task. Corresponds to the JSON property taskId

Returns:

  • (Fixnum)


17921
17922
17923
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17921

def task_id
  @task_id
end

#task_nameString

Output only. The user specified name of the task that is defined in pipeline_spec. Corresponds to the JSON property taskName

Returns:

  • (String)


17927
17928
17929
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17927

def task_name
  @task_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17934
17935
17936
17937
17938
17939
17940
17941
17942
17943
17944
17945
17946
17947
17948
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17934

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @error = args[:error] if args.key?(:error)
  @execution = args[:execution] if args.key?(:execution)
  @executor_detail = args[:executor_detail] if args.key?(:executor_detail)
  @inputs = args[:inputs] if args.key?(:inputs)
  @outputs = args[:outputs] if args.key?(:outputs)
  @parent_task_id = args[:parent_task_id] if args.key?(:parent_task_id)
  @pipeline_task_status = args[:pipeline_task_status] if args.key?(:pipeline_task_status)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @task_id = args[:task_id] if args.key?(:task_id)
  @task_name = args[:task_name] if args.key?(:task_name)
end