Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetailPipelineTaskStatus
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetailPipelineTaskStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A single record of the task status.
Instance Attribute Summary collapse
-
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1PipelineTaskDetailPipelineTaskStatus
constructor
A new instance of GoogleCloudAiplatformV1PipelineTaskDetailPipelineTaskStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1PipelineTaskDetailPipelineTaskStatus
Returns a new instance of GoogleCloudAiplatformV1PipelineTaskDetailPipelineTaskStatus.
29815 29816 29817 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29815 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
29803 29804 29805 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29803 def error @error end |
#state ⇒ String
Output only. The state of the task.
Corresponds to the JSON property state
29808 29809 29810 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29808 def state @state end |
#update_time ⇒ String
Output only. Update time of this status.
Corresponds to the JSON property updateTime
29813 29814 29815 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29813 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29820 29821 29822 29823 29824 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29820 def update!(**args) @error = args[:error] if args.key?(:error) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |