Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskDetailPipelineTaskStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A single record of the task status.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1PipelineTaskDetailPipelineTaskStatus

Returns a new instance of GoogleCloudAiplatformV1PipelineTaskDetailPipelineTaskStatus.



22082
22083
22084
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22082

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::AiplatformV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



22070
22071
22072
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22070

def error
  @error
end

#stateString

Output only. The state of the task. Corresponds to the JSON property state

Returns:

  • (String)


22075
22076
22077
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22075

def state
  @state
end

#update_timeString

Output only. Update time of this status. Corresponds to the JSON property updateTime

Returns:

  • (String)


22080
22081
22082
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22080

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22087
22088
22089
22090
22091
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22087

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end