Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskExecutorDetailContainerDetail
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PipelineTaskExecutorDetailContainerDetail
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The detail of a container execution. It contains the job names of the lifecycle of a container execution.
Instance Attribute Summary collapse
-
#failed_main_jobs ⇒ Array<String>
Output only.
-
#failed_pre_caching_check_jobs ⇒ Array<String>
Output only.
-
#main_job ⇒ String
Output only.
-
#pre_caching_check_job ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1PipelineTaskExecutorDetailContainerDetail
constructor
A new instance of GoogleCloudAiplatformV1PipelineTaskExecutorDetailContainerDetail.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1PipelineTaskExecutorDetailContainerDetail
Returns a new instance of GoogleCloudAiplatformV1PipelineTaskExecutorDetailContainerDetail.
26600 26601 26602 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26600 def initialize(**args) update!(**args) end |
Instance Attribute Details
#failed_main_jobs ⇒ Array<String>
Output only. The names of the previously failed CustomJob for the main
container executions. The list includes the all attempts in chronological
order.
Corresponds to the JSON property failedMainJobs
26578 26579 26580 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26578 def failed_main_jobs @failed_main_jobs end |
#failed_pre_caching_check_jobs ⇒ Array<String>
Output only. The names of the previously failed CustomJob for the pre-caching-
check container executions. This job will be available if the PipelineJob.
pipeline_spec specifies the pre_caching_check hook in the lifecycle events.
The list includes the all attempts in chronological order.
Corresponds to the JSON property failedPreCachingCheckJobs
26586 26587 26588 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26586 def failed_pre_caching_check_jobs @failed_pre_caching_check_jobs end |
#main_job ⇒ String
Output only. The name of the CustomJob for the main container execution.
Corresponds to the JSON property mainJob
26591 26592 26593 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26591 def main_job @main_job end |
#pre_caching_check_job ⇒ String
Output only. The name of the CustomJob for the pre-caching-check container
execution. This job will be available if the PipelineJob.pipeline_spec
specifies the pre_caching_check hook in the lifecycle events.
Corresponds to the JSON property preCachingCheckJob
26598 26599 26600 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26598 def pre_caching_check_job @pre_caching_check_job end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26605 26606 26607 26608 26609 26610 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26605 def update!(**args) @failed_main_jobs = args[:failed_main_jobs] if args.key?(:failed_main_jobs) @failed_pre_caching_check_jobs = args[:failed_pre_caching_check_jobs] if args.key?(:failed_pre_caching_check_jobs) @main_job = args[:main_job] if args.key?(:main_job) @pre_caching_check_job = args[:pre_caching_check_job] if args.key?(:pre_caching_check_job) end |