Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PointwiseMetricInstance
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PointwiseMetricInstance
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Pointwise metric instance. Usually one instance corresponds to one row in an evaluation dataset.
Instance Attribute Summary collapse
-
#content_map_instance ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ContentMap
Map of placeholder in metric prompt template to contents of model input.
-
#json_instance ⇒ String
Instance specified as a json string.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1PointwiseMetricInstance
constructor
A new instance of GoogleCloudAiplatformV1PointwiseMetricInstance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1PointwiseMetricInstance
Returns a new instance of GoogleCloudAiplatformV1PointwiseMetricInstance.
22650 22651 22652 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22650 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content_map_instance ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ContentMap
Map of placeholder in metric prompt template to contents of model input.
Corresponds to the JSON property contentMapInstance
22642 22643 22644 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22642 def content_map_instance @content_map_instance end |
#json_instance ⇒ String
Instance specified as a json string. String key-value pairs are expected in
the json_instance to render PointwiseMetricSpec.instance_prompt_template.
Corresponds to the JSON property jsonInstance
22648 22649 22650 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22648 def json_instance @json_instance end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22655 22656 22657 22658 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22655 def update!(**args) @content_map_instance = args[:content_map_instance] if args.key?(:content_map_instance) @json_instance = args[:json_instance] if args.key?(:json_instance) end |