Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PostStartupScriptConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PostStartupScriptConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Post startup script config.
Instance Attribute Summary collapse
-
#post_startup_script ⇒ String
Optional.
-
#post_startup_script_behavior ⇒ String
Optional.
-
#post_startup_script_url ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1PostStartupScriptConfig
constructor
A new instance of GoogleCloudAiplatformV1PostStartupScriptConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1PostStartupScriptConfig
Returns a new instance of GoogleCloudAiplatformV1PostStartupScriptConfig.
22763 22764 22765 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22763 def initialize(**args) update!(**args) end |
Instance Attribute Details
#post_startup_script ⇒ String
Optional. Post startup script to run after runtime is started.
Corresponds to the JSON property postStartupScript
22750 22751 22752 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22750 def post_startup_script @post_startup_script end |
#post_startup_script_behavior ⇒ String
Optional. Post startup script behavior that defines download and execution
behavior.
Corresponds to the JSON property postStartupScriptBehavior
22756 22757 22758 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22756 def post_startup_script_behavior @post_startup_script_behavior end |
#post_startup_script_url ⇒ String
Optional. Post startup script url to download. Example: gs://bucket/script.sh
Corresponds to the JSON property postStartupScriptUrl
22761 22762 22763 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22761 def post_startup_script_url @post_startup_script_url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22768 22769 22770 22771 22772 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22768 def update!(**args) @post_startup_script = args[:post_startup_script] if args.key?(:post_startup_script) @post_startup_script_behavior = args[:post_startup_script_behavior] if args.key?(:post_startup_script_behavior) @post_startup_script_url = args[:post_startup_script_url] if args.key?(:post_startup_script_url) end |