Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PostStartupScriptConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Post startup script config.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1PostStartupScriptConfig

Returns a new instance of GoogleCloudAiplatformV1PostStartupScriptConfig.



22432
22433
22434
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22432

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#post_startup_scriptString

Optional. Post startup script to run after runtime is started. Corresponds to the JSON property postStartupScript

Returns:

  • (String)


22419
22420
22421
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22419

def post_startup_script
  @post_startup_script
end

#post_startup_script_behaviorString

Optional. Post startup script behavior that defines download and execution behavior. Corresponds to the JSON property postStartupScriptBehavior

Returns:

  • (String)


22425
22426
22427
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22425

def post_startup_script_behavior
  @post_startup_script_behavior
end

#post_startup_script_urlString

Optional. Post startup script url to download. Example: gs://bucket/script.sh Corresponds to the JSON property postStartupScriptUrl

Returns:

  • (String)


22430
22431
22432
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22430

def post_startup_script_url
  @post_startup_script_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22437
22438
22439
22440
22441
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22437

def update!(**args)
  @post_startup_script = args[:post_startup_script] if args.key?(:post_startup_script)
  @post_startup_script_behavior = args[:post_startup_script_behavior] if args.key?(:post_startup_script_behavior)
  @post_startup_script_url = args[:post_startup_script_url] if args.key?(:post_startup_script_url)
end