Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PredictLongRunningRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PredictLongRunningRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Request message for PredictionService.PredictLongRunning.
Instance Attribute Summary collapse
-
#instances ⇒ Array<Object>
Required.
-
#labels ⇒ Hash<String,String>
Optional.
-
#parameters ⇒ Object
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1PredictLongRunningRequest
constructor
A new instance of GoogleCloudAiplatformV1PredictLongRunningRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1PredictLongRunningRequest
Returns a new instance of GoogleCloudAiplatformV1PredictLongRunningRequest.
28467 28468 28469 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28467 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instances ⇒ Array<Object>
Required. The instances that are the input to the prediction call. A
DeployedModel may have an upper limit on the number of instances it supports
per request, and when it is exceeded the prediction call errors in case of
AutoML Models, or, in case of customer created Models, the behaviour is as
documented by that Model. The schema of any single instance may be specified
via Endpoint's DeployedModels' Model's PredictSchemata's instance_schema_uri.
Corresponds to the JSON property instances
28449 28450 28451 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28449 def instances @instances end |
#labels ⇒ Hash<String,String>
Optional. The labels with user-defined metadata for the request. It is used
for billing and reporting only. Label keys and values can be no longer than 63
characters (Unicode codepoints) and can only contain lowercase letters,
numeric characters, underscores, and dashes. International characters are
allowed. Label values are optional. Label keys must start with a letter.
Corresponds to the JSON property labels
28458 28459 28460 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28458 def labels @labels end |
#parameters ⇒ Object
Optional. The parameters that govern the prediction. The schema of the
parameters may be specified via Endpoint's DeployedModels' Model's
PredictSchemata's parameters_schema_uri.
Corresponds to the JSON property parameters
28465 28466 28467 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28465 def parameters @parameters end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28472 28473 28474 28475 28476 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28472 def update!(**args) @instances = args[:instances] if args.key?(:instances) @labels = args[:labels] if args.key?(:labels) @parameters = args[:parameters] if args.key?(:parameters) end |