Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PredictLongRunningRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for PredictionService.PredictLongRunning.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1PredictLongRunningRequest

Returns a new instance of GoogleCloudAiplatformV1PredictLongRunningRequest.



21660
21661
21662
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21660

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instancesArray<Object>

Required. The instances that are the input to the prediction call. A DeployedModel may have an upper limit on the number of instances it supports per request, and when it is exceeded the prediction call errors in case of AutoML Models, or, in case of customer created Models, the behaviour is as documented by that Model. The schema of any single instance may be specified via Endpoint's DeployedModels' Model's PredictSchemata's instance_schema_uri. Corresponds to the JSON property instances

Returns:

  • (Array<Object>)


21651
21652
21653
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21651

def instances
  @instances
end

#parametersObject

Optional. The parameters that govern the prediction. The schema of the parameters may be specified via Endpoint's DeployedModels' Model's PredictSchemata's parameters_schema_uri. Corresponds to the JSON property parameters

Returns:

  • (Object)


21658
21659
21660
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21658

def parameters
  @parameters
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21665
21666
21667
21668
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21665

def update!(**args)
  @instances = args[:instances] if args.key?(:instances)
  @parameters = args[:parameters] if args.key?(:parameters)
end