Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PredictLongRunningRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PredictLongRunningRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Request message for PredictionService.PredictLongRunning.
Instance Attribute Summary collapse
-
#instances ⇒ Array<Object>
Required.
-
#parameters ⇒ Object
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1PredictLongRunningRequest
constructor
A new instance of GoogleCloudAiplatformV1PredictLongRunningRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1PredictLongRunningRequest
Returns a new instance of GoogleCloudAiplatformV1PredictLongRunningRequest.
21395 21396 21397 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21395 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instances ⇒ Array<Object>
Required. The instances that are the input to the prediction call. A
DeployedModel may have an upper limit on the number of instances it supports
per request, and when it is exceeded the prediction call errors in case of
AutoML Models, or, in case of customer created Models, the behaviour is as
documented by that Model. The schema of any single instance may be specified
via Endpoint's DeployedModels' Model's PredictSchemata's instance_schema_uri.
Corresponds to the JSON property instances
21386 21387 21388 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21386 def instances @instances end |
#parameters ⇒ Object
Optional. The parameters that govern the prediction. The schema of the
parameters may be specified via Endpoint's DeployedModels' Model's
PredictSchemata's parameters_schema_uri.
Corresponds to the JSON property parameters
21393 21394 21395 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21393 def parameters @parameters end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21400 21401 21402 21403 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21400 def update!(**args) @instances = args[:instances] if args.key?(:instances) @parameters = args[:parameters] if args.key?(:parameters) end |