Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PredictRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PredictRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Request message for PredictionService.Predict.
Instance Attribute Summary collapse
-
#instances ⇒ Array<Object>
Required.
-
#labels ⇒ Hash<String,String>
Optional.
-
#parameters ⇒ Object
The parameters that govern the prediction.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1PredictRequest
constructor
A new instance of GoogleCloudAiplatformV1PredictRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1PredictRequest
Returns a new instance of GoogleCloudAiplatformV1PredictRequest.
31239 31240 31241 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31239 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instances ⇒ Array<Object>
Required. The instances that are the input to the prediction call. A
DeployedModel may have an upper limit on the number of instances it supports
per request, and when it is exceeded the prediction call errors in case of
AutoML Models, or, in case of customer created Models, the behaviour is as
documented by that Model. The schema of any single instance may be specified
via Endpoint's DeployedModels' Model's PredictSchemata's instance_schema_uri.
Corresponds to the JSON property instances
31224 31225 31226 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31224 def instances @instances end |
#labels ⇒ Hash<String,String>
Optional. The user labels for Imagen billing usage only. Only Imagen supports
labels. For other use cases, it will be ignored.
Corresponds to the JSON property labels
31230 31231 31232 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31230 def labels @labels end |
#parameters ⇒ Object
The parameters that govern the prediction. The schema of the parameters may be
specified via Endpoint's DeployedModels' Model's PredictSchemata's
parameters_schema_uri.
Corresponds to the JSON property parameters
31237 31238 31239 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31237 def parameters @parameters end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31244 31245 31246 31247 31248 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31244 def update!(**args) @instances = args[:instances] if args.key?(:instances) @labels = args[:labels] if args.key?(:labels) @parameters = args[:parameters] if args.key?(:parameters) end |