Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PredictRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PredictRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Request message for PredictionService.Predict.
Instance Attribute Summary collapse
-
#instances ⇒ Array<Object>
Required.
-
#labels ⇒ Hash<String,String>
Optional.
-
#parameters ⇒ Object
The parameters that govern the prediction.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1PredictRequest
constructor
A new instance of GoogleCloudAiplatformV1PredictRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1PredictRequest
Returns a new instance of GoogleCloudAiplatformV1PredictRequest.
28449 28450 28451 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28449 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instances ⇒ Array<Object>
Required. The instances that are the input to the prediction call. A
DeployedModel may have an upper limit on the number of instances it supports
per request, and when it is exceeded the prediction call errors in case of
AutoML Models, or, in case of customer created Models, the behaviour is as
documented by that Model. The schema of any single instance may be specified
via Endpoint's DeployedModels' Model's PredictSchemata's instance_schema_uri.
Corresponds to the JSON property instances
28434 28435 28436 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28434 def instances @instances end |
#labels ⇒ Hash<String,String>
Optional. The user labels for Imagen billing usage only. Only Imagen supports
labels. For other use cases, it will be ignored.
Corresponds to the JSON property labels
28440 28441 28442 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28440 def labels @labels end |
#parameters ⇒ Object
The parameters that govern the prediction. The schema of the parameters may be
specified via Endpoint's DeployedModels' Model's PredictSchemata's
parameters_schema_uri.
Corresponds to the JSON property parameters
28447 28448 28449 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28447 def parameters @parameters end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28454 28455 28456 28457 28458 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28454 def update!(**args) @instances = args[:instances] if args.key?(:instances) @labels = args[:labels] if args.key?(:labels) @parameters = args[:parameters] if args.key?(:parameters) end |