Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PredictRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PredictRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Request message for PredictionService.Predict.
Instance Attribute Summary collapse
-
#instances ⇒ Array<Object>
Required.
-
#parameters ⇒ Object
The parameters that govern the prediction.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1PredictRequest
constructor
A new instance of GoogleCloudAiplatformV1PredictRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1PredictRequest
Returns a new instance of GoogleCloudAiplatformV1PredictRequest.
21427 21428 21429 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21427 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instances ⇒ Array<Object>
Required. The instances that are the input to the prediction call. A
DeployedModel may have an upper limit on the number of instances it supports
per request, and when it is exceeded the prediction call errors in case of
AutoML Models, or, in case of customer created Models, the behaviour is as
documented by that Model. The schema of any single instance may be specified
via Endpoint's DeployedModels' Model's PredictSchemata's instance_schema_uri.
Corresponds to the JSON property instances
21418 21419 21420 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21418 def instances @instances end |
#parameters ⇒ Object
The parameters that govern the prediction. The schema of the parameters may be
specified via Endpoint's DeployedModels' Model's PredictSchemata's
parameters_schema_uri.
Corresponds to the JSON property parameters
21425 21426 21427 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21425 def parameters @parameters end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21432 21433 21434 21435 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21432 def update!(**args) @instances = args[:instances] if args.key?(:instances) @parameters = args[:parameters] if args.key?(:parameters) end |