Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PredictResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PredictResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Response message for PredictionService.Predict.
Instance Attribute Summary collapse
-
#deployed_model_id ⇒ String
ID of the Endpoint's DeployedModel that served this prediction.
-
#metadata ⇒ Object
Output only.
-
#model ⇒ String
Output only.
-
#model_display_name ⇒ String
Output only.
-
#model_version_id ⇒ String
Output only.
-
#predictions ⇒ Array<Object>
The predictions that are the output of the predictions call.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1PredictResponse
constructor
A new instance of GoogleCloudAiplatformV1PredictResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1PredictResponse
Returns a new instance of GoogleCloudAiplatformV1PredictResponse.
21733 21734 21735 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21733 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deployed_model_id ⇒ String
ID of the Endpoint's DeployedModel that served this prediction.
Corresponds to the JSON property deployedModelId
21700 21701 21702 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21700 def deployed_model_id @deployed_model_id end |
#metadata ⇒ Object
Output only. Request-level metadata returned by the model. The metadata type
will be dependent upon the model implementation.
Corresponds to the JSON property metadata
21706 21707 21708 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21706 def @metadata end |
#model ⇒ String
Output only. The resource name of the Model which is deployed as the
DeployedModel that this prediction hits.
Corresponds to the JSON property model
21712 21713 21714 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21712 def model @model end |
#model_display_name ⇒ String
Output only. The display name of the Model which is deployed as the
DeployedModel that this prediction hits.
Corresponds to the JSON property modelDisplayName
21718 21719 21720 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21718 def model_display_name @model_display_name end |
#model_version_id ⇒ String
Output only. The version ID of the Model which is deployed as the
DeployedModel that this prediction hits.
Corresponds to the JSON property modelVersionId
21724 21725 21726 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21724 def model_version_id @model_version_id end |
#predictions ⇒ Array<Object>
The predictions that are the output of the predictions call. The schema of any
single prediction may be specified via Endpoint's DeployedModels' Model's
PredictSchemata's prediction_schema_uri.
Corresponds to the JSON property predictions
21731 21732 21733 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21731 def predictions @predictions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21738 21739 21740 21741 21742 21743 21744 21745 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21738 def update!(**args) @deployed_model_id = args[:deployed_model_id] if args.key?(:deployed_model_id) @metadata = args[:metadata] if args.key?(:metadata) @model = args[:model] if args.key?(:model) @model_display_name = args[:model_display_name] if args.key?(:model_display_name) @model_version_id = args[:model_version_id] if args.key?(:model_version_id) @predictions = args[:predictions] if args.key?(:predictions) end |