Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PredictResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PredictResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Response message for PredictionService.Predict.
Instance Attribute Summary collapse
-
#deployed_model_id ⇒ String
ID of the Endpoint's DeployedModel that served this prediction.
-
#metadata ⇒ Object
Output only.
-
#model ⇒ String
Output only.
-
#model_display_name ⇒ String
Output only.
-
#model_version_id ⇒ String
Output only.
-
#predictions ⇒ Array<Object>
The predictions that are the output of the predictions call.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1PredictResponse
constructor
A new instance of GoogleCloudAiplatformV1PredictResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1PredictResponse
Returns a new instance of GoogleCloudAiplatformV1PredictResponse.
21486 21487 21488 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21486 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deployed_model_id ⇒ String
ID of the Endpoint's DeployedModel that served this prediction.
Corresponds to the JSON property deployedModelId
21453 21454 21455 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21453 def deployed_model_id @deployed_model_id end |
#metadata ⇒ Object
Output only. Request-level metadata returned by the model. The metadata type
will be dependent upon the model implementation.
Corresponds to the JSON property metadata
21459 21460 21461 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21459 def @metadata end |
#model ⇒ String
Output only. The resource name of the Model which is deployed as the
DeployedModel that this prediction hits.
Corresponds to the JSON property model
21465 21466 21467 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21465 def model @model end |
#model_display_name ⇒ String
Output only. The display name of the Model which is deployed as the
DeployedModel that this prediction hits.
Corresponds to the JSON property modelDisplayName
21471 21472 21473 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21471 def model_display_name @model_display_name end |
#model_version_id ⇒ String
Output only. The version ID of the Model which is deployed as the
DeployedModel that this prediction hits.
Corresponds to the JSON property modelVersionId
21477 21478 21479 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21477 def model_version_id @model_version_id end |
#predictions ⇒ Array<Object>
The predictions that are the output of the predictions call. The schema of any
single prediction may be specified via Endpoint's DeployedModels' Model's
PredictSchemata's prediction_schema_uri.
Corresponds to the JSON property predictions
21484 21485 21486 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21484 def predictions @predictions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21491 21492 21493 21494 21495 21496 21497 21498 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21491 def update!(**args) @deployed_model_id = args[:deployed_model_id] if args.key?(:deployed_model_id) @metadata = args[:metadata] if args.key?(:metadata) @model = args[:model] if args.key?(:model) @model_display_name = args[:model_display_name] if args.key?(:model_display_name) @model_version_id = args[:model_version_id] if args.key?(:model_version_id) @predictions = args[:predictions] if args.key?(:predictions) end |