Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PredictResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Response message for PredictionService.Predict.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1PredictResponse

Returns a new instance of GoogleCloudAiplatformV1PredictResponse.



21462
21463
21464
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21462

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deployed_model_idString

ID of the Endpoint's DeployedModel that served this prediction. Corresponds to the JSON property deployedModelId

Returns:

  • (String)


21429
21430
21431
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21429

def deployed_model_id
  @deployed_model_id
end

#metadataObject

Output only. Request-level metadata returned by the model. The metadata type will be dependent upon the model implementation. Corresponds to the JSON property metadata

Returns:

  • (Object)


21435
21436
21437
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21435

def 
  @metadata
end

#modelString

Output only. The resource name of the Model which is deployed as the DeployedModel that this prediction hits. Corresponds to the JSON property model

Returns:

  • (String)


21441
21442
21443
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21441

def model
  @model
end

#model_display_nameString

Output only. The display name of the Model which is deployed as the DeployedModel that this prediction hits. Corresponds to the JSON property modelDisplayName

Returns:

  • (String)


21447
21448
21449
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21447

def model_display_name
  @model_display_name
end

#model_version_idString

Output only. The version ID of the Model which is deployed as the DeployedModel that this prediction hits. Corresponds to the JSON property modelVersionId

Returns:

  • (String)


21453
21454
21455
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21453

def model_version_id
  @model_version_id
end

#predictionsArray<Object>

The predictions that are the output of the predictions call. The schema of any single prediction may be specified via Endpoint's DeployedModels' Model's PredictSchemata's prediction_schema_uri. Corresponds to the JSON property predictions

Returns:

  • (Array<Object>)


21460
21461
21462
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21460

def predictions
  @predictions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21467
21468
21469
21470
21471
21472
21473
21474
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21467

def update!(**args)
  @deployed_model_id = args[:deployed_model_id] if args.key?(:deployed_model_id)
  @metadata = args[:metadata] if args.key?(:metadata)
  @model = args[:model] if args.key?(:model)
  @model_display_name = args[:model_display_name] if args.key?(:model_display_name)
  @model_version_id = args[:model_version_id] if args.key?(:model_version_id)
  @predictions = args[:predictions] if args.key?(:predictions)
end