Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PredictSchemata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PredictSchemata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Contains the schemata used in Model's predictions and explanations via PredictionService.Predict, PredictionService.Explain and BatchPredictionJob.
Instance Attribute Summary collapse
-
#instance_schema_uri ⇒ String
Immutable.
-
#parameters_schema_uri ⇒ String
Immutable.
-
#prediction_schema_uri ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1PredictSchemata
constructor
A new instance of GoogleCloudAiplatformV1PredictSchemata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1PredictSchemata
Returns a new instance of GoogleCloudAiplatformV1PredictSchemata.
28545 28546 28547 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28545 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instance_schema_uri ⇒ String
Immutable. Points to a YAML file stored on Google Cloud Storage describing the
format of a single instance, which are used in PredictRequest.instances,
ExplainRequest.instances and BatchPredictionJob.input_config. The schema is
defined as an OpenAPI 3.0.2 Schema Object. AutoML Models always
have this field populated by Vertex AI. Note: The URI given on output will be
immutable and probably different, including the URI scheme, than the one given
on input. The output URI will point to a location where the user only has a
read access.
Corresponds to the JSON property instanceSchemaUri
28517 28518 28519 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28517 def instance_schema_uri @instance_schema_uri end |
#parameters_schema_uri ⇒ String
Immutable. Points to a YAML file stored on Google Cloud Storage describing the
parameters of prediction and explanation via PredictRequest.parameters,
ExplainRequest.parameters and BatchPredictionJob.model_parameters. The schema
is defined as an OpenAPI 3.0.2 Schema Object. AutoML Models always
have this field populated by Vertex AI, if no parameters are supported, then
it is set to an empty string. Note: The URI given on output will be immutable
and probably different, including the URI scheme, than the one given on input.
The output URI will point to a location where the user only has a read access.
Corresponds to the JSON property parametersSchemaUri
28530 28531 28532 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28530 def parameters_schema_uri @parameters_schema_uri end |
#prediction_schema_uri ⇒ String
Immutable. Points to a YAML file stored on Google Cloud Storage describing the
format of a single prediction produced by this Model, which are returned via
PredictResponse.predictions, ExplainResponse.explanations, and
BatchPredictionJob.output_config. The schema is defined as an OpenAPI 3.0.2
Schema Object. AutoML Models always have this field populated by
Vertex AI. Note: The URI given on output will be immutable and probably
different, including the URI scheme, than the one given on input. The output
URI will point to a location where the user only has a read access.
Corresponds to the JSON property predictionSchemaUri
28543 28544 28545 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28543 def prediction_schema_uri @prediction_schema_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28550 28551 28552 28553 28554 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28550 def update!(**args) @instance_schema_uri = args[:instance_schema_uri] if args.key?(:instance_schema_uri) @parameters_schema_uri = args[:parameters_schema_uri] if args.key?(:parameters_schema_uri) @prediction_schema_uri = args[:prediction_schema_uri] if args.key?(:prediction_schema_uri) end |