Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PredictSchemata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Contains the schemata used in Model's predictions and explanations via PredictionService.Predict, PredictionService.Explain and BatchPredictionJob.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1PredictSchemata

Returns a new instance of GoogleCloudAiplatformV1PredictSchemata.



22618
22619
22620
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22618

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_schema_uriString

Immutable. Points to a YAML file stored on Google Cloud Storage describing the format of a single instance, which are used in PredictRequest.instances, ExplainRequest.instances and BatchPredictionJob.input_config. The schema is defined as an OpenAPI 3.0.2 Schema Object. AutoML Models always have this field populated by Vertex AI. Note: The URI given on output will be immutable and probably different, including the URI scheme, than the one given on input. The output URI will point to a location where the user only has a read access. Corresponds to the JSON property instanceSchemaUri

Returns:

  • (String)


22590
22591
22592
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22590

def instance_schema_uri
  @instance_schema_uri
end

#parameters_schema_uriString

Immutable. Points to a YAML file stored on Google Cloud Storage describing the parameters of prediction and explanation via PredictRequest.parameters, ExplainRequest.parameters and BatchPredictionJob.model_parameters. The schema is defined as an OpenAPI 3.0.2 Schema Object. AutoML Models always have this field populated by Vertex AI, if no parameters are supported, then it is set to an empty string. Note: The URI given on output will be immutable and probably different, including the URI scheme, than the one given on input. The output URI will point to a location where the user only has a read access. Corresponds to the JSON property parametersSchemaUri

Returns:

  • (String)


22603
22604
22605
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22603

def parameters_schema_uri
  @parameters_schema_uri
end

#prediction_schema_uriString

Immutable. Points to a YAML file stored on Google Cloud Storage describing the format of a single prediction produced by this Model, which are returned via PredictResponse.predictions, ExplainResponse.explanations, and BatchPredictionJob.output_config. The schema is defined as an OpenAPI 3.0.2 Schema Object. AutoML Models always have this field populated by Vertex AI. Note: The URI given on output will be immutable and probably different, including the URI scheme, than the one given on input. The output URI will point to a location where the user only has a read access. Corresponds to the JSON property predictionSchemaUri

Returns:

  • (String)


22616
22617
22618
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22616

def prediction_schema_uri
  @prediction_schema_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22623
22624
22625
22626
22627
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22623

def update!(**args)
  @instance_schema_uri = args[:instance_schema_uri] if args.key?(:instance_schema_uri)
  @parameters_schema_uri = args[:parameters_schema_uri] if args.key?(:parameters_schema_uri)
  @prediction_schema_uri = args[:prediction_schema_uri] if args.key?(:prediction_schema_uri)
end