Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Presets

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Preset configuration for example-based explanations

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Presets

Returns a new instance of GoogleCloudAiplatformV1Presets.



28730
28731
28732
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28730

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#modalityString

The modality of the uploaded model, which automatically configures the distance measurement and feature normalization for the underlying example index and queries. If your model does not precisely fit one of these types, it is okay to choose the closest type. Corresponds to the JSON property modality

Returns:

  • (String)


28722
28723
28724
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28722

def modality
  @modality
end

#queryString

Preset option controlling parameters for speed-precision trade-off when querying for examples. If omitted, defaults to PRECISE. Corresponds to the JSON property query

Returns:

  • (String)


28728
28729
28730
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28728

def query
  @query
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28735
28736
28737
28738
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28735

def update!(**args)
  @modality = args[:modality] if args.key?(:modality)
  @query = args[:query] if args.key?(:query)
end