Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Presets

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Preset configuration for example-based explanations

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Presets

Returns a new instance of GoogleCloudAiplatformV1Presets.



18362
18363
18364
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18362

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#modalityString

The modality of the uploaded model, which automatically configures the distance measurement and feature normalization for the underlying example index and queries. If your model does not precisely fit one of these types, it is okay to choose the closest type. Corresponds to the JSON property modality

Returns:

  • (String)


18354
18355
18356
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18354

def modality
  @modality
end

#queryString

Preset option controlling parameters for speed-precision trade-off when querying for examples. If omitted, defaults to PRECISE. Corresponds to the JSON property query

Returns:

  • (String)


18360
18361
18362
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18360

def query
  @query
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18367
18368
18369
18370
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18367

def update!(**args)
  @modality = args[:modality] if args.key?(:modality)
  @query = args[:query] if args.key?(:query)
end