Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Presets

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Preset configuration for example-based explanations

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Presets

Returns a new instance of GoogleCloudAiplatformV1Presets.



17843
17844
17845
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17843

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#modalityString

The modality of the uploaded model, which automatically configures the distance measurement and feature normalization for the underlying example index and queries. If your model does not precisely fit one of these types, it is okay to choose the closest type. Corresponds to the JSON property modality

Returns:

  • (String)


17835
17836
17837
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17835

def modality
  @modality
end

#queryString

Preset option controlling parameters for speed-precision trade-off when querying for examples. If omitted, defaults to PRECISE. Corresponds to the JSON property query

Returns:

  • (String)


17841
17842
17843
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17841

def query
  @query
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17848
17849
17850
17851
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17848

def update!(**args)
  @modality = args[:modality] if args.key?(:modality)
  @query = args[:query] if args.key?(:query)
end