Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Presets
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Presets
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Preset configuration for example-based explanations
Instance Attribute Summary collapse
-
#modality ⇒ String
The modality of the uploaded model, which automatically configures the distance measurement and feature normalization for the underlying example index and queries.
-
#query ⇒ String
Preset option controlling parameters for speed-precision trade-off when querying for examples.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Presets
constructor
A new instance of GoogleCloudAiplatformV1Presets.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Presets
Returns a new instance of GoogleCloudAiplatformV1Presets.
16566 16567 16568 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16566 def initialize(**args) update!(**args) end |
Instance Attribute Details
#modality ⇒ String
The modality of the uploaded model, which automatically configures the
distance measurement and feature normalization for the underlying example
index and queries. If your model does not precisely fit one of these types, it
is okay to choose the closest type.
Corresponds to the JSON property modality
16558 16559 16560 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16558 def modality @modality end |
#query ⇒ String
Preset option controlling parameters for speed-precision trade-off when
querying for examples. If omitted, defaults to PRECISE.
Corresponds to the JSON property query
16564 16565 16566 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16564 def query @query end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16571 16572 16573 16574 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16571 def update!(**args) @modality = args[:modality] if args.key?(:modality) @query = args[:query] if args.key?(:query) end |