Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PrivateEndpoints

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

PrivateEndpoints proto is used to provide paths for users to send requests privately. To send request via private service access, use predict_http_uri, explain_http_uri or health_http_uri. To send request via private service connect, use service_attachment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1PrivateEndpoints

Returns a new instance of GoogleCloudAiplatformV1PrivateEndpoints.



28816
28817
28818
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28816

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#explain_http_uriString

Output only. Http(s) path to send explain requests. Corresponds to the JSON property explainHttpUri

Returns:

  • (String)


28798
28799
28800
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28798

def explain_http_uri
  @explain_http_uri
end

#health_http_uriString

Output only. Http(s) path to send health check requests. Corresponds to the JSON property healthHttpUri

Returns:

  • (String)


28803
28804
28805
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28803

def health_http_uri
  @health_http_uri
end

#predict_http_uriString

Output only. Http(s) path to send prediction requests. Corresponds to the JSON property predictHttpUri

Returns:

  • (String)


28808
28809
28810
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28808

def predict_http_uri
  @predict_http_uri
end

#service_attachmentString

Output only. The name of the service attachment resource. Populated if private service connect is enabled. Corresponds to the JSON property serviceAttachment

Returns:

  • (String)


28814
28815
28816
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28814

def service_attachment
  @service_attachment
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28821
28822
28823
28824
28825
28826
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28821

def update!(**args)
  @explain_http_uri = args[:explain_http_uri] if args.key?(:explain_http_uri)
  @health_http_uri = args[:health_http_uri] if args.key?(:health_http_uri)
  @predict_http_uri = args[:predict_http_uri] if args.key?(:predict_http_uri)
  @service_attachment = args[:service_attachment] if args.key?(:service_attachment)
end