Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PrivateEndpoints

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

PrivateEndpoints proto is used to provide paths for users to send requests privately. To send request via private service access, use predict_http_uri, explain_http_uri or health_http_uri. To send request via private service connect, use service_attachment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1PrivateEndpoints

Returns a new instance of GoogleCloudAiplatformV1PrivateEndpoints.



21861
21862
21863
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21861

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#explain_http_uriString

Output only. Http(s) path to send explain requests. Corresponds to the JSON property explainHttpUri

Returns:

  • (String)


21843
21844
21845
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21843

def explain_http_uri
  @explain_http_uri
end

#health_http_uriString

Output only. Http(s) path to send health check requests. Corresponds to the JSON property healthHttpUri

Returns:

  • (String)


21848
21849
21850
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21848

def health_http_uri
  @health_http_uri
end

#predict_http_uriString

Output only. Http(s) path to send prediction requests. Corresponds to the JSON property predictHttpUri

Returns:

  • (String)


21853
21854
21855
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21853

def predict_http_uri
  @predict_http_uri
end

#service_attachmentString

Output only. The name of the service attachment resource. Populated if private service connect is enabled. Corresponds to the JSON property serviceAttachment

Returns:

  • (String)


21859
21860
21861
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21859

def service_attachment
  @service_attachment
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21866
21867
21868
21869
21870
21871
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21866

def update!(**args)
  @explain_http_uri = args[:explain_http_uri] if args.key?(:explain_http_uri)
  @health_http_uri = args[:health_http_uri] if args.key?(:health_http_uri)
  @predict_http_uri = args[:predict_http_uri] if args.key?(:predict_http_uri)
  @service_attachment = args[:service_attachment] if args.key?(:service_attachment)
end