Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PrivateServiceConnectConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PrivateServiceConnectConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Represents configuration for private service connect.
Instance Attribute Summary collapse
-
#enable_private_service_connect ⇒ Boolean
(also: #enable_private_service_connect?)
Required.
-
#project_allowlist ⇒ Array<String>
A list of Projects from which the forwarding rule will target the service attachment.
-
#psc_automation_configs ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PscAutomationConfig>
Optional.
-
#service_attachment ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1PrivateServiceConnectConfig
constructor
A new instance of GoogleCloudAiplatformV1PrivateServiceConnectConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1PrivateServiceConnectConfig
Returns a new instance of GoogleCloudAiplatformV1PrivateServiceConnectConfig.
31204 31205 31206 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31204 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable_private_service_connect ⇒ Boolean Also known as: enable_private_service_connect?
Required. If true, expose the IndexEndpoint via private service connect.
Corresponds to the JSON property enablePrivateServiceConnect
31183 31184 31185 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31183 def enable_private_service_connect @enable_private_service_connect end |
#project_allowlist ⇒ Array<String>
A list of Projects from which the forwarding rule will target the service
attachment.
Corresponds to the JSON property projectAllowlist
31190 31191 31192 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31190 def project_allowlist @project_allowlist end |
#psc_automation_configs ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PscAutomationConfig>
Optional. List of projects and networks where the PSC endpoints will be
created. This field is used by Online Inference(Prediction) only.
Corresponds to the JSON property pscAutomationConfigs
31196 31197 31198 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31196 def psc_automation_configs @psc_automation_configs end |
#service_attachment ⇒ String
Output only. The name of the generated service attachment resource. This is
only populated if the endpoint is deployed with PrivateServiceConnect.
Corresponds to the JSON property serviceAttachment
31202 31203 31204 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31202 def @service_attachment end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31209 31210 31211 31212 31213 31214 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31209 def update!(**args) @enable_private_service_connect = args[:enable_private_service_connect] if args.key?(:enable_private_service_connect) @project_allowlist = args[:project_allowlist] if args.key?(:project_allowlist) @psc_automation_configs = args[:psc_automation_configs] if args.key?(:psc_automation_configs) @service_attachment = args[:service_attachment] if args.key?(:service_attachment) end |