Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PrivateServiceConnectConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents configuration for private service connect.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1PrivateServiceConnectConfig

Returns a new instance of GoogleCloudAiplatformV1PrivateServiceConnectConfig.



28810
28811
28812
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28810

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_private_service_connectBoolean Also known as: enable_private_service_connect?

Required. If true, expose the IndexEndpoint via private service connect. Corresponds to the JSON property enablePrivateServiceConnect

Returns:

  • (Boolean)


28789
28790
28791
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28789

def enable_private_service_connect
  @enable_private_service_connect
end

#project_allowlistArray<String>

A list of Projects from which the forwarding rule will target the service attachment. Corresponds to the JSON property projectAllowlist

Returns:

  • (Array<String>)


28796
28797
28798
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28796

def project_allowlist
  @project_allowlist
end

#psc_automation_configsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PscAutomationConfig>

Optional. List of projects and networks where the PSC endpoints will be created. This field is used by Online Inference(Prediction) only. Corresponds to the JSON property pscAutomationConfigs



28802
28803
28804
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28802

def psc_automation_configs
  @psc_automation_configs
end

#service_attachmentString

Output only. The name of the generated service attachment resource. This is only populated if the endpoint is deployed with PrivateServiceConnect. Corresponds to the JSON property serviceAttachment

Returns:

  • (String)


28808
28809
28810
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28808

def service_attachment
  @service_attachment
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28815
28816
28817
28818
28819
28820
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28815

def update!(**args)
  @enable_private_service_connect = args[:enable_private_service_connect] if args.key?(:enable_private_service_connect)
  @project_allowlist = args[:project_allowlist] if args.key?(:project_allowlist)
  @psc_automation_configs = args[:psc_automation_configs] if args.key?(:psc_automation_configs)
  @service_attachment = args[:service_attachment] if args.key?(:service_attachment)
end