Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PrivateServiceConnectConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents configuration for private service connect.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1PrivateServiceConnectConfig

Returns a new instance of GoogleCloudAiplatformV1PrivateServiceConnectConfig.



23138
23139
23140
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23138

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_private_service_connectBoolean Also known as: enable_private_service_connect?

Required. If true, expose the IndexEndpoint via private service connect. Corresponds to the JSON property enablePrivateServiceConnect

Returns:

  • (Boolean)


23117
23118
23119
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23117

def enable_private_service_connect
  @enable_private_service_connect
end

#project_allowlistArray<String>

A list of Projects from which the forwarding rule will target the service attachment. Corresponds to the JSON property projectAllowlist

Returns:

  • (Array<String>)


23124
23125
23126
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23124

def project_allowlist
  @project_allowlist
end

#psc_automation_configsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PscAutomationConfig>

Optional. List of projects and networks where the PSC endpoints will be created. This field is used by Online Inference(Prediction) only. Corresponds to the JSON property pscAutomationConfigs



23130
23131
23132
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23130

def psc_automation_configs
  @psc_automation_configs
end

#service_attachmentString

Output only. The name of the generated service attachment resource. This is only populated if the endpoint is deployed with PrivateServiceConnect. Corresponds to the JSON property serviceAttachment

Returns:

  • (String)


23136
23137
23138
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23136

def service_attachment
  @service_attachment
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23143
23144
23145
23146
23147
23148
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23143

def update!(**args)
  @enable_private_service_connect = args[:enable_private_service_connect] if args.key?(:enable_private_service_connect)
  @project_allowlist = args[:project_allowlist] if args.key?(:project_allowlist)
  @psc_automation_configs = args[:psc_automation_configs] if args.key?(:psc_automation_configs)
  @service_attachment = args[:service_attachment] if args.key?(:service_attachment)
end