Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PrivateServiceConnectConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PrivateServiceConnectConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Represents configuration for private service connect.
Instance Attribute Summary collapse
-
#enable_private_service_connect ⇒ Boolean
(also: #enable_private_service_connect?)
Required.
-
#project_allowlist ⇒ Array<String>
A list of Projects from which the forwarding rule will target the service attachment.
-
#service_attachment ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1PrivateServiceConnectConfig
constructor
A new instance of GoogleCloudAiplatformV1PrivateServiceConnectConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1PrivateServiceConnectConfig
Returns a new instance of GoogleCloudAiplatformV1PrivateServiceConnectConfig.
22401 22402 22403 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22401 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable_private_service_connect ⇒ Boolean Also known as: enable_private_service_connect?
Required. If true, expose the IndexEndpoint via private service connect.
Corresponds to the JSON property enablePrivateServiceConnect
22386 22387 22388 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22386 def enable_private_service_connect @enable_private_service_connect end |
#project_allowlist ⇒ Array<String>
A list of Projects from which the forwarding rule will target the service
attachment.
Corresponds to the JSON property projectAllowlist
22393 22394 22395 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22393 def project_allowlist @project_allowlist end |
#service_attachment ⇒ String
Output only. The name of the generated service attachment resource. This is
only populated if the endpoint is deployed with PrivateServiceConnect.
Corresponds to the JSON property serviceAttachment
22399 22400 22401 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22399 def @service_attachment end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22406 22407 22408 22409 22410 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22406 def update!(**args) @enable_private_service_connect = args[:enable_private_service_connect] if args.key?(:enable_private_service_connect) @project_allowlist = args[:project_allowlist] if args.key?(:project_allowlist) @service_attachment = args[:service_attachment] if args.key?(:service_attachment) end |