Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Probe

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Probe describes a health check to be performed against a container to determine whether it is alive or ready to receive traffic.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Probe

Returns a new instance of GoogleCloudAiplatformV1Probe.



29102
29103
29104
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29102

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#execGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeExecAction

ExecAction specifies a command to execute. Corresponds to the JSON property exec



29051
29052
29053
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29051

def exec
  @exec
end

#failure_thresholdFixnum

Number of consecutive failures before the probe is considered failed. Defaults to 3. Minimum value is 1. Maps to Kubernetes probe argument 'failureThreshold'. Corresponds to the JSON property failureThreshold

Returns:

  • (Fixnum)


29057
29058
29059
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29057

def failure_threshold
  @failure_threshold
end

#grpcGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeGrpcAction

GrpcAction checks the health of a container using a gRPC service. Corresponds to the JSON property grpc



29062
29063
29064
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29062

def grpc
  @grpc
end

#http_getGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeHttpGetAction

HttpGetAction describes an action based on HTTP Get requests. Corresponds to the JSON property httpGet



29067
29068
29069
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29067

def http_get
  @http_get
end

#initial_delay_secondsFixnum

Number of seconds to wait before starting the probe. Defaults to 0. Minimum value is 0. Maps to Kubernetes probe argument 'initialDelaySeconds'. Corresponds to the JSON property initialDelaySeconds

Returns:

  • (Fixnum)


29073
29074
29075
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29073

def initial_delay_seconds
  @initial_delay_seconds
end

#period_secondsFixnum

How often (in seconds) to perform the probe. Default to 10 seconds. Minimum value is 1. Must be less than timeout_seconds. Maps to Kubernetes probe argument 'periodSeconds'. Corresponds to the JSON property periodSeconds

Returns:

  • (Fixnum)


29080
29081
29082
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29080

def period_seconds
  @period_seconds
end

#success_thresholdFixnum

Number of consecutive successes before the probe is considered successful. Defaults to 1. Minimum value is 1. Maps to Kubernetes probe argument ' successThreshold'. Corresponds to the JSON property successThreshold

Returns:

  • (Fixnum)


29087
29088
29089
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29087

def success_threshold
  @success_threshold
end

#tcp_socketGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeTcpSocketAction

TcpSocketAction probes the health of a container by opening a TCP socket connection. Corresponds to the JSON property tcpSocket



29093
29094
29095
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29093

def tcp_socket
  @tcp_socket
end

#timeout_secondsFixnum

Number of seconds after which the probe times out. Defaults to 1 second. Minimum value is 1. Must be greater or equal to period_seconds. Maps to Kubernetes probe argument 'timeoutSeconds'. Corresponds to the JSON property timeoutSeconds

Returns:

  • (Fixnum)


29100
29101
29102
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29100

def timeout_seconds
  @timeout_seconds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29107
29108
29109
29110
29111
29112
29113
29114
29115
29116
29117
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29107

def update!(**args)
  @exec = args[:exec] if args.key?(:exec)
  @failure_threshold = args[:failure_threshold] if args.key?(:failure_threshold)
  @grpc = args[:grpc] if args.key?(:grpc)
  @http_get = args[:http_get] if args.key?(:http_get)
  @initial_delay_seconds = args[:initial_delay_seconds] if args.key?(:initial_delay_seconds)
  @period_seconds = args[:period_seconds] if args.key?(:period_seconds)
  @success_threshold = args[:success_threshold] if args.key?(:success_threshold)
  @tcp_socket = args[:tcp_socket] if args.key?(:tcp_socket)
  @timeout_seconds = args[:timeout_seconds] if args.key?(:timeout_seconds)
end