Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Probe
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Probe
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Probe describes a health check to be performed against a container to determine whether it is alive or ready to receive traffic.
Instance Attribute Summary collapse
-
#exec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeExecAction
ExecAction specifies a command to execute.
-
#failure_threshold ⇒ Fixnum
Number of consecutive failures before the probe is considered failed.
-
#grpc ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeGrpcAction
GrpcAction checks the health of a container using a gRPC service.
-
#http_get ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeHttpGetAction
HttpGetAction describes an action based on HTTP Get requests.
-
#initial_delay_seconds ⇒ Fixnum
Number of seconds to wait before starting the probe.
-
#period_seconds ⇒ Fixnum
How often (in seconds) to perform the probe.
-
#success_threshold ⇒ Fixnum
Number of consecutive successes before the probe is considered successful.
-
#tcp_socket ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeTcpSocketAction
TcpSocketAction probes the health of a container by opening a TCP socket connection.
-
#timeout_seconds ⇒ Fixnum
Number of seconds after which the probe times out.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Probe
constructor
A new instance of GoogleCloudAiplatformV1Probe.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Probe
Returns a new instance of GoogleCloudAiplatformV1Probe.
23195 23196 23197 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23195 def initialize(**args) update!(**args) end |
Instance Attribute Details
#exec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeExecAction
ExecAction specifies a command to execute.
Corresponds to the JSON property exec
23144 23145 23146 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23144 def exec @exec end |
#failure_threshold ⇒ Fixnum
Number of consecutive failures before the probe is considered failed. Defaults
to 3. Minimum value is 1. Maps to Kubernetes probe argument 'failureThreshold'.
Corresponds to the JSON property failureThreshold
23150 23151 23152 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23150 def failure_threshold @failure_threshold end |
#grpc ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeGrpcAction
GrpcAction checks the health of a container using a gRPC service.
Corresponds to the JSON property grpc
23155 23156 23157 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23155 def grpc @grpc end |
#http_get ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeHttpGetAction
HttpGetAction describes an action based on HTTP Get requests.
Corresponds to the JSON property httpGet
23160 23161 23162 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23160 def http_get @http_get end |
#initial_delay_seconds ⇒ Fixnum
Number of seconds to wait before starting the probe. Defaults to 0. Minimum
value is 0. Maps to Kubernetes probe argument 'initialDelaySeconds'.
Corresponds to the JSON property initialDelaySeconds
23166 23167 23168 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23166 def initial_delay_seconds @initial_delay_seconds end |
#period_seconds ⇒ Fixnum
How often (in seconds) to perform the probe. Default to 10 seconds. Minimum
value is 1. Must be less than timeout_seconds. Maps to Kubernetes probe
argument 'periodSeconds'.
Corresponds to the JSON property periodSeconds
23173 23174 23175 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23173 def period_seconds @period_seconds end |
#success_threshold ⇒ Fixnum
Number of consecutive successes before the probe is considered successful.
Defaults to 1. Minimum value is 1. Maps to Kubernetes probe argument '
successThreshold'.
Corresponds to the JSON property successThreshold
23180 23181 23182 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23180 def success_threshold @success_threshold end |
#tcp_socket ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeTcpSocketAction
TcpSocketAction probes the health of a container by opening a TCP socket
connection.
Corresponds to the JSON property tcpSocket
23186 23187 23188 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23186 def tcp_socket @tcp_socket end |
#timeout_seconds ⇒ Fixnum
Number of seconds after which the probe times out. Defaults to 1 second.
Minimum value is 1. Must be greater or equal to period_seconds. Maps to
Kubernetes probe argument 'timeoutSeconds'.
Corresponds to the JSON property timeoutSeconds
23193 23194 23195 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23193 def timeout_seconds @timeout_seconds end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23200 23201 23202 23203 23204 23205 23206 23207 23208 23209 23210 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23200 def update!(**args) @exec = args[:exec] if args.key?(:exec) @failure_threshold = args[:failure_threshold] if args.key?(:failure_threshold) @grpc = args[:grpc] if args.key?(:grpc) @http_get = args[:http_get] if args.key?(:http_get) @initial_delay_seconds = args[:initial_delay_seconds] if args.key?(:initial_delay_seconds) @period_seconds = args[:period_seconds] if args.key?(:period_seconds) @success_threshold = args[:success_threshold] if args.key?(:success_threshold) @tcp_socket = args[:tcp_socket] if args.key?(:tcp_socket) @timeout_seconds = args[:timeout_seconds] if args.key?(:timeout_seconds) end |