Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Probe
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Probe
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Probe describes a health check to be performed against a container to determine whether it is alive or ready to receive traffic.
Instance Attribute Summary collapse
-
#exec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeExecAction
ExecAction specifies a command to execute.
-
#failure_threshold ⇒ Fixnum
Number of consecutive failures before the probe is considered failed.
-
#grpc ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeGrpcAction
GrpcAction checks the health of a container using a gRPC service.
-
#http_get ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeHttpGetAction
HttpGetAction describes an action based on HTTP Get requests.
-
#initial_delay_seconds ⇒ Fixnum
Number of seconds to wait before starting the probe.
-
#period_seconds ⇒ Fixnum
How often (in seconds) to perform the probe.
-
#success_threshold ⇒ Fixnum
Number of consecutive successes before the probe is considered successful.
-
#tcp_socket ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeTcpSocketAction
TcpSocketAction probes the health of a container by opening a TCP socket connection.
-
#timeout_seconds ⇒ Fixnum
Number of seconds after which the probe times out.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Probe
constructor
A new instance of GoogleCloudAiplatformV1Probe.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Probe
Returns a new instance of GoogleCloudAiplatformV1Probe.
22864 22865 22866 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22864 def initialize(**args) update!(**args) end |
Instance Attribute Details
#exec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeExecAction
ExecAction specifies a command to execute.
Corresponds to the JSON property exec
22813 22814 22815 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22813 def exec @exec end |
#failure_threshold ⇒ Fixnum
Number of consecutive failures before the probe is considered failed. Defaults
to 3. Minimum value is 1. Maps to Kubernetes probe argument 'failureThreshold'.
Corresponds to the JSON property failureThreshold
22819 22820 22821 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22819 def failure_threshold @failure_threshold end |
#grpc ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeGrpcAction
GrpcAction checks the health of a container using a gRPC service.
Corresponds to the JSON property grpc
22824 22825 22826 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22824 def grpc @grpc end |
#http_get ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeHttpGetAction
HttpGetAction describes an action based on HTTP Get requests.
Corresponds to the JSON property httpGet
22829 22830 22831 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22829 def http_get @http_get end |
#initial_delay_seconds ⇒ Fixnum
Number of seconds to wait before starting the probe. Defaults to 0. Minimum
value is 0. Maps to Kubernetes probe argument 'initialDelaySeconds'.
Corresponds to the JSON property initialDelaySeconds
22835 22836 22837 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22835 def initial_delay_seconds @initial_delay_seconds end |
#period_seconds ⇒ Fixnum
How often (in seconds) to perform the probe. Default to 10 seconds. Minimum
value is 1. Must be less than timeout_seconds. Maps to Kubernetes probe
argument 'periodSeconds'.
Corresponds to the JSON property periodSeconds
22842 22843 22844 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22842 def period_seconds @period_seconds end |
#success_threshold ⇒ Fixnum
Number of consecutive successes before the probe is considered successful.
Defaults to 1. Minimum value is 1. Maps to Kubernetes probe argument '
successThreshold'.
Corresponds to the JSON property successThreshold
22849 22850 22851 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22849 def success_threshold @success_threshold end |
#tcp_socket ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeTcpSocketAction
TcpSocketAction probes the health of a container by opening a TCP socket
connection.
Corresponds to the JSON property tcpSocket
22855 22856 22857 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22855 def tcp_socket @tcp_socket end |
#timeout_seconds ⇒ Fixnum
Number of seconds after which the probe times out. Defaults to 1 second.
Minimum value is 1. Must be greater or equal to period_seconds. Maps to
Kubernetes probe argument 'timeoutSeconds'.
Corresponds to the JSON property timeoutSeconds
22862 22863 22864 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22862 def timeout_seconds @timeout_seconds end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22869 22870 22871 22872 22873 22874 22875 22876 22877 22878 22879 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22869 def update!(**args) @exec = args[:exec] if args.key?(:exec) @failure_threshold = args[:failure_threshold] if args.key?(:failure_threshold) @grpc = args[:grpc] if args.key?(:grpc) @http_get = args[:http_get] if args.key?(:http_get) @initial_delay_seconds = args[:initial_delay_seconds] if args.key?(:initial_delay_seconds) @period_seconds = args[:period_seconds] if args.key?(:period_seconds) @success_threshold = args[:success_threshold] if args.key?(:success_threshold) @tcp_socket = args[:tcp_socket] if args.key?(:tcp_socket) @timeout_seconds = args[:timeout_seconds] if args.key?(:timeout_seconds) end |