Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Probe
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Probe
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Probe describes a health check to be performed against a container to determine whether it is alive or ready to receive traffic.
Instance Attribute Summary collapse
-
#exec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeExecAction
ExecAction specifies a command to execute.
-
#failure_threshold ⇒ Fixnum
Number of consecutive failures before the probe is considered failed.
-
#grpc ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeGrpcAction
GrpcAction checks the health of a container using a gRPC service.
-
#http_get ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeHttpGetAction
HttpGetAction describes an action based on HTTP Get requests.
-
#initial_delay_seconds ⇒ Fixnum
Number of seconds to wait before starting the probe.
-
#period_seconds ⇒ Fixnum
How often (in seconds) to perform the probe.
-
#success_threshold ⇒ Fixnum
Number of consecutive successes before the probe is considered successful.
-
#tcp_socket ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeTcpSocketAction
TcpSocketAction probes the health of a container by opening a TCP socket connection.
-
#timeout_seconds ⇒ Fixnum
Number of seconds after which the probe times out.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Probe
constructor
A new instance of GoogleCloudAiplatformV1Probe.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Probe
Returns a new instance of GoogleCloudAiplatformV1Probe.
21967 21968 21969 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21967 def initialize(**args) update!(**args) end |
Instance Attribute Details
#exec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeExecAction
ExecAction specifies a command to execute.
Corresponds to the JSON property exec
21916 21917 21918 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21916 def exec @exec end |
#failure_threshold ⇒ Fixnum
Number of consecutive failures before the probe is considered failed. Defaults
to 3. Minimum value is 1. Maps to Kubernetes probe argument 'failureThreshold'.
Corresponds to the JSON property failureThreshold
21922 21923 21924 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21922 def failure_threshold @failure_threshold end |
#grpc ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeGrpcAction
GrpcAction checks the health of a container using a gRPC service.
Corresponds to the JSON property grpc
21927 21928 21929 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21927 def grpc @grpc end |
#http_get ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeHttpGetAction
HttpGetAction describes an action based on HTTP Get requests.
Corresponds to the JSON property httpGet
21932 21933 21934 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21932 def http_get @http_get end |
#initial_delay_seconds ⇒ Fixnum
Number of seconds to wait before starting the probe. Defaults to 0. Minimum
value is 0. Maps to Kubernetes probe argument 'initialDelaySeconds'.
Corresponds to the JSON property initialDelaySeconds
21938 21939 21940 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21938 def initial_delay_seconds @initial_delay_seconds end |
#period_seconds ⇒ Fixnum
How often (in seconds) to perform the probe. Default to 10 seconds. Minimum
value is 1. Must be less than timeout_seconds. Maps to Kubernetes probe
argument 'periodSeconds'.
Corresponds to the JSON property periodSeconds
21945 21946 21947 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21945 def period_seconds @period_seconds end |
#success_threshold ⇒ Fixnum
Number of consecutive successes before the probe is considered successful.
Defaults to 1. Minimum value is 1. Maps to Kubernetes probe argument '
successThreshold'.
Corresponds to the JSON property successThreshold
21952 21953 21954 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21952 def success_threshold @success_threshold end |
#tcp_socket ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeTcpSocketAction
TcpSocketAction probes the health of a container by opening a TCP socket
connection.
Corresponds to the JSON property tcpSocket
21958 21959 21960 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21958 def tcp_socket @tcp_socket end |
#timeout_seconds ⇒ Fixnum
Number of seconds after which the probe times out. Defaults to 1 second.
Minimum value is 1. Must be greater or equal to period_seconds. Maps to
Kubernetes probe argument 'timeoutSeconds'.
Corresponds to the JSON property timeoutSeconds
21965 21966 21967 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21965 def timeout_seconds @timeout_seconds end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21972 21973 21974 21975 21976 21977 21978 21979 21980 21981 21982 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21972 def update!(**args) @exec = args[:exec] if args.key?(:exec) @failure_threshold = args[:failure_threshold] if args.key?(:failure_threshold) @grpc = args[:grpc] if args.key?(:grpc) @http_get = args[:http_get] if args.key?(:http_get) @initial_delay_seconds = args[:initial_delay_seconds] if args.key?(:initial_delay_seconds) @period_seconds = args[:period_seconds] if args.key?(:period_seconds) @success_threshold = args[:success_threshold] if args.key?(:success_threshold) @tcp_socket = args[:tcp_socket] if args.key?(:tcp_socket) @timeout_seconds = args[:timeout_seconds] if args.key?(:timeout_seconds) end |