Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Probe

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Probe describes a health check to be performed against a container to determine whether it is alive or ready to receive traffic.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Probe

Returns a new instance of GoogleCloudAiplatformV1Probe.



21744
21745
21746
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21744

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#execGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeExecAction

ExecAction specifies a command to execute. Corresponds to the JSON property exec



21693
21694
21695
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21693

def exec
  @exec
end

#failure_thresholdFixnum

Number of consecutive failures before the probe is considered failed. Defaults to 3. Minimum value is 1. Maps to Kubernetes probe argument 'failureThreshold'. Corresponds to the JSON property failureThreshold

Returns:

  • (Fixnum)


21699
21700
21701
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21699

def failure_threshold
  @failure_threshold
end

#grpcGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeGrpcAction

GrpcAction checks the health of a container using a gRPC service. Corresponds to the JSON property grpc



21704
21705
21706
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21704

def grpc
  @grpc
end

#http_getGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeHttpGetAction

HttpGetAction describes an action based on HTTP Get requests. Corresponds to the JSON property httpGet



21709
21710
21711
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21709

def http_get
  @http_get
end

#initial_delay_secondsFixnum

Number of seconds to wait before starting the probe. Defaults to 0. Minimum value is 0. Maps to Kubernetes probe argument 'initialDelaySeconds'. Corresponds to the JSON property initialDelaySeconds

Returns:

  • (Fixnum)


21715
21716
21717
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21715

def initial_delay_seconds
  @initial_delay_seconds
end

#period_secondsFixnum

How often (in seconds) to perform the probe. Default to 10 seconds. Minimum value is 1. Must be less than timeout_seconds. Maps to Kubernetes probe argument 'periodSeconds'. Corresponds to the JSON property periodSeconds

Returns:

  • (Fixnum)


21722
21723
21724
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21722

def period_seconds
  @period_seconds
end

#success_thresholdFixnum

Number of consecutive successes before the probe is considered successful. Defaults to 1. Minimum value is 1. Maps to Kubernetes probe argument ' successThreshold'. Corresponds to the JSON property successThreshold

Returns:

  • (Fixnum)


21729
21730
21731
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21729

def success_threshold
  @success_threshold
end

#tcp_socketGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeTcpSocketAction

TcpSocketAction probes the health of a container by opening a TCP socket connection. Corresponds to the JSON property tcpSocket



21735
21736
21737
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21735

def tcp_socket
  @tcp_socket
end

#timeout_secondsFixnum

Number of seconds after which the probe times out. Defaults to 1 second. Minimum value is 1. Must be greater or equal to period_seconds. Maps to Kubernetes probe argument 'timeoutSeconds'. Corresponds to the JSON property timeoutSeconds

Returns:

  • (Fixnum)


21742
21743
21744
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21742

def timeout_seconds
  @timeout_seconds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21749
21750
21751
21752
21753
21754
21755
21756
21757
21758
21759
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21749

def update!(**args)
  @exec = args[:exec] if args.key?(:exec)
  @failure_threshold = args[:failure_threshold] if args.key?(:failure_threshold)
  @grpc = args[:grpc] if args.key?(:grpc)
  @http_get = args[:http_get] if args.key?(:http_get)
  @initial_delay_seconds = args[:initial_delay_seconds] if args.key?(:initial_delay_seconds)
  @period_seconds = args[:period_seconds] if args.key?(:period_seconds)
  @success_threshold = args[:success_threshold] if args.key?(:success_threshold)
  @tcp_socket = args[:tcp_socket] if args.key?(:tcp_socket)
  @timeout_seconds = args[:timeout_seconds] if args.key?(:timeout_seconds)
end