Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Probe

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Probe describes a health check to be performed against a container to determine whether it is alive or ready to receive traffic.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Probe

Returns a new instance of GoogleCloudAiplatformV1Probe.



16620
16621
16622
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16620

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#execGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeExecAction

ExecAction specifies a command to execute. Corresponds to the JSON property exec



16604
16605
16606
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16604

def exec
  @exec
end

#period_secondsFixnum

How often (in seconds) to perform the probe. Default to 10 seconds. Minimum value is 1. Must be less than timeout_seconds. Maps to Kubernetes probe argument 'periodSeconds'. Corresponds to the JSON property periodSeconds

Returns:

  • (Fixnum)


16611
16612
16613
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16611

def period_seconds
  @period_seconds
end

#timeout_secondsFixnum

Number of seconds after which the probe times out. Defaults to 1 second. Minimum value is 1. Must be greater or equal to period_seconds. Maps to Kubernetes probe argument 'timeoutSeconds'. Corresponds to the JSON property timeoutSeconds

Returns:

  • (Fixnum)


16618
16619
16620
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16618

def timeout_seconds
  @timeout_seconds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16625
16626
16627
16628
16629
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 16625

def update!(**args)
  @exec = args[:exec] if args.key?(:exec)
  @period_seconds = args[:period_seconds] if args.key?(:period_seconds)
  @timeout_seconds = args[:timeout_seconds] if args.key?(:timeout_seconds)
end