Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeGrpcAction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

GrpcAction checks the health of a container using a gRPC service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ProbeGrpcAction

Returns a new instance of GoogleCloudAiplatformV1ProbeGrpcAction.



21767
21768
21769
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21767

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#portFixnum

Port number of the gRPC service. Number must be in the range 1 to 65535. Corresponds to the JSON property port

Returns:

  • (Fixnum)


21758
21759
21760
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21758

def port
  @port
end

#serviceString

Service is the name of the service to place in the gRPC HealthCheckRequest ( see https://github.com/grpc/grpc/blob/master/doc/health-checking.md). If this is not specified, the default behavior is defined by gRPC. Corresponds to the JSON property service

Returns:

  • (String)


21765
21766
21767
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21765

def service
  @service
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21772
21773
21774
21775
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21772

def update!(**args)
  @port = args[:port] if args.key?(:port)
  @service = args[:service] if args.key?(:service)
end