Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeHttpGetAction
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeHttpGetAction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
HttpGetAction describes an action based on HTTP Get requests.
Instance Attribute Summary collapse
-
#host ⇒ String
Host name to connect to, defaults to the model serving container's IP.
-
#http_headers ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeHttpHeader>
Custom headers to set in the request.
-
#path ⇒ String
Path to access on the HTTP server.
-
#port ⇒ Fixnum
Number of the port to access on the container.
-
#scheme ⇒ String
Scheme to use for connecting to the host.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ProbeHttpGetAction
constructor
A new instance of GoogleCloudAiplatformV1ProbeHttpGetAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ProbeHttpGetAction
Returns a new instance of GoogleCloudAiplatformV1ProbeHttpGetAction.
31820 31821 31822 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31820 def initialize(**args) update!(**args) end |
Instance Attribute Details
#host ⇒ String
Host name to connect to, defaults to the model serving container's IP. You
probably want to set "Host" in httpHeaders instead.
Corresponds to the JSON property host
31796 31797 31798 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31796 def host @host end |
#http_headers ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeHttpHeader>
Custom headers to set in the request. HTTP allows repeated headers.
Corresponds to the JSON property httpHeaders
31801 31802 31803 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31801 def http_headers @http_headers end |
#path ⇒ String
Path to access on the HTTP server.
Corresponds to the JSON property path
31806 31807 31808 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31806 def path @path end |
#port ⇒ Fixnum
Number of the port to access on the container. Number must be in the range 1
to 65535.
Corresponds to the JSON property port
31812 31813 31814 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31812 def port @port end |
#scheme ⇒ String
Scheme to use for connecting to the host. Defaults to HTTP. Acceptable values
are "HTTP" or "HTTPS".
Corresponds to the JSON property scheme
31818 31819 31820 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31818 def scheme @scheme end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31825 31826 31827 31828 31829 31830 31831 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31825 def update!(**args) @host = args[:host] if args.key?(:host) @http_headers = args[:http_headers] if args.key?(:http_headers) @path = args[:path] if args.key?(:path) @port = args[:port] if args.key?(:port) @scheme = args[:scheme] if args.key?(:scheme) end |