Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeHttpGetAction
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeHttpGetAction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
HttpGetAction describes an action based on HTTP Get requests.
Instance Attribute Summary collapse
-
#host ⇒ String
Host name to connect to, defaults to the model serving container's IP.
-
#http_headers ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeHttpHeader>
Custom headers to set in the request.
-
#path ⇒ String
Path to access on the HTTP server.
-
#port ⇒ Fixnum
Number of the port to access on the container.
-
#scheme ⇒ String
Scheme to use for connecting to the host.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ProbeHttpGetAction
constructor
A new instance of GoogleCloudAiplatformV1ProbeHttpGetAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ProbeHttpGetAction
Returns a new instance of GoogleCloudAiplatformV1ProbeHttpGetAction.
29030 29031 29032 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29030 def initialize(**args) update!(**args) end |
Instance Attribute Details
#host ⇒ String
Host name to connect to, defaults to the model serving container's IP. You
probably want to set "Host" in httpHeaders instead.
Corresponds to the JSON property host
29006 29007 29008 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29006 def host @host end |
#http_headers ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeHttpHeader>
Custom headers to set in the request. HTTP allows repeated headers.
Corresponds to the JSON property httpHeaders
29011 29012 29013 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29011 def http_headers @http_headers end |
#path ⇒ String
Path to access on the HTTP server.
Corresponds to the JSON property path
29016 29017 29018 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29016 def path @path end |
#port ⇒ Fixnum
Number of the port to access on the container. Number must be in the range 1
to 65535.
Corresponds to the JSON property port
29022 29023 29024 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29022 def port @port end |
#scheme ⇒ String
Scheme to use for connecting to the host. Defaults to HTTP. Acceptable values
are "HTTP" or "HTTPS".
Corresponds to the JSON property scheme
29028 29029 29030 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29028 def scheme @scheme end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29035 29036 29037 29038 29039 29040 29041 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29035 def update!(**args) @host = args[:host] if args.key?(:host) @http_headers = args[:http_headers] if args.key?(:http_headers) @path = args[:path] if args.key?(:path) @port = args[:port] if args.key?(:port) @scheme = args[:scheme] if args.key?(:scheme) end |