Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeHttpGetAction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

HttpGetAction describes an action based on HTTP Get requests.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ProbeHttpGetAction

Returns a new instance of GoogleCloudAiplatformV1ProbeHttpGetAction.



27573
27574
27575
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27573

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hostString

Host name to connect to, defaults to the model serving container's IP. You probably want to set "Host" in httpHeaders instead. Corresponds to the JSON property host

Returns:

  • (String)


27549
27550
27551
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27549

def host
  @host
end

#http_headersArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeHttpHeader>

Custom headers to set in the request. HTTP allows repeated headers. Corresponds to the JSON property httpHeaders



27554
27555
27556
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27554

def http_headers
  @http_headers
end

#pathString

Path to access on the HTTP server. Corresponds to the JSON property path

Returns:

  • (String)


27559
27560
27561
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27559

def path
  @path
end

#portFixnum

Number of the port to access on the container. Number must be in the range 1 to 65535. Corresponds to the JSON property port

Returns:

  • (Fixnum)


27565
27566
27567
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27565

def port
  @port
end

#schemeString

Scheme to use for connecting to the host. Defaults to HTTP. Acceptable values are "HTTP" or "HTTPS". Corresponds to the JSON property scheme

Returns:

  • (String)


27571
27572
27573
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27571

def scheme
  @scheme
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27578
27579
27580
27581
27582
27583
27584
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27578

def update!(**args)
  @host = args[:host] if args.key?(:host)
  @http_headers = args[:http_headers] if args.key?(:http_headers)
  @path = args[:path] if args.key?(:path)
  @port = args[:port] if args.key?(:port)
  @scheme = args[:scheme] if args.key?(:scheme)
end