Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeHttpGetAction
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeHttpGetAction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
HttpGetAction describes an action based on HTTP Get requests.
Instance Attribute Summary collapse
-
#host ⇒ String
Host name to connect to, defaults to the model serving container's IP.
-
#http_headers ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeHttpHeader>
Custom headers to set in the request.
-
#path ⇒ String
Path to access on the HTTP server.
-
#port ⇒ Fixnum
Number of the port to access on the container.
-
#scheme ⇒ String
Scheme to use for connecting to the host.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ProbeHttpGetAction
constructor
A new instance of GoogleCloudAiplatformV1ProbeHttpGetAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ProbeHttpGetAction
Returns a new instance of GoogleCloudAiplatformV1ProbeHttpGetAction.
22068 22069 22070 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22068 def initialize(**args) update!(**args) end |
Instance Attribute Details
#host ⇒ String
Host name to connect to, defaults to the model serving container's IP. You
probably want to set "Host" in httpHeaders instead.
Corresponds to the JSON property host
22044 22045 22046 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22044 def host @host end |
#http_headers ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeHttpHeader>
Custom headers to set in the request. HTTP allows repeated headers.
Corresponds to the JSON property httpHeaders
22049 22050 22051 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22049 def http_headers @http_headers end |
#path ⇒ String
Path to access on the HTTP server.
Corresponds to the JSON property path
22054 22055 22056 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22054 def path @path end |
#port ⇒ Fixnum
Number of the port to access on the container. Number must be in the range 1
to 65535.
Corresponds to the JSON property port
22060 22061 22062 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22060 def port @port end |
#scheme ⇒ String
Scheme to use for connecting to the host. Defaults to HTTP. Acceptable values
are "HTTP" or "HTTPS".
Corresponds to the JSON property scheme
22066 22067 22068 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22066 def scheme @scheme end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22073 22074 22075 22076 22077 22078 22079 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22073 def update!(**args) @host = args[:host] if args.key?(:host) @http_headers = args[:http_headers] if args.key?(:http_headers) @path = args[:path] if args.key?(:path) @port = args[:port] if args.key?(:port) @scheme = args[:scheme] if args.key?(:scheme) end |