Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeHttpGetAction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

HttpGetAction describes an action based on HTTP Get requests.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ProbeHttpGetAction

Returns a new instance of GoogleCloudAiplatformV1ProbeHttpGetAction.



21665
21666
21667
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21665

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hostString

Host name to connect to, defaults to the model serving container's IP. You probably want to set "Host" in httpHeaders instead. Corresponds to the JSON property host

Returns:

  • (String)


21641
21642
21643
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21641

def host
  @host
end

#http_headersArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeHttpHeader>

Custom headers to set in the request. HTTP allows repeated headers. Corresponds to the JSON property httpHeaders



21646
21647
21648
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21646

def http_headers
  @http_headers
end

#pathString

Path to access on the HTTP server. Corresponds to the JSON property path

Returns:

  • (String)


21651
21652
21653
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21651

def path
  @path
end

#portFixnum

Number of the port to access on the container. Number must be in the range 1 to 65535. Corresponds to the JSON property port

Returns:

  • (Fixnum)


21657
21658
21659
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21657

def port
  @port
end

#schemeString

Scheme to use for connecting to the host. Defaults to HTTP. Acceptable values are "HTTP" or "HTTPS". Corresponds to the JSON property scheme

Returns:

  • (String)


21663
21664
21665
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21663

def scheme
  @scheme
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21670
21671
21672
21673
21674
21675
21676
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21670

def update!(**args)
  @host = args[:host] if args.key?(:host)
  @http_headers = args[:http_headers] if args.key?(:http_headers)
  @path = args[:path] if args.key?(:path)
  @port = args[:port] if args.key?(:port)
  @scheme = args[:scheme] if args.key?(:scheme)
end