Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeHttpHeader

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

HttpHeader describes a custom header to be used in HTTP probes

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ProbeHttpHeader

Returns a new instance of GoogleCloudAiplatformV1ProbeHttpHeader.



23325
23326
23327
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23325

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

The header field name. This will be canonicalized upon output, so case-variant names will be understood as the same header. Corresponds to the JSON property name

Returns:

  • (String)


23318
23319
23320
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23318

def name
  @name
end

#valueString

The header field value Corresponds to the JSON property value

Returns:

  • (String)


23323
23324
23325
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23323

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23330
23331
23332
23333
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23330

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @value = args[:value] if args.key?(:value)
end