Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeHttpHeader

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

HttpHeader describes a custom header to be used in HTTP probes

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ProbeHttpHeader

Returns a new instance of GoogleCloudAiplatformV1ProbeHttpHeader.



22547
22548
22549
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22547

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

The header field name. This will be canonicalized upon output, so case-variant names will be understood as the same header. Corresponds to the JSON property name

Returns:

  • (String)


22540
22541
22542
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22540

def name
  @name
end

#valueString

The header field value Corresponds to the JSON property value

Returns:

  • (String)


22545
22546
22547
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22545

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22552
22553
22554
22555
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22552

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @value = args[:value] if args.key?(:value)
end