Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeHttpHeader

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

HttpHeader describes a custom header to be used in HTTP probes

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ProbeHttpHeader

Returns a new instance of GoogleCloudAiplatformV1ProbeHttpHeader.



22487
22488
22489
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22487

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

The header field name. This will be canonicalized upon output, so case-variant names will be understood as the same header. Corresponds to the JSON property name

Returns:

  • (String)


22480
22481
22482
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22480

def name
  @name
end

#valueString

The header field value Corresponds to the JSON property value

Returns:

  • (String)


22485
22486
22487
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22485

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22492
22493
22494
22495
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22492

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @value = args[:value] if args.key?(:value)
end