Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ProbeTcpSocketAction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

TcpSocketAction probes the health of a container by opening a TCP socket connection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ProbeTcpSocketAction

Returns a new instance of GoogleCloudAiplatformV1ProbeTcpSocketAction.



30521
30522
30523
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30521

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hostString

Optional: Host name to connect to, defaults to the model serving container's IP. Corresponds to the JSON property host

Returns:

  • (String)


30513
30514
30515
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30513

def host
  @host
end

#portFixnum

Number of the port to access on the container. Number must be in the range 1 to 65535. Corresponds to the JSON property port

Returns:

  • (Fixnum)


30519
30520
30521
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30519

def port
  @port
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30526
30527
30528
30529
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30526

def update!(**args)
  @host = args[:host] if args.key?(:host)
  @port = args[:port] if args.key?(:port)
end