Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PscAutomationConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

PSC config that is used to automatically create PSC endpoints in the user projects.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1PscAutomationConfig

Returns a new instance of GoogleCloudAiplatformV1PscAutomationConfig.



29086
29087
29088
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29086

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_messageString

Output only. Error message if the PSC service automation failed. Corresponds to the JSON property errorMessage

Returns:

  • (String)


29056
29057
29058
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29056

def error_message
  @error_message
end

#forwarding_ruleString

Output only. Forwarding rule created by the PSC service automation. Corresponds to the JSON property forwardingRule

Returns:

  • (String)


29061
29062
29063
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29061

def forwarding_rule
  @forwarding_rule
end

#ip_addressString

Output only. IP address rule created by the PSC service automation. Corresponds to the JSON property ipAddress

Returns:

  • (String)


29066
29067
29068
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29066

def ip_address
  @ip_address
end

#networkString

Required. The full name of the Google Compute Engine network. Format: projects/ project/global/networks/network`. Corresponds to the JSON propertynetwork`

Returns:

  • (String)


29074
29075
29076
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29074

def network
  @network
end

#project_idString

Required. Project id used to create forwarding rule. Corresponds to the JSON property projectId

Returns:

  • (String)


29079
29080
29081
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29079

def project_id
  @project_id
end

#stateString

Output only. The state of the PSC service automation. Corresponds to the JSON property state

Returns:

  • (String)


29084
29085
29086
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29084

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29091
29092
29093
29094
29095
29096
29097
29098
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29091

def update!(**args)
  @error_message = args[:error_message] if args.key?(:error_message)
  @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @network = args[:network] if args.key?(:network)
  @project_id = args[:project_id] if args.key?(:project_id)
  @state = args[:state] if args.key?(:state)
end