Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PscAutomationConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

PSC config that is used to automatically create PSC endpoints in the user projects.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1PscAutomationConfig

Returns a new instance of GoogleCloudAiplatformV1PscAutomationConfig.



26716
26717
26718
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26716

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_messageString

Output only. Error message if the PSC service automation failed. Corresponds to the JSON property errorMessage

Returns:

  • (String)


26686
26687
26688
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26686

def error_message
  @error_message
end

#forwarding_ruleString

Output only. Forwarding rule created by the PSC service automation. Corresponds to the JSON property forwardingRule

Returns:

  • (String)


26691
26692
26693
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26691

def forwarding_rule
  @forwarding_rule
end

#ip_addressString

Output only. IP address rule created by the PSC service automation. Corresponds to the JSON property ipAddress

Returns:

  • (String)


26696
26697
26698
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26696

def ip_address
  @ip_address
end

#networkString

Required. The full name of the Google Compute Engine network. Format: projects/ project/global/networks/network`. Corresponds to the JSON propertynetwork`

Returns:

  • (String)


26704
26705
26706
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26704

def network
  @network
end

#project_idString

Required. Project id used to create forwarding rule. Corresponds to the JSON property projectId

Returns:

  • (String)


26709
26710
26711
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26709

def project_id
  @project_id
end

#stateString

Output only. The state of the PSC service automation. Corresponds to the JSON property state

Returns:

  • (String)


26714
26715
26716
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26714

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26721
26722
26723
26724
26725
26726
26727
26728
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26721

def update!(**args)
  @error_message = args[:error_message] if args.key?(:error_message)
  @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @network = args[:network] if args.key?(:network)
  @project_id = args[:project_id] if args.key?(:project_id)
  @state = args[:state] if args.key?(:state)
end