Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PscAutomationConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

PSC config that is used to automatically create PSC endpoints in the user projects.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1PscAutomationConfig

Returns a new instance of GoogleCloudAiplatformV1PscAutomationConfig.



25315
25316
25317
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25315

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_messageString

Output only. Error message if the PSC service automation failed. Corresponds to the JSON property errorMessage

Returns:

  • (String)


25285
25286
25287
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25285

def error_message
  @error_message
end

#forwarding_ruleString

Output only. Forwarding rule created by the PSC service automation. Corresponds to the JSON property forwardingRule

Returns:

  • (String)


25290
25291
25292
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25290

def forwarding_rule
  @forwarding_rule
end

#ip_addressString

Output only. IP address rule created by the PSC service automation. Corresponds to the JSON property ipAddress

Returns:

  • (String)


25295
25296
25297
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25295

def ip_address
  @ip_address
end

#networkString

Required. The full name of the Google Compute Engine network. Format: projects/ project/global/networks/network`. Corresponds to the JSON propertynetwork`

Returns:

  • (String)


25303
25304
25305
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25303

def network
  @network
end

#project_idString

Required. Project id used to create forwarding rule. Corresponds to the JSON property projectId

Returns:

  • (String)


25308
25309
25310
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25308

def project_id
  @project_id
end

#stateString

Output only. The state of the PSC service automation. Corresponds to the JSON property state

Returns:

  • (String)


25313
25314
25315
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25313

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25320
25321
25322
25323
25324
25325
25326
25327
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25320

def update!(**args)
  @error_message = args[:error_message] if args.key?(:error_message)
  @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @network = args[:network] if args.key?(:network)
  @project_id = args[:project_id] if args.key?(:project_id)
  @state = args[:state] if args.key?(:state)
end