Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PscAutomationConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

PSC config that is used to automatically create PSC endpoints in the user projects.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1PscAutomationConfig

Returns a new instance of GoogleCloudAiplatformV1PscAutomationConfig.



20966
20967
20968
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20966

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_messageString

Output only. Error message if the PSC service automation failed. Corresponds to the JSON property errorMessage

Returns:

  • (String)


20936
20937
20938
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20936

def error_message
  @error_message
end

#forwarding_ruleString

Output only. Forwarding rule created by the PSC service automation. Corresponds to the JSON property forwardingRule

Returns:

  • (String)


20941
20942
20943
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20941

def forwarding_rule
  @forwarding_rule
end

#ip_addressString

Output only. IP address rule created by the PSC service automation. Corresponds to the JSON property ipAddress

Returns:

  • (String)


20946
20947
20948
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20946

def ip_address
  @ip_address
end

#networkString

Required. The full name of the Google Compute Engine network. Format: projects/ project/global/networks/network`. Corresponds to the JSON propertynetwork`

Returns:

  • (String)


20954
20955
20956
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20954

def network
  @network
end

#project_idString

Required. Project id used to create forwarding rule. Corresponds to the JSON property projectId

Returns:

  • (String)


20959
20960
20961
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20959

def project_id
  @project_id
end

#stateString

Output only. The state of the PSC service automation. Corresponds to the JSON property state

Returns:

  • (String)


20964
20965
20966
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20964

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20971
20972
20973
20974
20975
20976
20977
20978
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20971

def update!(**args)
  @error_message = args[:error_message] if args.key?(:error_message)
  @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @network = args[:network] if args.key?(:network)
  @project_id = args[:project_id] if args.key?(:project_id)
  @state = args[:state] if args.key?(:state)
end