Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PscAutomationConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

PSC config that is used to automatically create forwarding rule via ServiceConnectionMap.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1PscAutomationConfig

Returns a new instance of GoogleCloudAiplatformV1PscAutomationConfig.



20613
20614
20615
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20613

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#forwarding_ruleString

Output only. Forwarding rule created by the PSC service automation. Note for Vector search, use IndexPrivateEndpoint instead. Corresponds to the JSON property forwardingRule

Returns:

  • (String)


20591
20592
20593
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20591

def forwarding_rule
  @forwarding_rule
end

#ip_addressString

Output only. IP address rule created by the PSC service automation. Note for Vector search, use IndexPrivateEndpoint instead. Corresponds to the JSON property ipAddress

Returns:

  • (String)


20597
20598
20599
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20597

def ip_address
  @ip_address
end

#networkString

Required. The full name of the Google Compute Engine network. Format: projects/ project/global/networks/network`. Whereprojectis a project number, as in '12345', andnetworkis network name. Corresponds to the JSON propertynetwork`

Returns:

  • (String)


20606
20607
20608
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20606

def network
  @network
end

#project_idString

Required. Project id used to create forwarding rule. Corresponds to the JSON property projectId

Returns:

  • (String)


20611
20612
20613
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20611

def project_id
  @project_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20618
20619
20620
20621
20622
20623
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20618

def update!(**args)
  @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @network = args[:network] if args.key?(:network)
  @project_id = args[:project_id] if args.key?(:project_id)
end