Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PscAutomationConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

PSC config that is used to automatically create forwarding rule via ServiceConnectionMap.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1PscAutomationConfig

Returns a new instance of GoogleCloudAiplatformV1PscAutomationConfig.



20085
20086
20087
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20085

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#networkString

Required. The full name of the Google Compute Engine network. Format: projects/ project/global/networks/network`. Whereprojectis a project number, as in '12345', andnetworkis network name. Corresponds to the JSON propertynetwork`

Returns:

  • (String)


20078
20079
20080
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20078

def network
  @network
end

#project_idString

Required. Project id used to create forwarding rule. Corresponds to the JSON property projectId

Returns:

  • (String)


20083
20084
20085
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20083

def project_id
  @project_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20090
20091
20092
20093
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20090

def update!(**args)
  @network = args[:network] if args.key?(:network)
  @project_id = args[:project_id] if args.key?(:project_id)
end