Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PscInterfaceConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Configuration for PSC-I.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1PscInterfaceConfig

Returns a new instance of GoogleCloudAiplatformV1PscInterfaceConfig.



29209
29210
29211
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29209

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dns_peering_configsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DnsPeeringConfig>

Optional. DNS peering configurations. When specified, Vertex AI will attempt to configure DNS peering zones in the tenant project VPC to resolve the specified domains using the target network's Cloud DNS. The user must grant the dns.peer role to the Vertex AI Service Agent on the target project. Corresponds to the JSON property dnsPeeringConfigs



29197
29198
29199
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29197

def dns_peering_configs
  @dns_peering_configs
end

#network_attachmentString

Optional. The name of the Compute Engine network attachment to attach to the resource within the region and user project. To specify this field, you must have already created a network attachment. This field is only used for resources using PSC-I. Corresponds to the JSON property networkAttachment

Returns:

  • (String)


29207
29208
29209
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29207

def network_attachment
  @network_attachment
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29214
29215
29216
29217
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29214

def update!(**args)
  @dns_peering_configs = args[:dns_peering_configs] if args.key?(:dns_peering_configs)
  @network_attachment = args[:network_attachment] if args.key?(:network_attachment)
end