Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PscInterfaceConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Configuration for PSC-I.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1PscInterfaceConfig

Returns a new instance of GoogleCloudAiplatformV1PscInterfaceConfig.



22687
22688
22689
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22687

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#network_attachmentString

Optional. The name of the Compute Engine network attachment to attach to the resource within the region and user project. To specify this field, you must have already created a network attachment. This field is only used for resources using PSC-I. Corresponds to the JSON property networkAttachment

Returns:

  • (String)


22685
22686
22687
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22685

def network_attachment
  @network_attachment
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22692
22693
22694
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22692

def update!(**args)
  @network_attachment = args[:network_attachment] if args.key?(:network_attachment)
end