Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PscInterfaceConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Configuration for PSC-I.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1PscInterfaceConfig

Returns a new instance of GoogleCloudAiplatformV1PscInterfaceConfig.



18550
18551
18552
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18550

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#network_attachmentString

Optional. The full name of the Compute Engine network attachment to attach to the resource. For example, projects/12345/regions/us-central1/networkAttachments/myNA. is of the form projects/project/regions/region/networkAttachments/ networkAttachment`. Whereprojectis a project number, as in12345, and networkAttachmentis a network attachment name. To specify this field, you must have already [created a network attachment] (https://cloud.google.com/vpc/ docs/create-manage-network-attachments#create-network-attachments). This field is only used for resources using PSC-I. Corresponds to the JSON propertynetworkAttachment`

Returns:

  • (String)


18548
18549
18550
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18548

def network_attachment
  @network_attachment
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18555
18556
18557
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18555

def update!(**args)
  @network_attachment = args[:network_attachment] if args.key?(:network_attachment)
end