Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PublisherModel
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PublisherModel
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A Model Garden Publisher Model.
Instance Attribute Summary collapse
-
#frameworks ⇒ Array<String>
Optional.
-
#launch_stage ⇒ String
Optional.
-
#name ⇒ String
Output only.
-
#open_source_category ⇒ String
Required.
-
#predict_schemata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PredictSchemata
Contains the schemata used in Model's predictions and explanations via PredictionService.Predict, PredictionService.Explain and BatchPredictionJob.
-
#publisher_model_template ⇒ String
Optional.
-
#supported_actions ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PublisherModelCallToAction
Actions could take on this Publisher Model.
-
#version_id ⇒ String
Output only.
-
#version_state ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1PublisherModel
constructor
A new instance of GoogleCloudAiplatformV1PublisherModel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1PublisherModel
Returns a new instance of GoogleCloudAiplatformV1PublisherModel.
31054 31055 31056 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31054 def initialize(**args) update!(**args) end |
Instance Attribute Details
#frameworks ⇒ Array<String>
Optional. Additional information about the model's Frameworks.
Corresponds to the JSON property frameworks
31008 31009 31010 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31008 def frameworks @frameworks end |
#launch_stage ⇒ String
Optional. Indicates the launch stage of the model.
Corresponds to the JSON property launchStage
31013 31014 31015 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31013 def launch_stage @launch_stage end |
#name ⇒ String
Output only. Identifier. The resource name of the PublisherModel.
Corresponds to the JSON property name
31018 31019 31020 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31018 def name @name end |
#open_source_category ⇒ String
Required. Indicates the open source category of the publisher model.
Corresponds to the JSON property openSourceCategory
31023 31024 31025 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31023 def open_source_category @open_source_category end |
#predict_schemata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PredictSchemata
Contains the schemata used in Model's predictions and explanations via
PredictionService.Predict, PredictionService.Explain and BatchPredictionJob.
Corresponds to the JSON property predictSchemata
31029 31030 31031 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31029 def predict_schemata @predict_schemata end |
#publisher_model_template ⇒ String
Optional. Output only. Immutable. Used to indicate this model has a publisher
model and provide the template of the publisher model resource name.
Corresponds to the JSON property publisherModelTemplate
31035 31036 31037 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31035 def publisher_model_template @publisher_model_template end |
#supported_actions ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PublisherModelCallToAction
Actions could take on this Publisher Model.
Corresponds to the JSON property supportedActions
31040 31041 31042 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31040 def supported_actions @supported_actions end |
#version_id ⇒ String
Output only. Immutable. The version ID of the PublisherModel. A new version is
committed when a new model version is uploaded under an existing model id. It
is an auto-incrementing decimal number in string representation.
Corresponds to the JSON property versionId
31047 31048 31049 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31047 def version_id @version_id end |
#version_state ⇒ String
Optional. Indicates the state of the model version.
Corresponds to the JSON property versionState
31052 31053 31054 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31052 def version_state @version_state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31059 31060 31061 31062 31063 31064 31065 31066 31067 31068 31069 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31059 def update!(**args) @frameworks = args[:frameworks] if args.key?(:frameworks) @launch_stage = args[:launch_stage] if args.key?(:launch_stage) @name = args[:name] if args.key?(:name) @open_source_category = args[:open_source_category] if args.key?(:open_source_category) @predict_schemata = args[:predict_schemata] if args.key?(:predict_schemata) @publisher_model_template = args[:publisher_model_template] if args.key?(:publisher_model_template) @supported_actions = args[:supported_actions] if args.key?(:supported_actions) @version_id = args[:version_id] if args.key?(:version_id) @version_state = args[:version_state] if args.key?(:version_state) end |