Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PublisherModel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A Model Garden Publisher Model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1PublisherModel

Returns a new instance of GoogleCloudAiplatformV1PublisherModel.



30650
30651
30652
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30650

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#frameworksArray<String>

Optional. Additional information about the model's Frameworks. Corresponds to the JSON property frameworks

Returns:

  • (Array<String>)


30604
30605
30606
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30604

def frameworks
  @frameworks
end

#launch_stageString

Optional. Indicates the launch stage of the model. Corresponds to the JSON property launchStage

Returns:

  • (String)


30609
30610
30611
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30609

def launch_stage
  @launch_stage
end

#nameString

Output only. Identifier. The resource name of the PublisherModel. Corresponds to the JSON property name

Returns:

  • (String)


30614
30615
30616
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30614

def name
  @name
end

#open_source_categoryString

Required. Indicates the open source category of the publisher model. Corresponds to the JSON property openSourceCategory

Returns:

  • (String)


30619
30620
30621
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30619

def open_source_category
  @open_source_category
end

#predict_schemataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PredictSchemata

Contains the schemata used in Model's predictions and explanations via PredictionService.Predict, PredictionService.Explain and BatchPredictionJob. Corresponds to the JSON property predictSchemata



30625
30626
30627
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30625

def predict_schemata
  @predict_schemata
end

#publisher_model_templateString

Optional. Output only. Immutable. Used to indicate this model has a publisher model and provide the template of the publisher model resource name. Corresponds to the JSON property publisherModelTemplate

Returns:

  • (String)


30631
30632
30633
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30631

def publisher_model_template
  @publisher_model_template
end

#supported_actionsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PublisherModelCallToAction

Actions could take on this Publisher Model. Corresponds to the JSON property supportedActions



30636
30637
30638
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30636

def supported_actions
  @supported_actions
end

#version_idString

Output only. Immutable. The version ID of the PublisherModel. A new version is committed when a new model version is uploaded under an existing model id. It is an auto-incrementing decimal number in string representation. Corresponds to the JSON property versionId

Returns:

  • (String)


30643
30644
30645
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30643

def version_id
  @version_id
end

#version_stateString

Optional. Indicates the state of the model version. Corresponds to the JSON property versionState

Returns:

  • (String)


30648
30649
30650
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30648

def version_state
  @version_state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30655
30656
30657
30658
30659
30660
30661
30662
30663
30664
30665
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30655

def update!(**args)
  @frameworks = args[:frameworks] if args.key?(:frameworks)
  @launch_stage = args[:launch_stage] if args.key?(:launch_stage)
  @name = args[:name] if args.key?(:name)
  @open_source_category = args[:open_source_category] if args.key?(:open_source_category)
  @predict_schemata = args[:predict_schemata] if args.key?(:predict_schemata)
  @publisher_model_template = args[:publisher_model_template] if args.key?(:publisher_model_template)
  @supported_actions = args[:supported_actions] if args.key?(:supported_actions)
  @version_id = args[:version_id] if args.key?(:version_id)
  @version_state = args[:version_state] if args.key?(:version_state)
end