Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PublisherModel
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PublisherModel
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A Model Garden Publisher Model.
Instance Attribute Summary collapse
-
#frameworks ⇒ Array<String>
Optional.
-
#launch_stage ⇒ String
Optional.
-
#name ⇒ String
Output only.
-
#open_source_category ⇒ String
Required.
-
#predict_schemata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PredictSchemata
Contains the schemata used in Model's predictions and explanations via PredictionService.Predict, PredictionService.Explain and BatchPredictionJob.
-
#publisher_model_template ⇒ String
Optional.
-
#supported_actions ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PublisherModelCallToAction
Actions could take on this Publisher Model.
-
#version_id ⇒ String
Output only.
-
#version_state ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1PublisherModel
constructor
A new instance of GoogleCloudAiplatformV1PublisherModel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1PublisherModel
Returns a new instance of GoogleCloudAiplatformV1PublisherModel.
23151 23152 23153 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23151 def initialize(**args) update!(**args) end |
Instance Attribute Details
#frameworks ⇒ Array<String>
Optional. Additional information about the model's Frameworks.
Corresponds to the JSON property frameworks
23105 23106 23107 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23105 def frameworks @frameworks end |
#launch_stage ⇒ String
Optional. Indicates the launch stage of the model.
Corresponds to the JSON property launchStage
23110 23111 23112 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23110 def launch_stage @launch_stage end |
#name ⇒ String
Output only. The resource name of the PublisherModel.
Corresponds to the JSON property name
23115 23116 23117 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23115 def name @name end |
#open_source_category ⇒ String
Required. Indicates the open source category of the publisher model.
Corresponds to the JSON property openSourceCategory
23120 23121 23122 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23120 def open_source_category @open_source_category end |
#predict_schemata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PredictSchemata
Contains the schemata used in Model's predictions and explanations via
PredictionService.Predict, PredictionService.Explain and BatchPredictionJob.
Corresponds to the JSON property predictSchemata
23126 23127 23128 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23126 def predict_schemata @predict_schemata end |
#publisher_model_template ⇒ String
Optional. Output only. Immutable. Used to indicate this model has a publisher
model and provide the template of the publisher model resource name.
Corresponds to the JSON property publisherModelTemplate
23132 23133 23134 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23132 def publisher_model_template @publisher_model_template end |
#supported_actions ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PublisherModelCallToAction
Actions could take on this Publisher Model.
Corresponds to the JSON property supportedActions
23137 23138 23139 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23137 def supported_actions @supported_actions end |
#version_id ⇒ String
Output only. Immutable. The version ID of the PublisherModel. A new version is
committed when a new model version is uploaded under an existing model id. It
is an auto-incrementing decimal number in string representation.
Corresponds to the JSON property versionId
23144 23145 23146 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23144 def version_id @version_id end |
#version_state ⇒ String
Optional. Indicates the state of the model version.
Corresponds to the JSON property versionState
23149 23150 23151 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23149 def version_state @version_state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23156 23157 23158 23159 23160 23161 23162 23163 23164 23165 23166 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23156 def update!(**args) @frameworks = args[:frameworks] if args.key?(:frameworks) @launch_stage = args[:launch_stage] if args.key?(:launch_stage) @name = args[:name] if args.key?(:name) @open_source_category = args[:open_source_category] if args.key?(:open_source_category) @predict_schemata = args[:predict_schemata] if args.key?(:predict_schemata) @publisher_model_template = args[:publisher_model_template] if args.key?(:publisher_model_template) @supported_actions = args[:supported_actions] if args.key?(:supported_actions) @version_id = args[:version_id] if args.key?(:version_id) @version_state = args[:version_state] if args.key?(:version_state) end |