Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PublisherModel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A Model Garden Publisher Model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1PublisherModel

Returns a new instance of GoogleCloudAiplatformV1PublisherModel.



22284
22285
22286
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22284

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#frameworksArray<String>

Optional. Additional information about the model's Frameworks. Corresponds to the JSON property frameworks

Returns:

  • (Array<String>)


22238
22239
22240
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22238

def frameworks
  @frameworks
end

#launch_stageString

Optional. Indicates the launch stage of the model. Corresponds to the JSON property launchStage

Returns:

  • (String)


22243
22244
22245
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22243

def launch_stage
  @launch_stage
end

#nameString

Output only. The resource name of the PublisherModel. Corresponds to the JSON property name

Returns:

  • (String)


22248
22249
22250
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22248

def name
  @name
end

#open_source_categoryString

Required. Indicates the open source category of the publisher model. Corresponds to the JSON property openSourceCategory

Returns:

  • (String)


22253
22254
22255
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22253

def open_source_category
  @open_source_category
end

#predict_schemataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PredictSchemata

Contains the schemata used in Model's predictions and explanations via PredictionService.Predict, PredictionService.Explain and BatchPredictionJob. Corresponds to the JSON property predictSchemata



22259
22260
22261
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22259

def predict_schemata
  @predict_schemata
end

#publisher_model_templateString

Optional. Output only. Immutable. Used to indicate this model has a publisher model and provide the template of the publisher model resource name. Corresponds to the JSON property publisherModelTemplate

Returns:

  • (String)


22265
22266
22267
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22265

def publisher_model_template
  @publisher_model_template
end

#supported_actionsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PublisherModelCallToAction

Actions could take on this Publisher Model. Corresponds to the JSON property supportedActions



22270
22271
22272
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22270

def supported_actions
  @supported_actions
end

#version_idString

Output only. Immutable. The version ID of the PublisherModel. A new version is committed when a new model version is uploaded under an existing model id. It is an auto-incrementing decimal number in string representation. Corresponds to the JSON property versionId

Returns:

  • (String)


22277
22278
22279
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22277

def version_id
  @version_id
end

#version_stateString

Optional. Indicates the state of the model version. Corresponds to the JSON property versionState

Returns:

  • (String)


22282
22283
22284
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22282

def version_state
  @version_state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22289
22290
22291
22292
22293
22294
22295
22296
22297
22298
22299
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22289

def update!(**args)
  @frameworks = args[:frameworks] if args.key?(:frameworks)
  @launch_stage = args[:launch_stage] if args.key?(:launch_stage)
  @name = args[:name] if args.key?(:name)
  @open_source_category = args[:open_source_category] if args.key?(:open_source_category)
  @predict_schemata = args[:predict_schemata] if args.key?(:predict_schemata)
  @publisher_model_template = args[:publisher_model_template] if args.key?(:publisher_model_template)
  @supported_actions = args[:supported_actions] if args.key?(:supported_actions)
  @version_id = args[:version_id] if args.key?(:version_id)
  @version_state = args[:version_state] if args.key?(:version_state)
end