Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PublisherModel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A Model Garden Publisher Model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1PublisherModel

Returns a new instance of GoogleCloudAiplatformV1PublisherModel.



21998
21999
22000
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21998

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#frameworksArray<String>

Optional. Additional information about the model's Frameworks. Corresponds to the JSON property frameworks

Returns:

  • (Array<String>)


21952
21953
21954
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21952

def frameworks
  @frameworks
end

#launch_stageString

Optional. Indicates the launch stage of the model. Corresponds to the JSON property launchStage

Returns:

  • (String)


21957
21958
21959
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21957

def launch_stage
  @launch_stage
end

#nameString

Output only. The resource name of the PublisherModel. Corresponds to the JSON property name

Returns:

  • (String)


21962
21963
21964
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21962

def name
  @name
end

#open_source_categoryString

Required. Indicates the open source category of the publisher model. Corresponds to the JSON property openSourceCategory

Returns:

  • (String)


21967
21968
21969
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21967

def open_source_category
  @open_source_category
end

#predict_schemataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PredictSchemata

Contains the schemata used in Model's predictions and explanations via PredictionService.Predict, PredictionService.Explain and BatchPredictionJob. Corresponds to the JSON property predictSchemata



21973
21974
21975
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21973

def predict_schemata
  @predict_schemata
end

#publisher_model_templateString

Optional. Output only. Immutable. Used to indicate this model has a publisher model and provide the template of the publisher model resource name. Corresponds to the JSON property publisherModelTemplate

Returns:

  • (String)


21979
21980
21981
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21979

def publisher_model_template
  @publisher_model_template
end

#supported_actionsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PublisherModelCallToAction

Actions could take on this Publisher Model. Corresponds to the JSON property supportedActions



21984
21985
21986
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21984

def supported_actions
  @supported_actions
end

#version_idString

Output only. Immutable. The version ID of the PublisherModel. A new version is committed when a new model version is uploaded under an existing model id. It is an auto-incrementing decimal number in string representation. Corresponds to the JSON property versionId

Returns:

  • (String)


21991
21992
21993
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21991

def version_id
  @version_id
end

#version_stateString

Optional. Indicates the state of the model version. Corresponds to the JSON property versionState

Returns:

  • (String)


21996
21997
21998
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21996

def version_state
  @version_state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22003
22004
22005
22006
22007
22008
22009
22010
22011
22012
22013
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22003

def update!(**args)
  @frameworks = args[:frameworks] if args.key?(:frameworks)
  @launch_stage = args[:launch_stage] if args.key?(:launch_stage)
  @name = args[:name] if args.key?(:name)
  @open_source_category = args[:open_source_category] if args.key?(:open_source_category)
  @predict_schemata = args[:predict_schemata] if args.key?(:predict_schemata)
  @publisher_model_template = args[:publisher_model_template] if args.key?(:publisher_model_template)
  @supported_actions = args[:supported_actions] if args.key?(:supported_actions)
  @version_id = args[:version_id] if args.key?(:version_id)
  @version_state = args[:version_state] if args.key?(:version_state)
end