Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PublisherModel
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PublisherModel
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A Model Garden Publisher Model.
Instance Attribute Summary collapse
-
#frameworks ⇒ Array<String>
Optional.
-
#launch_stage ⇒ String
Optional.
-
#name ⇒ String
Output only.
-
#open_source_category ⇒ String
Required.
-
#predict_schemata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PredictSchemata
Contains the schemata used in Model's predictions and explanations via PredictionService.Predict, PredictionService.Explain and BatchPredictionJob.
-
#publisher_model_template ⇒ String
Optional.
-
#supported_actions ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PublisherModelCallToAction
Actions could take on this Publisher Model.
-
#version_id ⇒ String
Output only.
-
#version_state ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1PublisherModel
constructor
A new instance of GoogleCloudAiplatformV1PublisherModel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1PublisherModel
Returns a new instance of GoogleCloudAiplatformV1PublisherModel.
15777 15778 15779 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15777 def initialize(**args) update!(**args) end |
Instance Attribute Details
#frameworks ⇒ Array<String>
Optional. Additional information about the model's Frameworks.
Corresponds to the JSON property frameworks
15731 15732 15733 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15731 def frameworks @frameworks end |
#launch_stage ⇒ String
Optional. Indicates the launch stage of the model.
Corresponds to the JSON property launchStage
15736 15737 15738 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15736 def launch_stage @launch_stage end |
#name ⇒ String
Output only. The resource name of the PublisherModel.
Corresponds to the JSON property name
15741 15742 15743 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15741 def name @name end |
#open_source_category ⇒ String
Required. Indicates the open source category of the publisher model.
Corresponds to the JSON property openSourceCategory
15746 15747 15748 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15746 def open_source_category @open_source_category end |
#predict_schemata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PredictSchemata
Contains the schemata used in Model's predictions and explanations via
PredictionService.Predict, PredictionService.Explain and BatchPredictionJob.
Corresponds to the JSON property predictSchemata
15752 15753 15754 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15752 def predict_schemata @predict_schemata end |
#publisher_model_template ⇒ String
Optional. Output only. Immutable. Used to indicate this model has a publisher
model and provide the template of the publisher model resource name.
Corresponds to the JSON property publisherModelTemplate
15758 15759 15760 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15758 def publisher_model_template @publisher_model_template end |
#supported_actions ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PublisherModelCallToAction
Actions could take on this Publisher Model.
Corresponds to the JSON property supportedActions
15763 15764 15765 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15763 def supported_actions @supported_actions end |
#version_id ⇒ String
Output only. Immutable. The version ID of the PublisherModel. A new version is
committed when a new model version is uploaded under an existing model id. It
is an auto-incrementing decimal number in string representation.
Corresponds to the JSON property versionId
15770 15771 15772 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15770 def version_id @version_id end |
#version_state ⇒ String
Optional. Indicates the state of the model version.
Corresponds to the JSON property versionState
15775 15776 15777 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15775 def version_state @version_state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15782 15783 15784 15785 15786 15787 15788 15789 15790 15791 15792 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 15782 def update!(**args) @frameworks = args[:frameworks] if args.key?(:frameworks) @launch_stage = args[:launch_stage] if args.key?(:launch_stage) @name = args[:name] if args.key?(:name) @open_source_category = args[:open_source_category] if args.key?(:open_source_category) @predict_schemata = args[:predict_schemata] if args.key?(:predict_schemata) @publisher_model_template = args[:publisher_model_template] if args.key?(:publisher_model_template) @supported_actions = args[:supported_actions] if args.key?(:supported_actions) @version_id = args[:version_id] if args.key?(:version_id) @version_state = args[:version_state] if args.key?(:version_state) end |