Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PublisherModelCallToActionDeploy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Model metadata that is needed for UploadModel or DeployModel/CreateEndpoint requests.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1PublisherModelCallToActionDeploy

Returns a new instance of GoogleCloudAiplatformV1PublisherModelCallToActionDeploy.



31247
31248
31249
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31247

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_uriString

Optional. The path to the directory containing the Model artifact and any of its supporting files. Corresponds to the JSON property artifactUri

Returns:

  • (String)


31187
31188
31189
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31187

def artifact_uri
  @artifact_uri
end

#automatic_resourcesGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1AutomaticResources

A description of resources that to large degree are decided by Agent Platform, and require only a modest additional configuration. Each Model supporting these resources documents its specific guidelines. Corresponds to the JSON property automaticResources



31194
31195
31196
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31194

def automatic_resources
  @automatic_resources
end

#container_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelContainerSpec

Specification of a container for serving predictions. Some fields in this message correspond to fields in the Kubernetes Container v1 core specification. Corresponds to the JSON property containerSpec



31202
31203
31204
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31202

def container_spec
  @container_spec
end

#dedicated_resourcesGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1DedicatedResources

A description of resources that are dedicated to a DeployedModel or DeployedIndex, and that need a higher degree of manual configuration. Corresponds to the JSON property dedicatedResources



31208
31209
31210
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31208

def dedicated_resources
  @dedicated_resources
end

#deploy_metadataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PublisherModelCallToActionDeployDeployMetadata

Metadata information about the deployment for managing deployment config. Corresponds to the JSON property deployMetadata



31213
31214
31215
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31213

def 
  @deploy_metadata
end

#deploy_task_nameString

Optional. The name of the deploy task (e.g., "text to image generation"). Corresponds to the JSON property deployTaskName

Returns:

  • (String)


31218
31219
31220
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31218

def deploy_task_name
  @deploy_task_name
end

#large_model_referenceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1LargeModelReference

Contains information about the Large Model. Corresponds to the JSON property largeModelReference



31223
31224
31225
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31223

def large_model_reference
  @large_model_reference
end

#model_display_nameString

Optional. Default model display name. Corresponds to the JSON property modelDisplayName

Returns:

  • (String)


31228
31229
31230
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31228

def model_display_name
  @model_display_name
end

#public_artifact_uriString

Optional. The signed URI for ephemeral Cloud Storage access to model artifact. Corresponds to the JSON property publicArtifactUri

Returns:

  • (String)


31233
31234
31235
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31233

def public_artifact_uri
  @public_artifact_uri
end

#shared_resourcesString

The resource name of the shared DeploymentResourcePool to deploy on. Format: projects/project/locations/location/deploymentResourcePools/ deployment_resource_pool` Corresponds to the JSON propertysharedResources`

Returns:

  • (String)


31240
31241
31242
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31240

def shared_resources
  @shared_resources
end

#titleString

Required. The title of the regional resource reference. Corresponds to the JSON property title

Returns:

  • (String)


31245
31246
31247
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31245

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31252
31253
31254
31255
31256
31257
31258
31259
31260
31261
31262
31263
31264
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31252

def update!(**args)
  @artifact_uri = args[:artifact_uri] if args.key?(:artifact_uri)
  @automatic_resources = args[:automatic_resources] if args.key?(:automatic_resources)
  @container_spec = args[:container_spec] if args.key?(:container_spec)
  @dedicated_resources = args[:dedicated_resources] if args.key?(:dedicated_resources)
  @deploy_metadata = args[:deploy_metadata] if args.key?(:deploy_metadata)
  @deploy_task_name = args[:deploy_task_name] if args.key?(:deploy_task_name)
  @large_model_reference = args[:large_model_reference] if args.key?(:large_model_reference)
  @model_display_name = args[:model_display_name] if args.key?(:model_display_name)
  @public_artifact_uri = args[:public_artifact_uri] if args.key?(:public_artifact_uri)
  @shared_resources = args[:shared_resources] if args.key?(:shared_resources)
  @title = args[:title] if args.key?(:title)
end