Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PublisherModelCallToActionDeploy
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PublisherModelCallToActionDeploy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Model metadata that is needed for UploadModel or DeployModel/CreateEndpoint requests.
Instance Attribute Summary collapse
-
#artifact_uri ⇒ String
Optional.
-
#automatic_resources ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AutomaticResources
A description of resources that to large degree are decided by Vertex AI, and require only a modest additional configuration.
-
#container_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelContainerSpec
Specification of a container for serving predictions.
-
#dedicated_resources ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DedicatedResources
A description of resources that are dedicated to a DeployedModel or DeployedIndex, and that need a higher degree of manual configuration.
-
#deploy_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PublisherModelCallToActionDeployDeployMetadata
Metadata information about the deployment for managing deployment config.
-
#deploy_task_name ⇒ String
Optional.
-
#large_model_reference ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1LargeModelReference
Contains information about the Large Model.
-
#model_display_name ⇒ String
Optional.
-
#public_artifact_uri ⇒ String
Optional.
-
#shared_resources ⇒ String
The resource name of the shared DeploymentResourcePool to deploy on.
-
#title ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1PublisherModelCallToActionDeploy
constructor
A new instance of GoogleCloudAiplatformV1PublisherModelCallToActionDeploy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1PublisherModelCallToActionDeploy
Returns a new instance of GoogleCloudAiplatformV1PublisherModelCallToActionDeploy.
22477 22478 22479 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22477 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_uri ⇒ String
Optional. The path to the directory containing the Model artifact and any of
its supporting files.
Corresponds to the JSON property artifactUri
22417 22418 22419 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22417 def artifact_uri @artifact_uri end |
#automatic_resources ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AutomaticResources
A description of resources that to large degree are decided by Vertex AI, and
require only a modest additional configuration. Each Model supporting these
resources documents its specific guidelines.
Corresponds to the JSON property automaticResources
22424 22425 22426 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22424 def automatic_resources @automatic_resources end |
#container_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelContainerSpec
Specification of a container for serving predictions. Some fields in this
message correspond to fields in the Kubernetes Container v1 core
specification.
Corresponds to the JSON property containerSpec
22432 22433 22434 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22432 def container_spec @container_spec end |
#dedicated_resources ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DedicatedResources
A description of resources that are dedicated to a DeployedModel or
DeployedIndex, and that need a higher degree of manual configuration.
Corresponds to the JSON property dedicatedResources
22438 22439 22440 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22438 def dedicated_resources @dedicated_resources end |
#deploy_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PublisherModelCallToActionDeployDeployMetadata
Metadata information about the deployment for managing deployment config.
Corresponds to the JSON property deployMetadata
22443 22444 22445 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22443 def @deploy_metadata end |
#deploy_task_name ⇒ String
Optional. The name of the deploy task (e.g., "text to image generation").
Corresponds to the JSON property deployTaskName
22448 22449 22450 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22448 def deploy_task_name @deploy_task_name end |
#large_model_reference ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1LargeModelReference
Contains information about the Large Model.
Corresponds to the JSON property largeModelReference
22453 22454 22455 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22453 def large_model_reference @large_model_reference end |
#model_display_name ⇒ String
Optional. Default model display name.
Corresponds to the JSON property modelDisplayName
22458 22459 22460 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22458 def model_display_name @model_display_name end |
#public_artifact_uri ⇒ String
Optional. The signed URI for ephemeral Cloud Storage access to model artifact.
Corresponds to the JSON property publicArtifactUri
22463 22464 22465 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22463 def public_artifact_uri @public_artifact_uri end |
#shared_resources ⇒ String
The resource name of the shared DeploymentResourcePool to deploy on. Format:
projects/project/locations/location/deploymentResourcePools/
deployment_resource_pool`
Corresponds to the JSON propertysharedResources`
22470 22471 22472 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22470 def shared_resources @shared_resources end |
#title ⇒ String
Required. The title of the regional resource reference.
Corresponds to the JSON property title
22475 22476 22477 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22475 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22482 22483 22484 22485 22486 22487 22488 22489 22490 22491 22492 22493 22494 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22482 def update!(**args) @artifact_uri = args[:artifact_uri] if args.key?(:artifact_uri) @automatic_resources = args[:automatic_resources] if args.key?(:automatic_resources) @container_spec = args[:container_spec] if args.key?(:container_spec) @dedicated_resources = args[:dedicated_resources] if args.key?(:dedicated_resources) @deploy_metadata = args[:deploy_metadata] if args.key?(:deploy_metadata) @deploy_task_name = args[:deploy_task_name] if args.key?(:deploy_task_name) @large_model_reference = args[:large_model_reference] if args.key?(:large_model_reference) @model_display_name = args[:model_display_name] if args.key?(:model_display_name) @public_artifact_uri = args[:public_artifact_uri] if args.key?(:public_artifact_uri) @shared_resources = args[:shared_resources] if args.key?(:shared_resources) @title = args[:title] if args.key?(:title) end |