Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PublisherModelCallToActionDeploy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Model metadata that is needed for UploadModel or DeployModel/CreateEndpoint requests.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1PublisherModelCallToActionDeploy

Returns a new instance of GoogleCloudAiplatformV1PublisherModelCallToActionDeploy.



17282
17283
17284
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17282

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_uriString

Optional. The path to the directory containing the Model artifact and any of its supporting files. Corresponds to the JSON property artifactUri

Returns:

  • (String)


17227
17228
17229
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17227

def artifact_uri
  @artifact_uri
end

#automatic_resourcesGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1AutomaticResources

A description of resources that to large degree are decided by Vertex AI, and require only a modest additional configuration. Each Model supporting these resources documents its specific guidelines. Corresponds to the JSON property automaticResources



17234
17235
17236
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17234

def automatic_resources
  @automatic_resources
end

#container_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelContainerSpec

Specification of a container for serving predictions. Some fields in this message correspond to fields in the Kubernetes Container v1 core specification. Corresponds to the JSON property containerSpec



17242
17243
17244
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17242

def container_spec
  @container_spec
end

#dedicated_resourcesGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1DedicatedResources

A description of resources that are dedicated to a DeployedModel, and that need a higher degree of manual configuration. Corresponds to the JSON property dedicatedResources



17248
17249
17250
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17248

def dedicated_resources
  @dedicated_resources
end

#deploy_task_nameString

Optional. The name of the deploy task (e.g., "text to image generation"). Corresponds to the JSON property deployTaskName

Returns:

  • (String)


17253
17254
17255
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17253

def deploy_task_name
  @deploy_task_name
end

#large_model_referenceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1LargeModelReference

Contains information about the Large Model. Corresponds to the JSON property largeModelReference



17258
17259
17260
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17258

def large_model_reference
  @large_model_reference
end

#model_display_nameString

Optional. Default model display name. Corresponds to the JSON property modelDisplayName

Returns:

  • (String)


17263
17264
17265
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17263

def model_display_name
  @model_display_name
end

#public_artifact_uriString

Optional. The signed URI for ephemeral Cloud Storage access to model artifact. Corresponds to the JSON property publicArtifactUri

Returns:

  • (String)


17268
17269
17270
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17268

def public_artifact_uri
  @public_artifact_uri
end

#shared_resourcesString

The resource name of the shared DeploymentResourcePool to deploy on. Format: projects/project/locations/location/deploymentResourcePools/ deployment_resource_pool` Corresponds to the JSON propertysharedResources`

Returns:

  • (String)


17275
17276
17277
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17275

def shared_resources
  @shared_resources
end

#titleString

Required. The title of the regional resource reference. Corresponds to the JSON property title

Returns:

  • (String)


17280
17281
17282
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17280

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17287
17288
17289
17290
17291
17292
17293
17294
17295
17296
17297
17298
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17287

def update!(**args)
  @artifact_uri = args[:artifact_uri] if args.key?(:artifact_uri)
  @automatic_resources = args[:automatic_resources] if args.key?(:automatic_resources)
  @container_spec = args[:container_spec] if args.key?(:container_spec)
  @dedicated_resources = args[:dedicated_resources] if args.key?(:dedicated_resources)
  @deploy_task_name = args[:deploy_task_name] if args.key?(:deploy_task_name)
  @large_model_reference = args[:large_model_reference] if args.key?(:large_model_reference)
  @model_display_name = args[:model_display_name] if args.key?(:model_display_name)
  @public_artifact_uri = args[:public_artifact_uri] if args.key?(:public_artifact_uri)
  @shared_resources = args[:shared_resources] if args.key?(:shared_resources)
  @title = args[:title] if args.key?(:title)
end