Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PublisherModelCallToActionDeploy
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PublisherModelCallToActionDeploy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Model metadata that is needed for UploadModel or DeployModel/CreateEndpoint requests.
Instance Attribute Summary collapse
-
#artifact_uri ⇒ String
Optional.
-
#automatic_resources ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AutomaticResources
A description of resources that to large degree are decided by Vertex AI, and require only a modest additional configuration.
-
#container_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelContainerSpec
Specification of a container for serving predictions.
-
#dedicated_resources ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DedicatedResources
A description of resources that are dedicated to a DeployedModel, and that need a higher degree of manual configuration.
-
#large_model_reference ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1LargeModelReference
Contains information about the Large Model.
-
#model_display_name ⇒ String
Optional.
-
#public_artifact_uri ⇒ String
Optional.
-
#shared_resources ⇒ String
The resource name of the shared DeploymentResourcePool to deploy on.
-
#title ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1PublisherModelCallToActionDeploy
constructor
A new instance of GoogleCloudAiplatformV1PublisherModelCallToActionDeploy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1PublisherModelCallToActionDeploy
Returns a new instance of GoogleCloudAiplatformV1PublisherModelCallToActionDeploy.
17749 17750 17751 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17749 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_uri ⇒ String
Optional. The path to the directory containing the Model artifact and any of
its supporting files.
Corresponds to the JSON property artifactUri
17699 17700 17701 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17699 def artifact_uri @artifact_uri end |
#automatic_resources ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1AutomaticResources
A description of resources that to large degree are decided by Vertex AI, and
require only a modest additional configuration. Each Model supporting these
resources documents its specific guidelines.
Corresponds to the JSON property automaticResources
17706 17707 17708 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17706 def automatic_resources @automatic_resources end |
#container_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelContainerSpec
Specification of a container for serving predictions. Some fields in this
message correspond to fields in the Kubernetes Container v1 core
specification.
Corresponds to the JSON property containerSpec
17714 17715 17716 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17714 def container_spec @container_spec end |
#dedicated_resources ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DedicatedResources
A description of resources that are dedicated to a DeployedModel, and that
need a higher degree of manual configuration.
Corresponds to the JSON property dedicatedResources
17720 17721 17722 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17720 def dedicated_resources @dedicated_resources end |
#large_model_reference ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1LargeModelReference
Contains information about the Large Model.
Corresponds to the JSON property largeModelReference
17725 17726 17727 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17725 def large_model_reference @large_model_reference end |
#model_display_name ⇒ String
Optional. Default model display name.
Corresponds to the JSON property modelDisplayName
17730 17731 17732 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17730 def model_display_name @model_display_name end |
#public_artifact_uri ⇒ String
Optional. The signed URI for ephemeral Cloud Storage access to model artifact.
Corresponds to the JSON property publicArtifactUri
17735 17736 17737 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17735 def public_artifact_uri @public_artifact_uri end |
#shared_resources ⇒ String
The resource name of the shared DeploymentResourcePool to deploy on. Format:
projects/project/locations/location/deploymentResourcePools/
deployment_resource_pool`
Corresponds to the JSON propertysharedResources`
17742 17743 17744 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17742 def shared_resources @shared_resources end |
#title ⇒ String
Required. The title of the regional resource reference.
Corresponds to the JSON property title
17747 17748 17749 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17747 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17754 17755 17756 17757 17758 17759 17760 17761 17762 17763 17764 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 17754 def update!(**args) @artifact_uri = args[:artifact_uri] if args.key?(:artifact_uri) @automatic_resources = args[:automatic_resources] if args.key?(:automatic_resources) @container_spec = args[:container_spec] if args.key?(:container_spec) @dedicated_resources = args[:dedicated_resources] if args.key?(:dedicated_resources) @large_model_reference = args[:large_model_reference] if args.key?(:large_model_reference) @model_display_name = args[:model_display_name] if args.key?(:model_display_name) @public_artifact_uri = args[:public_artifact_uri] if args.key?(:public_artifact_uri) @shared_resources = args[:shared_resources] if args.key?(:shared_resources) @title = args[:title] if args.key?(:title) end |