Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PublisherModelCallToActionDeployDeployMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Metadata information about the deployment for managing deployment config.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1PublisherModelCallToActionDeployDeployMetadata

Returns a new instance of GoogleCloudAiplatformV1PublisherModelCallToActionDeployDeployMetadata.



22178
22179
22180
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22178

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#labelsHash<String,String>

Optional. Labels for the deployment config. For managing deployment config like verifying, source of deployment config, etc. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


22171
22172
22173
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22171

def labels
  @labels
end

#sample_requestString

Optional. Sample request for deployed endpoint. Corresponds to the JSON property sampleRequest

Returns:

  • (String)


22176
22177
22178
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22176

def sample_request
  @sample_request
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22183
22184
22185
22186
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22183

def update!(**args)
  @labels = args[:labels] if args.key?(:labels)
  @sample_request = args[:sample_request] if args.key?(:sample_request)
end