Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PublisherModelCallToActionDeployDeployMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Metadata information about the deployment for managing deployment config.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1PublisherModelCallToActionDeployDeployMetadata

Returns a new instance of GoogleCloudAiplatformV1PublisherModelCallToActionDeployDeployMetadata.



22046
22047
22048
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22046

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#labelsHash<String,String>

Optional. Labels for the deployment config. For managing deployment config like verifying, source of deployment config, etc. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


22039
22040
22041
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22039

def labels
  @labels
end

#sample_requestString

Optional. Sample request for deployed endpoint. Corresponds to the JSON property sampleRequest

Returns:

  • (String)


22044
22045
22046
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22044

def sample_request
  @sample_request
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22051
22052
22053
22054
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22051

def update!(**args)
  @labels = args[:labels] if args.key?(:labels)
  @sample_request = args[:sample_request] if args.key?(:sample_request)
end