Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PublisherModelCallToActionDeployDeployMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Metadata information about the deployment for managing deployment config.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1PublisherModelCallToActionDeployDeployMetadata

Returns a new instance of GoogleCloudAiplatformV1PublisherModelCallToActionDeployDeployMetadata.



18830
18831
18832
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18830

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#labelsHash<String,String>

Optional. Labels for the deployment. For managing deployment config like verifying, source of deployment config, etc. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


18828
18829
18830
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18828

def labels
  @labels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18835
18836
18837
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18835

def update!(**args)
  @labels = args[:labels] if args.key?(:labels)
end