Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PurgeArtifactsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for MetadataService.PurgeArtifacts.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1PurgeArtifactsRequest

Returns a new instance of GoogleCloudAiplatformV1PurgeArtifactsRequest.



29771
29772
29773
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29771

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#filterString

Required. A required filter matching the Artifacts to be purged. E.g., update_time <= 2020-11-19T11:30:00-04:00. Corresponds to the JSON property filter

Returns:

  • (String)


29762
29763
29764
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29762

def filter
  @filter
end

#forceBoolean Also known as: force?

Optional. Flag to indicate to actually perform the purge. If force is set to false, the method will return a sample of Artifact names that would be deleted. Corresponds to the JSON property force

Returns:

  • (Boolean)


29768
29769
29770
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29768

def force
  @force
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29776
29777
29778
29779
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29776

def update!(**args)
  @filter = args[:filter] if args.key?(:filter)
  @force = args[:force] if args.key?(:force)
end