Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PurgeArtifactsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Response message for MetadataService.PurgeArtifacts.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1PurgeArtifactsResponse

Returns a new instance of GoogleCloudAiplatformV1PurgeArtifactsResponse.



29742
29743
29744
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29742

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#purge_countFixnum

The number of Artifacts that this request deleted (or, if force is false, the number of Artifacts that will be deleted). This can be an estimate. Corresponds to the JSON property purgeCount

Returns:

  • (Fixnum)


29733
29734
29735
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29733

def purge_count
  @purge_count
end

#purge_sampleArray<String>

A sample of the Artifact names that will be deleted. Only populated if force is set to false. The maximum number of samples is 100 (it is possible to return fewer). Corresponds to the JSON property purgeSample

Returns:

  • (Array<String>)


29740
29741
29742
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29740

def purge_sample
  @purge_sample
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29747
29748
29749
29750
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29747

def update!(**args)
  @purge_count = args[:purge_count] if args.key?(:purge_count)
  @purge_sample = args[:purge_sample] if args.key?(:purge_sample)
end