Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PurgeArtifactsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Response message for MetadataService.PurgeArtifacts.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1PurgeArtifactsResponse

Returns a new instance of GoogleCloudAiplatformV1PurgeArtifactsResponse.



23269
23270
23271
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23269

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#purge_countFixnum

The number of Artifacts that this request deleted (or, if force is false, the number of Artifacts that will be deleted). This can be an estimate. Corresponds to the JSON property purgeCount

Returns:

  • (Fixnum)


23260
23261
23262
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23260

def purge_count
  @purge_count
end

#purge_sampleArray<String>

A sample of the Artifact names that will be deleted. Only populated if force is set to false. The maximum number of samples is 100 (it is possible to return fewer). Corresponds to the JSON property purgeSample

Returns:

  • (Array<String>)


23267
23268
23269
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23267

def purge_sample
  @purge_sample
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23274
23275
23276
23277
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23274

def update!(**args)
  @purge_count = args[:purge_count] if args.key?(:purge_count)
  @purge_sample = args[:purge_sample] if args.key?(:purge_sample)
end