Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PurgeArtifactsResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PurgeArtifactsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Response message for MetadataService.PurgeArtifacts.
Instance Attribute Summary collapse
-
#purge_count ⇒ Fixnum
The number of Artifacts that this request deleted (or, if
forceis false, the number of Artifacts that will be deleted). -
#purge_sample ⇒ Array<String>
A sample of the Artifact names that will be deleted.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1PurgeArtifactsResponse
constructor
A new instance of GoogleCloudAiplatformV1PurgeArtifactsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1PurgeArtifactsResponse
Returns a new instance of GoogleCloudAiplatformV1PurgeArtifactsResponse.
22461 22462 22463 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22461 def initialize(**args) update!(**args) end |
Instance Attribute Details
#purge_count ⇒ Fixnum
The number of Artifacts that this request deleted (or, if force is false,
the number of Artifacts that will be deleted). This can be an estimate.
Corresponds to the JSON property purgeCount
22452 22453 22454 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22452 def purge_count @purge_count end |
#purge_sample ⇒ Array<String>
A sample of the Artifact names that will be deleted. Only populated if force
is set to false. The maximum number of samples is 100 (it is possible to
return fewer).
Corresponds to the JSON property purgeSample
22459 22460 22461 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22459 def purge_sample @purge_sample end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22466 22467 22468 22469 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22466 def update!(**args) @purge_count = args[:purge_count] if args.key?(:purge_count) @purge_sample = args[:purge_sample] if args.key?(:purge_sample) end |