Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PurgeContextsRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PurgeContextsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Request message for MetadataService.PurgeContexts.
Instance Attribute Summary collapse
-
#filter ⇒ String
Required.
-
#force ⇒ Boolean
(also: #force?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1PurgeContextsRequest
constructor
A new instance of GoogleCloudAiplatformV1PurgeContextsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1PurgeContextsRequest
Returns a new instance of GoogleCloudAiplatformV1PurgeContextsRequest.
23308 23309 23310 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23308 def initialize(**args) update!(**args) end |
Instance Attribute Details
#filter ⇒ String
Required. A required filter matching the Contexts to be purged. E.g.,
update_time <= 2020-11-19T11:30:00-04:00.
Corresponds to the JSON property filter
23299 23300 23301 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23299 def filter @filter end |
#force ⇒ Boolean Also known as: force?
Optional. Flag to indicate to actually perform the purge. If force is set to
false, the method will return a sample of Context names that would be deleted.
Corresponds to the JSON property force
23305 23306 23307 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23305 def force @force end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23313 23314 23315 23316 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23313 def update!(**args) @filter = args[:filter] if args.key?(:filter) @force = args[:force] if args.key?(:force) end |