Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PurgeContextsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for MetadataService.PurgeContexts.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1PurgeContextsRequest

Returns a new instance of GoogleCloudAiplatformV1PurgeContextsRequest.



18067
18068
18069
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18067

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#filterString

Required. A required filter matching the Contexts to be purged. E.g., update_time <= 2020-11-19T11:30:00-04:00. Corresponds to the JSON property filter

Returns:

  • (String)


18058
18059
18060
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18058

def filter
  @filter
end

#forceBoolean Also known as: force?

Optional. Flag to indicate to actually perform the purge. If force is set to false, the method will return a sample of Context names that would be deleted. Corresponds to the JSON property force

Returns:

  • (Boolean)


18064
18065
18066
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18064

def force
  @force
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18072
18073
18074
18075
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18072

def update!(**args)
  @filter = args[:filter] if args.key?(:filter)
  @force = args[:force] if args.key?(:force)
end