Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PurgeContextsResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PurgeContextsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Response message for MetadataService.PurgeContexts.
Instance Attribute Summary collapse
-
#purge_count ⇒ Fixnum
The number of Contexts that this request deleted (or, if
forceis false, the number of Contexts that will be deleted). -
#purge_sample ⇒ Array<String>
A sample of the Context names that will be deleted.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1PurgeContextsResponse
constructor
A new instance of GoogleCloudAiplatformV1PurgeContextsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1PurgeContextsResponse
Returns a new instance of GoogleCloudAiplatformV1PurgeContextsResponse.
32607 32608 32609 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32607 def initialize(**args) update!(**args) end |
Instance Attribute Details
#purge_count ⇒ Fixnum
The number of Contexts that this request deleted (or, if force is false, the
number of Contexts that will be deleted). This can be an estimate.
Corresponds to the JSON property purgeCount
32598 32599 32600 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32598 def purge_count @purge_count end |
#purge_sample ⇒ Array<String>
A sample of the Context names that will be deleted. Only populated if force
is set to false. The maximum number of samples is 100 (it is possible to
return fewer).
Corresponds to the JSON property purgeSample
32605 32606 32607 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32605 def purge_sample @purge_sample end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32612 32613 32614 32615 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32612 def update!(**args) @purge_count = args[:purge_count] if args.key?(:purge_count) @purge_sample = args[:purge_sample] if args.key?(:purge_sample) end |