Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PurgeContextsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Response message for MetadataService.PurgeContexts.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1PurgeContextsResponse

Returns a new instance of GoogleCloudAiplatformV1PurgeContextsResponse.



18596
18597
18598
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18596

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#purge_countFixnum

The number of Contexts that this request deleted (or, if force is false, the number of Contexts that will be deleted). This can be an estimate. Corresponds to the JSON property purgeCount

Returns:

  • (Fixnum)


18587
18588
18589
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18587

def purge_count
  @purge_count
end

#purge_sampleArray<String>

A sample of the Context names that will be deleted. Only populated if force is set to false. The maximum number of samples is 100 (it is possible to return fewer). Corresponds to the JSON property purgeSample

Returns:

  • (Array<String>)


18594
18595
18596
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18594

def purge_sample
  @purge_sample
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18601
18602
18603
18604
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18601

def update!(**args)
  @purge_count = args[:purge_count] if args.key?(:purge_count)
  @purge_sample = args[:purge_sample] if args.key?(:purge_sample)
end