Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PurgeExecutionsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for MetadataService.PurgeExecutions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1PurgeExecutionsRequest

Returns a new instance of GoogleCloudAiplatformV1PurgeExecutionsRequest.



23245
23246
23247
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23245

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#filterString

Required. A required filter matching the Executions to be purged. E.g., update_time <= 2020-11-19T11:30:00-04:00. Corresponds to the JSON property filter

Returns:

  • (String)


23235
23236
23237
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23235

def filter
  @filter
end

#forceBoolean Also known as: force?

Optional. Flag to indicate to actually perform the purge. If force is set to false, the method will return a sample of Execution names that would be deleted. Corresponds to the JSON property force

Returns:

  • (Boolean)


23242
23243
23244
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23242

def force
  @force
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23250
23251
23252
23253
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23250

def update!(**args)
  @filter = args[:filter] if args.key?(:filter)
  @force = args[:force] if args.key?(:force)
end