Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PurgeExecutionsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Response message for MetadataService.PurgeExecutions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1PurgeExecutionsResponse

Returns a new instance of GoogleCloudAiplatformV1PurgeExecutionsResponse.



32240
32241
32242
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32240

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#purge_countFixnum

The number of Executions that this request deleted (or, if force is false, the number of Executions that will be deleted). This can be an estimate. Corresponds to the JSON property purgeCount

Returns:

  • (Fixnum)


32231
32232
32233
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32231

def purge_count
  @purge_count
end

#purge_sampleArray<String>

A sample of the Execution names that will be deleted. Only populated if force is set to false. The maximum number of samples is 100 (it is possible to return fewer). Corresponds to the JSON property purgeSample

Returns:

  • (Array<String>)


32238
32239
32240
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32238

def purge_sample
  @purge_sample
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32245
32246
32247
32248
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32245

def update!(**args)
  @purge_count = args[:purge_count] if args.key?(:purge_count)
  @purge_sample = args[:purge_sample] if args.key?(:purge_sample)
end