Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PurgeExecutionsResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PurgeExecutionsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Response message for MetadataService.PurgeExecutions.
Instance Attribute Summary collapse
-
#purge_count ⇒ Fixnum
The number of Executions that this request deleted (or, if
forceis false, the number of Executions that will be deleted). -
#purge_sample ⇒ Array<String>
A sample of the Execution names that will be deleted.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1PurgeExecutionsResponse
constructor
A new instance of GoogleCloudAiplatformV1PurgeExecutionsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1PurgeExecutionsResponse
Returns a new instance of GoogleCloudAiplatformV1PurgeExecutionsResponse.
23420 23421 23422 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23420 def initialize(**args) update!(**args) end |
Instance Attribute Details
#purge_count ⇒ Fixnum
The number of Executions that this request deleted (or, if force is false,
the number of Executions that will be deleted). This can be an estimate.
Corresponds to the JSON property purgeCount
23411 23412 23413 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23411 def purge_count @purge_count end |
#purge_sample ⇒ Array<String>
A sample of the Execution names that will be deleted. Only populated if force
is set to false. The maximum number of samples is 100 (it is possible to
return fewer).
Corresponds to the JSON property purgeSample
23418 23419 23420 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23418 def purge_sample @purge_sample end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23425 23426 23427 23428 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23425 def update!(**args) @purge_count = args[:purge_count] if args.key?(:purge_count) @purge_sample = args[:purge_sample] if args.key?(:purge_sample) end |