Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PurgeMemoriesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for MemoryBankService.PurgeMemories.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1PurgeMemoriesRequest

Returns a new instance of GoogleCloudAiplatformV1PurgeMemoriesRequest.



28682
28683
28684
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28682

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#filterString

Required. The standard list filter to determine which memories to purge. More detail in AIP-160. Corresponds to the JSON property filter

Returns:

  • (String)


28662
28663
28664
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28662

def filter
  @filter
end

#filter_groupsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryConjunctionFilter>

Optional. Metadata filters that will be applied to the memories to be purged. Filters are defined using disjunctive normal form (OR of ANDs). For example: filter_groups: [filters: [key: "author", value:string_value: "agent 123", op: EQUAL],filters: [key: "label", value:string_value: "travel", op: EQUAL, key: "author", value:string_value: "agent 321", op: EQUAL]] would be equivalent to the logical expression: (metadata.author = "agent 123" OR (metadata.label = "travel" AND metadata.author = "agent 321")). Corresponds to the JSON property filterGroups



28673
28674
28675
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28673

def filter_groups
  @filter_groups
end

#forceBoolean Also known as: force?

Optional. If true, the memories will actually be purged. If false, the purge request will be validated but not executed. Corresponds to the JSON property force

Returns:

  • (Boolean)


28679
28680
28681
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28679

def force
  @force
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28687
28688
28689
28690
28691
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28687

def update!(**args)
  @filter = args[:filter] if args.key?(:filter)
  @filter_groups = args[:filter_groups] if args.key?(:filter_groups)
  @force = args[:force] if args.key?(:force)
end