Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PurgeMemoriesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for MemoryBankService.PurgeMemories.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1PurgeMemoriesRequest

Returns a new instance of GoogleCloudAiplatformV1PurgeMemoriesRequest.



28464
28465
28466
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28464

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#filterString

Required. The standard list filter to determine which memories to purge. More detail in AIP-160. Corresponds to the JSON property filter

Returns:

  • (String)


28455
28456
28457
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28455

def filter
  @filter
end

#forceBoolean Also known as: force?

Optional. If true, the memories will actually be purged. If false, the purge request will be validated but not executed. Corresponds to the JSON property force

Returns:

  • (Boolean)


28461
28462
28463
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28461

def force
  @force
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28469
28470
28471
28472
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28469

def update!(**args)
  @filter = args[:filter] if args.key?(:filter)
  @force = args[:force] if args.key?(:force)
end