Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PythonPackageSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PythonPackageSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The spec of a Python packaged code.
Instance Attribute Summary collapse
-
#args ⇒ Array<String>
Command line arguments to be passed to the Python task.
-
#env ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EnvVar>
Environment variables to be passed to the python module.
-
#executor_image_uri ⇒ String
Required.
-
#package_uris ⇒ Array<String>
Required.
-
#python_module ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1PythonPackageSpec
constructor
A new instance of GoogleCloudAiplatformV1PythonPackageSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1PythonPackageSpec
Returns a new instance of GoogleCloudAiplatformV1PythonPackageSpec.
28729 28730 28731 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28729 def initialize(**args) update!(**args) end |
Instance Attribute Details
#args ⇒ Array<String>
Command line arguments to be passed to the Python task.
Corresponds to the JSON property args
28701 28702 28703 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28701 def args @args end |
#env ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EnvVar>
Environment variables to be passed to the python module. Maximum limit is 100.
Corresponds to the JSON property env
28706 28707 28708 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28706 def env @env end |
#executor_image_uri ⇒ String
Required. The URI of a container image in Artifact Registry that will run the
provided Python package. Vertex AI provides a wide range of executor images
with pre-installed packages to meet users' various use cases. See the list of
pre-built containers for training. You must use an image from this list.
Corresponds to the JSON property executorImageUri
28715 28716 28717 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28715 def executor_image_uri @executor_image_uri end |
#package_uris ⇒ Array<String>
Required. The Google Cloud Storage location of the Python package files which
are the training program and its dependent packages. The maximum number of
package URIs is 100.
Corresponds to the JSON property packageUris
28722 28723 28724 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28722 def package_uris @package_uris end |
#python_module ⇒ String
Required. The Python module name to run after installing the packages.
Corresponds to the JSON property pythonModule
28727 28728 28729 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28727 def python_module @python_module end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28734 28735 28736 28737 28738 28739 28740 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28734 def update!(**args) @args = args[:args] if args.key?(:args) @env = args[:env] if args.key?(:env) @executor_image_uri = args[:executor_image_uri] if args.key?(:executor_image_uri) @package_uris = args[:package_uris] if args.key?(:package_uris) @python_module = args[:python_module] if args.key?(:python_module) end |