Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PythonPackageSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The spec of a Python packaged code.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1PythonPackageSpec

Returns a new instance of GoogleCloudAiplatformV1PythonPackageSpec.



23319
23320
23321
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23319

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#argsArray<String>

Command line arguments to be passed to the Python task. Corresponds to the JSON property args

Returns:

  • (Array<String>)


23291
23292
23293
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23291

def args
  @args
end

#envArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EnvVar>

Environment variables to be passed to the python module. Maximum limit is 100. Corresponds to the JSON property env



23296
23297
23298
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23296

def env
  @env
end

#executor_image_uriString

Required. The URI of a container image in Artifact Registry that will run the provided Python package. Vertex AI provides a wide range of executor images with pre-installed packages to meet users' various use cases. See the list of pre-built containers for training. You must use an image from this list. Corresponds to the JSON property executorImageUri

Returns:

  • (String)


23305
23306
23307
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23305

def executor_image_uri
  @executor_image_uri
end

#package_urisArray<String>

Required. The Google Cloud Storage location of the Python package files which are the training program and its dependent packages. The maximum number of package URIs is 100. Corresponds to the JSON property packageUris

Returns:

  • (Array<String>)


23312
23313
23314
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23312

def package_uris
  @package_uris
end

#python_moduleString

Required. The Python module name to run after installing the packages. Corresponds to the JSON property pythonModule

Returns:

  • (String)


23317
23318
23319
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23317

def python_module
  @python_module
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23324
23325
23326
23327
23328
23329
23330
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23324

def update!(**args)
  @args = args[:args] if args.key?(:args)
  @env = args[:env] if args.key?(:env)
  @executor_image_uri = args[:executor_image_uri] if args.key?(:executor_image_uri)
  @package_uris = args[:package_uris] if args.key?(:package_uris)
  @python_module = args[:python_module] if args.key?(:python_module)
end