Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagChunk
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagChunk
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A RagChunk includes the content of a chunk of a RagFile, and associated metadata.
Instance Attribute Summary collapse
-
#page_span ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagChunkPageSpan
Represents where the chunk starts and ends in the document.
-
#text ⇒ String
The content of the chunk.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1RagChunk
constructor
A new instance of GoogleCloudAiplatformV1RagChunk.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1RagChunk
Returns a new instance of GoogleCloudAiplatformV1RagChunk.
29330 29331 29332 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29330 def initialize(**args) update!(**args) end |
Instance Attribute Details
#page_span ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagChunkPageSpan
Represents where the chunk starts and ends in the document.
Corresponds to the JSON property pageSpan
29323 29324 29325 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29323 def page_span @page_span end |
#text ⇒ String
The content of the chunk.
Corresponds to the JSON property text
29328 29329 29330 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29328 def text @text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29335 29336 29337 29338 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29335 def update!(**args) @page_span = args[:page_span] if args.key?(:page_span) @text = args[:text] if args.key?(:text) end |