Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagChunk
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagChunk
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A RagChunk includes the content of a chunk of a RagFile, and associated metadata.
Instance Attribute Summary collapse
-
#page_span ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagChunkPageSpan
Represents where the chunk starts and ends in the document.
-
#text ⇒ String
The content of the chunk.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1RagChunk
constructor
A new instance of GoogleCloudAiplatformV1RagChunk.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1RagChunk
Returns a new instance of GoogleCloudAiplatformV1RagChunk.
23920 23921 23922 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23920 def initialize(**args) update!(**args) end |
Instance Attribute Details
#page_span ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagChunkPageSpan
Represents where the chunk starts and ends in the document.
Corresponds to the JSON property pageSpan
23913 23914 23915 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23913 def page_span @page_span end |
#text ⇒ String
The content of the chunk.
Corresponds to the JSON property text
23918 23919 23920 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23918 def text @text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23925 23926 23927 23928 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23925 def update!(**args) @page_span = args[:page_span] if args.key?(:page_span) @text = args[:text] if args.key?(:text) end |