Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagContextsContext
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagContextsContext
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A context of the query.
Instance Attribute Summary collapse
-
#chunk ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagChunk
A RagChunk includes the content of a chunk of a RagFile, and associated metadata.
-
#score ⇒ Float
According to the underlying Vector DB and the selected metric type, the score can be either the distance or the similarity between the query and the context and its range depends on the metric type.
-
#source_display_name ⇒ String
The file display name.
-
#source_uri ⇒ String
If the file is imported from Cloud Storage or Google Drive, source_uri will be original file URI in Cloud Storage or Google Drive; if file is uploaded, source_uri will be file display name.
-
#text ⇒ String
The text chunk.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1RagContextsContext
constructor
A new instance of GoogleCloudAiplatformV1RagContextsContext.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1RagContextsContext
Returns a new instance of GoogleCloudAiplatformV1RagContextsContext.
24013 24014 24015 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24013 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chunk ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagChunk
A RagChunk includes the content of a chunk of a RagFile, and associated
metadata.
Corresponds to the JSON property chunk
23983 23984 23985 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23983 def chunk @chunk end |
#score ⇒ Float
According to the underlying Vector DB and the selected metric type, the score
can be either the distance or the similarity between the query and the context
and its range depends on the metric type. For example, if the metric type is
COSINE_DISTANCE, it represents the distance between the query and the context.
The larger the distance, the less relevant the context is to the query. The
range is [0, 2], while 0 means the most relevant and 2 means the least
relevant.
Corresponds to the JSON property score
23994 23995 23996 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23994 def score @score end |
#source_display_name ⇒ String
The file display name.
Corresponds to the JSON property sourceDisplayName
23999 24000 24001 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23999 def source_display_name @source_display_name end |
#source_uri ⇒ String
If the file is imported from Cloud Storage or Google Drive, source_uri will be
original file URI in Cloud Storage or Google Drive; if file is uploaded,
source_uri will be file display name.
Corresponds to the JSON property sourceUri
24006 24007 24008 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24006 def source_uri @source_uri end |
#text ⇒ String
The text chunk.
Corresponds to the JSON property text
24011 24012 24013 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24011 def text @text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24018 24019 24020 24021 24022 24023 24024 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24018 def update!(**args) @chunk = args[:chunk] if args.key?(:chunk) @score = args[:score] if args.key?(:score) @source_display_name = args[:source_display_name] if args.key?(:source_display_name) @source_uri = args[:source_uri] if args.key?(:source_uri) @text = args[:text] if args.key?(:text) end |