Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagContextsContext

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A context of the query.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1RagContextsContext

Returns a new instance of GoogleCloudAiplatformV1RagContextsContext.



23477
23478
23479
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23477

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#scoreFloat

According to the underlying Vector DB and the selected metric type, the score can be either the distance or the similarity between the query and the context and its range depends on the metric type. For example, if the metric type is COSINE_DISTANCE, it represents the distance between the query and the context. The larger the distance, the less relevant the context is to the query. The range is [0, 2], while 0 means the most relevant and 2 means the least relevant. Corresponds to the JSON property score

Returns:

  • (Float)


23458
23459
23460
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23458

def score
  @score
end

#source_display_nameString

The file display name. Corresponds to the JSON property sourceDisplayName

Returns:

  • (String)


23463
23464
23465
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23463

def source_display_name
  @source_display_name
end

#source_uriString

If the file is imported from Cloud Storage or Google Drive, source_uri will be original file URI in Cloud Storage or Google Drive; if file is uploaded, source_uri will be file display name. Corresponds to the JSON property sourceUri

Returns:

  • (String)


23470
23471
23472
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23470

def source_uri
  @source_uri
end

#textString

The text chunk. Corresponds to the JSON property text

Returns:

  • (String)


23475
23476
23477
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23475

def text
  @text
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23482
23483
23484
23485
23486
23487
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23482

def update!(**args)
  @score = args[:score] if args.key?(:score)
  @source_display_name = args[:source_display_name] if args.key?(:source_display_name)
  @source_uri = args[:source_uri] if args.key?(:source_uri)
  @text = args[:text] if args.key?(:text)
end