Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagContextsContext

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A context of the query.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1RagContextsContext

Returns a new instance of GoogleCloudAiplatformV1RagContextsContext.



23308
23309
23310
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23308

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#scoreFloat

According to the underlying Vector DB and the selected metric type, the score can be either the distance or the similarity between the query and the context and its range depends on the metric type. For example, if the metric type is COSINE_DISTANCE, it represents the distance between the query and the context. The larger the distance, the less relevant the context is to the query. The range is [0, 2], while 0 means the most relevant and 2 means the least relevant. Corresponds to the JSON property score

Returns:

  • (Float)


23289
23290
23291
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23289

def score
  @score
end

#source_display_nameString

The file display name. Corresponds to the JSON property sourceDisplayName

Returns:

  • (String)


23294
23295
23296
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23294

def source_display_name
  @source_display_name
end

#source_uriString

If the file is imported from Cloud Storage or Google Drive, source_uri will be original file URI in Cloud Storage or Google Drive; if file is uploaded, source_uri will be file display name. Corresponds to the JSON property sourceUri

Returns:

  • (String)


23301
23302
23303
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23301

def source_uri
  @source_uri
end

#textString

The text chunk. Corresponds to the JSON property text

Returns:

  • (String)


23306
23307
23308
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23306

def text
  @text
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23313
23314
23315
23316
23317
23318
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23313

def update!(**args)
  @score = args[:score] if args.key?(:score)
  @source_display_name = args[:source_display_name] if args.key?(:source_display_name)
  @source_uri = args[:source_uri] if args.key?(:source_uri)
  @text = args[:text] if args.key?(:text)
end