Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagCorpus
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagCorpus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A RagCorpus is a RagFile container and a project can have multiple RagCorpora.
Instance Attribute Summary collapse
-
#corpus_status ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CorpusStatus
RagCorpus status.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Required.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.
-
#name ⇒ String
Output only.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#update_time ⇒ String
Output only.
-
#vector_db_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagVectorDbConfig
Config for the Vector DB to use for RAG.
-
#vertex_ai_search_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexAiSearchConfig
Config for the Vertex AI Search.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1RagCorpus
constructor
A new instance of GoogleCloudAiplatformV1RagCorpus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1RagCorpus
Returns a new instance of GoogleCloudAiplatformV1RagCorpus.
30923 30924 30925 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30923 def initialize(**args) update!(**args) end |
Instance Attribute Details
#corpus_status ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CorpusStatus
RagCorpus status.
Corresponds to the JSON property corpusStatus
30867 30868 30869 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30867 def corpus_status @corpus_status end |
#create_time ⇒ String
Output only. Timestamp when this RagCorpus was created.
Corresponds to the JSON property createTime
30872 30873 30874 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30872 def create_time @create_time end |
#description ⇒ String
Optional. The description of the RagCorpus.
Corresponds to the JSON property description
30877 30878 30879 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30877 def description @description end |
#display_name ⇒ String
Required. The display name of the RagCorpus. The name can be up to 128
characters long and can consist of any UTF-8 characters.
Corresponds to the JSON property displayName
30883 30884 30885 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30883 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied
to a Vertex AI resource.
Corresponds to the JSON property encryptionSpec
30889 30890 30891 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30889 def encryption_spec @encryption_spec end |
#name ⇒ String
Output only. The resource name of the RagCorpus.
Corresponds to the JSON property name
30894 30895 30896 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30894 def name @name end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
30899 30900 30901 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30899 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
30905 30906 30907 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30905 def satisfies_pzs @satisfies_pzs end |
#update_time ⇒ String
Output only. Timestamp when this RagCorpus was last updated.
Corresponds to the JSON property updateTime
30911 30912 30913 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30911 def update_time @update_time end |
#vector_db_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagVectorDbConfig
Config for the Vector DB to use for RAG.
Corresponds to the JSON property vectorDbConfig
30916 30917 30918 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30916 def vector_db_config @vector_db_config end |
#vertex_ai_search_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexAiSearchConfig
Config for the Vertex AI Search.
Corresponds to the JSON property vertexAiSearchConfig
30921 30922 30923 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30921 def vertex_ai_search_config @vertex_ai_search_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30928 30929 30930 30931 30932 30933 30934 30935 30936 30937 30938 30939 30940 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30928 def update!(**args) @corpus_status = args[:corpus_status] if args.key?(:corpus_status) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @name = args[:name] if args.key?(:name) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @update_time = args[:update_time] if args.key?(:update_time) @vector_db_config = args[:vector_db_config] if args.key?(:vector_db_config) @vertex_ai_search_config = args[:vertex_ai_search_config] if args.key?(:vertex_ai_search_config) end |