Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagCorpus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A RagCorpus is a RagFile container and a project can have multiple RagCorpora.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1RagCorpus

Returns a new instance of GoogleCloudAiplatformV1RagCorpus.



29281
29282
29283
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29281

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#corpus_statusGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1CorpusStatus

RagCorpus status. Corresponds to the JSON property corpusStatus



29225
29226
29227
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29225

def corpus_status
  @corpus_status
end

#create_timeString

Output only. Timestamp when this RagCorpus was created. Corresponds to the JSON property createTime

Returns:

  • (String)


29230
29231
29232
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29230

def create_time
  @create_time
end

#descriptionString

Optional. The description of the RagCorpus. Corresponds to the JSON property description

Returns:

  • (String)


29235
29236
29237
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29235

def description
  @description
end

#display_nameString

Required. The display name of the RagCorpus. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


29241
29242
29243
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29241

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



29247
29248
29249
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29247

def encryption_spec
  @encryption_spec
end

#nameString

Output only. The resource name of the RagCorpus. Corresponds to the JSON property name

Returns:

  • (String)


29252
29253
29254
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29252

def name
  @name
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


29257
29258
29259
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29257

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


29263
29264
29265
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29263

def satisfies_pzs
  @satisfies_pzs
end

#update_timeString

Output only. Timestamp when this RagCorpus was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


29269
29270
29271
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29269

def update_time
  @update_time
end

#vector_db_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RagVectorDbConfig

Config for the Vector DB to use for RAG. Corresponds to the JSON property vectorDbConfig



29274
29275
29276
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29274

def vector_db_config
  @vector_db_config
end

#vertex_ai_search_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexAiSearchConfig

Config for the Vertex AI Search. Corresponds to the JSON property vertexAiSearchConfig



29279
29280
29281
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29279

def vertex_ai_search_config
  @vertex_ai_search_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29286
29287
29288
29289
29290
29291
29292
29293
29294
29295
29296
29297
29298
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29286

def update!(**args)
  @corpus_status = args[:corpus_status] if args.key?(:corpus_status)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @name = args[:name] if args.key?(:name)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @update_time = args[:update_time] if args.key?(:update_time)
  @vector_db_config = args[:vector_db_config] if args.key?(:vector_db_config)
  @vertex_ai_search_config = args[:vertex_ai_search_config] if args.key?(:vertex_ai_search_config)
end