Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagCorpus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A RagCorpus is a RagFile container and a project can have multiple RagCorpora.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1RagCorpus

Returns a new instance of GoogleCloudAiplatformV1RagCorpus.



24979
24980
24981
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24979

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#corpus_statusGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1CorpusStatus

RagCorpus status. Corresponds to the JSON property corpusStatus



24935
24936
24937
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24935

def corpus_status
  @corpus_status
end

#create_timeString

Output only. Timestamp when this RagCorpus was created. Corresponds to the JSON property createTime

Returns:

  • (String)


24940
24941
24942
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24940

def create_time
  @create_time
end

#descriptionString

Optional. The description of the RagCorpus. Corresponds to the JSON property description

Returns:

  • (String)


24945
24946
24947
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24945

def description
  @description
end

#display_nameString

Required. The display name of the RagCorpus. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


24951
24952
24953
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24951

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key spec that can be applied to a top- level resource. Corresponds to the JSON property encryptionSpec



24957
24958
24959
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24957

def encryption_spec
  @encryption_spec
end

#nameString

Output only. The resource name of the RagCorpus. Corresponds to the JSON property name

Returns:

  • (String)


24962
24963
24964
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24962

def name
  @name
end

#update_timeString

Output only. Timestamp when this RagCorpus was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


24967
24968
24969
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24967

def update_time
  @update_time
end

#vector_db_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RagVectorDbConfig

Config for the Vector DB to use for RAG. Corresponds to the JSON property vectorDbConfig



24972
24973
24974
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24972

def vector_db_config
  @vector_db_config
end

#vertex_ai_search_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexAiSearchConfig

Config for the Vertex AI Search. Corresponds to the JSON property vertexAiSearchConfig



24977
24978
24979
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24977

def vertex_ai_search_config
  @vertex_ai_search_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24984
24985
24986
24987
24988
24989
24990
24991
24992
24993
24994
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24984

def update!(**args)
  @corpus_status = args[:corpus_status] if args.key?(:corpus_status)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
  @vector_db_config = args[:vector_db_config] if args.key?(:vector_db_config)
  @vertex_ai_search_config = args[:vertex_ai_search_config] if args.key?(:vertex_ai_search_config)
end