Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagCorpus
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagCorpus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A RagCorpus is a RagFile container and a project can have multiple RagCorpora.
Instance Attribute Summary collapse
-
#corpus_status ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CorpusStatus
RagCorpus status.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Required.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top- level resource.
-
#name ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
-
#vector_db_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagVectorDbConfig
Config for the Vector DB to use for RAG.
-
#vertex_ai_search_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexAiSearchConfig
Config for the Vertex AI Search.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1RagCorpus
constructor
A new instance of GoogleCloudAiplatformV1RagCorpus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1RagCorpus
Returns a new instance of GoogleCloudAiplatformV1RagCorpus.
24625 24626 24627 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24625 def initialize(**args) update!(**args) end |
Instance Attribute Details
#corpus_status ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CorpusStatus
RagCorpus status.
Corresponds to the JSON property corpusStatus
24581 24582 24583 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24581 def corpus_status @corpus_status end |
#create_time ⇒ String
Output only. Timestamp when this RagCorpus was created.
Corresponds to the JSON property createTime
24586 24587 24588 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24586 def create_time @create_time end |
#description ⇒ String
Optional. The description of the RagCorpus.
Corresponds to the JSON property description
24591 24592 24593 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24591 def description @description end |
#display_name ⇒ String
Required. The display name of the RagCorpus. The name can be up to 128
characters long and can consist of any UTF-8 characters.
Corresponds to the JSON property displayName
24597 24598 24599 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24597 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top-
level resource.
Corresponds to the JSON property encryptionSpec
24603 24604 24605 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24603 def encryption_spec @encryption_spec end |
#name ⇒ String
Output only. The resource name of the RagCorpus.
Corresponds to the JSON property name
24608 24609 24610 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24608 def name @name end |
#update_time ⇒ String
Output only. Timestamp when this RagCorpus was last updated.
Corresponds to the JSON property updateTime
24613 24614 24615 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24613 def update_time @update_time end |
#vector_db_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagVectorDbConfig
Config for the Vector DB to use for RAG.
Corresponds to the JSON property vectorDbConfig
24618 24619 24620 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24618 def vector_db_config @vector_db_config end |
#vertex_ai_search_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexAiSearchConfig
Config for the Vertex AI Search.
Corresponds to the JSON property vertexAiSearchConfig
24623 24624 24625 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24623 def vertex_ai_search_config @vertex_ai_search_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24630 24631 24632 24633 24634 24635 24636 24637 24638 24639 24640 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24630 def update!(**args) @corpus_status = args[:corpus_status] if args.key?(:corpus_status) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) @vector_db_config = args[:vector_db_config] if args.key?(:vector_db_config) @vertex_ai_search_config = args[:vertex_ai_search_config] if args.key?(:vertex_ai_search_config) end |