Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagCorpus
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagCorpus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A RagCorpus is a RagFile container and a project can have multiple RagCorpora.
Instance Attribute Summary collapse
-
#corpus_status ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CorpusStatus
RagCorpus status.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Required.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top- level resource.
-
#name ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
-
#vector_db_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagVectorDbConfig
Config for the Vector DB to use for RAG.
-
#vertex_ai_search_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexAiSearchConfig
Config for the Vertex AI Search.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1RagCorpus
constructor
A new instance of GoogleCloudAiplatformV1RagCorpus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1RagCorpus
Returns a new instance of GoogleCloudAiplatformV1RagCorpus.
24554 24555 24556 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24554 def initialize(**args) update!(**args) end |
Instance Attribute Details
#corpus_status ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CorpusStatus
RagCorpus status.
Corresponds to the JSON property corpusStatus
24510 24511 24512 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24510 def corpus_status @corpus_status end |
#create_time ⇒ String
Output only. Timestamp when this RagCorpus was created.
Corresponds to the JSON property createTime
24515 24516 24517 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24515 def create_time @create_time end |
#description ⇒ String
Optional. The description of the RagCorpus.
Corresponds to the JSON property description
24520 24521 24522 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24520 def description @description end |
#display_name ⇒ String
Required. The display name of the RagCorpus. The name can be up to 128
characters long and can consist of any UTF-8 characters.
Corresponds to the JSON property displayName
24526 24527 24528 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24526 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top-
level resource.
Corresponds to the JSON property encryptionSpec
24532 24533 24534 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24532 def encryption_spec @encryption_spec end |
#name ⇒ String
Output only. The resource name of the RagCorpus.
Corresponds to the JSON property name
24537 24538 24539 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24537 def name @name end |
#update_time ⇒ String
Output only. Timestamp when this RagCorpus was last updated.
Corresponds to the JSON property updateTime
24542 24543 24544 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24542 def update_time @update_time end |
#vector_db_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagVectorDbConfig
Config for the Vector DB to use for RAG.
Corresponds to the JSON property vectorDbConfig
24547 24548 24549 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24547 def vector_db_config @vector_db_config end |
#vertex_ai_search_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexAiSearchConfig
Config for the Vertex AI Search.
Corresponds to the JSON property vertexAiSearchConfig
24552 24553 24554 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24552 def vertex_ai_search_config @vertex_ai_search_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24559 24560 24561 24562 24563 24564 24565 24566 24567 24568 24569 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24559 def update!(**args) @corpus_status = args[:corpus_status] if args.key?(:corpus_status) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) @vector_db_config = args[:vector_db_config] if args.key?(:vector_db_config) @vertex_ai_search_config = args[:vertex_ai_search_config] if args.key?(:vertex_ai_search_config) end |