Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagEmbeddingModelConfigVertexPredictionEndpoint
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagEmbeddingModelConfigVertexPredictionEndpoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Config representing a model hosted on Vertex Prediction Endpoint.
Instance Attribute Summary collapse
-
#endpoint ⇒ String
Required.
-
#model ⇒ String
Output only.
-
#model_version_id ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1RagEmbeddingModelConfigVertexPredictionEndpoint
constructor
A new instance of GoogleCloudAiplatformV1RagEmbeddingModelConfigVertexPredictionEndpoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1RagEmbeddingModelConfigVertexPredictionEndpoint
Returns a new instance of GoogleCloudAiplatformV1RagEmbeddingModelConfigVertexPredictionEndpoint.
24132 24133 24134 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24132 def initialize(**args) update!(**args) end |
Instance Attribute Details
#endpoint ⇒ String
Required. The endpoint resource name. Format: projects/project/locations/
location/publishers/publisher/models/modelor `projects/`project`/
locations/`location`/endpoints/`endpoint
Corresponds to the JSON property endpoint
24117 24118 24119 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24117 def endpoint @endpoint end |
#model ⇒ String
Output only. The resource name of the model that is deployed on the endpoint.
Present only when the endpoint is not a publisher model. Pattern: projects/
project/locations/location/models/model`
Corresponds to the JSON propertymodel`
24124 24125 24126 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24124 def model @model end |
#model_version_id ⇒ String
Output only. Version ID of the model that is deployed on the endpoint. Present
only when the endpoint is not a publisher model.
Corresponds to the JSON property modelVersionId
24130 24131 24132 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24130 def model_version_id @model_version_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24137 24138 24139 24140 24141 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24137 def update!(**args) @endpoint = args[:endpoint] if args.key?(:endpoint) @model = args[:model] if args.key?(:model) @model_version_id = args[:model_version_id] if args.key?(:model_version_id) end |