Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagFile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A RagFile contains user data for chunking, embedding and indexing.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1RagFile

Returns a new instance of GoogleCloudAiplatformV1RagFile.



30979
30980
30981
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30979

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this RagFile was created. Corresponds to the JSON property createTime

Returns:

  • (String)


30915
30916
30917
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30915

def create_time
  @create_time
end

#descriptionString

Optional. The description of the RagFile. Corresponds to the JSON property description

Returns:

  • (String)


30920
30921
30922
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30920

def description
  @description
end

#direct_upload_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1DirectUploadSource

The input content is encapsulated and uploaded in the request. Corresponds to the JSON property directUploadSource



30925
30926
30927
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30925

def direct_upload_source
  @direct_upload_source
end

#display_nameString

Required. The display name of the RagFile. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


30931
30932
30933
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30931

def display_name
  @display_name
end

#file_statusGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FileStatus

RagFile status. Corresponds to the JSON property fileStatus



30936
30937
30938
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30936

def file_status
  @file_status
end

#gcs_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsSource

The Google Cloud Storage location for the input content. Corresponds to the JSON property gcsSource



30941
30942
30943
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30941

def gcs_source
  @gcs_source
end

#google_drive_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GoogleDriveSource

The Google Drive location for the input content. Corresponds to the JSON property googleDriveSource



30946
30947
30948
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30946

def google_drive_source
  @google_drive_source
end

#jira_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1JiraSource

The Jira source for the ImportRagFilesRequest. Corresponds to the JSON property jiraSource



30951
30952
30953
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30951

def jira_source
  @jira_source
end

#nameString

Output only. The resource name of the RagFile. Corresponds to the JSON property name

Returns:

  • (String)


30956
30957
30958
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30956

def name
  @name
end

#share_point_sourcesGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SharePointSources

The SharePointSources to pass to ImportRagFiles. Corresponds to the JSON property sharePointSources



30961
30962
30963
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30961

def share_point_sources
  @share_point_sources
end

#slack_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SlackSource

The Slack source for the ImportRagFilesRequest. Corresponds to the JSON property slackSource



30966
30967
30968
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30966

def slack_source
  @slack_source
end

#update_timeString

Output only. Timestamp when this RagFile was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


30971
30972
30973
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30971

def update_time
  @update_time
end

#user_metadataString

Output only. The metadata for metadata search. The user_metadata Needs to be in JSON format. Corresponds to the JSON property userMetadata

Returns:

  • (String)


30977
30978
30979
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30977

def 
  @user_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30984
30985
30986
30987
30988
30989
30990
30991
30992
30993
30994
30995
30996
30997
30998
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30984

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @direct_upload_source = args[:direct_upload_source] if args.key?(:direct_upload_source)
  @display_name = args[:display_name] if args.key?(:display_name)
  @file_status = args[:file_status] if args.key?(:file_status)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @google_drive_source = args[:google_drive_source] if args.key?(:google_drive_source)
  @jira_source = args[:jira_source] if args.key?(:jira_source)
  @name = args[:name] if args.key?(:name)
  @share_point_sources = args[:share_point_sources] if args.key?(:share_point_sources)
  @slack_source = args[:slack_source] if args.key?(:slack_source)
  @update_time = args[:update_time] if args.key?(:update_time)
  @user_metadata = args[:user_metadata] if args.key?(:user_metadata)
end