Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagFile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A RagFile contains user data for chunking, embedding and indexing.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1RagFile

Returns a new instance of GoogleCloudAiplatformV1RagFile.



30922
30923
30924
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30922

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this RagFile was created. Corresponds to the JSON property createTime

Returns:

  • (String)


30858
30859
30860
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30858

def create_time
  @create_time
end

#descriptionString

Optional. The description of the RagFile. Corresponds to the JSON property description

Returns:

  • (String)


30863
30864
30865
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30863

def description
  @description
end

#direct_upload_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1DirectUploadSource

The input content is encapsulated and uploaded in the request. Corresponds to the JSON property directUploadSource



30868
30869
30870
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30868

def direct_upload_source
  @direct_upload_source
end

#display_nameString

Required. The display name of the RagFile. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


30874
30875
30876
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30874

def display_name
  @display_name
end

#file_statusGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FileStatus

RagFile status. Corresponds to the JSON property fileStatus



30879
30880
30881
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30879

def file_status
  @file_status
end

#gcs_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsSource

The Google Cloud Storage location for the input content. Corresponds to the JSON property gcsSource



30884
30885
30886
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30884

def gcs_source
  @gcs_source
end

#google_drive_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GoogleDriveSource

The Google Drive location for the input content. Corresponds to the JSON property googleDriveSource



30889
30890
30891
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30889

def google_drive_source
  @google_drive_source
end

#jira_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1JiraSource

The Jira source for the ImportRagFilesRequest. Corresponds to the JSON property jiraSource



30894
30895
30896
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30894

def jira_source
  @jira_source
end

#nameString

Output only. The resource name of the RagFile. Corresponds to the JSON property name

Returns:

  • (String)


30899
30900
30901
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30899

def name
  @name
end

#share_point_sourcesGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SharePointSources

The SharePointSources to pass to ImportRagFiles. Corresponds to the JSON property sharePointSources



30904
30905
30906
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30904

def share_point_sources
  @share_point_sources
end

#slack_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SlackSource

The Slack source for the ImportRagFilesRequest. Corresponds to the JSON property slackSource



30909
30910
30911
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30909

def slack_source
  @slack_source
end

#update_timeString

Output only. Timestamp when this RagFile was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


30914
30915
30916
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30914

def update_time
  @update_time
end

#user_metadataString

Output only. The metadata for metadata search. The user_metadata Needs to be in JSON format. Corresponds to the JSON property userMetadata

Returns:

  • (String)


30920
30921
30922
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30920

def 
  @user_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30927
30928
30929
30930
30931
30932
30933
30934
30935
30936
30937
30938
30939
30940
30941
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30927

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @direct_upload_source = args[:direct_upload_source] if args.key?(:direct_upload_source)
  @display_name = args[:display_name] if args.key?(:display_name)
  @file_status = args[:file_status] if args.key?(:file_status)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @google_drive_source = args[:google_drive_source] if args.key?(:google_drive_source)
  @jira_source = args[:jira_source] if args.key?(:jira_source)
  @name = args[:name] if args.key?(:name)
  @share_point_sources = args[:share_point_sources] if args.key?(:share_point_sources)
  @slack_source = args[:slack_source] if args.key?(:slack_source)
  @update_time = args[:update_time] if args.key?(:update_time)
  @user_metadata = args[:user_metadata] if args.key?(:user_metadata)
end