Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagFile
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagFile
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A RagFile contains user data for chunking, embedding and indexing.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#direct_upload_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DirectUploadSource
The input content is encapsulated and uploaded in the request.
-
#display_name ⇒ String
Required.
-
#file_status ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FileStatus
RagFile status.
-
#gcs_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsSource
The Google Cloud Storage location for the input content.
-
#google_drive_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GoogleDriveSource
The Google Drive location for the input content.
-
#jira_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1JiraSource
The Jira source for the ImportRagFilesRequest.
-
#name ⇒ String
Output only.
-
#share_point_sources ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SharePointSources
The SharePointSources to pass to ImportRagFiles.
-
#slack_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SlackSource
The Slack source for the ImportRagFilesRequest.
-
#update_time ⇒ String
Output only.
-
#user_metadata ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1RagFile
constructor
A new instance of GoogleCloudAiplatformV1RagFile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1RagFile
Returns a new instance of GoogleCloudAiplatformV1RagFile.
29453 29454 29455 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29453 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this RagFile was created.
Corresponds to the JSON property createTime
29389 29390 29391 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29389 def create_time @create_time end |
#description ⇒ String
Optional. The description of the RagFile.
Corresponds to the JSON property description
29394 29395 29396 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29394 def description @description end |
#direct_upload_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DirectUploadSource
The input content is encapsulated and uploaded in the request.
Corresponds to the JSON property directUploadSource
29399 29400 29401 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29399 def direct_upload_source @direct_upload_source end |
#display_name ⇒ String
Required. The display name of the RagFile. The name can be up to 128
characters long and can consist of any UTF-8 characters.
Corresponds to the JSON property displayName
29405 29406 29407 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29405 def display_name @display_name end |
#file_status ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FileStatus
RagFile status.
Corresponds to the JSON property fileStatus
29410 29411 29412 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29410 def file_status @file_status end |
#gcs_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsSource
The Google Cloud Storage location for the input content.
Corresponds to the JSON property gcsSource
29415 29416 29417 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29415 def gcs_source @gcs_source end |
#google_drive_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GoogleDriveSource
The Google Drive location for the input content.
Corresponds to the JSON property googleDriveSource
29420 29421 29422 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29420 def google_drive_source @google_drive_source end |
#jira_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1JiraSource
The Jira source for the ImportRagFilesRequest.
Corresponds to the JSON property jiraSource
29425 29426 29427 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29425 def jira_source @jira_source end |
#name ⇒ String
Output only. The resource name of the RagFile.
Corresponds to the JSON property name
29430 29431 29432 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29430 def name @name end |
#share_point_sources ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SharePointSources
The SharePointSources to pass to ImportRagFiles.
Corresponds to the JSON property sharePointSources
29435 29436 29437 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29435 def share_point_sources @share_point_sources end |
#slack_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SlackSource
The Slack source for the ImportRagFilesRequest.
Corresponds to the JSON property slackSource
29440 29441 29442 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29440 def slack_source @slack_source end |
#update_time ⇒ String
Output only. Timestamp when this RagFile was last updated.
Corresponds to the JSON property updateTime
29445 29446 29447 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29445 def update_time @update_time end |
#user_metadata ⇒ String
Output only. The metadata for metadata search. The user_metadata Needs to be
in JSON format.
Corresponds to the JSON property userMetadata
29451 29452 29453 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29451 def @user_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29458 29459 29460 29461 29462 29463 29464 29465 29466 29467 29468 29469 29470 29471 29472 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29458 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @direct_upload_source = args[:direct_upload_source] if args.key?(:direct_upload_source) @display_name = args[:display_name] if args.key?(:display_name) @file_status = args[:file_status] if args.key?(:file_status) @gcs_source = args[:gcs_source] if args.key?(:gcs_source) @google_drive_source = args[:google_drive_source] if args.key?(:google_drive_source) @jira_source = args[:jira_source] if args.key?(:jira_source) @name = args[:name] if args.key?(:name) @share_point_sources = args[:share_point_sources] if args.key?(:share_point_sources) @slack_source = args[:slack_source] if args.key?(:slack_source) @update_time = args[:update_time] if args.key?(:update_time) @user_metadata = args[:user_metadata] if args.key?(:user_metadata) end |