Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagFile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A RagFile contains user data for chunking, embedding and indexing.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1RagFile

Returns a new instance of GoogleCloudAiplatformV1RagFile.



25149
25150
25151
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25149

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this RagFile was created. Corresponds to the JSON property createTime

Returns:

  • (String)


25085
25086
25087
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25085

def create_time
  @create_time
end

#descriptionString

Optional. The description of the RagFile. Corresponds to the JSON property description

Returns:

  • (String)


25090
25091
25092
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25090

def description
  @description
end

#direct_upload_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1DirectUploadSource

The input content is encapsulated and uploaded in the request. Corresponds to the JSON property directUploadSource



25095
25096
25097
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25095

def direct_upload_source
  @direct_upload_source
end

#display_nameString

Required. The display name of the RagFile. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


25101
25102
25103
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25101

def display_name
  @display_name
end

#file_statusGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FileStatus

RagFile status. Corresponds to the JSON property fileStatus



25106
25107
25108
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25106

def file_status
  @file_status
end

#gcs_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsSource

The Google Cloud Storage location for the input content. Corresponds to the JSON property gcsSource



25111
25112
25113
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25111

def gcs_source
  @gcs_source
end

#google_drive_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GoogleDriveSource

The Google Drive location for the input content. Corresponds to the JSON property googleDriveSource



25116
25117
25118
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25116

def google_drive_source
  @google_drive_source
end

#jira_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1JiraSource

The Jira source for the ImportRagFilesRequest. Corresponds to the JSON property jiraSource



25121
25122
25123
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25121

def jira_source
  @jira_source
end

#nameString

Output only. The resource name of the RagFile. Corresponds to the JSON property name

Returns:

  • (String)


25126
25127
25128
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25126

def name
  @name
end

#share_point_sourcesGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SharePointSources

The SharePointSources to pass to ImportRagFiles. Corresponds to the JSON property sharePointSources



25131
25132
25133
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25131

def share_point_sources
  @share_point_sources
end

#slack_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SlackSource

The Slack source for the ImportRagFilesRequest. Corresponds to the JSON property slackSource



25136
25137
25138
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25136

def slack_source
  @slack_source
end

#update_timeString

Output only. Timestamp when this RagFile was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


25141
25142
25143
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25141

def update_time
  @update_time
end

#user_metadataString

Output only. The metadata for metadata search. The user_metadata Needs to be in JSON format. Corresponds to the JSON property userMetadata

Returns:

  • (String)


25147
25148
25149
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25147

def 
  @user_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25154
25155
25156
25157
25158
25159
25160
25161
25162
25163
25164
25165
25166
25167
25168
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25154

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @direct_upload_source = args[:direct_upload_source] if args.key?(:direct_upload_source)
  @display_name = args[:display_name] if args.key?(:display_name)
  @file_status = args[:file_status] if args.key?(:file_status)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @google_drive_source = args[:google_drive_source] if args.key?(:google_drive_source)
  @jira_source = args[:jira_source] if args.key?(:jira_source)
  @name = args[:name] if args.key?(:name)
  @share_point_sources = args[:share_point_sources] if args.key?(:share_point_sources)
  @slack_source = args[:slack_source] if args.key?(:slack_source)
  @update_time = args[:update_time] if args.key?(:update_time)
  @user_metadata = args[:user_metadata] if args.key?(:user_metadata)
end