Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagFile
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagFile
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A RagFile contains user data for chunking, embedding and indexing.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#direct_upload_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DirectUploadSource
The input content is encapsulated and uploaded in the request.
-
#display_name ⇒ String
Required.
-
#file_status ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FileStatus
RagFile status.
-
#gcs_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsSource
The Google Cloud Storage location for the input content.
-
#google_drive_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GoogleDriveSource
The Google Drive location for the input content.
-
#jira_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1JiraSource
The Jira source for the ImportRagFilesRequest.
-
#name ⇒ String
Output only.
-
#share_point_sources ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SharePointSources
The SharePointSources to pass to ImportRagFiles.
-
#slack_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SlackSource
The Slack source for the ImportRagFilesRequest.
-
#update_time ⇒ String
Output only.
-
#user_metadata ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1RagFile
constructor
A new instance of GoogleCloudAiplatformV1RagFile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1RagFile
Returns a new instance of GoogleCloudAiplatformV1RagFile.
24795 24796 24797 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24795 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this RagFile was created.
Corresponds to the JSON property createTime
24731 24732 24733 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24731 def create_time @create_time end |
#description ⇒ String
Optional. The description of the RagFile.
Corresponds to the JSON property description
24736 24737 24738 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24736 def description @description end |
#direct_upload_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DirectUploadSource
The input content is encapsulated and uploaded in the request.
Corresponds to the JSON property directUploadSource
24741 24742 24743 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24741 def direct_upload_source @direct_upload_source end |
#display_name ⇒ String
Required. The display name of the RagFile. The name can be up to 128
characters long and can consist of any UTF-8 characters.
Corresponds to the JSON property displayName
24747 24748 24749 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24747 def display_name @display_name end |
#file_status ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FileStatus
RagFile status.
Corresponds to the JSON property fileStatus
24752 24753 24754 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24752 def file_status @file_status end |
#gcs_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsSource
The Google Cloud Storage location for the input content.
Corresponds to the JSON property gcsSource
24757 24758 24759 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24757 def gcs_source @gcs_source end |
#google_drive_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GoogleDriveSource
The Google Drive location for the input content.
Corresponds to the JSON property googleDriveSource
24762 24763 24764 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24762 def google_drive_source @google_drive_source end |
#jira_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1JiraSource
The Jira source for the ImportRagFilesRequest.
Corresponds to the JSON property jiraSource
24767 24768 24769 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24767 def jira_source @jira_source end |
#name ⇒ String
Output only. The resource name of the RagFile.
Corresponds to the JSON property name
24772 24773 24774 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24772 def name @name end |
#share_point_sources ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SharePointSources
The SharePointSources to pass to ImportRagFiles.
Corresponds to the JSON property sharePointSources
24777 24778 24779 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24777 def share_point_sources @share_point_sources end |
#slack_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SlackSource
The Slack source for the ImportRagFilesRequest.
Corresponds to the JSON property slackSource
24782 24783 24784 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24782 def slack_source @slack_source end |
#update_time ⇒ String
Output only. Timestamp when this RagFile was last updated.
Corresponds to the JSON property updateTime
24787 24788 24789 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24787 def update_time @update_time end |
#user_metadata ⇒ String
Output only. The metadata for metadata search. The user_metadata Needs to be
in JSON format.
Corresponds to the JSON property userMetadata
24793 24794 24795 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24793 def @user_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24800 24801 24802 24803 24804 24805 24806 24807 24808 24809 24810 24811 24812 24813 24814 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24800 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @direct_upload_source = args[:direct_upload_source] if args.key?(:direct_upload_source) @display_name = args[:display_name] if args.key?(:display_name) @file_status = args[:file_status] if args.key?(:file_status) @gcs_source = args[:gcs_source] if args.key?(:gcs_source) @google_drive_source = args[:google_drive_source] if args.key?(:google_drive_source) @jira_source = args[:jira_source] if args.key?(:jira_source) @name = args[:name] if args.key?(:name) @share_point_sources = args[:share_point_sources] if args.key?(:share_point_sources) @slack_source = args[:slack_source] if args.key?(:slack_source) @update_time = args[:update_time] if args.key?(:update_time) @user_metadata = args[:user_metadata] if args.key?(:user_metadata) end |