Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagFile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A RagFile contains user data for chunking, embedding and indexing.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1RagFile

Returns a new instance of GoogleCloudAiplatformV1RagFile.



24269
24270
24271
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24269

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this RagFile was created. Corresponds to the JSON property createTime

Returns:

  • (String)


24211
24212
24213
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24211

def create_time
  @create_time
end

#descriptionString

Optional. The description of the RagFile. Corresponds to the JSON property description

Returns:

  • (String)


24216
24217
24218
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24216

def description
  @description
end

#direct_upload_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1DirectUploadSource

The input content is encapsulated and uploaded in the request. Corresponds to the JSON property directUploadSource



24221
24222
24223
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24221

def direct_upload_source
  @direct_upload_source
end

#display_nameString

Required. The display name of the RagFile. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


24227
24228
24229
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24227

def display_name
  @display_name
end

#file_statusGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FileStatus

RagFile status. Corresponds to the JSON property fileStatus



24232
24233
24234
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24232

def file_status
  @file_status
end

#gcs_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsSource

The Google Cloud Storage location for the input content. Corresponds to the JSON property gcsSource



24237
24238
24239
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24237

def gcs_source
  @gcs_source
end

#google_drive_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GoogleDriveSource

The Google Drive location for the input content. Corresponds to the JSON property googleDriveSource



24242
24243
24244
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24242

def google_drive_source
  @google_drive_source
end

#jira_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1JiraSource

The Jira source for the ImportRagFilesRequest. Corresponds to the JSON property jiraSource



24247
24248
24249
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24247

def jira_source
  @jira_source
end

#nameString

Output only. The resource name of the RagFile. Corresponds to the JSON property name

Returns:

  • (String)


24252
24253
24254
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24252

def name
  @name
end

#share_point_sourcesGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SharePointSources

The SharePointSources to pass to ImportRagFiles. Corresponds to the JSON property sharePointSources



24257
24258
24259
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24257

def share_point_sources
  @share_point_sources
end

#slack_sourceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SlackSource

The Slack source for the ImportRagFilesRequest. Corresponds to the JSON property slackSource



24262
24263
24264
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24262

def slack_source
  @slack_source
end

#update_timeString

Output only. Timestamp when this RagFile was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


24267
24268
24269
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24267

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24274
24275
24276
24277
24278
24279
24280
24281
24282
24283
24284
24285
24286
24287
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24274

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @direct_upload_source = args[:direct_upload_source] if args.key?(:direct_upload_source)
  @display_name = args[:display_name] if args.key?(:display_name)
  @file_status = args[:file_status] if args.key?(:file_status)
  @gcs_source = args[:gcs_source] if args.key?(:gcs_source)
  @google_drive_source = args[:google_drive_source] if args.key?(:google_drive_source)
  @jira_source = args[:jira_source] if args.key?(:jira_source)
  @name = args[:name] if args.key?(:name)
  @share_point_sources = args[:share_point_sources] if args.key?(:share_point_sources)
  @slack_source = args[:slack_source] if args.key?(:slack_source)
  @update_time = args[:update_time] if args.key?(:update_time)
end