Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagFile
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagFile
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A RagFile contains user data for chunking, embedding and indexing.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#direct_upload_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DirectUploadSource
The input content is encapsulated and uploaded in the request.
-
#display_name ⇒ String
Required.
-
#file_status ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FileStatus
RagFile status.
-
#gcs_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsSource
The Google Cloud Storage location for the input content.
-
#google_drive_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GoogleDriveSource
The Google Drive location for the input content.
-
#jira_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1JiraSource
The Jira source for the ImportRagFilesRequest.
-
#name ⇒ String
Output only.
-
#share_point_sources ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SharePointSources
The SharePointSources to pass to ImportRagFiles.
-
#slack_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SlackSource
The Slack source for the ImportRagFilesRequest.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1RagFile
constructor
A new instance of GoogleCloudAiplatformV1RagFile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1RagFile
Returns a new instance of GoogleCloudAiplatformV1RagFile.
23882 23883 23884 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23882 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this RagFile was created.
Corresponds to the JSON property createTime
23824 23825 23826 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23824 def create_time @create_time end |
#description ⇒ String
Optional. The description of the RagFile.
Corresponds to the JSON property description
23829 23830 23831 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23829 def description @description end |
#direct_upload_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DirectUploadSource
The input content is encapsulated and uploaded in the request.
Corresponds to the JSON property directUploadSource
23834 23835 23836 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23834 def direct_upload_source @direct_upload_source end |
#display_name ⇒ String
Required. The display name of the RagFile. The name can be up to 128
characters long and can consist of any UTF-8 characters.
Corresponds to the JSON property displayName
23840 23841 23842 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23840 def display_name @display_name end |
#file_status ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FileStatus
RagFile status.
Corresponds to the JSON property fileStatus
23845 23846 23847 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23845 def file_status @file_status end |
#gcs_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsSource
The Google Cloud Storage location for the input content.
Corresponds to the JSON property gcsSource
23850 23851 23852 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23850 def gcs_source @gcs_source end |
#google_drive_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GoogleDriveSource
The Google Drive location for the input content.
Corresponds to the JSON property googleDriveSource
23855 23856 23857 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23855 def google_drive_source @google_drive_source end |
#jira_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1JiraSource
The Jira source for the ImportRagFilesRequest.
Corresponds to the JSON property jiraSource
23860 23861 23862 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23860 def jira_source @jira_source end |
#name ⇒ String
Output only. The resource name of the RagFile.
Corresponds to the JSON property name
23865 23866 23867 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23865 def name @name end |
#share_point_sources ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SharePointSources
The SharePointSources to pass to ImportRagFiles.
Corresponds to the JSON property sharePointSources
23870 23871 23872 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23870 def share_point_sources @share_point_sources end |
#slack_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SlackSource
The Slack source for the ImportRagFilesRequest.
Corresponds to the JSON property slackSource
23875 23876 23877 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23875 def slack_source @slack_source end |
#update_time ⇒ String
Output only. Timestamp when this RagFile was last updated.
Corresponds to the JSON property updateTime
23880 23881 23882 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23880 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23887 23888 23889 23890 23891 23892 23893 23894 23895 23896 23897 23898 23899 23900 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23887 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @direct_upload_source = args[:direct_upload_source] if args.key?(:direct_upload_source) @display_name = args[:display_name] if args.key?(:display_name) @file_status = args[:file_status] if args.key?(:file_status) @gcs_source = args[:gcs_source] if args.key?(:gcs_source) @google_drive_source = args[:google_drive_source] if args.key?(:google_drive_source) @jira_source = args[:jira_source] if args.key?(:jira_source) @name = args[:name] if args.key?(:name) @share_point_sources = args[:share_point_sources] if args.key?(:share_point_sources) @slack_source = args[:slack_source] if args.key?(:slack_source) @update_time = args[:update_time] if args.key?(:update_time) end |