Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagFile
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagFile
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A RagFile contains user data for chunking, embedding and indexing.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#direct_upload_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DirectUploadSource
The input content is encapsulated and uploaded in the request.
-
#display_name ⇒ String
Required.
-
#file_status ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FileStatus
RagFile status.
-
#gcs_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsSource
The Google Cloud Storage location for the input content.
-
#google_drive_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GoogleDriveSource
The Google Drive location for the input content.
-
#jira_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1JiraSource
The Jira source for the ImportRagFilesRequest.
-
#name ⇒ String
Output only.
-
#share_point_sources ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SharePointSources
The SharePointSources to pass to ImportRagFiles.
-
#slack_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SlackSource
The Slack source for the ImportRagFilesRequest.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1RagFile
constructor
A new instance of GoogleCloudAiplatformV1RagFile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1RagFile
Returns a new instance of GoogleCloudAiplatformV1RagFile.
23484 23485 23486 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23484 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this RagFile was created.
Corresponds to the JSON property createTime
23426 23427 23428 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23426 def create_time @create_time end |
#description ⇒ String
Optional. The description of the RagFile.
Corresponds to the JSON property description
23431 23432 23433 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23431 def description @description end |
#direct_upload_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DirectUploadSource
The input content is encapsulated and uploaded in the request.
Corresponds to the JSON property directUploadSource
23436 23437 23438 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23436 def direct_upload_source @direct_upload_source end |
#display_name ⇒ String
Required. The display name of the RagFile. The name can be up to 128
characters long and can consist of any UTF-8 characters.
Corresponds to the JSON property displayName
23442 23443 23444 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23442 def display_name @display_name end |
#file_status ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FileStatus
RagFile status.
Corresponds to the JSON property fileStatus
23447 23448 23449 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23447 def file_status @file_status end |
#gcs_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsSource
The Google Cloud Storage location for the input content.
Corresponds to the JSON property gcsSource
23452 23453 23454 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23452 def gcs_source @gcs_source end |
#google_drive_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GoogleDriveSource
The Google Drive location for the input content.
Corresponds to the JSON property googleDriveSource
23457 23458 23459 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23457 def google_drive_source @google_drive_source end |
#jira_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1JiraSource
The Jira source for the ImportRagFilesRequest.
Corresponds to the JSON property jiraSource
23462 23463 23464 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23462 def jira_source @jira_source end |
#name ⇒ String
Output only. The resource name of the RagFile.
Corresponds to the JSON property name
23467 23468 23469 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23467 def name @name end |
#share_point_sources ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SharePointSources
The SharePointSources to pass to ImportRagFiles.
Corresponds to the JSON property sharePointSources
23472 23473 23474 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23472 def share_point_sources @share_point_sources end |
#slack_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SlackSource
The Slack source for the ImportRagFilesRequest.
Corresponds to the JSON property slackSource
23477 23478 23479 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23477 def slack_source @slack_source end |
#update_time ⇒ String
Output only. Timestamp when this RagFile was last updated.
Corresponds to the JSON property updateTime
23482 23483 23484 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23482 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23489 23490 23491 23492 23493 23494 23495 23496 23497 23498 23499 23500 23501 23502 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23489 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @direct_upload_source = args[:direct_upload_source] if args.key?(:direct_upload_source) @display_name = args[:display_name] if args.key?(:display_name) @file_status = args[:file_status] if args.key?(:file_status) @gcs_source = args[:gcs_source] if args.key?(:gcs_source) @google_drive_source = args[:google_drive_source] if args.key?(:google_drive_source) @jira_source = args[:jira_source] if args.key?(:jira_source) @name = args[:name] if args.key?(:name) @share_point_sources = args[:share_point_sources] if args.key?(:share_point_sources) @slack_source = args[:slack_source] if args.key?(:slack_source) @update_time = args[:update_time] if args.key?(:update_time) end |