Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagFileParsingConfigLayoutParser

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Document AI Layout Parser config.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1RagFileParsingConfigLayoutParser

Returns a new instance of GoogleCloudAiplatformV1RagFileParsingConfigLayoutParser.



23644
23645
23646
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23644

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_parsing_requests_per_minFixnum

The maximum number of requests the job is allowed to make to the Document AI processor per minute. Consult https://cloud.google.com/document-ai/quotas and the Quota page for your project to set an appropriate value here. If unspecified, a default value of 120 QPM would be used. Corresponds to the JSON property maxParsingRequestsPerMin

Returns:

  • (Fixnum)


23632
23633
23634
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23632

def max_parsing_requests_per_min
  @max_parsing_requests_per_min
end

#processor_nameString

The full resource name of a Document AI processor or processor version. The processor must have type LAYOUT_PARSER_PROCESSOR. If specified, the additional_config.parse_as_scanned_pdf field must be false. Format: * projects/project_id/locations/location/processors/processor_id* ` projects/`project_id`/locations/`location`/processors/`processor_id`/ processorVersions/`processor_version_id Corresponds to the JSON property processorName

Returns:

  • (String)


23642
23643
23644
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23642

def processor_name
  @processor_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23649
23650
23651
23652
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23649

def update!(**args)
  @max_parsing_requests_per_min = args[:max_parsing_requests_per_min] if args.key?(:max_parsing_requests_per_min)
  @processor_name = args[:processor_name] if args.key?(:processor_name)
end