Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagFileParsingConfigLlmParser
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagFileParsingConfigLlmParser
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Specifies the LLM parsing for RagFiles.
Instance Attribute Summary collapse
-
#custom_parsing_prompt ⇒ String
The prompt to use for parsing.
-
#max_parsing_requests_per_min ⇒ Fixnum
The maximum number of requests the job is allowed to make to the LLM model per minute.
-
#model_name ⇒ String
The name of a LLM model used for parsing.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1RagFileParsingConfigLlmParser
constructor
A new instance of GoogleCloudAiplatformV1RagFileParsingConfigLlmParser.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1RagFileParsingConfigLlmParser
Returns a new instance of GoogleCloudAiplatformV1RagFileParsingConfigLlmParser.
29819 29820 29821 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29819 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_parsing_prompt ⇒ String
The prompt to use for parsing. If not specified, a default prompt will be used.
Corresponds to the JSON property customParsingPrompt
29803 29804 29805 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29803 def custom_parsing_prompt @custom_parsing_prompt end |
#max_parsing_requests_per_min ⇒ Fixnum
The maximum number of requests the job is allowed to make to the LLM model per
minute. Consult https://cloud.google.com/vertex-ai/generative-ai/docs/quotas
and your document size to set an appropriate value here. If unspecified, a
default value of 5000 QPM would be used.
Corresponds to the JSON property maxParsingRequestsPerMin
29811 29812 29813 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29811 def max_parsing_requests_per_min @max_parsing_requests_per_min end |
#model_name ⇒ String
The name of a LLM model used for parsing. Format: * projects/project_id/
locations/location/publishers/publisher/models/model`
Corresponds to the JSON propertymodelName`
29817 29818 29819 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29817 def model_name @model_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29824 29825 29826 29827 29828 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29824 def update!(**args) @custom_parsing_prompt = args[:custom_parsing_prompt] if args.key?(:custom_parsing_prompt) @max_parsing_requests_per_min = args[:max_parsing_requests_per_min] if args.key?(:max_parsing_requests_per_min) @model_name = args[:model_name] if args.key?(:model_name) end |