Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagFileParsingConfigLlmParser

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Specifies the LLM parsing for RagFiles.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1RagFileParsingConfigLlmParser

Returns a new instance of GoogleCloudAiplatformV1RagFileParsingConfigLlmParser.



24355
24356
24357
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24355

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#custom_parsing_promptString

The prompt to use for parsing. If not specified, a default prompt will be used. Corresponds to the JSON property customParsingPrompt

Returns:

  • (String)


24339
24340
24341
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24339

def custom_parsing_prompt
  @custom_parsing_prompt
end

#max_parsing_requests_per_minFixnum

The maximum number of requests the job is allowed to make to the LLM model per minute. Consult https://cloud.google.com/vertex-ai/generative-ai/docs/quotas and your document size to set an appropriate value here. If unspecified, a default value of 5000 QPM would be used. Corresponds to the JSON property maxParsingRequestsPerMin

Returns:

  • (Fixnum)


24347
24348
24349
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24347

def max_parsing_requests_per_min
  @max_parsing_requests_per_min
end

#model_nameString

The name of a LLM model used for parsing. Format: * projects/project_id/ locations/location/publishers/publisher/models/model` Corresponds to the JSON propertymodelName`

Returns:

  • (String)


24353
24354
24355
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24353

def model_name
  @model_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24360
24361
24362
24363
24364
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24360

def update!(**args)
  @custom_parsing_prompt = args[:custom_parsing_prompt] if args.key?(:custom_parsing_prompt)
  @max_parsing_requests_per_min = args[:max_parsing_requests_per_min] if args.key?(:max_parsing_requests_per_min)
  @model_name = args[:model_name] if args.key?(:model_name)
end