Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Configuration message for RagManagedDb used by RagEngine.
Instance Attribute Summary collapse
-
#basic ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigBasic
Basic tier is a cost-effective and low compute tier suitable for the following cases: * Experimenting with RagManagedDb.
-
#scaled ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigScaled
Scaled tier offers production grade performance along with autoscaling functionality.
-
#serverless ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigServerless
Message to configure the serverless mode offered by RAG Engine.
-
#spanner ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigSpanner
Message to configure the Spanner database used by RagManagedDb.
-
#unprovisioned ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigUnprovisioned
Disables the RAG Engine service and deletes all your data held within this service.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1RagManagedDbConfig
constructor
A new instance of GoogleCloudAiplatformV1RagManagedDbConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1RagManagedDbConfig
Returns a new instance of GoogleCloudAiplatformV1RagManagedDbConfig.
34070 34071 34072 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34070 def initialize(**args) update!(**args) end |
Instance Attribute Details
#basic ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigBasic
Basic tier is a cost-effective and low compute tier suitable for the following
cases: * Experimenting with RagManagedDb. * Small data size. * Latency
insensitive workload. * Only using RAG Engine with external vector DBs. NOTE:
This is the default tier under Spanner mode if not explicitly chosen.
Corresponds to the JSON property basic
34043 34044 34045 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34043 def basic @basic end |
#scaled ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigScaled
Scaled tier offers production grade performance along with autoscaling
functionality. It is suitable for customers with large amounts of data or
performance sensitive workloads.
Corresponds to the JSON property scaled
34050 34051 34052 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34050 def scaled @scaled end |
#serverless ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigServerless
Message to configure the serverless mode offered by RAG Engine.
Corresponds to the JSON property serverless
34055 34056 34057 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34055 def serverless @serverless end |
#spanner ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigSpanner
Message to configure the Spanner database used by RagManagedDb.
Corresponds to the JSON property spanner
34060 34061 34062 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34060 def spanner @spanner end |
#unprovisioned ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigUnprovisioned
Disables the RAG Engine service and deletes all your data held within this
service. This will halt the billing of the service. NOTE: Once deleted the
data cannot be recovered. To start using RAG Engine again, you will need to
update the tier by calling the UpdateRagEngineConfig API.
Corresponds to the JSON property unprovisioned
34068 34069 34070 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34068 def unprovisioned @unprovisioned end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34075 34076 34077 34078 34079 34080 34081 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34075 def update!(**args) @basic = args[:basic] if args.key?(:basic) @scaled = args[:scaled] if args.key?(:scaled) @serverless = args[:serverless] if args.key?(:serverless) @spanner = args[:spanner] if args.key?(:spanner) @unprovisioned = args[:unprovisioned] if args.key?(:unprovisioned) end |