Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Configuration message for RagManagedDb used by RagEngine.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1RagManagedDbConfig

Returns a new instance of GoogleCloudAiplatformV1RagManagedDbConfig.



31310
31311
31312
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31310

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#basicGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigBasic

Basic tier is a cost-effective and low compute tier suitable for the following cases: * Experimenting with RagManagedDb. * Small data size. * Latency insensitive workload. * Only using RAG Engine with external vector DBs. NOTE: This is the default tier under Spanner mode if not explicitly chosen. Corresponds to the JSON property basic



31283
31284
31285
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31283

def basic
  @basic
end

#scaledGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigScaled

Scaled tier offers production grade performance along with autoscaling functionality. It is suitable for customers with large amounts of data or performance sensitive workloads. Corresponds to the JSON property scaled



31290
31291
31292
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31290

def scaled
  @scaled
end

#serverlessGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigServerless

Message to configure the serverless mode offered by RAG Engine. Corresponds to the JSON property serverless



31295
31296
31297
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31295

def serverless
  @serverless
end

#spannerGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigSpanner

Message to configure the Spanner database used by RagManagedDb. Corresponds to the JSON property spanner



31300
31301
31302
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31300

def spanner
  @spanner
end

#unprovisionedGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigUnprovisioned

Disables the RAG Engine service and deletes all your data held within this service. This will halt the billing of the service. NOTE: Once deleted the data cannot be recovered. To start using RAG Engine again, you will need to update the tier by calling the UpdateRagEngineConfig API. Corresponds to the JSON property unprovisioned



31308
31309
31310
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31308

def unprovisioned
  @unprovisioned
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31315
31316
31317
31318
31319
31320
31321
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31315

def update!(**args)
  @basic = args[:basic] if args.key?(:basic)
  @scaled = args[:scaled] if args.key?(:scaled)
  @serverless = args[:serverless] if args.key?(:serverless)
  @spanner = args[:spanner] if args.key?(:spanner)
  @unprovisioned = args[:unprovisioned] if args.key?(:unprovisioned)
end