Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Configuration message for RagManagedDb used by RagEngine.
Instance Attribute Summary collapse
-
#basic ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigBasic
Basic tier is a cost-effective and low compute tier suitable for the following cases: * Experimenting with RagManagedDb.
-
#scaled ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigScaled
Scaled tier offers production grade performance along with autoscaling functionality.
-
#serverless ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigServerless
Message to configure the serverless mode offered by RAG Engine.
-
#spanner ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigSpanner
Message to configure the Spanner database used by RagManagedDb.
-
#unprovisioned ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigUnprovisioned
Disables the RAG Engine service and deletes all your data held within this service.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1RagManagedDbConfig
constructor
A new instance of GoogleCloudAiplatformV1RagManagedDbConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1RagManagedDbConfig
Returns a new instance of GoogleCloudAiplatformV1RagManagedDbConfig.
31090 31091 31092 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31090 def initialize(**args) update!(**args) end |
Instance Attribute Details
#basic ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigBasic
Basic tier is a cost-effective and low compute tier suitable for the following
cases: * Experimenting with RagManagedDb. * Small data size. * Latency
insensitive workload. * Only using RAG Engine with external vector DBs. NOTE:
This is the default tier under Spanner mode if not explicitly chosen.
Corresponds to the JSON property basic
31063 31064 31065 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31063 def basic @basic end |
#scaled ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigScaled
Scaled tier offers production grade performance along with autoscaling
functionality. It is suitable for customers with large amounts of data or
performance sensitive workloads.
Corresponds to the JSON property scaled
31070 31071 31072 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31070 def scaled @scaled end |
#serverless ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigServerless
Message to configure the serverless mode offered by RAG Engine.
Corresponds to the JSON property serverless
31075 31076 31077 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31075 def serverless @serverless end |
#spanner ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigSpanner
Message to configure the Spanner database used by RagManagedDb.
Corresponds to the JSON property spanner
31080 31081 31082 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31080 def spanner @spanner end |
#unprovisioned ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigUnprovisioned
Disables the RAG Engine service and deletes all your data held within this
service. This will halt the billing of the service. NOTE: Once deleted the
data cannot be recovered. To start using RAG Engine again, you will need to
update the tier by calling the UpdateRagEngineConfig API.
Corresponds to the JSON property unprovisioned
31088 31089 31090 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31088 def unprovisioned @unprovisioned end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31095 31096 31097 31098 31099 31100 31101 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31095 def update!(**args) @basic = args[:basic] if args.key?(:basic) @scaled = args[:scaled] if args.key?(:scaled) @serverless = args[:serverless] if args.key?(:serverless) @spanner = args[:spanner] if args.key?(:spanner) @unprovisioned = args[:unprovisioned] if args.key?(:unprovisioned) end |