Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Configuration message for RagManagedDb used by RagEngine.
Instance Attribute Summary collapse
-
#basic ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigBasic
Basic tier is a cost-effective and low compute tier suitable for the following cases: * Experimenting with RagManagedDb.
-
#scaled ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigScaled
Scaled tier offers production grade performance along with autoscaling functionality.
-
#unprovisioned ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigUnprovisioned
Disables the RAG Engine service and deletes all your data held within this service.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1RagManagedDbConfig
constructor
A new instance of GoogleCloudAiplatformV1RagManagedDbConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1RagManagedDbConfig
Returns a new instance of GoogleCloudAiplatformV1RagManagedDbConfig.
25354 25355 25356 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25354 def initialize(**args) update!(**args) end |
Instance Attribute Details
#basic ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigBasic
Basic tier is a cost-effective and low compute tier suitable for the following
cases: * Experimenting with RagManagedDb. * Small data size. * Latency
insensitive workload. * Only using RAG Engine with external vector DBs. NOTE:
This is the default tier if not explicitly chosen.
Corresponds to the JSON property basic
25337 25338 25339 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25337 def basic @basic end |
#scaled ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigScaled
Scaled tier offers production grade performance along with autoscaling
functionality. It is suitable for customers with large amounts of data or
performance sensitive workloads.
Corresponds to the JSON property scaled
25344 25345 25346 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25344 def scaled @scaled end |
#unprovisioned ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigUnprovisioned
Disables the RAG Engine service and deletes all your data held within this
service. This will halt the billing of the service. NOTE: Once deleted the
data cannot be recovered. To start using RAG Engine again, you will need to
update the tier by calling the UpdateRagEngineConfig API.
Corresponds to the JSON property unprovisioned
25352 25353 25354 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25352 def unprovisioned @unprovisioned end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25359 25360 25361 25362 25363 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25359 def update!(**args) @basic = args[:basic] if args.key?(:basic) @scaled = args[:scaled] if args.key?(:scaled) @unprovisioned = args[:unprovisioned] if args.key?(:unprovisioned) end |