Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Configuration message for RagManagedDb used by RagEngine.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1RagManagedDbConfig

Returns a new instance of GoogleCloudAiplatformV1RagManagedDbConfig.



24929
24930
24931
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24929

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#basicGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigBasic

Basic tier is a cost-effective and low compute tier suitable for the following cases: * Experimenting with RagManagedDb. * Small data size. * Latency insensitive workload. * Only using RAG Engine with external vector DBs. NOTE: This is the default tier if not explicitly chosen. Corresponds to the JSON property basic



24912
24913
24914
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24912

def basic
  @basic
end

#scaledGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigScaled

Scaled tier offers production grade performance along with autoscaling functionality. It is suitable for customers with large amounts of data or performance sensitive workloads. Corresponds to the JSON property scaled



24919
24920
24921
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24919

def scaled
  @scaled
end

#unprovisionedGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigUnprovisioned

Disables the RAG Engine service and deletes all your data held within this service. This will halt the billing of the service. NOTE: Once deleted the data cannot be recovered. To start using RAG Engine again, you will need to update the tier by calling the UpdateRagEngineConfig API. Corresponds to the JSON property unprovisioned



24927
24928
24929
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24927

def unprovisioned
  @unprovisioned
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24934
24935
24936
24937
24938
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24934

def update!(**args)
  @basic = args[:basic] if args.key?(:basic)
  @scaled = args[:scaled] if args.key?(:scaled)
  @unprovisioned = args[:unprovisioned] if args.key?(:unprovisioned)
end