Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigScaled

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Scaled tier offers production grade performance along with autoscaling functionality. It is suitable for customers with large amounts of data or performance sensitive workloads.

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1RagManagedDbConfigScaled

Returns a new instance of GoogleCloudAiplatformV1RagManagedDbConfigScaled.



32607
32608
32609
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32607

def initialize(**args)
   update!(**args)
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32612
32613
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32612

def update!(**args)
end