Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigScaled
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigScaled
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Scaled tier offers production grade performance along with autoscaling functionality. It is suitable for customers with large amounts of data or performance sensitive workloads.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1RagManagedDbConfigScaled
constructor
A new instance of GoogleCloudAiplatformV1RagManagedDbConfigScaled.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1RagManagedDbConfigScaled
Returns a new instance of GoogleCloudAiplatformV1RagManagedDbConfigScaled.
29923 29924 29925 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29923 def initialize(**args) update!(**args) end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29928 29929 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29928 def update!(**args) end |