Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigSpanner

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Message to configure the Spanner database used by RagManagedDb.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1RagManagedDbConfigSpanner

Returns a new instance of GoogleCloudAiplatformV1RagManagedDbConfigSpanner.



34012
34013
34014
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34012

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#basicGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigBasic

Basic tier is a cost-effective and low compute tier suitable for the following cases: * Experimenting with RagManagedDb. * Small data size. * Latency insensitive workload. * Only using RAG Engine with external vector DBs. NOTE: This is the default tier under Spanner mode if not explicitly chosen. Corresponds to the JSON property basic



33995
33996
33997
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33995

def basic
  @basic
end

#scaledGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigScaled

Scaled tier offers production grade performance along with autoscaling functionality. It is suitable for customers with large amounts of data or performance sensitive workloads. Corresponds to the JSON property scaled



34002
34003
34004
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34002

def scaled
  @scaled
end

#unprovisionedGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigUnprovisioned

Disables the RAG Engine service and deletes all your data held within this service. This will halt the billing of the service. NOTE: Once deleted the data cannot be recovered. To start using RAG Engine again, you will need to update the tier by calling the UpdateRagEngineConfig API. Corresponds to the JSON property unprovisioned



34010
34011
34012
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34010

def unprovisioned
  @unprovisioned
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34017
34018
34019
34020
34021
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34017

def update!(**args)
  @basic = args[:basic] if args.key?(:basic)
  @scaled = args[:scaled] if args.key?(:scaled)
  @unprovisioned = args[:unprovisioned] if args.key?(:unprovisioned)
end