Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigSpanner
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigSpanner
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Message to configure the Spanner database used by RagManagedDb.
Instance Attribute Summary collapse
-
#basic ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigBasic
Basic tier is a cost-effective and low compute tier suitable for the following cases: * Experimenting with RagManagedDb.
-
#scaled ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigScaled
Scaled tier offers production grade performance along with autoscaling functionality.
-
#unprovisioned ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigUnprovisioned
Disables the RAG Engine service and deletes all your data held within this service.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1RagManagedDbConfigSpanner
constructor
A new instance of GoogleCloudAiplatformV1RagManagedDbConfigSpanner.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1RagManagedDbConfigSpanner
Returns a new instance of GoogleCloudAiplatformV1RagManagedDbConfigSpanner.
33073 33074 33075 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33073 def initialize(**args) update!(**args) end |
Instance Attribute Details
#basic ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigBasic
Basic tier is a cost-effective and low compute tier suitable for the following
cases: * Experimenting with RagManagedDb. * Small data size. * Latency
insensitive workload. * Only using RAG Engine with external vector DBs. NOTE:
This is the default tier under Spanner mode if not explicitly chosen.
Corresponds to the JSON property basic
33056 33057 33058 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33056 def basic @basic end |
#scaled ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigScaled
Scaled tier offers production grade performance along with autoscaling
functionality. It is suitable for customers with large amounts of data or
performance sensitive workloads.
Corresponds to the JSON property scaled
33063 33064 33065 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33063 def scaled @scaled end |
#unprovisioned ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigUnprovisioned
Disables the RAG Engine service and deletes all your data held within this
service. This will halt the billing of the service. NOTE: Once deleted the
data cannot be recovered. To start using RAG Engine again, you will need to
update the tier by calling the UpdateRagEngineConfig API.
Corresponds to the JSON property unprovisioned
33071 33072 33073 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33071 def unprovisioned @unprovisioned end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33078 33079 33080 33081 33082 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33078 def update!(**args) @basic = args[:basic] if args.key?(:basic) @scaled = args[:scaled] if args.key?(:scaled) @unprovisioned = args[:unprovisioned] if args.key?(:unprovisioned) end |