Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigSpanner

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Message to configure the Spanner database used by RagManagedDb.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1RagManagedDbConfigSpanner

Returns a new instance of GoogleCloudAiplatformV1RagManagedDbConfigSpanner.



31395
31396
31397
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31395

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#basicGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigBasic

Basic tier is a cost-effective and low compute tier suitable for the following cases: * Experimenting with RagManagedDb. * Small data size. * Latency insensitive workload. * Only using RAG Engine with external vector DBs. NOTE: This is the default tier under Spanner mode if not explicitly chosen. Corresponds to the JSON property basic



31378
31379
31380
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31378

def basic
  @basic
end

#scaledGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigScaled

Scaled tier offers production grade performance along with autoscaling functionality. It is suitable for customers with large amounts of data or performance sensitive workloads. Corresponds to the JSON property scaled



31385
31386
31387
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31385

def scaled
  @scaled
end

#unprovisionedGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RagManagedDbConfigUnprovisioned

Disables the RAG Engine service and deletes all your data held within this service. This will halt the billing of the service. NOTE: Once deleted the data cannot be recovered. To start using RAG Engine again, you will need to update the tier by calling the UpdateRagEngineConfig API. Corresponds to the JSON property unprovisioned



31393
31394
31395
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31393

def unprovisioned
  @unprovisioned
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31400
31401
31402
31403
31404
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31400

def update!(**args)
  @basic = args[:basic] if args.key?(:basic)
  @scaled = args[:scaled] if args.key?(:scaled)
  @unprovisioned = args[:unprovisioned] if args.key?(:unprovisioned)
end