Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagVectorDbConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagVectorDbConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Config for the Vector DB to use for RAG.
Instance Attribute Summary collapse
-
#api_auth ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ApiAuth
The generic reusable api auth config.
-
#pinecone ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagVectorDbConfigPinecone
The config for the Pinecone.
-
#rag_embedding_model_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagEmbeddingModelConfig
Config for the embedding model to use for RAG.
-
#rag_managed_db ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagVectorDbConfigRagManagedDb
The config for the default RAG-managed Vector DB.
-
#vertex_vector_search ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagVectorDbConfigVertexVectorSearch
The config for the Vertex Vector Search.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1RagVectorDbConfig
constructor
A new instance of GoogleCloudAiplatformV1RagVectorDbConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1RagVectorDbConfig
Returns a new instance of GoogleCloudAiplatformV1RagVectorDbConfig.
23757 23758 23759 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23757 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_auth ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ApiAuth
The generic reusable api auth config. Deprecated. Please use AuthConfig (
google/cloud/aiplatform/master/auth.proto) instead.
Corresponds to the JSON property apiAuth
23735 23736 23737 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23735 def api_auth @api_auth end |
#pinecone ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagVectorDbConfigPinecone
The config for the Pinecone.
Corresponds to the JSON property pinecone
23740 23741 23742 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23740 def pinecone @pinecone end |
#rag_embedding_model_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagEmbeddingModelConfig
Config for the embedding model to use for RAG.
Corresponds to the JSON property ragEmbeddingModelConfig
23745 23746 23747 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23745 def @rag_embedding_model_config end |
#rag_managed_db ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagVectorDbConfigRagManagedDb
The config for the default RAG-managed Vector DB.
Corresponds to the JSON property ragManagedDb
23750 23751 23752 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23750 def rag_managed_db @rag_managed_db end |
#vertex_vector_search ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagVectorDbConfigVertexVectorSearch
The config for the Vertex Vector Search.
Corresponds to the JSON property vertexVectorSearch
23755 23756 23757 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23755 def vertex_vector_search @vertex_vector_search end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23762 23763 23764 23765 23766 23767 23768 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23762 def update!(**args) @api_auth = args[:api_auth] if args.key?(:api_auth) @pinecone = args[:pinecone] if args.key?(:pinecone) @rag_embedding_model_config = args[:rag_embedding_model_config] if args.key?(:rag_embedding_model_config) @rag_managed_db = args[:rag_managed_db] if args.key?(:rag_managed_db) @vertex_vector_search = args[:vertex_vector_search] if args.key?(:vertex_vector_search) end |