Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagVectorDbConfigRagManagedDb

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The config for the default RAG-managed Vector DB.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1RagVectorDbConfigRagManagedDb

Returns a new instance of GoogleCloudAiplatformV1RagVectorDbConfigRagManagedDb.



25240
25241
25242
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25240

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RagVectorDbConfigRagManagedDbAnn

Config for ANN search. RagManagedDb uses a tree-based structure to partition data and facilitate faster searches. As a tradeoff, it requires longer indexing time and manual triggering of index rebuild via the ImportRagFiles and UpdateRagCorpus API. Corresponds to the JSON property ann



25233
25234
25235
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25233

def ann
  @ann
end

#knnGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RagVectorDbConfigRagManagedDbKnn

Config for KNN search. Corresponds to the JSON property knn



25238
25239
25240
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25238

def knn
  @knn
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25245
25246
25247
25248
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25245

def update!(**args)
  @ann = args[:ann] if args.key?(:ann)
  @knn = args[:knn] if args.key?(:knn)
end