Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagVectorDbConfigRagManagedDb

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The config for the default RAG-managed Vector DB.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1RagVectorDbConfigRagManagedDb

Returns a new instance of GoogleCloudAiplatformV1RagVectorDbConfigRagManagedDb.



24768
24769
24770
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24768

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RagVectorDbConfigRagManagedDbAnn

Config for ANN search. RagManagedDb uses a tree-based structure to partition data and facilitate faster searches. As a tradeoff, it requires longer indexing time and manual triggering of index rebuild via the ImportRagFiles and UpdateRagCorpus API. Corresponds to the JSON property ann



24761
24762
24763
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24761

def ann
  @ann
end

#knnGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RagVectorDbConfigRagManagedDbKnn

Config for KNN search. Corresponds to the JSON property knn



24766
24767
24768
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24766

def knn
  @knn
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24773
24774
24775
24776
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24773

def update!(**args)
  @ann = args[:ann] if args.key?(:ann)
  @knn = args[:knn] if args.key?(:knn)
end