Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RaySpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RaySpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Configuration information for the Ray cluster. For experimental launch, Ray cluster creation and Persistent cluster creation are 1:1 mapping: We will provision all the nodes within the Persistent cluster as Ray nodes.
Instance Attribute Summary collapse
-
#head_node_resource_pool_id ⇒ String
Optional.
-
#image_uri ⇒ String
Optional.
-
#ray_logs_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RayLogsSpec
Configuration for the Ray OSS Logs.
-
#ray_metric_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RayMetricSpec
Configuration for the Ray metrics.
-
#resource_pool_images ⇒ Hash<String,String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1RaySpec
constructor
A new instance of GoogleCloudAiplatformV1RaySpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1RaySpec
Returns a new instance of GoogleCloudAiplatformV1RaySpec.
33542 33543 33544 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33542 def initialize(**args) update!(**args) end |
Instance Attribute Details
#head_node_resource_pool_id ⇒ String
Optional. This will be used to indicate which resource pool will serve as the
Ray head node(the first node within that pool). Will use the machine from the
first workerpool as the head node by default if this field isn't set.
Corresponds to the JSON property headNodeResourcePoolId
33511 33512 33513 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33511 def head_node_resource_pool_id @head_node_resource_pool_id end |
#image_uri ⇒ String
Optional. Default image for user to choose a preferred ML framework (for
example, TensorFlow or Pytorch) by choosing from Vertex prebuilt images. Either
this or the resource_pool_images is required. Use this field if you need all
the resource pools to have the same Ray image. Otherwise, use the @code
resource_pool_images field.
Corresponds to the JSON property imageUri
33521 33522 33523 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33521 def image_uri @image_uri end |
#ray_logs_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RayLogsSpec
Configuration for the Ray OSS Logs.
Corresponds to the JSON property rayLogsSpec
33526 33527 33528 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33526 def ray_logs_spec @ray_logs_spec end |
#ray_metric_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RayMetricSpec
Configuration for the Ray metrics.
Corresponds to the JSON property rayMetricSpec
33531 33532 33533 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33531 def ray_metric_spec @ray_metric_spec end |
#resource_pool_images ⇒ Hash<String,String>
Optional. Required if image_uri isn't set. A map of resource_pool_id to
prebuild Ray image if user need to use different images for different head/
worker pools. This map needs to cover all the resource pool ids. Example: "
ray_head_node_pool": "head image" "ray_worker_node_pool1": "worker image" "
ray_worker_node_pool2": "another worker image"
Corresponds to the JSON property resourcePoolImages
33540 33541 33542 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33540 def resource_pool_images @resource_pool_images end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33547 33548 33549 33550 33551 33552 33553 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33547 def update!(**args) @head_node_resource_pool_id = args[:head_node_resource_pool_id] if args.key?(:head_node_resource_pool_id) @image_uri = args[:image_uri] if args.key?(:image_uri) @ray_logs_spec = args[:ray_logs_spec] if args.key?(:ray_logs_spec) @ray_metric_spec = args[:ray_metric_spec] if args.key?(:ray_metric_spec) @resource_pool_images = args[:resource_pool_images] if args.key?(:resource_pool_images) end |