Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RaySpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Configuration information for the Ray cluster. For experimental launch, Ray cluster creation and Persistent cluster creation are 1:1 mapping: We will provision all the nodes within the Persistent cluster as Ray nodes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1RaySpec

Returns a new instance of GoogleCloudAiplatformV1RaySpec.



31877
31878
31879
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31877

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#head_node_resource_pool_idString

Optional. This will be used to indicate which resource pool will serve as the Ray head node(the first node within that pool). Will use the machine from the first workerpool as the head node by default if this field isn't set. Corresponds to the JSON property headNodeResourcePoolId

Returns:

  • (String)


31846
31847
31848
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31846

def head_node_resource_pool_id
  @head_node_resource_pool_id
end

#image_uriString

Optional. Default image for user to choose a preferred ML framework (for example, TensorFlow or Pytorch) by choosing from Vertex prebuilt images. Either this or the resource_pool_images is required. Use this field if you need all the resource pools to have the same Ray image. Otherwise, use the @code resource_pool_images field. Corresponds to the JSON property imageUri

Returns:

  • (String)


31856
31857
31858
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31856

def image_uri
  @image_uri
end

#ray_logs_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RayLogsSpec

Configuration for the Ray OSS Logs. Corresponds to the JSON property rayLogsSpec



31861
31862
31863
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31861

def ray_logs_spec
  @ray_logs_spec
end

#ray_metric_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RayMetricSpec

Configuration for the Ray metrics. Corresponds to the JSON property rayMetricSpec



31866
31867
31868
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31866

def ray_metric_spec
  @ray_metric_spec
end

#resource_pool_imagesHash<String,String>

Optional. Required if image_uri isn't set. A map of resource_pool_id to prebuild Ray image if user need to use different images for different head/ worker pools. This map needs to cover all the resource pool ids. Example: " ray_head_node_pool": "head image" "ray_worker_node_pool1": "worker image" " ray_worker_node_pool2": "another worker image" Corresponds to the JSON property resourcePoolImages

Returns:

  • (Hash<String,String>)


31875
31876
31877
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31875

def resource_pool_images
  @resource_pool_images
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31882
31883
31884
31885
31886
31887
31888
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31882

def update!(**args)
  @head_node_resource_pool_id = args[:head_node_resource_pool_id] if args.key?(:head_node_resource_pool_id)
  @image_uri = args[:image_uri] if args.key?(:image_uri)
  @ray_logs_spec = args[:ray_logs_spec] if args.key?(:ray_logs_spec)
  @ray_metric_spec = args[:ray_metric_spec] if args.key?(:ray_metric_spec)
  @resource_pool_images = args[:resource_pool_images] if args.key?(:resource_pool_images)
end