Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReadFeatureValuesResponseEntityView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Entity view with Feature values.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ReadFeatureValuesResponseEntityView

Returns a new instance of GoogleCloudAiplatformV1ReadFeatureValuesResponseEntityView.



34577
34578
34579
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34577

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dataArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReadFeatureValuesResponseEntityViewData>

Each piece of data holds the k requested values for one requested Feature. If no values for the requested Feature exist, the corresponding cell will be empty. This has the same size and is in the same order as the features from the header ReadFeatureValuesResponse.header. Corresponds to the JSON property data



34570
34571
34572
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34570

def data
  @data
end

#entity_idString

ID of the requested entity. Corresponds to the JSON property entityId

Returns:

  • (String)


34575
34576
34577
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34575

def entity_id
  @entity_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34582
34583
34584
34585
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34582

def update!(**args)
  @data = args[:data] if args.key?(:data)
  @entity_id = args[:entity_id] if args.key?(:entity_id)
end