Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReadFeatureValuesResponseEntityView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Entity view with Feature values.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ReadFeatureValuesResponseEntityView

Returns a new instance of GoogleCloudAiplatformV1ReadFeatureValuesResponseEntityView.



25542
25543
25544
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25542

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dataArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReadFeatureValuesResponseEntityViewData>

Each piece of data holds the k requested values for one requested Feature. If no values for the requested Feature exist, the corresponding cell will be empty. This has the same size and is in the same order as the features from the header ReadFeatureValuesResponse.header. Corresponds to the JSON property data



25535
25536
25537
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25535

def data
  @data
end

#entity_idString

ID of the requested entity. Corresponds to the JSON property entityId

Returns:

  • (String)


25540
25541
25542
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25540

def entity_id
  @entity_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25547
25548
25549
25550
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25547

def update!(**args)
  @data = args[:data] if args.key?(:data)
  @entity_id = args[:entity_id] if args.key?(:entity_id)
end