Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReadFeatureValuesResponseEntityView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Entity view with Feature values.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ReadFeatureValuesResponseEntityView

Returns a new instance of GoogleCloudAiplatformV1ReadFeatureValuesResponseEntityView.



24029
24030
24031
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24029

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dataArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReadFeatureValuesResponseEntityViewData>

Each piece of data holds the k requested values for one requested Feature. If no values for the requested Feature exist, the corresponding cell will be empty. This has the same size and is in the same order as the features from the header ReadFeatureValuesResponse.header. Corresponds to the JSON property data



24022
24023
24024
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24022

def data
  @data
end

#entity_idString

ID of the requested entity. Corresponds to the JSON property entityId

Returns:

  • (String)


24027
24028
24029
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24027

def entity_id
  @entity_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24034
24035
24036
24037
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24034

def update!(**args)
  @data = args[:data] if args.key?(:data)
  @entity_id = args[:entity_id] if args.key?(:entity_id)
end