Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReadFeatureValuesResponseEntityView
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReadFeatureValuesResponseEntityView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Entity view with Feature values.
Instance Attribute Summary collapse
-
#data ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReadFeatureValuesResponseEntityViewData>
Each piece of data holds the k requested values for one requested Feature.
-
#entity_id ⇒ String
ID of the requested entity.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ReadFeatureValuesResponseEntityView
constructor
A new instance of GoogleCloudAiplatformV1ReadFeatureValuesResponseEntityView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ReadFeatureValuesResponseEntityView
Returns a new instance of GoogleCloudAiplatformV1ReadFeatureValuesResponseEntityView.
23953 23954 23955 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23953 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReadFeatureValuesResponseEntityViewData>
Each piece of data holds the k requested values for one requested Feature. If
no values for the requested Feature exist, the corresponding cell will be
empty. This has the same size and is in the same order as the features from
the header ReadFeatureValuesResponse.header.
Corresponds to the JSON property data
23946 23947 23948 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23946 def data @data end |
#entity_id ⇒ String
ID of the requested entity.
Corresponds to the JSON property entityId
23951 23952 23953 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23951 def entity_id @entity_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23958 23959 23960 23961 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23958 def update!(**args) @data = args[:data] if args.key?(:data) @entity_id = args[:entity_id] if args.key?(:entity_id) end |