Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReadTensorboardUsageResponsePerUserUsageData
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReadTensorboardUsageResponsePerUserUsageData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Per user usage data.
Instance Attribute Summary collapse
-
#username ⇒ String
User's username Corresponds to the JSON property
username. -
#view_count ⇒ Fixnum
Number of times the user has read data within the Tensorboard.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ReadTensorboardUsageResponsePerUserUsageData
constructor
A new instance of GoogleCloudAiplatformV1ReadTensorboardUsageResponsePerUserUsageData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ReadTensorboardUsageResponsePerUserUsageData
Returns a new instance of GoogleCloudAiplatformV1ReadTensorboardUsageResponsePerUserUsageData.
24059 24060 24061 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24059 def initialize(**args) update!(**args) end |
Instance Attribute Details
#username ⇒ String
User's username
Corresponds to the JSON property username
24052 24053 24054 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24052 def username @username end |
#view_count ⇒ Fixnum
Number of times the user has read data within the Tensorboard.
Corresponds to the JSON property viewCount
24057 24058 24059 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24057 def view_count @view_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24064 24065 24066 24067 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24064 def update!(**args) @username = args[:username] if args.key?(:username) @view_count = args[:view_count] if args.key?(:view_count) end |