Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngine

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

ReasoningEngine provides a customizable runtime for models to determine which actions to take and in which order.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngine

Returns a new instance of GoogleCloudAiplatformV1ReasoningEngine.



34441
34442
34443
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34441

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#context_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineContextSpec

Configuration for how Agent Engine sub-resources should manage context. Corresponds to the JSON property contextSpec



34391
34392
34393
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34391

def context_spec
  @context_spec
end

#create_timeString

Output only. Timestamp when this ReasoningEngine was created. Corresponds to the JSON property createTime

Returns:

  • (String)


34396
34397
34398
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34396

def create_time
  @create_time
end

#descriptionString

Optional. The description of the ReasoningEngine. Corresponds to the JSON property description

Returns:

  • (String)


34401
34402
34403
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34401

def description
  @description
end

#display_nameString

Required. The display name of the ReasoningEngine. Corresponds to the JSON property displayName

Returns:

  • (String)


34406
34407
34408
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34406

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



34412
34413
34414
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34412

def encryption_spec
  @encryption_spec
end

#etagString

Optional. Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


34418
34419
34420
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34418

def etag
  @etag
end

#labelsHash<String,String>

Labels for the ReasoningEngine. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


34423
34424
34425
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34423

def labels
  @labels
end

#nameString

Identifier. The resource name of the ReasoningEngine. Format: projects/ project/locations/location/reasoningEngines/reasoning_engine` Corresponds to the JSON propertyname`

Returns:

  • (String)


34429
34430
34431
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34429

def name
  @name
end

#specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpec

ReasoningEngine configurations Corresponds to the JSON property spec



34434
34435
34436
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34434

def spec
  @spec
end

#update_timeString

Output only. Timestamp when this ReasoningEngine was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


34439
34440
34441
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34439

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34446
34447
34448
34449
34450
34451
34452
34453
34454
34455
34456
34457
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34446

def update!(**args)
  @context_spec = args[:context_spec] if args.key?(:context_spec)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @spec = args[:spec] if args.key?(:spec)
  @update_time = args[:update_time] if args.key?(:update_time)
end