Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngine

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

ReasoningEngine provides a customizable runtime for models to determine which actions to take and in which order.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngine

Returns a new instance of GoogleCloudAiplatformV1ReasoningEngine.



33528
33529
33530
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33528

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#context_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineContextSpec

Configuration for how Agent Engine sub-resources should manage context. Corresponds to the JSON property contextSpec



33478
33479
33480
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33478

def context_spec
  @context_spec
end

#create_timeString

Output only. Timestamp when this ReasoningEngine was created. Corresponds to the JSON property createTime

Returns:

  • (String)


33483
33484
33485
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33483

def create_time
  @create_time
end

#descriptionString

Optional. The description of the ReasoningEngine. Corresponds to the JSON property description

Returns:

  • (String)


33488
33489
33490
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33488

def description
  @description
end

#display_nameString

Required. The display name of the ReasoningEngine. Corresponds to the JSON property displayName

Returns:

  • (String)


33493
33494
33495
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33493

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



33499
33500
33501
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33499

def encryption_spec
  @encryption_spec
end

#etagString

Optional. Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


33505
33506
33507
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33505

def etag
  @etag
end

#labelsHash<String,String>

Labels for the ReasoningEngine. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


33510
33511
33512
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33510

def labels
  @labels
end

#nameString

Identifier. The resource name of the ReasoningEngine. Format: projects/ project/locations/location/reasoningEngines/reasoning_engine` Corresponds to the JSON propertyname`

Returns:

  • (String)


33516
33517
33518
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33516

def name
  @name
end

#specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpec

ReasoningEngine configurations Corresponds to the JSON property spec



33521
33522
33523
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33521

def spec
  @spec
end

#update_timeString

Output only. Timestamp when this ReasoningEngine was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


33526
33527
33528
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33526

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33533
33534
33535
33536
33537
33538
33539
33540
33541
33542
33543
33544
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33533

def update!(**args)
  @context_spec = args[:context_spec] if args.key?(:context_spec)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @spec = args[:spec] if args.key?(:spec)
  @update_time = args[:update_time] if args.key?(:update_time)
end