Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngine

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

ReasoningEngine provides a customizable runtime for models to determine which actions to take and in which order.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngine

Returns a new instance of GoogleCloudAiplatformV1ReasoningEngine.



32151
32152
32153
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32151

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#context_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineContextSpec

Configuration for how Agent Engine sub-resources should manage context. Corresponds to the JSON property contextSpec



32101
32102
32103
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32101

def context_spec
  @context_spec
end

#create_timeString

Output only. Timestamp when this ReasoningEngine was created. Corresponds to the JSON property createTime

Returns:

  • (String)


32106
32107
32108
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32106

def create_time
  @create_time
end

#descriptionString

Optional. The description of the ReasoningEngine. Corresponds to the JSON property description

Returns:

  • (String)


32111
32112
32113
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32111

def description
  @description
end

#display_nameString

Required. The display name of the ReasoningEngine. Corresponds to the JSON property displayName

Returns:

  • (String)


32116
32117
32118
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32116

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



32122
32123
32124
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32122

def encryption_spec
  @encryption_spec
end

#etagString

Optional. Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


32128
32129
32130
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32128

def etag
  @etag
end

#labelsHash<String,String>

Labels for the ReasoningEngine. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


32133
32134
32135
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32133

def labels
  @labels
end

#nameString

Identifier. The resource name of the ReasoningEngine. Format: projects/ project/locations/location/reasoningEngines/reasoning_engine` Corresponds to the JSON propertyname`

Returns:

  • (String)


32139
32140
32141
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32139

def name
  @name
end

#specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpec

ReasoningEngine configurations Corresponds to the JSON property spec



32144
32145
32146
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32144

def spec
  @spec
end

#update_timeString

Output only. Timestamp when this ReasoningEngine was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


32149
32150
32151
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32149

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32156
32157
32158
32159
32160
32161
32162
32163
32164
32165
32166
32167
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32156

def update!(**args)
  @context_spec = args[:context_spec] if args.key?(:context_spec)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @spec = args[:spec] if args.key?(:spec)
  @update_time = args[:update_time] if args.key?(:update_time)
end