Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngine
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngine
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
ReasoningEngine provides a customizable runtime for models to determine which actions to take and in which order.
Instance Attribute Summary collapse
-
#context_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineContextSpec
Configuration for how Agent Engine sub-resources should manage context.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Required.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.
-
#etag ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Labels for the ReasoningEngine.
-
#name ⇒ String
Identifier.
-
#spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpec
ReasoningEngine configurations Corresponds to the JSON property
spec. -
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngine
constructor
A new instance of GoogleCloudAiplatformV1ReasoningEngine.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngine
Returns a new instance of GoogleCloudAiplatformV1ReasoningEngine.
32047 32048 32049 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32047 def initialize(**args) update!(**args) end |
Instance Attribute Details
#context_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineContextSpec
Configuration for how Agent Engine sub-resources should manage context.
Corresponds to the JSON property contextSpec
31997 31998 31999 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31997 def context_spec @context_spec end |
#create_time ⇒ String
Output only. Timestamp when this ReasoningEngine was created.
Corresponds to the JSON property createTime
32002 32003 32004 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32002 def create_time @create_time end |
#description ⇒ String
Optional. The description of the ReasoningEngine.
Corresponds to the JSON property description
32007 32008 32009 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32007 def description @description end |
#display_name ⇒ String
Required. The display name of the ReasoningEngine.
Corresponds to the JSON property displayName
32012 32013 32014 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32012 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied
to a Vertex AI resource.
Corresponds to the JSON property encryptionSpec
32018 32019 32020 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32018 def encryption_spec @encryption_spec end |
#etag ⇒ String
Optional. Used to perform consistent read-modify-write updates. If not set, a
blind "overwrite" update happens.
Corresponds to the JSON property etag
32024 32025 32026 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32024 def etag @etag end |
#labels ⇒ Hash<String,String>
Labels for the ReasoningEngine.
Corresponds to the JSON property labels
32029 32030 32031 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32029 def labels @labels end |
#name ⇒ String
Identifier. The resource name of the ReasoningEngine. Format: projects/
project/locations/location/reasoningEngines/reasoning_engine`
Corresponds to the JSON propertyname`
32035 32036 32037 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32035 def name @name end |
#spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpec
ReasoningEngine configurations
Corresponds to the JSON property spec
32040 32041 32042 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32040 def spec @spec end |
#update_time ⇒ String
Output only. Timestamp when this ReasoningEngine was most recently updated.
Corresponds to the JSON property updateTime
32045 32046 32047 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32045 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32052 32053 32054 32055 32056 32057 32058 32059 32060 32061 32062 32063 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32052 def update!(**args) @context_spec = args[:context_spec] if args.key?(:context_spec) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @spec = args[:spec] if args.key?(:spec) @update_time = args[:update_time] if args.key?(:update_time) end |