Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngine

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

ReasoningEngine provides a customizable runtime for models to determine which actions to take and in which order.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngine

Returns a new instance of GoogleCloudAiplatformV1ReasoningEngine.



26232
26233
26234
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26232

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this ReasoningEngine was created. Corresponds to the JSON property createTime

Returns:

  • (String)


26192
26193
26194
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26192

def create_time
  @create_time
end

#descriptionString

Optional. The description of the ReasoningEngine. Corresponds to the JSON property description

Returns:

  • (String)


26197
26198
26199
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26197

def description
  @description
end

#display_nameString

Required. The display name of the ReasoningEngine. Corresponds to the JSON property displayName

Returns:

  • (String)


26202
26203
26204
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26202

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key spec that can be applied to a top- level resource. Corresponds to the JSON property encryptionSpec



26208
26209
26210
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26208

def encryption_spec
  @encryption_spec
end

#etagString

Optional. Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


26214
26215
26216
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26214

def etag
  @etag
end

#nameString

Identifier. The resource name of the ReasoningEngine. Format: projects/ project/locations/location/reasoningEngines/reasoning_engine` Corresponds to the JSON propertyname`

Returns:

  • (String)


26220
26221
26222
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26220

def name
  @name
end

#specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpec

ReasoningEngine configurations Corresponds to the JSON property spec



26225
26226
26227
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26225

def spec
  @spec
end

#update_timeString

Output only. Timestamp when this ReasoningEngine was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


26230
26231
26232
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26230

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26237
26238
26239
26240
26241
26242
26243
26244
26245
26246
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26237

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @etag = args[:etag] if args.key?(:etag)
  @name = args[:name] if args.key?(:name)
  @spec = args[:spec] if args.key?(:spec)
  @update_time = args[:update_time] if args.key?(:update_time)
end