Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngine
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngine
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
ReasoningEngine provides a customizable runtime for models to determine which actions to take and in which order.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Required.
-
#etag ⇒ String
Optional.
-
#name ⇒ String
Identifier.
-
#spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpec
ReasoningEngine configurations Corresponds to the JSON property
spec. -
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngine
constructor
A new instance of GoogleCloudAiplatformV1ReasoningEngine.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngine
Returns a new instance of GoogleCloudAiplatformV1ReasoningEngine.
25816 25817 25818 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25816 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this ReasoningEngine was created.
Corresponds to the JSON property createTime
25782 25783 25784 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25782 def create_time @create_time end |
#description ⇒ String
Optional. The description of the ReasoningEngine.
Corresponds to the JSON property description
25787 25788 25789 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25787 def description @description end |
#display_name ⇒ String
Required. The display name of the ReasoningEngine.
Corresponds to the JSON property displayName
25792 25793 25794 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25792 def display_name @display_name end |
#etag ⇒ String
Optional. Used to perform consistent read-modify-write updates. If not set, a
blind "overwrite" update happens.
Corresponds to the JSON property etag
25798 25799 25800 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25798 def etag @etag end |
#name ⇒ String
Identifier. The resource name of the ReasoningEngine. Format: projects/
project/locations/location/reasoningEngines/reasoning_engine`
Corresponds to the JSON propertyname`
25804 25805 25806 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25804 def name @name end |
#spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpec
ReasoningEngine configurations
Corresponds to the JSON property spec
25809 25810 25811 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25809 def spec @spec end |
#update_time ⇒ String
Output only. Timestamp when this ReasoningEngine was most recently updated.
Corresponds to the JSON property updateTime
25814 25815 25816 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25814 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25821 25822 25823 25824 25825 25826 25827 25828 25829 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25821 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @name = args[:name] if args.key?(:name) @spec = args[:spec] if args.key?(:spec) @update_time = args[:update_time] if args.key?(:update_time) end |