Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngine
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngine
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
ReasoningEngine provides a customizable runtime for models to determine which actions to take and in which order.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Required.
-
#etag ⇒ String
Optional.
-
#name ⇒ String
Identifier.
-
#spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpec
ReasoningEngine configurations Corresponds to the JSON property
spec. -
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngine
constructor
A new instance of GoogleCloudAiplatformV1ReasoningEngine.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngine
Returns a new instance of GoogleCloudAiplatformV1ReasoningEngine.
25688 25689 25690 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25688 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this ReasoningEngine was created.
Corresponds to the JSON property createTime
25654 25655 25656 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25654 def create_time @create_time end |
#description ⇒ String
Optional. The description of the ReasoningEngine.
Corresponds to the JSON property description
25659 25660 25661 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25659 def description @description end |
#display_name ⇒ String
Required. The display name of the ReasoningEngine.
Corresponds to the JSON property displayName
25664 25665 25666 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25664 def display_name @display_name end |
#etag ⇒ String
Optional. Used to perform consistent read-modify-write updates. If not set, a
blind "overwrite" update happens.
Corresponds to the JSON property etag
25670 25671 25672 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25670 def etag @etag end |
#name ⇒ String
Identifier. The resource name of the ReasoningEngine. Format: projects/
project/locations/location/reasoningEngines/reasoning_engine`
Corresponds to the JSON propertyname`
25676 25677 25678 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25676 def name @name end |
#spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpec
ReasoningEngine configurations
Corresponds to the JSON property spec
25681 25682 25683 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25681 def spec @spec end |
#update_time ⇒ String
Output only. Timestamp when this ReasoningEngine was most recently updated.
Corresponds to the JSON property updateTime
25686 25687 25688 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25686 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25693 25694 25695 25696 25697 25698 25699 25700 25701 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25693 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @name = args[:name] if args.key?(:name) @spec = args[:spec] if args.key?(:spec) @update_time = args[:update_time] if args.key?(:update_time) end |