Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngine

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

ReasoningEngine provides a customizable runtime for models to determine which actions to take and in which order.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngine

Returns a new instance of GoogleCloudAiplatformV1ReasoningEngine.



24826
24827
24828
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24826

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this ReasoningEngine was created. Corresponds to the JSON property createTime

Returns:

  • (String)


24792
24793
24794
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24792

def create_time
  @create_time
end

#descriptionString

Optional. The description of the ReasoningEngine. Corresponds to the JSON property description

Returns:

  • (String)


24797
24798
24799
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24797

def description
  @description
end

#display_nameString

Required. The display name of the ReasoningEngine. Corresponds to the JSON property displayName

Returns:

  • (String)


24802
24803
24804
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24802

def display_name
  @display_name
end

#etagString

Optional. Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


24808
24809
24810
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24808

def etag
  @etag
end

#nameString

Identifier. The resource name of the ReasoningEngine. Format: projects/ project/locations/location/reasoningEngines/reasoning_engine` Corresponds to the JSON propertyname`

Returns:

  • (String)


24814
24815
24816
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24814

def name
  @name
end

#specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpec

ReasoningEngine configurations Corresponds to the JSON property spec



24819
24820
24821
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24819

def spec
  @spec
end

#update_timeString

Output only. Timestamp when this ReasoningEngine was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


24824
24825
24826
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24824

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24831
24832
24833
24834
24835
24836
24837
24838
24839
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24831

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @name = args[:name] if args.key?(:name)
  @spec = args[:spec] if args.key?(:spec)
  @update_time = args[:update_time] if args.key?(:update_time)
end