Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngine

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

ReasoningEngine provides a customizable runtime for models to determine which actions to take and in which order.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngine

Returns a new instance of GoogleCloudAiplatformV1ReasoningEngine.



24763
24764
24765
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24763

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this ReasoningEngine was created. Corresponds to the JSON property createTime

Returns:

  • (String)


24730
24731
24732
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24730

def create_time
  @create_time
end

#descriptionString

Optional. The description of the ReasoningEngine. Corresponds to the JSON property description

Returns:

  • (String)


24735
24736
24737
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24735

def description
  @description
end

#display_nameString

Required. The display name of the ReasoningEngine. Corresponds to the JSON property displayName

Returns:

  • (String)


24740
24741
24742
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24740

def display_name
  @display_name
end

#etagString

Optional. Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


24746
24747
24748
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24746

def etag
  @etag
end

#nameString

Identifier. The resource name of the ReasoningEngine. Corresponds to the JSON property name

Returns:

  • (String)


24751
24752
24753
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24751

def name
  @name
end

#specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpec

ReasoningEngine configurations Corresponds to the JSON property spec



24756
24757
24758
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24756

def spec
  @spec
end

#update_timeString

Output only. Timestamp when this ReasoningEngine was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


24761
24762
24763
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24761

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24768
24769
24770
24771
24772
24773
24774
24775
24776
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24768

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @name = args[:name] if args.key?(:name)
  @spec = args[:spec] if args.key?(:spec)
  @update_time = args[:update_time] if args.key?(:update_time)
end