Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngine

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

ReasoningEngine provides a customizable runtime for models to determine which actions to take and in which order.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngine

Returns a new instance of GoogleCloudAiplatformV1ReasoningEngine.



24721
24722
24723
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24721

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this ReasoningEngine was created. Corresponds to the JSON property createTime

Returns:

  • (String)


24688
24689
24690
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24688

def create_time
  @create_time
end

#descriptionString

Optional. The description of the ReasoningEngine. Corresponds to the JSON property description

Returns:

  • (String)


24693
24694
24695
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24693

def description
  @description
end

#display_nameString

Required. The display name of the ReasoningEngine. Corresponds to the JSON property displayName

Returns:

  • (String)


24698
24699
24700
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24698

def display_name
  @display_name
end

#etagString

Optional. Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


24704
24705
24706
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24704

def etag
  @etag
end

#nameString

Identifier. The resource name of the ReasoningEngine. Corresponds to the JSON property name

Returns:

  • (String)


24709
24710
24711
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24709

def name
  @name
end

#specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpec

ReasoningEngine configurations Corresponds to the JSON property spec



24714
24715
24716
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24714

def spec
  @spec
end

#update_timeString

Output only. Timestamp when this ReasoningEngine was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


24719
24720
24721
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24719

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24726
24727
24728
24729
24730
24731
24732
24733
24734
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24726

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @name = args[:name] if args.key?(:name)
  @spec = args[:spec] if args.key?(:spec)
  @update_time = args[:update_time] if args.key?(:update_time)
end