Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngine

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

ReasoningEngine provides a customizable runtime for models to determine which actions to take and in which order.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngine

Returns a new instance of GoogleCloudAiplatformV1ReasoningEngine.



24572
24573
24574
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24572

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this ReasoningEngine was created. Corresponds to the JSON property createTime

Returns:

  • (String)


24539
24540
24541
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24539

def create_time
  @create_time
end

#descriptionString

Optional. The description of the ReasoningEngine. Corresponds to the JSON property description

Returns:

  • (String)


24544
24545
24546
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24544

def description
  @description
end

#display_nameString

Required. The display name of the ReasoningEngine. Corresponds to the JSON property displayName

Returns:

  • (String)


24549
24550
24551
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24549

def display_name
  @display_name
end

#etagString

Optional. Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


24555
24556
24557
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24555

def etag
  @etag
end

#nameString

Identifier. The resource name of the ReasoningEngine. Corresponds to the JSON property name

Returns:

  • (String)


24560
24561
24562
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24560

def name
  @name
end

#specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpec

ReasoningEngine configurations Corresponds to the JSON property spec



24565
24566
24567
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24565

def spec
  @spec
end

#update_timeString

Output only. Timestamp when this ReasoningEngine was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


24570
24571
24572
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24570

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24577
24578
24579
24580
24581
24582
24583
24584
24585
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24577

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @name = args[:name] if args.key?(:name)
  @spec = args[:spec] if args.key?(:spec)
  @update_time = args[:update_time] if args.key?(:update_time)
end