Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngine
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngine
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
ReasoningEngine provides a customizable runtime for models to determine which actions to take and in which order.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Required.
-
#etag ⇒ String
Optional.
-
#name ⇒ String
Identifier.
-
#spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpec
ReasoningEngine configurations Corresponds to the JSON property
spec. -
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngine
constructor
A new instance of GoogleCloudAiplatformV1ReasoningEngine.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngine
Returns a new instance of GoogleCloudAiplatformV1ReasoningEngine.
24419 24420 24421 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24419 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this ReasoningEngine was created.
Corresponds to the JSON property createTime
24386 24387 24388 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24386 def create_time @create_time end |
#description ⇒ String
Optional. The description of the ReasoningEngine.
Corresponds to the JSON property description
24391 24392 24393 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24391 def description @description end |
#display_name ⇒ String
Required. The display name of the ReasoningEngine.
Corresponds to the JSON property displayName
24396 24397 24398 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24396 def display_name @display_name end |
#etag ⇒ String
Optional. Used to perform consistent read-modify-write updates. If not set, a
blind "overwrite" update happens.
Corresponds to the JSON property etag
24402 24403 24404 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24402 def etag @etag end |
#name ⇒ String
Identifier. The resource name of the ReasoningEngine.
Corresponds to the JSON property name
24407 24408 24409 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24407 def name @name end |
#spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpec
ReasoningEngine configurations
Corresponds to the JSON property spec
24412 24413 24414 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24412 def spec @spec end |
#update_time ⇒ String
Output only. Timestamp when this ReasoningEngine was most recently updated.
Corresponds to the JSON property updateTime
24417 24418 24419 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24417 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24424 24425 24426 24427 24428 24429 24430 24431 24432 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24424 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @name = args[:name] if args.key?(:name) @spec = args[:spec] if args.key?(:spec) @update_time = args[:update_time] if args.key?(:update_time) end |