Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngine

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

ReasoningEngine provides a customizable runtime for models to determine which actions to take and in which order.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngine

Returns a new instance of GoogleCloudAiplatformV1ReasoningEngine.



24111
24112
24113
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24111

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this ReasoningEngine was created. Corresponds to the JSON property createTime

Returns:

  • (String)


24078
24079
24080
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24078

def create_time
  @create_time
end

#descriptionString

Optional. The description of the ReasoningEngine. Corresponds to the JSON property description

Returns:

  • (String)


24083
24084
24085
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24083

def description
  @description
end

#display_nameString

Required. The display name of the ReasoningEngine. Corresponds to the JSON property displayName

Returns:

  • (String)


24088
24089
24090
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24088

def display_name
  @display_name
end

#etagString

Optional. Used to perform consistent read-modify-write updates. If not set, a blind "overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


24094
24095
24096
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24094

def etag
  @etag
end

#nameString

Identifier. The resource name of the ReasoningEngine. Corresponds to the JSON property name

Returns:

  • (String)


24099
24100
24101
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24099

def name
  @name
end

#specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpec

ReasoningEngine configurations Corresponds to the JSON property spec



24104
24105
24106
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24104

def spec
  @spec
end

#update_timeString

Output only. Timestamp when this ReasoningEngine was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


24109
24110
24111
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24109

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24116
24117
24118
24119
24120
24121
24122
24123
24124
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24116

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @name = args[:name] if args.key?(:name)
  @spec = args[:spec] if args.key?(:spec)
  @update_time = args[:update_time] if args.key?(:update_time)
end