Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineContextSpecMemoryBankConfigTtlConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineContextSpecMemoryBankConfigTtlConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Configuration for automatically setting the TTL ("time-to-live") of the memories in the Memory Bank.
Instance Attribute Summary collapse
-
#default_ttl ⇒ String
Optional.
-
#granular_ttl_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineContextSpecMemoryBankConfigTtlConfigGranularTtlConfig
Configuration for TTL of the memories in the Memory Bank based on the action that created or updated the memory.
-
#memory_revision_default_ttl ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngineContextSpecMemoryBankConfigTtlConfig
constructor
A new instance of GoogleCloudAiplatformV1ReasoningEngineContextSpecMemoryBankConfigTtlConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngineContextSpecMemoryBankConfigTtlConfig
Returns a new instance of GoogleCloudAiplatformV1ReasoningEngineContextSpecMemoryBankConfigTtlConfig.
32203 32204 32205 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32203 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_ttl ⇒ String
Optional. The default TTL duration of the memories in the Memory Bank. This
applies to all operations that create or update a memory.
Corresponds to the JSON property defaultTtl
32188 32189 32190 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32188 def default_ttl @default_ttl end |
#granular_ttl_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineContextSpecMemoryBankConfigTtlConfigGranularTtlConfig
Configuration for TTL of the memories in the Memory Bank based on the action
that created or updated the memory.
Corresponds to the JSON property granularTtlConfig
32194 32195 32196 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32194 def granular_ttl_config @granular_ttl_config end |
#memory_revision_default_ttl ⇒ String
Optional. The default TTL duration of the memory revisions in the Memory Bank.
This applies to all operations that create a memory revision. If not set, a
default TTL of 365 days will be used.
Corresponds to the JSON property memoryRevisionDefaultTtl
32201 32202 32203 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32201 def memory_revision_default_ttl @memory_revision_default_ttl end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32208 32209 32210 32211 32212 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32208 def update!(**args) @default_ttl = args[:default_ttl] if args.key?(:default_ttl) @granular_ttl_config = args[:granular_ttl_config] if args.key?(:granular_ttl_config) @memory_revision_default_ttl = args[:memory_revision_default_ttl] if args.key?(:memory_revision_default_ttl) end |