Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineContextSpecMemoryBankConfigTtlConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineContextSpecMemoryBankConfigTtlConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Configuration for automatically setting the TTL ("time-to-live") of the memories in the Memory Bank.
Instance Attribute Summary collapse
-
#default_ttl ⇒ String
Optional.
-
#granular_ttl_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineContextSpecMemoryBankConfigTtlConfigGranularTtlConfig
Configuration for TTL of the memories in the Memory Bank based on the action that created or updated the memory.
-
#memory_revision_default_ttl ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngineContextSpecMemoryBankConfigTtlConfig
constructor
A new instance of GoogleCloudAiplatformV1ReasoningEngineContextSpecMemoryBankConfigTtlConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngineContextSpecMemoryBankConfigTtlConfig
Returns a new instance of GoogleCloudAiplatformV1ReasoningEngineContextSpecMemoryBankConfigTtlConfig.
30994 30995 30996 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30994 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_ttl ⇒ String
Optional. The default TTL duration of the memories in the Memory Bank. This
applies to all operations that create or update a memory.
Corresponds to the JSON property defaultTtl
30979 30980 30981 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30979 def default_ttl @default_ttl end |
#granular_ttl_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineContextSpecMemoryBankConfigTtlConfigGranularTtlConfig
Configuration for TTL of the memories in the Memory Bank based on the action
that created or updated the memory.
Corresponds to the JSON property granularTtlConfig
30985 30986 30987 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30985 def granular_ttl_config @granular_ttl_config end |
#memory_revision_default_ttl ⇒ String
Optional. The default TTL duration of the memory revisions in the Memory Bank.
This applies to all operations that create a memory revision. If not set, a
default TTL of 365 days will be used.
Corresponds to the JSON property memoryRevisionDefaultTtl
30992 30993 30994 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30992 def memory_revision_default_ttl @memory_revision_default_ttl end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30999 31000 31001 31002 31003 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30999 def update!(**args) @default_ttl = args[:default_ttl] if args.key?(:default_ttl) @granular_ttl_config = args[:granular_ttl_config] if args.key?(:granular_ttl_config) @memory_revision_default_ttl = args[:memory_revision_default_ttl] if args.key?(:memory_revision_default_ttl) end |