Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineContextSpecMemoryBankConfigTtlConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Configuration for automatically setting the TTL ("time-to-live") of the memories in the Memory Bank.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngineContextSpecMemoryBankConfigTtlConfig

Returns a new instance of GoogleCloudAiplatformV1ReasoningEngineContextSpecMemoryBankConfigTtlConfig.



30711
30712
30713
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30711

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#default_ttlString

Optional. The default TTL duration of the memories in the Memory Bank. This applies to all operations that create or update a memory. Corresponds to the JSON property defaultTtl

Returns:

  • (String)


30696
30697
30698
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30696

def default_ttl
  @default_ttl
end

#granular_ttl_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineContextSpecMemoryBankConfigTtlConfigGranularTtlConfig

Configuration for TTL of the memories in the Memory Bank based on the action that created or updated the memory. Corresponds to the JSON property granularTtlConfig



30702
30703
30704
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30702

def granular_ttl_config
  @granular_ttl_config
end

#memory_revision_default_ttlString

Optional. The default TTL duration of the memory revisions in the Memory Bank. This applies to all operations that create a memory revision. If not set, a default TTL of 365 days will be used. Corresponds to the JSON property memoryRevisionDefaultTtl

Returns:

  • (String)


30709
30710
30711
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30709

def memory_revision_default_ttl
  @memory_revision_default_ttl
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30716
30717
30718
30719
30720
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30716

def update!(**args)
  @default_ttl = args[:default_ttl] if args.key?(:default_ttl)
  @granular_ttl_config = args[:granular_ttl_config] if args.key?(:granular_ttl_config)
  @memory_revision_default_ttl = args[:memory_revision_default_ttl] if args.key?(:memory_revision_default_ttl)
end