Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineContextSpecMemoryBankConfigTtlConfigGranularTtlConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Configuration for TTL of the memories in the Memory Bank based on the action that created or updated the memory.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngineContextSpecMemoryBankConfigTtlConfigGranularTtlConfig

Returns a new instance of GoogleCloudAiplatformV1ReasoningEngineContextSpecMemoryBankConfigTtlConfigGranularTtlConfig.



31030
31031
31032
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31030

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_ttlString

Optional. The TTL duration for memories uploaded via CreateMemory. Corresponds to the JSON property createTtl

Returns:

  • (String)


31014
31015
31016
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31014

def create_ttl
  @create_ttl
end

#generate_created_ttlString

Optional. The TTL duration for memories newly generated via GenerateMemories ( GenerateMemoriesResponse.GeneratedMemory.Action.CREATED). Corresponds to the JSON property generateCreatedTtl

Returns:

  • (String)


31020
31021
31022
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31020

def generate_created_ttl
  @generate_created_ttl
end

#generate_updated_ttlString

Optional. The TTL duration for memories updated via GenerateMemories ( GenerateMemoriesResponse.GeneratedMemory.Action.UPDATED). In the case of an UPDATE action, the expire_time of the existing memory will be updated to the new value (now + TTL). Corresponds to the JSON property generateUpdatedTtl

Returns:

  • (String)


31028
31029
31030
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31028

def generate_updated_ttl
  @generate_updated_ttl
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31035
31036
31037
31038
31039
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31035

def update!(**args)
  @create_ttl = args[:create_ttl] if args.key?(:create_ttl)
  @generate_created_ttl = args[:generate_created_ttl] if args.key?(:generate_created_ttl)
  @generate_updated_ttl = args[:generate_updated_ttl] if args.key?(:generate_updated_ttl)
end