Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

ReasoningEngine configurations

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngineSpec

Returns a new instance of GoogleCloudAiplatformV1ReasoningEngineSpec.



35157
35158
35159
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35157

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_frameworkString

Optional. The OSS agent framework used to develop the agent. Currently supported values: "google-adk", "langchain", "langgraph", "ag2", "llama-index", "custom". Corresponds to the JSON property agentFramework

Returns:

  • (String)


35097
35098
35099
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35097

def agent_framework
  @agent_framework
end

#build_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecBuildSpec

Specification for building container image. Corresponds to the JSON property buildSpec



35102
35103
35104
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35102

def build_spec
  @build_spec
end

#class_methodsArray<Hash<String,Object>>

Optional. Declarations for object class methods in OpenAPI specification format. Corresponds to the JSON property classMethods

Returns:

  • (Array<Hash<String,Object>>)


35108
35109
35110
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35108

def class_methods
  @class_methods
end

#container_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecContainerSpec

Specification for deploying from a container image. Corresponds to the JSON property containerSpec



35113
35114
35115
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35113

def container_spec
  @container_spec
end

#deployment_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecDeploymentSpec

The specification of a Reasoning Engine deployment. Corresponds to the JSON property deploymentSpec



35118
35119
35120
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35118

def deployment_spec
  @deployment_spec
end

#effective_identityString

Output only. The identity to use for the Reasoning Engine. It can contain one of the following values: * service-project@gcp-sa-aiplatform-re.googleapis. com (for SERVICE_AGENT identity type) * name@project.gserviceaccount.com ( for SERVICE_ACCOUNT identity type) * agents.global.org.system.id.goog/ resources/aiplatform/projects/project/locations/location/reasoningEngines/ reasoning_engine (for AGENT_IDENTITY identity type) Corresponds to the JSON property effectiveIdentity

Returns:

  • (String)


35128
35129
35130
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35128

def effective_identity
  @effective_identity
end

#identity_typeString

Optional. The identity type to use for the Reasoning Engine. If not specified, the service_account field will be used if set, otherwise the default Vertex AI Reasoning Engine Service Agent in the project will be used. Corresponds to the JSON property identityType

Returns:

  • (String)


35135
35136
35137
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35135

def identity_type
  @identity_type
end

#package_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecPackageSpec

User-provided package specification, containing pickled object and package requirements. Corresponds to the JSON property packageSpec



35141
35142
35143
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35141

def package_spec
  @package_spec
end

#service_accountString

Optional. The service account that the Reasoning Engine artifact runs as. It should have "roles/storage.objectViewer" for reading the user project's Cloud Storage and "roles/aiplatform.user" for using Vertex extensions. If not specified, the Vertex AI Reasoning Engine Service Agent in the project will be used. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


35150
35151
35152
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35150

def 
  @service_account
end

#source_code_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpec

Specification for deploying from source code. Corresponds to the JSON property sourceCodeSpec



35155
35156
35157
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35155

def source_code_spec
  @source_code_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35162
35163
35164
35165
35166
35167
35168
35169
35170
35171
35172
35173
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35162

def update!(**args)
  @agent_framework = args[:agent_framework] if args.key?(:agent_framework)
  @build_spec = args[:build_spec] if args.key?(:build_spec)
  @class_methods = args[:class_methods] if args.key?(:class_methods)
  @container_spec = args[:container_spec] if args.key?(:container_spec)
  @deployment_spec = args[:deployment_spec] if args.key?(:deployment_spec)
  @effective_identity = args[:effective_identity] if args.key?(:effective_identity)
  @identity_type = args[:identity_type] if args.key?(:identity_type)
  @package_spec = args[:package_spec] if args.key?(:package_spec)
  @service_account = args[:service_account] if args.key?(:service_account)
  @source_code_spec = args[:source_code_spec] if args.key?(:source_code_spec)
end