Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
ReasoningEngine configurations
Instance Attribute Summary collapse
-
#agent_framework ⇒ String
Optional.
-
#build_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecBuildSpec
Specification for building container image.
-
#class_methods ⇒ Array<Hash<String,Object>>
Optional.
-
#container_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecContainerSpec
Specification for deploying from a container image.
-
#deployment_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecDeploymentSpec
The specification of a Reasoning Engine deployment.
-
#effective_identity ⇒ String
Output only.
-
#identity_type ⇒ String
Optional.
-
#package_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecPackageSpec
User-provided package specification, containing pickled object and package requirements.
-
#service_account ⇒ String
Optional.
-
#source_code_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpec
Specification for deploying from source code.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngineSpec
constructor
A new instance of GoogleCloudAiplatformV1ReasoningEngineSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngineSpec
Returns a new instance of GoogleCloudAiplatformV1ReasoningEngineSpec.
34205 34206 34207 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34205 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_framework ⇒ String
Optional. The OSS agent framework used to develop the agent. Currently
supported values: "google-adk", "langchain", "langgraph", "ag2", "llama-index",
"custom".
Corresponds to the JSON property agentFramework
34145 34146 34147 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34145 def agent_framework @agent_framework end |
#build_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecBuildSpec
Specification for building container image.
Corresponds to the JSON property buildSpec
34150 34151 34152 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34150 def build_spec @build_spec end |
#class_methods ⇒ Array<Hash<String,Object>>
Optional. Declarations for object class methods in OpenAPI specification
format.
Corresponds to the JSON property classMethods
34156 34157 34158 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34156 def class_methods @class_methods end |
#container_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecContainerSpec
Specification for deploying from a container image.
Corresponds to the JSON property containerSpec
34161 34162 34163 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34161 def container_spec @container_spec end |
#deployment_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecDeploymentSpec
The specification of a Reasoning Engine deployment.
Corresponds to the JSON property deploymentSpec
34166 34167 34168 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34166 def deployment_spec @deployment_spec end |
#effective_identity ⇒ String
Output only. The identity to use for the Reasoning Engine. It can contain one
of the following values: * service-project@gcp-sa-aiplatform-re.googleapis.
com (for SERVICE_AGENT identity type) * name@project.gserviceaccount.com (
for SERVICE_ACCOUNT identity type) * agents.global.org.system.id.goog/
resources/aiplatform/projects/project/locations/location/reasoningEngines/
reasoning_engine (for AGENT_IDENTITY identity type)
Corresponds to the JSON property effectiveIdentity
34176 34177 34178 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34176 def effective_identity @effective_identity end |
#identity_type ⇒ String
Optional. The identity type to use for the Reasoning Engine. If not specified,
the service_account field will be used if set, otherwise the default Vertex
AI Reasoning Engine Service Agent in the project will be used.
Corresponds to the JSON property identityType
34183 34184 34185 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34183 def identity_type @identity_type end |
#package_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecPackageSpec
User-provided package specification, containing pickled object and package
requirements.
Corresponds to the JSON property packageSpec
34189 34190 34191 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34189 def package_spec @package_spec end |
#service_account ⇒ String
Optional. The service account that the Reasoning Engine artifact runs as. It
should have "roles/storage.objectViewer" for reading the user project's Cloud
Storage and "roles/aiplatform.user" for using Vertex extensions. If not
specified, the Vertex AI Reasoning Engine Service Agent in the project will be
used.
Corresponds to the JSON property serviceAccount
34198 34199 34200 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34198 def service_account @service_account end |
#source_code_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpec
Specification for deploying from source code.
Corresponds to the JSON property sourceCodeSpec
34203 34204 34205 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34203 def source_code_spec @source_code_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34210 34211 34212 34213 34214 34215 34216 34217 34218 34219 34220 34221 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34210 def update!(**args) @agent_framework = args[:agent_framework] if args.key?(:agent_framework) @build_spec = args[:build_spec] if args.key?(:build_spec) @class_methods = args[:class_methods] if args.key?(:class_methods) @container_spec = args[:container_spec] if args.key?(:container_spec) @deployment_spec = args[:deployment_spec] if args.key?(:deployment_spec) @effective_identity = args[:effective_identity] if args.key?(:effective_identity) @identity_type = args[:identity_type] if args.key?(:identity_type) @package_spec = args[:package_spec] if args.key?(:package_spec) @service_account = args[:service_account] if args.key?(:service_account) @source_code_spec = args[:source_code_spec] if args.key?(:source_code_spec) end |