Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
ReasoningEngine configurations
Instance Attribute Summary collapse
-
#agent_framework ⇒ String
Optional.
-
#class_methods ⇒ Array<Hash<String,Object>>
Optional.
-
#container_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecContainerSpec
Specification for deploying from a container image.
-
#deployment_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecDeploymentSpec
The specification of a Reasoning Engine deployment.
-
#effective_identity ⇒ String
Output only.
-
#identity_type ⇒ String
Optional.
-
#package_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecPackageSpec
User-provided package specification, containing pickled object and package requirements.
-
#service_account ⇒ String
Optional.
-
#source_code_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpec
Specification for deploying from source code.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngineSpec
constructor
A new instance of GoogleCloudAiplatformV1ReasoningEngineSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngineSpec
Returns a new instance of GoogleCloudAiplatformV1ReasoningEngineSpec.
33796 33797 33798 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33796 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_framework ⇒ String
Optional. The OSS agent framework used to develop the agent. Currently
supported values: "google-adk", "langchain", "langgraph", "ag2", "llama-index",
"custom".
Corresponds to the JSON property agentFramework
33741 33742 33743 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33741 def agent_framework @agent_framework end |
#class_methods ⇒ Array<Hash<String,Object>>
Optional. Declarations for object class methods in OpenAPI specification
format.
Corresponds to the JSON property classMethods
33747 33748 33749 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33747 def class_methods @class_methods end |
#container_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecContainerSpec
Specification for deploying from a container image.
Corresponds to the JSON property containerSpec
33752 33753 33754 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33752 def container_spec @container_spec end |
#deployment_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecDeploymentSpec
The specification of a Reasoning Engine deployment.
Corresponds to the JSON property deploymentSpec
33757 33758 33759 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33757 def deployment_spec @deployment_spec end |
#effective_identity ⇒ String
Output only. The identity to use for the Reasoning Engine. It can contain one
of the following values: * service-project@gcp-sa-aiplatform-re.googleapis.
com (for SERVICE_AGENT identity type) * name@project.gserviceaccount.com (
for SERVICE_ACCOUNT identity type) * agents.global.org.system.id.goog/
resources/aiplatform/projects/project/locations/location/reasoningEngines/
reasoning_engine (for AGENT_IDENTITY identity type)
Corresponds to the JSON property effectiveIdentity
33767 33768 33769 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33767 def effective_identity @effective_identity end |
#identity_type ⇒ String
Optional. The identity type to use for the Reasoning Engine. If not specified,
the service_account field will be used if set, otherwise the default Vertex
AI Reasoning Engine Service Agent in the project will be used.
Corresponds to the JSON property identityType
33774 33775 33776 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33774 def identity_type @identity_type end |
#package_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecPackageSpec
User-provided package specification, containing pickled object and package
requirements.
Corresponds to the JSON property packageSpec
33780 33781 33782 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33780 def package_spec @package_spec end |
#service_account ⇒ String
Optional. The service account that the Reasoning Engine artifact runs as. It
should have "roles/storage.objectViewer" for reading the user project's Cloud
Storage and "roles/aiplatform.user" for using Vertex extensions. If not
specified, the Vertex AI Reasoning Engine Service Agent in the project will be
used.
Corresponds to the JSON property serviceAccount
33789 33790 33791 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33789 def service_account @service_account end |
#source_code_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpec
Specification for deploying from source code.
Corresponds to the JSON property sourceCodeSpec
33794 33795 33796 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33794 def source_code_spec @source_code_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33801 33802 33803 33804 33805 33806 33807 33808 33809 33810 33811 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33801 def update!(**args) @agent_framework = args[:agent_framework] if args.key?(:agent_framework) @class_methods = args[:class_methods] if args.key?(:class_methods) @container_spec = args[:container_spec] if args.key?(:container_spec) @deployment_spec = args[:deployment_spec] if args.key?(:deployment_spec) @effective_identity = args[:effective_identity] if args.key?(:effective_identity) @identity_type = args[:identity_type] if args.key?(:identity_type) @package_spec = args[:package_spec] if args.key?(:package_spec) @service_account = args[:service_account] if args.key?(:service_account) @source_code_spec = args[:source_code_spec] if args.key?(:source_code_spec) end |