Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
ReasoningEngine configurations
Instance Attribute Summary collapse
-
#agent_framework ⇒ String
Optional.
-
#class_methods ⇒ Array<Hash<String,Object>>
Optional.
-
#container_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecContainerSpec
Specification for deploying from a container image.
-
#deployment_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecDeploymentSpec
The specification of a Reasoning Engine deployment.
-
#effective_identity ⇒ String
Output only.
-
#identity_type ⇒ String
Optional.
-
#package_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecPackageSpec
User-provided package specification, containing pickled object and package requirements.
-
#service_account ⇒ String
Optional.
-
#source_code_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpec
Specification for deploying from source code.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngineSpec
constructor
A new instance of GoogleCloudAiplatformV1ReasoningEngineSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngineSpec
Returns a new instance of GoogleCloudAiplatformV1ReasoningEngineSpec.
32419 32420 32421 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32419 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_framework ⇒ String
Optional. The OSS agent framework used to develop the agent. Currently
supported values: "google-adk", "langchain", "langgraph", "ag2", "llama-index",
"custom".
Corresponds to the JSON property agentFramework
32364 32365 32366 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32364 def agent_framework @agent_framework end |
#class_methods ⇒ Array<Hash<String,Object>>
Optional. Declarations for object class methods in OpenAPI specification
format.
Corresponds to the JSON property classMethods
32370 32371 32372 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32370 def class_methods @class_methods end |
#container_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecContainerSpec
Specification for deploying from a container image.
Corresponds to the JSON property containerSpec
32375 32376 32377 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32375 def container_spec @container_spec end |
#deployment_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecDeploymentSpec
The specification of a Reasoning Engine deployment.
Corresponds to the JSON property deploymentSpec
32380 32381 32382 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32380 def deployment_spec @deployment_spec end |
#effective_identity ⇒ String
Output only. The identity to use for the Reasoning Engine. It can contain one
of the following values: * service-project@gcp-sa-aiplatform-re.googleapis.
com (for SERVICE_AGENT identity type) * name@project.gserviceaccount.com (
for SERVICE_ACCOUNT identity type) * agents.global.org.system.id.goog/
resources/aiplatform/projects/project/locations/location/reasoningEngines/
reasoning_engine (for AGENT_IDENTITY identity type)
Corresponds to the JSON property effectiveIdentity
32390 32391 32392 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32390 def effective_identity @effective_identity end |
#identity_type ⇒ String
Optional. The identity type to use for the Reasoning Engine. If not specified,
the service_account field will be used if set, otherwise the default Vertex
AI Reasoning Engine Service Agent in the project will be used.
Corresponds to the JSON property identityType
32397 32398 32399 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32397 def identity_type @identity_type end |
#package_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecPackageSpec
User-provided package specification, containing pickled object and package
requirements.
Corresponds to the JSON property packageSpec
32403 32404 32405 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32403 def package_spec @package_spec end |
#service_account ⇒ String
Optional. The service account that the Reasoning Engine artifact runs as. It
should have "roles/storage.objectViewer" for reading the user project's Cloud
Storage and "roles/aiplatform.user" for using Vertex extensions. If not
specified, the Vertex AI Reasoning Engine Service Agent in the project will be
used.
Corresponds to the JSON property serviceAccount
32412 32413 32414 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32412 def service_account @service_account end |
#source_code_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpec
Specification for deploying from source code.
Corresponds to the JSON property sourceCodeSpec
32417 32418 32419 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32417 def source_code_spec @source_code_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32424 32425 32426 32427 32428 32429 32430 32431 32432 32433 32434 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32424 def update!(**args) @agent_framework = args[:agent_framework] if args.key?(:agent_framework) @class_methods = args[:class_methods] if args.key?(:class_methods) @container_spec = args[:container_spec] if args.key?(:container_spec) @deployment_spec = args[:deployment_spec] if args.key?(:deployment_spec) @effective_identity = args[:effective_identity] if args.key?(:effective_identity) @identity_type = args[:identity_type] if args.key?(:identity_type) @package_spec = args[:package_spec] if args.key?(:package_spec) @service_account = args[:service_account] if args.key?(:service_account) @source_code_spec = args[:source_code_spec] if args.key?(:source_code_spec) end |