Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

ReasoningEngine configurations

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngineSpec

Returns a new instance of GoogleCloudAiplatformV1ReasoningEngineSpec.



31101
31102
31103
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31101

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_frameworkString

Optional. The OSS agent framework used to develop the agent. Currently supported values: "google-adk", "langchain", "langgraph", "ag2", "llama-index", "custom". Corresponds to the JSON property agentFramework

Returns:

  • (String)


31051
31052
31053
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31051

def agent_framework
  @agent_framework
end

#class_methodsArray<Hash<String,Object>>

Optional. Declarations for object class methods in OpenAPI specification format. Corresponds to the JSON property classMethods

Returns:

  • (Array<Hash<String,Object>>)


31057
31058
31059
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31057

def class_methods
  @class_methods
end

#deployment_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecDeploymentSpec

The specification of a Reasoning Engine deployment. Corresponds to the JSON property deploymentSpec



31062
31063
31064
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31062

def deployment_spec
  @deployment_spec
end

#effective_identityString

Output only. The identity to use for the Reasoning Engine. It can contain one of the following values: * service-project@gcp-sa-aiplatform-re.googleapis. com (for SERVICE_AGENT identity type) * name@project.gserviceaccount.com ( for SERVICE_ACCOUNT identity type) * agents.global.org.system.id.goog/ resources/aiplatform/projects/project/locations/location/reasoningEngines/ reasoning_engine (for AGENT_IDENTITY identity type) Corresponds to the JSON property effectiveIdentity

Returns:

  • (String)


31072
31073
31074
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31072

def effective_identity
  @effective_identity
end

#identity_typeString

Optional. The identity type to use for the Reasoning Engine. If not specified, the service_account field will be used if set, otherwise the default Vertex AI Reasoning Engine Service Agent in the project will be used. Corresponds to the JSON property identityType

Returns:

  • (String)


31079
31080
31081
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31079

def identity_type
  @identity_type
end

#package_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecPackageSpec

User-provided package specification, containing pickled object and package requirements. Corresponds to the JSON property packageSpec



31085
31086
31087
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31085

def package_spec
  @package_spec
end

#service_accountString

Optional. The service account that the Reasoning Engine artifact runs as. It should have "roles/storage.objectViewer" for reading the user project's Cloud Storage and "roles/aiplatform.user" for using Vertex extensions. If not specified, the Vertex AI Reasoning Engine Service Agent in the project will be used. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


31094
31095
31096
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31094

def 
  @service_account
end

#source_code_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpec

Specification for deploying from source code. Corresponds to the JSON property sourceCodeSpec



31099
31100
31101
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31099

def source_code_spec
  @source_code_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31106
31107
31108
31109
31110
31111
31112
31113
31114
31115
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31106

def update!(**args)
  @agent_framework = args[:agent_framework] if args.key?(:agent_framework)
  @class_methods = args[:class_methods] if args.key?(:class_methods)
  @deployment_spec = args[:deployment_spec] if args.key?(:deployment_spec)
  @effective_identity = args[:effective_identity] if args.key?(:effective_identity)
  @identity_type = args[:identity_type] if args.key?(:identity_type)
  @package_spec = args[:package_spec] if args.key?(:package_spec)
  @service_account = args[:service_account] if args.key?(:service_account)
  @source_code_spec = args[:source_code_spec] if args.key?(:source_code_spec)
end