Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
ReasoningEngine configurations
Instance Attribute Summary collapse
-
#agent_framework ⇒ String
Optional.
-
#class_methods ⇒ Array<Hash<String,Object>>
Optional.
-
#deployment_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecDeploymentSpec
The specification of a Reasoning Engine deployment.
-
#package_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecPackageSpec
User provided package spec like pickled object and package requirements.
-
#service_account ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngineSpec
constructor
A new instance of GoogleCloudAiplatformV1ReasoningEngineSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngineSpec
Returns a new instance of GoogleCloudAiplatformV1ReasoningEngineSpec.
26285 26286 26287 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26285 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_framework ⇒ String
Optional. The OSS agent framework used to develop the agent. Currently
supported values: "google-adk", "langchain", "langgraph", "ag2", "llama-index",
"custom".
Corresponds to the JSON property agentFramework
26258 26259 26260 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26258 def agent_framework @agent_framework end |
#class_methods ⇒ Array<Hash<String,Object>>
Optional. Declarations for object class methods in OpenAPI specification
format.
Corresponds to the JSON property classMethods
26264 26265 26266 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26264 def class_methods @class_methods end |
#deployment_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecDeploymentSpec
The specification of a Reasoning Engine deployment.
Corresponds to the JSON property deploymentSpec
26269 26270 26271 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26269 def deployment_spec @deployment_spec end |
#package_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecPackageSpec
User provided package spec like pickled object and package requirements.
Corresponds to the JSON property packageSpec
26274 26275 26276 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26274 def package_spec @package_spec end |
#service_account ⇒ String
Optional. The service account that the Reasoning Engine artifact runs as. It
should have "roles/storage.objectViewer" for reading the user project's Cloud
Storage and "roles/aiplatform.user" for using Vertex extensions. If not
specified, the Vertex AI Reasoning Engine Service Agent in the project will be
used.
Corresponds to the JSON property serviceAccount
26283 26284 26285 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26283 def service_account @service_account end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26290 26291 26292 26293 26294 26295 26296 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26290 def update!(**args) @agent_framework = args[:agent_framework] if args.key?(:agent_framework) @class_methods = args[:class_methods] if args.key?(:class_methods) @deployment_spec = args[:deployment_spec] if args.key?(:deployment_spec) @package_spec = args[:package_spec] if args.key?(:package_spec) @service_account = args[:service_account] if args.key?(:service_account) end |