Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
ReasoningEngine configurations
Instance Attribute Summary collapse
-
#agent_framework ⇒ String
Optional.
-
#class_methods ⇒ Array<Hash<String,Object>>
Optional.
-
#deployment_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecDeploymentSpec
The specification of a Reasoning Engine deployment.
-
#package_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecPackageSpec
User provided package spec like pickled object and package requirements.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngineSpec
constructor
A new instance of GoogleCloudAiplatformV1ReasoningEngineSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngineSpec
Returns a new instance of GoogleCloudAiplatformV1ReasoningEngineSpec.
24614 24615 24616 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24614 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_framework ⇒ String
Optional. The OSS agent framework used to develop the agent. Currently
supported values: "langchain", "langgraph", "ag2", "custom".
Corresponds to the JSON property agentFramework
24596 24597 24598 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24596 def agent_framework @agent_framework end |
#class_methods ⇒ Array<Hash<String,Object>>
Optional. Declarations for object class methods in OpenAPI specification
format.
Corresponds to the JSON property classMethods
24602 24603 24604 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24602 def class_methods @class_methods end |
#deployment_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecDeploymentSpec
The specification of a Reasoning Engine deployment.
Corresponds to the JSON property deploymentSpec
24607 24608 24609 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24607 def deployment_spec @deployment_spec end |
#package_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecPackageSpec
User provided package spec like pickled object and package requirements.
Corresponds to the JSON property packageSpec
24612 24613 24614 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24612 def package_spec @package_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24619 24620 24621 24622 24623 24624 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24619 def update!(**args) @agent_framework = args[:agent_framework] if args.key?(:agent_framework) @class_methods = args[:class_methods] if args.key?(:class_methods) @deployment_spec = args[:deployment_spec] if args.key?(:deployment_spec) @package_spec = args[:package_spec] if args.key?(:package_spec) end |