Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
ReasoningEngine configurations
Instance Attribute Summary collapse
-
#class_methods ⇒ Array<Hash<String,Object>>
Optional.
-
#deployment_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecDeploymentSpec
The specification of a Reasoning Engine deployment.
-
#package_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecPackageSpec
User provided package spec like pickled object and package requirements.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngineSpec
constructor
A new instance of GoogleCloudAiplatformV1ReasoningEngineSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngineSpec
Returns a new instance of GoogleCloudAiplatformV1ReasoningEngineSpec.
24279 24280 24281 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24279 def initialize(**args) update!(**args) end |
Instance Attribute Details
#class_methods ⇒ Array<Hash<String,Object>>
Optional. Declarations for object class methods in OpenAPI specification
format.
Corresponds to the JSON property classMethods
24267 24268 24269 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24267 def class_methods @class_methods end |
#deployment_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecDeploymentSpec
The specification of a Reasoning Engine deployment.
Corresponds to the JSON property deploymentSpec
24272 24273 24274 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24272 def deployment_spec @deployment_spec end |
#package_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecPackageSpec
User provided package spec like pickled object and package requirements.
Corresponds to the JSON property packageSpec
24277 24278 24279 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24277 def package_spec @package_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24284 24285 24286 24287 24288 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24284 def update!(**args) @class_methods = args[:class_methods] if args.key?(:class_methods) @deployment_spec = args[:deployment_spec] if args.key?(:deployment_spec) @package_spec = args[:package_spec] if args.key?(:package_spec) end |