Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecDeploymentSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The specification of a Reasoning Engine deployment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngineSpecDeploymentSpec

Returns a new instance of GoogleCloudAiplatformV1ReasoningEngineSpecDeploymentSpec.



32461
32462
32463
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32461

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#container_concurrencyFixnum

Optional. Concurrency for each container and agent server. Recommended value: 2 * cpu + 1. Defaults to 9. Corresponds to the JSON property containerConcurrency

Returns:

  • (Fixnum)


32409
32410
32411
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32409

def container_concurrency
  @container_concurrency
end

#envArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EnvVar>

Optional. Environment variables to be set with the Reasoning Engine deployment. The environment variables can be updated through the UpdateReasoningEngine API. Corresponds to the JSON property env



32416
32417
32418
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32416

def env
  @env
end

#keep_alive_probeGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1KeepAliveProbe

Represents the configuration for keep-alive probe. Contains configuration on a specified endpoint that a deployment host should use to keep the container alive based on the probe settings. Corresponds to the JSON property keepAliveProbe



32423
32424
32425
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32423

def keep_alive_probe
  @keep_alive_probe
end

#max_instancesFixnum

Optional. The maximum number of application instances that can be launched to handle increased traffic. Defaults to 100. Range: [1, 1000]. If VPC-SC or PSC- I is enabled, the acceptable range is [1, 100]. Corresponds to the JSON property maxInstances

Returns:

  • (Fixnum)


32430
32431
32432
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32430

def max_instances
  @max_instances
end

#min_instancesFixnum

Optional. The minimum number of application instances that will be kept running at all times. Defaults to 1. Range: [0, 75]. Corresponds to the JSON property minInstances

Returns:

  • (Fixnum)


32436
32437
32438
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32436

def min_instances
  @min_instances
end

#psc_interface_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PscInterfaceConfig

Configuration for PSC-I. Corresponds to the JSON property pscInterfaceConfig



32441
32442
32443
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32441

def psc_interface_config
  @psc_interface_config
end

#resource_limitsHash<String,String>

Optional. Resource limits for each container. Only 'cpu' and 'memory' keys are supported. Defaults to "cpu": "4", "memory": "4Gi". * The only supported values for CPU are '1', '2', '4', '6' and '8'. For more information, go to https://cloud.google.com/run/docs/configuring/cpu. * The only supported values for memory are '1Gi', '2Gi', ... '32 Gi'. * For required cpu on different memory values, go to https://cloud.google.com/run/docs/configuring/memory- limits Corresponds to the JSON property resourceLimits

Returns:

  • (Hash<String,String>)


32452
32453
32454
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32452

def resource_limits
  @resource_limits
end

#secret_envArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SecretEnvVar>

Optional. Environment variables where the value is a secret in Cloud Secret Manager. To use this feature, add 'Secret Manager Secret Accessor' role (roles/ secretmanager.secretAccessor) to AI Platform Reasoning Engine Service Agent. Corresponds to the JSON property secretEnv



32459
32460
32461
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32459

def secret_env
  @secret_env
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32466
32467
32468
32469
32470
32471
32472
32473
32474
32475
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32466

def update!(**args)
  @container_concurrency = args[:container_concurrency] if args.key?(:container_concurrency)
  @env = args[:env] if args.key?(:env)
  @keep_alive_probe = args[:keep_alive_probe] if args.key?(:keep_alive_probe)
  @max_instances = args[:max_instances] if args.key?(:max_instances)
  @min_instances = args[:min_instances] if args.key?(:min_instances)
  @psc_interface_config = args[:psc_interface_config] if args.key?(:psc_interface_config)
  @resource_limits = args[:resource_limits] if args.key?(:resource_limits)
  @secret_env = args[:secret_env] if args.key?(:secret_env)
end