Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecDeploymentSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The specification of a Reasoning Engine deployment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngineSpecDeploymentSpec

Returns a new instance of GoogleCloudAiplatformV1ReasoningEngineSpecDeploymentSpec.



30888
30889
30890
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30888

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#container_concurrencyFixnum

Optional. Concurrency for each container and agent server. Recommended value: 2 * cpu + 1. Defaults to 9. Corresponds to the JSON property containerConcurrency

Returns:

  • (Fixnum)


30843
30844
30845
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30843

def container_concurrency
  @container_concurrency
end

#envArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EnvVar>

Optional. Environment variables to be set with the Reasoning Engine deployment. The environment variables can be updated through the UpdateReasoningEngine API. Corresponds to the JSON property env



30850
30851
30852
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30850

def env
  @env
end

#max_instancesFixnum

Optional. The maximum number of application instances that can be launched to handle increased traffic. Defaults to 100. Range: [1, 1000]. If VPC-SC or PSC- I is enabled, the acceptable range is [1, 100]. Corresponds to the JSON property maxInstances

Returns:

  • (Fixnum)


30857
30858
30859
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30857

def max_instances
  @max_instances
end

#min_instancesFixnum

Optional. The minimum number of application instances that will be kept running at all times. Defaults to 1. Range: [0, 10]. Corresponds to the JSON property minInstances

Returns:

  • (Fixnum)


30863
30864
30865
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30863

def min_instances
  @min_instances
end

#psc_interface_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PscInterfaceConfig

Configuration for PSC-I. Corresponds to the JSON property pscInterfaceConfig



30868
30869
30870
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30868

def psc_interface_config
  @psc_interface_config
end

#resource_limitsHash<String,String>

Optional. Resource limits for each container. Only 'cpu' and 'memory' keys are supported. Defaults to "cpu": "4", "memory": "4Gi". * The only supported values for CPU are '1', '2', '4', '6' and '8'. For more information, go to https://cloud.google.com/run/docs/configuring/cpu. * The only supported values for memory are '1Gi', '2Gi', ... '32 Gi'. * For required cpu on different memory values, go to https://cloud.google.com/run/docs/configuring/memory- limits Corresponds to the JSON property resourceLimits

Returns:

  • (Hash<String,String>)


30879
30880
30881
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30879

def resource_limits
  @resource_limits
end

#secret_envArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SecretEnvVar>

Optional. Environment variables where the value is a secret in Cloud Secret Manager. To use this feature, add 'Secret Manager Secret Accessor' role (roles/ secretmanager.secretAccessor) to AI Platform Reasoning Engine Service Agent. Corresponds to the JSON property secretEnv



30886
30887
30888
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30886

def secret_env
  @secret_env
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30893
30894
30895
30896
30897
30898
30899
30900
30901
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30893

def update!(**args)
  @container_concurrency = args[:container_concurrency] if args.key?(:container_concurrency)
  @env = args[:env] if args.key?(:env)
  @max_instances = args[:max_instances] if args.key?(:max_instances)
  @min_instances = args[:min_instances] if args.key?(:min_instances)
  @psc_interface_config = args[:psc_interface_config] if args.key?(:psc_interface_config)
  @resource_limits = args[:resource_limits] if args.key?(:resource_limits)
  @secret_env = args[:secret_env] if args.key?(:secret_env)
end