Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Specification for deploying from source code.
Instance Attribute Summary collapse
-
#agent_config_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecAgentConfigSource
Specification for the deploying from agent config.
-
#developer_connect_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecDeveloperConnectSource
Specifies source code to be fetched from a Git repository managed through the Developer Connect service.
-
#image_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecImageSpec
The image spec for building an image (within a single build step), based on the config file (i.e. Dockerfile) in the source directory.
-
#inline_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecInlineSource
Specifies source code provided as a byte stream.
-
#python_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecPythonSpec
Specification for running a Python application from source.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpec
constructor
A new instance of GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpec
Returns a new instance of GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpec.
32721 32722 32723 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32721 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_config_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecAgentConfigSource
Specification for the deploying from agent config.
Corresponds to the JSON property agentConfigSource
32697 32698 32699 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32697 def agent_config_source @agent_config_source end |
#developer_connect_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecDeveloperConnectSource
Specifies source code to be fetched from a Git repository managed through the
Developer Connect service.
Corresponds to the JSON property developerConnectSource
32703 32704 32705 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32703 def developer_connect_source @developer_connect_source end |
#image_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecImageSpec
The image spec for building an image (within a single build step), based on
the config file (i.e. Dockerfile) in the source directory.
Corresponds to the JSON property imageSpec
32709 32710 32711 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32709 def image_spec @image_spec end |
#inline_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecInlineSource
Specifies source code provided as a byte stream.
Corresponds to the JSON property inlineSource
32714 32715 32716 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32714 def inline_source @inline_source end |
#python_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecPythonSpec
Specification for running a Python application from source.
Corresponds to the JSON property pythonSpec
32719 32720 32721 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32719 def python_spec @python_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32726 32727 32728 32729 32730 32731 32732 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32726 def update!(**args) @agent_config_source = args[:agent_config_source] if args.key?(:agent_config_source) @developer_connect_source = args[:developer_connect_source] if args.key?(:developer_connect_source) @image_spec = args[:image_spec] if args.key?(:image_spec) @inline_source = args[:inline_source] if args.key?(:inline_source) @python_spec = args[:python_spec] if args.key?(:python_spec) end |