Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Specification for deploying from source code.
Instance Attribute Summary collapse
-
#developer_connect_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecDeveloperConnectSource
Specifies source code to be fetched from a Git repository managed through the Developer Connect service.
-
#inline_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecInlineSource
Specifies source code provided as a byte stream.
-
#python_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecPythonSpec
Specification for running a Python application from source.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpec
constructor
A new instance of GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpec
Returns a new instance of GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpec.
31246 31247 31248 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31246 def initialize(**args) update!(**args) end |
Instance Attribute Details
#developer_connect_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecDeveloperConnectSource
Specifies source code to be fetched from a Git repository managed through the
Developer Connect service.
Corresponds to the JSON property developerConnectSource
31234 31235 31236 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31234 def developer_connect_source @developer_connect_source end |
#inline_source ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecInlineSource
Specifies source code provided as a byte stream.
Corresponds to the JSON property inlineSource
31239 31240 31241 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31239 def inline_source @inline_source end |
#python_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecPythonSpec
Specification for running a Python application from source.
Corresponds to the JSON property pythonSpec
31244 31245 31246 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31244 def python_spec @python_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31251 31252 31253 31254 31255 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31251 def update!(**args) @developer_connect_source = args[:developer_connect_source] if args.key?(:developer_connect_source) @inline_source = args[:inline_source] if args.key?(:inline_source) @python_spec = args[:python_spec] if args.key?(:python_spec) end |