Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecDeveloperConnectSource
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecDeveloperConnectSource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Specifies source code to be fetched from a Git repository managed through the Developer Connect service.
Instance Attribute Summary collapse
-
#config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecDeveloperConnectConfig
Specifies the configuration for fetching source code from a Git repository that is managed by Developer Connect.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecDeveloperConnectSource
constructor
A new instance of GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecDeveloperConnectSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecDeveloperConnectSource
Returns a new instance of GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecDeveloperConnectSource.
31305 31306 31307 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31305 def initialize(**args) update!(**args) end |
Instance Attribute Details
#config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecDeveloperConnectConfig
Specifies the configuration for fetching source code from a Git repository
that is managed by Developer Connect. This includes the repository, revision,
and directory to use.
Corresponds to the JSON property config
31303 31304 31305 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31303 def config @config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31310 31311 31312 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31310 def update!(**args) @config = args[:config] if args.key?(:config) end |