Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecPythonSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecPythonSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Specification for running a Python application from source.
Instance Attribute Summary collapse
-
#entrypoint_module ⇒ String
Optional.
-
#entrypoint_object ⇒ String
Optional.
-
#requirements_file ⇒ String
Optional.
-
#version ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecPythonSpec
constructor
A new instance of GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecPythonSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecPythonSpec
Returns a new instance of GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecPythonSpec.
35646 35647 35648 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35646 def initialize(**args) update!(**args) end |
Instance Attribute Details
#entrypoint_module ⇒ String
Optional. The Python module to load as the entrypoint, specified as a fully
qualified module name. For example: path.to.agent. If not specified, defaults
to "agent". The project root will be added to Python sys.path, allowing
imports to be specified relative to the root. This field should not be set if
the source is agent_config_source.
Corresponds to the JSON property entrypointModule
35625 35626 35627 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35625 def entrypoint_module @entrypoint_module end |
#entrypoint_object ⇒ String
Optional. The name of the callable object within the entrypoint_module to
use as the application If not specified, defaults to "root_agent". This field
should not be set if the source is agent_config_source.
Corresponds to the JSON property entrypointObject
35632 35633 35634 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35632 def entrypoint_object @entrypoint_object end |
#requirements_file ⇒ String
Optional. The path to the requirements file, relative to the source root. If
not specified, defaults to "requirements.txt".
Corresponds to the JSON property requirementsFile
35638 35639 35640 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35638 def requirements_file @requirements_file end |
#version ⇒ String
Optional. The version of Python to use. Supported versions include 3.10, 3.11,
3.12, 3.13, 3.14. If not specified, default value is 3.10.
Corresponds to the JSON property version
35644 35645 35646 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35644 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35651 35652 35653 35654 35655 35656 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35651 def update!(**args) @entrypoint_module = args[:entrypoint_module] if args.key?(:entrypoint_module) @entrypoint_object = args[:entrypoint_object] if args.key?(:entrypoint_object) @requirements_file = args[:requirements_file] if args.key?(:requirements_file) @version = args[:version] if args.key?(:version) end |