Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecPythonSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Specification for running a Python application from source.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecPythonSpec

Returns a new instance of GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecPythonSpec.



34690
34691
34692
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34690

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#entrypoint_moduleString

Optional. The Python module to load as the entrypoint, specified as a fully qualified module name. For example: path.to.agent. If not specified, defaults to "agent". The project root will be added to Python sys.path, allowing imports to be specified relative to the root. This field should not be set if the source is agent_config_source. Corresponds to the JSON property entrypointModule

Returns:

  • (String)


34669
34670
34671
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34669

def entrypoint_module
  @entrypoint_module
end

#entrypoint_objectString

Optional. The name of the callable object within the entrypoint_module to use as the application If not specified, defaults to "root_agent". This field should not be set if the source is agent_config_source. Corresponds to the JSON property entrypointObject

Returns:

  • (String)


34676
34677
34678
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34676

def entrypoint_object
  @entrypoint_object
end

#requirements_fileString

Optional. The path to the requirements file, relative to the source root. If not specified, defaults to "requirements.txt". Corresponds to the JSON property requirementsFile

Returns:

  • (String)


34682
34683
34684
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34682

def requirements_file
  @requirements_file
end

#versionString

Optional. The version of Python to use. Supported versions include 3.10, 3.11, 3.12, 3.13, 3.14. If not specified, default value is 3.10. Corresponds to the JSON property version

Returns:

  • (String)


34688
34689
34690
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34688

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34695
34696
34697
34698
34699
34700
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34695

def update!(**args)
  @entrypoint_module = args[:entrypoint_module] if args.key?(:entrypoint_module)
  @entrypoint_object = args[:entrypoint_object] if args.key?(:entrypoint_object)
  @requirements_file = args[:requirements_file] if args.key?(:requirements_file)
  @version = args[:version] if args.key?(:version)
end