Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RebaseTunedModelRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for GenAiTuningService.RebaseTunedModel.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1RebaseTunedModelRequest

Returns a new instance of GoogleCloudAiplatformV1RebaseTunedModelRequest.



24385
24386
24387
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24385

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_destinationGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GcsDestination

The Google Cloud Storage location where the output is to be written to. Corresponds to the JSON property artifactDestination



24365
24366
24367
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24365

def artifact_destination
  @artifact_destination
end

#deploy_to_same_endpointBoolean Also known as: deploy_to_same_endpoint?

Optional. By default, bison to gemini migration will always create new model/ endpoint, but for gemini-1.0 to gemini-1.5 migration, we default deploy to the same endpoint. See details in this Section. Corresponds to the JSON property deployToSameEndpoint

Returns:

  • (Boolean)


24372
24373
24374
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24372

def deploy_to_same_endpoint
  @deploy_to_same_endpoint
end

#tuned_model_refGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TunedModelRef

TunedModel Reference for legacy model migration. Corresponds to the JSON property tunedModelRef



24378
24379
24380
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24378

def tuned_model_ref
  @tuned_model_ref
end

#tuning_jobGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TuningJob

Represents a TuningJob that runs with Google owned models. Corresponds to the JSON property tuningJob



24383
24384
24385
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24383

def tuning_job
  @tuning_job
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24390
24391
24392
24393
24394
24395
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24390

def update!(**args)
  @artifact_destination = args[:artifact_destination] if args.key?(:artifact_destination)
  @deploy_to_same_endpoint = args[:deploy_to_same_endpoint] if args.key?(:deploy_to_same_endpoint)
  @tuned_model_ref = args[:tuned_model_ref] if args.key?(:tuned_model_ref)
  @tuning_job = args[:tuning_job] if args.key?(:tuning_job)
end