Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReservationAffinity

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A ReservationAffinity can be used to configure a Vertex AI resource (e.g., a DeployedModel) to draw its Compute Engine resources from a Shared Reservation, or exclusively from on-demand capacity.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ReservationAffinity

Returns a new instance of GoogleCloudAiplatformV1ReservationAffinity.



26532
26533
26534
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26532

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#keyString

Optional. Corresponds to the label key of a reservation resource. To target a SPECIFIC_RESERVATION by name, use compute.googleapis.com/reservation-name as the key and specify the name of your reservation as its value. Corresponds to the JSON property key

Returns:

  • (String)


26519
26520
26521
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26519

def key
  @key
end

#reservation_affinity_typeString

Required. Specifies the reservation affinity type. Corresponds to the JSON property reservationAffinityType

Returns:

  • (String)


26524
26525
26526
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26524

def reservation_affinity_type
  @reservation_affinity_type
end

#valuesArray<String>

Optional. Corresponds to the label values of a reservation resource. This must be the full resource name of the reservation or reservation block. Corresponds to the JSON property values

Returns:

  • (Array<String>)


26530
26531
26532
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26530

def values
  @values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26537
26538
26539
26540
26541
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26537

def update!(**args)
  @key = args[:key] if args.key?(:key)
  @reservation_affinity_type = args[:reservation_affinity_type] if args.key?(:reservation_affinity_type)
  @values = args[:values] if args.key?(:values)
end