Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReservationAffinity
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReservationAffinity
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A ReservationAffinity can be used to configure a Vertex AI resource (e.g., a DeployedModel) to draw its Compute Engine resources from a Shared Reservation, or exclusively from on-demand capacity.
Instance Attribute Summary collapse
-
#key ⇒ String
Optional.
-
#reservation_affinity_type ⇒ String
Required.
-
#values ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ReservationAffinity
constructor
A new instance of GoogleCloudAiplatformV1ReservationAffinity.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ReservationAffinity
Returns a new instance of GoogleCloudAiplatformV1ReservationAffinity.
25642 25643 25644 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25642 def initialize(**args) update!(**args) end |
Instance Attribute Details
#key ⇒ String
Optional. Corresponds to the label key of a reservation resource. To target a
SPECIFIC_RESERVATION by name, use compute.googleapis.com/reservation-name as
the key and specify the name of your reservation as its value.
Corresponds to the JSON property key
25629 25630 25631 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25629 def key @key end |
#reservation_affinity_type ⇒ String
Required. Specifies the reservation affinity type.
Corresponds to the JSON property reservationAffinityType
25634 25635 25636 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25634 def reservation_affinity_type @reservation_affinity_type end |
#values ⇒ Array<String>
Optional. Corresponds to the label values of a reservation resource. This must
be the full resource name of the reservation or reservation block.
Corresponds to the JSON property values
25640 25641 25642 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25640 def values @values end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25647 25648 25649 25650 25651 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25647 def update!(**args) @key = args[:key] if args.key?(:key) @reservation_affinity_type = args[:reservation_affinity_type] if args.key?(:reservation_affinity_type) @values = args[:values] if args.key?(:values) end |