Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ReservationAffinity

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A ReservationAffinity can be used to configure a Vertex AI resource (e.g., a DeployedModel) to draw its Compute Engine resources from a Shared Reservation, or exclusively from on-demand capacity.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ReservationAffinity

Returns a new instance of GoogleCloudAiplatformV1ReservationAffinity.



23591
23592
23593
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23591

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#keyString

Optional. Corresponds to the label key of a reservation resource. To target a SPECIFIC_RESERVATION by name, use compute.googleapis.com/reservation-name as the key and specify the name of your reservation as its value. Corresponds to the JSON property key

Returns:

  • (String)


23578
23579
23580
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23578

def key
  @key
end

#reservation_affinity_typeString

Required. Specifies the reservation affinity type. Corresponds to the JSON property reservationAffinityType

Returns:

  • (String)


23583
23584
23585
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23583

def reservation_affinity_type
  @reservation_affinity_type
end

#valuesArray<String>

Optional. Corresponds to the label values of a reservation resource. This must be the full resource name of the reservation. Corresponds to the JSON property values

Returns:

  • (Array<String>)


23589
23590
23591
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23589

def values
  @values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23596
23597
23598
23599
23600
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23596

def update!(**args)
  @key = args[:key] if args.key?(:key)
  @reservation_affinity_type = args[:reservation_affinity_type] if args.key?(:reservation_affinity_type)
  @values = args[:values] if args.key?(:values)
end