Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ResourcePool

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents the spec of a group of resources of the same type, for example machine type, disk, and accelerators, in a PersistentResource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ResourcePool

Returns a new instance of GoogleCloudAiplatformV1ResourcePool.



34504
34505
34506
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34504

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#autoscaling_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ResourcePoolAutoscalingSpec

The min/max number of replicas allowed if enabling autoscaling Corresponds to the JSON property autoscalingSpec



34474
34475
34476
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34474

def autoscaling_spec
  @autoscaling_spec
end

#disk_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1DiskSpec

Represents the spec of disk options. Corresponds to the JSON property diskSpec



34479
34480
34481
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34479

def disk_spec
  @disk_spec
end

#idString

Immutable. The unique ID in a PersistentResource for referring to this resource pool. User can specify it if necessary. Otherwise, it's generated automatically. Corresponds to the JSON property id

Returns:

  • (String)


34486
34487
34488
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34486

def id
  @id
end

#machine_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1MachineSpec

Specification of a single machine. Corresponds to the JSON property machineSpec



34491
34492
34493
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34491

def machine_spec
  @machine_spec
end

#replica_countFixnum

Optional. The total number of machines to use for this resource pool. Corresponds to the JSON property replicaCount

Returns:

  • (Fixnum)


34496
34497
34498
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34496

def replica_count
  @replica_count
end

#used_replica_countFixnum

Output only. The number of machines currently in use by training jobs for this resource pool. Will replace idle_replica_count. Corresponds to the JSON property usedReplicaCount

Returns:

  • (Fixnum)


34502
34503
34504
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34502

def used_replica_count
  @used_replica_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34509
34510
34511
34512
34513
34514
34515
34516
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34509

def update!(**args)
  @autoscaling_spec = args[:autoscaling_spec] if args.key?(:autoscaling_spec)
  @disk_spec = args[:disk_spec] if args.key?(:disk_spec)
  @id = args[:id] if args.key?(:id)
  @machine_spec = args[:machine_spec] if args.key?(:machine_spec)
  @replica_count = args[:replica_count] if args.key?(:replica_count)
  @used_replica_count = args[:used_replica_count] if args.key?(:used_replica_count)
end