Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ResourcePool
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ResourcePool
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Represents the spec of a group of resources of the same type, for example machine type, disk, and accelerators, in a PersistentResource.
Instance Attribute Summary collapse
-
#autoscaling_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ResourcePoolAutoscalingSpec
The min/max number of replicas allowed if enabling autoscaling Corresponds to the JSON property
autoscalingSpec. -
#disk_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DiskSpec
Represents the spec of disk options.
-
#id ⇒ String
Immutable.
-
#machine_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MachineSpec
Specification of a single machine.
-
#replica_count ⇒ Fixnum
Optional.
-
#used_replica_count ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ResourcePool
constructor
A new instance of GoogleCloudAiplatformV1ResourcePool.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ResourcePool
Returns a new instance of GoogleCloudAiplatformV1ResourcePool.
24910 24911 24912 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24910 def initialize(**args) update!(**args) end |
Instance Attribute Details
#autoscaling_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ResourcePoolAutoscalingSpec
The min/max number of replicas allowed if enabling autoscaling
Corresponds to the JSON property autoscalingSpec
24880 24881 24882 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24880 def autoscaling_spec @autoscaling_spec end |
#disk_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DiskSpec
Represents the spec of disk options.
Corresponds to the JSON property diskSpec
24885 24886 24887 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24885 def disk_spec @disk_spec end |
#id ⇒ String
Immutable. The unique ID in a PersistentResource for referring to this
resource pool. User can specify it if necessary. Otherwise, it's generated
automatically.
Corresponds to the JSON property id
24892 24893 24894 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24892 def id @id end |
#machine_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MachineSpec
Specification of a single machine.
Corresponds to the JSON property machineSpec
24897 24898 24899 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24897 def machine_spec @machine_spec end |
#replica_count ⇒ Fixnum
Optional. The total number of machines to use for this resource pool.
Corresponds to the JSON property replicaCount
24902 24903 24904 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24902 def replica_count @replica_count end |
#used_replica_count ⇒ Fixnum
Output only. The number of machines currently in use by training jobs for this
resource pool. Will replace idle_replica_count.
Corresponds to the JSON property usedReplicaCount
24908 24909 24910 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24908 def used_replica_count @used_replica_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24915 24916 24917 24918 24919 24920 24921 24922 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24915 def update!(**args) @autoscaling_spec = args[:autoscaling_spec] if args.key?(:autoscaling_spec) @disk_spec = args[:disk_spec] if args.key?(:disk_spec) @id = args[:id] if args.key?(:id) @machine_spec = args[:machine_spec] if args.key?(:machine_spec) @replica_count = args[:replica_count] if args.key?(:replica_count) @used_replica_count = args[:used_replica_count] if args.key?(:used_replica_count) end |