Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ResourcePool
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ResourcePool
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Represents the spec of a group of resources of the same type, for example machine type, disk, and accelerators, in a PersistentResource.
Instance Attribute Summary collapse
-
#autoscaling_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ResourcePoolAutoscalingSpec
The min/max number of replicas allowed if enabling autoscaling Corresponds to the JSON property
autoscalingSpec. -
#disk_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DiskSpec
Represents the spec of disk options.
-
#id ⇒ String
Immutable.
-
#machine_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MachineSpec
Specification of a single machine.
-
#replica_count ⇒ Fixnum
Optional.
-
#used_replica_count ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ResourcePool
constructor
A new instance of GoogleCloudAiplatformV1ResourcePool.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ResourcePool
Returns a new instance of GoogleCloudAiplatformV1ResourcePool.
21479 21480 21481 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21479 def initialize(**args) update!(**args) end |
Instance Attribute Details
#autoscaling_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ResourcePoolAutoscalingSpec
The min/max number of replicas allowed if enabling autoscaling
Corresponds to the JSON property autoscalingSpec
21449 21450 21451 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21449 def autoscaling_spec @autoscaling_spec end |
#disk_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DiskSpec
Represents the spec of disk options.
Corresponds to the JSON property diskSpec
21454 21455 21456 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21454 def disk_spec @disk_spec end |
#id ⇒ String
Immutable. The unique ID in a PersistentResource for referring to this
resource pool. User can specify it if necessary. Otherwise, it's generated
automatically.
Corresponds to the JSON property id
21461 21462 21463 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21461 def id @id end |
#machine_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MachineSpec
Specification of a single machine.
Corresponds to the JSON property machineSpec
21466 21467 21468 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21466 def machine_spec @machine_spec end |
#replica_count ⇒ Fixnum
Optional. The total number of machines to use for this resource pool.
Corresponds to the JSON property replicaCount
21471 21472 21473 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21471 def replica_count @replica_count end |
#used_replica_count ⇒ Fixnum
Output only. The number of machines currently in use by training jobs for this
resource pool. Will replace idle_replica_count.
Corresponds to the JSON property usedReplicaCount
21477 21478 21479 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21477 def used_replica_count @used_replica_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21484 21485 21486 21487 21488 21489 21490 21491 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21484 def update!(**args) @autoscaling_spec = args[:autoscaling_spec] if args.key?(:autoscaling_spec) @disk_spec = args[:disk_spec] if args.key?(:disk_spec) @id = args[:id] if args.key?(:id) @machine_spec = args[:machine_spec] if args.key?(:machine_spec) @replica_count = args[:replica_count] if args.key?(:replica_count) @used_replica_count = args[:used_replica_count] if args.key?(:used_replica_count) end |