Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ResourcesConsumed
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ResourcesConsumed
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Statistics information about resource consumption.
Instance Attribute Summary collapse
-
#replica_hours ⇒ Float
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ResourcesConsumed
constructor
A new instance of GoogleCloudAiplatformV1ResourcesConsumed.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ResourcesConsumed
Returns a new instance of GoogleCloudAiplatformV1ResourcesConsumed.
33160 33161 33162 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33160 def initialize(**args) update!(**args) end |
Instance Attribute Details
#replica_hours ⇒ Float
Output only. The number of replica hours used. Note that many replicas may run
in parallel, and additionally any given work may be queued for some time.
Therefore this value is not strictly related to wall time.
Corresponds to the JSON property replicaHours
33158 33159 33160 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33158 def replica_hours @replica_hours end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33165 33166 33167 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33165 def update!(**args) @replica_hours = args[:replica_hours] if args.key?(:replica_hours) end |