Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ResourcesConsumed

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Statistics information about resource consumption.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ResourcesConsumed

Returns a new instance of GoogleCloudAiplatformV1ResourcesConsumed.



33056
33057
33058
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33056

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#replica_hoursFloat

Output only. The number of replica hours used. Note that many replicas may run in parallel, and additionally any given work may be queued for some time. Therefore this value is not strictly related to wall time. Corresponds to the JSON property replicaHours

Returns:

  • (Float)


33054
33055
33056
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33054

def replica_hours
  @replica_hours
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33061
33062
33063
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33061

def update!(**args)
  @replica_hours = args[:replica_hours] if args.key?(:replica_hours)
end