Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ResumeScheduleRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ResumeScheduleRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Request message for ScheduleService.ResumeSchedule.
Instance Attribute Summary collapse
-
#catch_up ⇒ Boolean
(also: #catch_up?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ResumeScheduleRequest
constructor
A new instance of GoogleCloudAiplatformV1ResumeScheduleRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ResumeScheduleRequest
Returns a new instance of GoogleCloudAiplatformV1ResumeScheduleRequest.
25073 25074 25075 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25073 def initialize(**args) update!(**args) end |
Instance Attribute Details
#catch_up ⇒ Boolean Also known as: catch_up?
Optional. Whether to backfill missed runs when the schedule is resumed from
PAUSED state. If set to true, all missed runs will be scheduled. New runs will
be scheduled after the backfill is complete. This will also update Schedule.
catch_up field. Default to false.
Corresponds to the JSON property catchUp
25070 25071 25072 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25070 def catch_up @catch_up end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25078 25079 25080 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25078 def update!(**args) @catch_up = args[:catch_up] if args.key?(:catch_up) end |