Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ResumeScheduleRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for ScheduleService.ResumeSchedule.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ResumeScheduleRequest

Returns a new instance of GoogleCloudAiplatformV1ResumeScheduleRequest.



18934
18935
18936
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18934

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#catch_upBoolean Also known as: catch_up?

Optional. Whether to backfill missed runs when the schedule is resumed from PAUSED state. If set to true, all missed runs will be scheduled. New runs will be scheduled after the backfill is complete. This will also update Schedule. catch_up field. Default to false. Corresponds to the JSON property catchUp

Returns:

  • (Boolean)


18931
18932
18933
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18931

def catch_up
  @catch_up
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18939
18940
18941
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18939

def update!(**args)
  @catch_up = args[:catch_up] if args.key?(:catch_up)
end