Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Retrieval
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Retrieval
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Defines a retrieval tool that model can call to access external knowledge.
Instance Attribute Summary collapse
-
#disable_attribution ⇒ Boolean
(also: #disable_attribution?)
Optional.
-
#external_api ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExternalApi
Retrieve from data source powered by external API for grounding.
-
#vertex_ai_search ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexAiSearch
Retrieve from Vertex AI Search datastore or engine for grounding.
-
#vertex_rag_store ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexRagStore
Retrieve from Vertex RAG Store for grounding.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Retrieval
constructor
A new instance of GoogleCloudAiplatformV1Retrieval.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Retrieval
Returns a new instance of GoogleCloudAiplatformV1Retrieval.
33149 33150 33151 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33149 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disable_attribution ⇒ Boolean Also known as: disable_attribution?
Optional. Deprecated. This option is no longer supported.
Corresponds to the JSON property disableAttribution
33128 33129 33130 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33128 def disable_attribution @disable_attribution end |
#external_api ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ExternalApi
Retrieve from data source powered by external API for grounding. The external
API is not owned by Google, but need to follow the pre-defined API spec.
Corresponds to the JSON property externalApi
33135 33136 33137 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33135 def external_api @external_api end |
#vertex_ai_search ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexAiSearch
Retrieve from Vertex AI Search datastore or engine for grounding. datastore
and engine are mutually exclusive. See https://cloud.google.com/products/agent-
builder
Corresponds to the JSON property vertexAiSearch
33142 33143 33144 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33142 def vertex_ai_search @vertex_ai_search end |
#vertex_rag_store ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexRagStore
Retrieve from Vertex RAG Store for grounding.
Corresponds to the JSON property vertexRagStore
33147 33148 33149 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33147 def vertex_rag_store @vertex_rag_store end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33154 33155 33156 33157 33158 33159 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33154 def update!(**args) @disable_attribution = args[:disable_attribution] if args.key?(:disable_attribution) @external_api = args[:external_api] if args.key?(:external_api) @vertex_ai_search = args[:vertex_ai_search] if args.key?(:vertex_ai_search) @vertex_rag_store = args[:vertex_rag_store] if args.key?(:vertex_rag_store) end |