Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Retrieval

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Defines a retrieval tool that model can call to access external knowledge.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Retrieval

Returns a new instance of GoogleCloudAiplatformV1Retrieval.



20006
20007
20008
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20006

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disable_attributionBoolean Also known as: disable_attribution?

Optional. Disable using the result from this tool in detecting grounding attribution. This does not affect how the result is given to the model for generation. Corresponds to the JSON property disableAttribution

Returns:

  • (Boolean)


19997
19998
19999
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19997

def disable_attribution
  @disable_attribution
end

#vertex_ai_searchGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexAiSearch

Retrieve from Vertex AI Search datastore for grounding. See https://cloud. google.com/vertex-ai-search-and-conversation Corresponds to the JSON property vertexAiSearch



20004
20005
20006
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20004

def vertex_ai_search
  @vertex_ai_search
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20011
20012
20013
20014
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20011

def update!(**args)
  @disable_attribution = args[:disable_attribution] if args.key?(:disable_attribution)
  @vertex_ai_search = args[:vertex_ai_search] if args.key?(:vertex_ai_search)
end