Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Retrieval
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Retrieval
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Defines a retrieval tool that model can call to access external knowledge.
Instance Attribute Summary collapse
-
#disable_attribution ⇒ Boolean
(also: #disable_attribution?)
Optional.
-
#vertex_ai_search ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexAiSearch
Retrieve from Vertex AI Search datastore for grounding.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Retrieval
constructor
A new instance of GoogleCloudAiplatformV1Retrieval.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Retrieval
Returns a new instance of GoogleCloudAiplatformV1Retrieval.
18144 18145 18146 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18144 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disable_attribution ⇒ Boolean Also known as: disable_attribution?
Optional. Disable using the result from this tool in detecting grounding
attribution. This does not affect how the result is given to the model for
generation.
Corresponds to the JSON property disableAttribution
18135 18136 18137 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18135 def disable_attribution @disable_attribution end |
#vertex_ai_search ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexAiSearch
Retrieve from Vertex AI Search datastore for grounding. See https://cloud.
google.com/vertex-ai-search-and-conversation
Corresponds to the JSON property vertexAiSearch
18142 18143 18144 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18142 def vertex_ai_search @vertex_ai_search end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18149 18150 18151 18152 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18149 def update!(**args) @disable_attribution = args[:disable_attribution] if args.key?(:disable_attribution) @vertex_ai_search = args[:vertex_ai_search] if args.key?(:vertex_ai_search) end |