Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrievalConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Retrieval config.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1RetrievalConfig

Returns a new instance of GoogleCloudAiplatformV1RetrievalConfig.



33226
33227
33228
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33226

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#language_codeString

The language code of the user. Corresponds to the JSON property languageCode

Returns:

  • (String)


33216
33217
33218
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33216

def language_code
  @language_code
end

#lat_lngGoogle::Apis::AiplatformV1::GoogleTypeLatLng

An object that represents a latitude/longitude pair. This is expressed as a pair of doubles to represent degrees latitude and degrees longitude. Unless specified otherwise, this object must conform to the WGS84 standard. Values must be within normalized ranges. Corresponds to the JSON property latLng



33224
33225
33226
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33224

def lat_lng
  @lat_lng
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33231
33232
33233
33234
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33231

def update!(**args)
  @language_code = args[:language_code] if args.key?(:language_code)
  @lat_lng = args[:lat_lng] if args.key?(:lat_lng)
end