Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrievalConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrievalConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Retrieval config.
Instance Attribute Summary collapse
-
#language_code ⇒ String
The language code of the user.
-
#lat_lng ⇒ Google::Apis::AiplatformV1::GoogleTypeLatLng
An object that represents a latitude/longitude pair.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1RetrievalConfig
constructor
A new instance of GoogleCloudAiplatformV1RetrievalConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1RetrievalConfig
Returns a new instance of GoogleCloudAiplatformV1RetrievalConfig.
26403 26404 26405 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26403 def initialize(**args) update!(**args) end |
Instance Attribute Details
#language_code ⇒ String
The language code of the user.
Corresponds to the JSON property languageCode
26393 26394 26395 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26393 def language_code @language_code end |
#lat_lng ⇒ Google::Apis::AiplatformV1::GoogleTypeLatLng
An object that represents a latitude/longitude pair. This is expressed as a
pair of doubles to represent degrees latitude and degrees longitude. Unless
specified otherwise, this object must conform to the WGS84 standard. Values
must be within normalized ranges.
Corresponds to the JSON property latLng
26401 26402 26403 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26401 def lat_lng @lat_lng end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26408 26409 26410 26411 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26408 def update!(**args) @language_code = args[:language_code] if args.key?(:language_code) @lat_lng = args[:lat_lng] if args.key?(:lat_lng) end |