Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrievalConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrievalConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Retrieval config.
Instance Attribute Summary collapse
-
#language_code ⇒ String
The language code of the user.
-
#lat_lng ⇒ Google::Apis::AiplatformV1::GoogleTypeLatLng
An object that represents a latitude/longitude pair.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1RetrievalConfig
constructor
A new instance of GoogleCloudAiplatformV1RetrievalConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1RetrievalConfig
Returns a new instance of GoogleCloudAiplatformV1RetrievalConfig.
25134 25135 25136 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25134 def initialize(**args) update!(**args) end |
Instance Attribute Details
#language_code ⇒ String
The language code of the user.
Corresponds to the JSON property languageCode
25124 25125 25126 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25124 def language_code @language_code end |
#lat_lng ⇒ Google::Apis::AiplatformV1::GoogleTypeLatLng
An object that represents a latitude/longitude pair. This is expressed as a
pair of doubles to represent degrees latitude and degrees longitude. Unless
specified otherwise, this object must conform to the WGS84 standard. Values
must be within normalized ranges.
Corresponds to the JSON property latLng
25132 25133 25134 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25132 def lat_lng @lat_lng end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25139 25140 25141 25142 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25139 def update!(**args) @language_code = args[:language_code] if args.key?(:language_code) @lat_lng = args[:lat_lng] if args.key?(:lat_lng) end |