Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrievalMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrievalMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Metadata related to retrieval in the grounding flow.
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1RetrievalMetadata
constructor
A new instance of GoogleCloudAiplatformV1RetrievalMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1RetrievalMetadata
Returns a new instance of GoogleCloudAiplatformV1RetrievalMetadata.
25005 25006 25007 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25005 def initialize(**args) update!(**args) end |
Instance Attribute Details
#google_search_dynamic_retrieval_score ⇒ Float
Optional. Score indicating how likely information from Google Search could
help answer the prompt. The score is in the range [0, 1], where 0 is the
least likely and 1 is the most likely. This score is only populated when
Google Search grounding and dynamic retrieval is enabled. It will be compared
to the threshold to determine whether to trigger Google Search.
Corresponds to the JSON property googleSearchDynamicRetrievalScore
25003 25004 25005 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25003 def google_search_dynamic_retrieval_score @google_search_dynamic_retrieval_score end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25010 25011 25012 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25010 def update!(**args) @google_search_dynamic_retrieval_score = args[:google_search_dynamic_retrieval_score] if args.key?(:google_search_dynamic_retrieval_score) end |