Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrieveContextsRequestVertexRagStore

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The data source for Vertex RagStore.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1RetrieveContextsRequestVertexRagStore

Returns a new instance of GoogleCloudAiplatformV1RetrieveContextsRequestVertexRagStore.



35293
35294
35295
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35293

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#rag_resourcesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrieveContextsRequestVertexRagStoreRagResource>

Optional. The representation of the rag source. It can be used to specify corpus only or ragfiles. Currently only support one corpus or multiple files from one corpus. In the future we may open up multiple corpora support. Corresponds to the JSON property ragResources



35286
35287
35288
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35286

def rag_resources
  @rag_resources
end

#vector_distance_thresholdFloat

Optional. Only return contexts with vector distance smaller than the threshold. Corresponds to the JSON property vectorDistanceThreshold

Returns:

  • (Float)


35291
35292
35293
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35291

def vector_distance_threshold
  @vector_distance_threshold
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35298
35299
35300
35301
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35298

def update!(**args)
  @rag_resources = args[:rag_resources] if args.key?(:rag_resources)
  @vector_distance_threshold = args[:vector_distance_threshold] if args.key?(:vector_distance_threshold)
end