Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrieveContextsRequestVertexRagStore

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The data source for Vertex RagStore.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1RetrieveContextsRequestVertexRagStore

Returns a new instance of GoogleCloudAiplatformV1RetrieveContextsRequestVertexRagStore.



26333
26334
26335
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26333

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#rag_resourcesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrieveContextsRequestVertexRagStoreRagResource>

Optional. The representation of the rag source. It can be used to specify corpus only or ragfiles. Currently only support one corpus or multiple files from one corpus. In the future we may open up multiple corpora support. Corresponds to the JSON property ragResources



26326
26327
26328
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26326

def rag_resources
  @rag_resources
end

#vector_distance_thresholdFloat

Optional. Only return contexts with vector distance smaller than the threshold. Corresponds to the JSON property vectorDistanceThreshold

Returns:

  • (Float)


26331
26332
26333
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26331

def vector_distance_threshold
  @vector_distance_threshold
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26338
26339
26340
26341
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26338

def update!(**args)
  @rag_resources = args[:rag_resources] if args.key?(:rag_resources)
  @vector_distance_threshold = args[:vector_distance_threshold] if args.key?(:vector_distance_threshold)
end