Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrieveContextsRequestVertexRagStore

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The data source for Vertex RagStore.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1RetrieveContextsRequestVertexRagStore

Returns a new instance of GoogleCloudAiplatformV1RetrieveContextsRequestVertexRagStore.



26006
26007
26008
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26006

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#rag_resourcesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrieveContextsRequestVertexRagStoreRagResource>

Optional. The representation of the rag source. It can be used to specify corpus only or ragfiles. Currently only support one corpus or multiple files from one corpus. In the future we may open up multiple corpora support. Corresponds to the JSON property ragResources



25999
26000
26001
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25999

def rag_resources
  @rag_resources
end

#vector_distance_thresholdFloat

Optional. Only return contexts with vector distance smaller than the threshold. Corresponds to the JSON property vectorDistanceThreshold

Returns:

  • (Float)


26004
26005
26006
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26004

def vector_distance_threshold
  @vector_distance_threshold
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26011
26012
26013
26014
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26011

def update!(**args)
  @rag_resources = args[:rag_resources] if args.key?(:rag_resources)
  @vector_distance_threshold = args[:vector_distance_threshold] if args.key?(:vector_distance_threshold)
end