Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrieveContextsRequestVertexRagStore
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrieveContextsRequestVertexRagStore
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The data source for Vertex RagStore.
Instance Attribute Summary collapse
-
#rag_resources ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrieveContextsRequestVertexRagStoreRagResource>
Optional.
-
#vector_distance_threshold ⇒ Float
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1RetrieveContextsRequestVertexRagStore
constructor
A new instance of GoogleCloudAiplatformV1RetrieveContextsRequestVertexRagStore.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1RetrieveContextsRequestVertexRagStore
Returns a new instance of GoogleCloudAiplatformV1RetrieveContextsRequestVertexRagStore.
25401 25402 25403 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25401 def initialize(**args) update!(**args) end |
Instance Attribute Details
#rag_resources ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrieveContextsRequestVertexRagStoreRagResource>
Optional. The representation of the rag source. It can be used to specify
corpus only or ragfiles. Currently only support one corpus or multiple files
from one corpus. In the future we may open up multiple corpora support.
Corresponds to the JSON property ragResources
25394 25395 25396 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25394 def rag_resources @rag_resources end |
#vector_distance_threshold ⇒ Float
Optional. Only return contexts with vector distance smaller than the threshold.
Corresponds to the JSON property vectorDistanceThreshold
25399 25400 25401 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25399 def vector_distance_threshold @vector_distance_threshold end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25406 25407 25408 25409 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25406 def update!(**args) @rag_resources = args[:rag_resources] if args.key?(:rag_resources) @vector_distance_threshold = args[:vector_distance_threshold] if args.key?(:vector_distance_threshold) end |