Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrieveMemoriesRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrieveMemoriesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Request message for MemoryBankService.RetrieveMemories.
Instance Attribute Summary collapse
-
#filter ⇒ String
Optional.
-
#filter_groups ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryConjunctionFilter>
Optional.
-
#memory_types ⇒ Array<String>
Optional.
-
#scope ⇒ Hash<String,String>
Required.
-
#similarity_search_params ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrieveMemoriesRequestSimilaritySearchParams
Parameters for semantic similarity search based retrieval.
-
#simple_retrieval_params ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrieveMemoriesRequestSimpleRetrievalParams
Parameters for simple (non-similarity search) retrieval.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1RetrieveMemoriesRequest
constructor
A new instance of GoogleCloudAiplatformV1RetrieveMemoriesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1RetrieveMemoriesRequest
Returns a new instance of GoogleCloudAiplatformV1RetrieveMemoriesRequest.
33363 33364 33365 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33363 def initialize(**args) update!(**args) end |
Instance Attribute Details
#filter ⇒ String
Optional. The standard list filter that will be applied to the retrieved
memories. More detail in AIP-160. Supported
fields: * fact * create_time * update_time * topics (i.e. topics.
custom_memory_topic_label: "example topic" OR topics.managed_memory_topic:
USER_PREFERENCES)
Corresponds to the JSON property filter
33324 33325 33326 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33324 def filter @filter end |
#filter_groups ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryConjunctionFilter>
Optional. Metadata filters that will be applied to the retrieved memories'
metadata using OR logic. Filters are defined using disjunctive normal form (
OR of ANDs). For example: filter_groups: [filters: [key: "author", value:
string_value: "agent 123", op: EQUAL],filters: [key: "label", value:
string_value: "travel", op: EQUAL, key: "author", value:string_value: "
agent 321", op: EQUAL]] would be equivalent to the logical expression: (
metadata.author = "agent 123" OR (metadata.label = "travel" AND metadata.
author = "agent 321")).
Corresponds to the JSON property filterGroups
33336 33337 33338 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33336 def filter_groups @filter_groups end |
#memory_types ⇒ Array<String>
Optional. Specifies the types of memories to retrieve. If this field is empty
or not provided, the request will default to retrieving only memories of type
NATURAL_LANGUAGE_COLLECTION. If populated, the request will retrieve memories
matching any of the specified MemoryType values.
Corresponds to the JSON property memoryTypes
33344 33345 33346 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33344 def memory_types @memory_types end |
#scope ⇒ Hash<String,String>
Required. The scope of the memories to retrieve. A memory must have exactly
the same scope (Memory.scope) as the scope provided here to be retrieved (
same keys and values). Order does not matter, but it is case-sensitive.
Corresponds to the JSON property scope
33351 33352 33353 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33351 def scope @scope end |
#similarity_search_params ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrieveMemoriesRequestSimilaritySearchParams
Parameters for semantic similarity search based retrieval.
Corresponds to the JSON property similaritySearchParams
33356 33357 33358 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33356 def similarity_search_params @similarity_search_params end |
#simple_retrieval_params ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrieveMemoriesRequestSimpleRetrievalParams
Parameters for simple (non-similarity search) retrieval.
Corresponds to the JSON property simpleRetrievalParams
33361 33362 33363 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33361 def simple_retrieval_params @simple_retrieval_params end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33368 33369 33370 33371 33372 33373 33374 33375 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33368 def update!(**args) @filter = args[:filter] if args.key?(:filter) @filter_groups = args[:filter_groups] if args.key?(:filter_groups) @memory_types = args[:memory_types] if args.key?(:memory_types) @scope = args[:scope] if args.key?(:scope) @similarity_search_params = args[:similarity_search_params] if args.key?(:similarity_search_params) @simple_retrieval_params = args[:simple_retrieval_params] if args.key?(:simple_retrieval_params) end |