Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrieveMemoriesRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrieveMemoriesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Request message for MemoryBankService.RetrieveMemories.
Instance Attribute Summary collapse
-
#filter ⇒ String
Optional.
-
#filter_groups ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryConjunctionFilter>
Optional.
-
#scope ⇒ Hash<String,String>
Required.
-
#similarity_search_params ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrieveMemoriesRequestSimilaritySearchParams
Parameters for semantic similarity search based retrieval.
-
#simple_retrieval_params ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrieveMemoriesRequestSimpleRetrievalParams
Parameters for simple (non-similarity search) retrieval.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1RetrieveMemoriesRequest
constructor
A new instance of GoogleCloudAiplatformV1RetrieveMemoriesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1RetrieveMemoriesRequest
Returns a new instance of GoogleCloudAiplatformV1RetrieveMemoriesRequest.
32033 32034 32035 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32033 def initialize(**args) update!(**args) end |
Instance Attribute Details
#filter ⇒ String
Optional. The standard list filter that will be applied to the retrieved
memories. More detail in AIP-160. Supported
fields: * fact * create_time * update_time * topics (i.e. topics.
custom_memory_topic_label: "example topic" OR topics.managed_memory_topic:
USER_PREFERENCES)
Corresponds to the JSON property filter
32002 32003 32004 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32002 def filter @filter end |
#filter_groups ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryConjunctionFilter>
Optional. Metadata filters that will be applied to the retrieved memories'
metadata using OR logic. Filters are defined using disjunctive normal form (
OR of ANDs). For example: filter_groups: [filters: [key: "author", value:
string_value: "agent 123", op: EQUAL],filters: [key: "label", value:
string_value: "travel", op: EQUAL, key: "author", value:string_value: "
agent 321", op: EQUAL]] would be equivalent to the logical expression: (
metadata.author = "agent 123" OR (metadata.label = "travel" AND metadata.
author = "agent 321")).
Corresponds to the JSON property filterGroups
32014 32015 32016 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32014 def filter_groups @filter_groups end |
#scope ⇒ Hash<String,String>
Required. The scope of the memories to retrieve. A memory must have exactly
the same scope (Memory.scope) as the scope provided here to be retrieved (
same keys and values). Order does not matter, but it is case-sensitive.
Corresponds to the JSON property scope
32021 32022 32023 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32021 def scope @scope end |
#similarity_search_params ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrieveMemoriesRequestSimilaritySearchParams
Parameters for semantic similarity search based retrieval.
Corresponds to the JSON property similaritySearchParams
32026 32027 32028 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32026 def similarity_search_params @similarity_search_params end |
#simple_retrieval_params ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrieveMemoriesRequestSimpleRetrievalParams
Parameters for simple (non-similarity search) retrieval.
Corresponds to the JSON property simpleRetrievalParams
32031 32032 32033 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32031 def simple_retrieval_params @simple_retrieval_params end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32038 32039 32040 32041 32042 32043 32044 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32038 def update!(**args) @filter = args[:filter] if args.key?(:filter) @filter_groups = args[:filter_groups] if args.key?(:filter_groups) @scope = args[:scope] if args.key?(:scope) @similarity_search_params = args[:similarity_search_params] if args.key?(:similarity_search_params) @simple_retrieval_params = args[:simple_retrieval_params] if args.key?(:simple_retrieval_params) end |