Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrieveMemoriesRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrieveMemoriesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Request message for MemoryBankService.RetrieveMemories.
Instance Attribute Summary collapse
-
#filter ⇒ String
Optional.
-
#filter_groups ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryConjunctionFilter>
Optional.
-
#scope ⇒ Hash<String,String>
Required.
-
#similarity_search_params ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrieveMemoriesRequestSimilaritySearchParams
Parameters for semantic similarity search based retrieval.
-
#simple_retrieval_params ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrieveMemoriesRequestSimpleRetrievalParams
Parameters for simple (non-similarity search) retrieval.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1RetrieveMemoriesRequest
constructor
A new instance of GoogleCloudAiplatformV1RetrieveMemoriesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1RetrieveMemoriesRequest
Returns a new instance of GoogleCloudAiplatformV1RetrieveMemoriesRequest.
31749 31750 31751 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31749 def initialize(**args) update!(**args) end |
Instance Attribute Details
#filter ⇒ String
Optional. The standard list filter that will be applied to the retrieved
memories. More detail in AIP-160. Supported
fields: * fact * create_time * update_time * topics (i.e. topics.
custom_memory_topic_label: "example topic" OR topics.managed_memory_topic:
USER_PREFERENCES)
Corresponds to the JSON property filter
31718 31719 31720 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31718 def filter @filter end |
#filter_groups ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MemoryConjunctionFilter>
Optional. Metadata filters that will be applied to the retrieved memories'
metadata using OR logic. Filters are defined using disjunctive normal form (
OR of ANDs). For example: filter_groups: [filters: [key: "author", value:
string_value: "agent 123", op: EQUAL],filters: [key: "label", value:
string_value: "travel", op: EQUAL, key: "author", value:string_value: "
agent 321", op: EQUAL]] would be equivalent to the logical expression: (
metadata.author = "agent 123" OR (metadata.label = "travel" AND metadata.
author = "agent 321")).
Corresponds to the JSON property filterGroups
31730 31731 31732 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31730 def filter_groups @filter_groups end |
#scope ⇒ Hash<String,String>
Required. The scope of the memories to retrieve. A memory must have exactly
the same scope (Memory.scope) as the scope provided here to be retrieved (
same keys and values). Order does not matter, but it is case-sensitive.
Corresponds to the JSON property scope
31737 31738 31739 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31737 def scope @scope end |
#similarity_search_params ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrieveMemoriesRequestSimilaritySearchParams
Parameters for semantic similarity search based retrieval.
Corresponds to the JSON property similaritySearchParams
31742 31743 31744 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31742 def similarity_search_params @similarity_search_params end |
#simple_retrieval_params ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrieveMemoriesRequestSimpleRetrievalParams
Parameters for simple (non-similarity search) retrieval.
Corresponds to the JSON property simpleRetrievalParams
31747 31748 31749 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31747 def simple_retrieval_params @simple_retrieval_params end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31754 31755 31756 31757 31758 31759 31760 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31754 def update!(**args) @filter = args[:filter] if args.key?(:filter) @filter_groups = args[:filter_groups] if args.key?(:filter_groups) @scope = args[:scope] if args.key?(:scope) @similarity_search_params = args[:similarity_search_params] if args.key?(:similarity_search_params) @simple_retrieval_params = args[:simple_retrieval_params] if args.key?(:simple_retrieval_params) end |