Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrieveMemoriesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Response message for MemoryBankService.RetrieveMemories.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1RetrieveMemoriesResponse

Returns a new instance of GoogleCloudAiplatformV1RetrieveMemoriesResponse.



33498
33499
33500
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33498

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token that can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. This token is not set if similarity search was used for retrieval. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


33491
33492
33493
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33491

def next_page_token
  @next_page_token
end

#retrieved_memoriesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RetrieveMemoriesResponseRetrievedMemory>

The retrieved memories. Corresponds to the JSON property retrievedMemories



33496
33497
33498
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33496

def retrieved_memories
  @retrieved_memories
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33503
33504
33505
33506
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33503

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @retrieved_memories = args[:retrieved_memories] if args.key?(:retrieved_memories)
end