Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Rubric

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Message representing a single testable criterion for evaluation. One input prompt could have multiple rubrics.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Rubric

Returns a new instance of GoogleCloudAiplatformV1Rubric.



33707
33708
33709
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33707

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricContent

Content of the rubric, defining the testable criteria. Corresponds to the JSON property content



33686
33687
33688
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33686

def content
  @content
end

#importanceString

Optional. The relative importance of this rubric. Corresponds to the JSON property importance

Returns:

  • (String)


33691
33692
33693
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33691

def importance
  @importance
end

#rubric_idString

Unique identifier for the rubric. This ID is used to refer to this rubric, e.g. , in RubricVerdict. Corresponds to the JSON property rubricId

Returns:

  • (String)


33697
33698
33699
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33697

def rubric_id
  @rubric_id
end

#typeString

Optional. A type designator for the rubric, which can inform how it's evaluated or interpreted by systems or users. It's recommended to use consistent, well-defined, upper snake_case strings. Examples: " SUMMARIZATION_QUALITY", "SAFETY_HARMFUL_CONTENT", "INSTRUCTION_ADHERENCE". Corresponds to the JSON property type

Returns:

  • (String)


33705
33706
33707
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33705

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33712
33713
33714
33715
33716
33717
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33712

def update!(**args)
  @content = args[:content] if args.key?(:content)
  @importance = args[:importance] if args.key?(:importance)
  @rubric_id = args[:rubric_id] if args.key?(:rubric_id)
  @type = args[:type] if args.key?(:type)
end