Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Rubric
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Rubric
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Message representing a single testable criterion for evaluation. One input prompt could have multiple rubrics.
Instance Attribute Summary collapse
-
#content ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricContent
Content of the rubric, defining the testable criteria.
-
#importance ⇒ String
Optional.
-
#rubric_id ⇒ String
Unique identifier for the rubric.
-
#type ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Rubric
constructor
A new instance of GoogleCloudAiplatformV1Rubric.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Rubric
Returns a new instance of GoogleCloudAiplatformV1Rubric.
32045 32046 32047 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32045 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricContent
Content of the rubric, defining the testable criteria.
Corresponds to the JSON property content
32024 32025 32026 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32024 def content @content end |
#importance ⇒ String
Optional. The relative importance of this rubric.
Corresponds to the JSON property importance
32029 32030 32031 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32029 def importance @importance end |
#rubric_id ⇒ String
Unique identifier for the rubric. This ID is used to refer to this rubric, e.g.
, in RubricVerdict.
Corresponds to the JSON property rubricId
32035 32036 32037 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32035 def rubric_id @rubric_id end |
#type ⇒ String
Optional. A type designator for the rubric, which can inform how it's
evaluated or interpreted by systems or users. It's recommended to use
consistent, well-defined, upper snake_case strings. Examples: "
SUMMARIZATION_QUALITY", "SAFETY_HARMFUL_CONTENT", "INSTRUCTION_ADHERENCE".
Corresponds to the JSON property type
32043 32044 32045 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32043 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32050 32051 32052 32053 32054 32055 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32050 def update!(**args) @content = args[:content] if args.key?(:content) @importance = args[:importance] if args.key?(:importance) @rubric_id = args[:rubric_id] if args.key?(:rubric_id) @type = args[:type] if args.key?(:type) end |