Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricBasedInstructionFollowingInput
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricBasedInstructionFollowingInput
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Instance and metric spec for RubricBasedInstructionFollowing metric.
Instance Attribute Summary collapse
-
#instance ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricBasedInstructionFollowingInstance
Instance for RubricBasedInstructionFollowing metric - one instance corresponds to one row in an evaluation dataset.
-
#metric_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricBasedInstructionFollowingSpec
Spec for RubricBasedInstructionFollowing metric - returns rubrics and verdicts corresponding to rubrics along with overall score.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1RubricBasedInstructionFollowingInput
constructor
A new instance of GoogleCloudAiplatformV1RubricBasedInstructionFollowingInput.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1RubricBasedInstructionFollowingInput
Returns a new instance of GoogleCloudAiplatformV1RubricBasedInstructionFollowingInput.
33793 33794 33795 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33793 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instance ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricBasedInstructionFollowingInstance
Instance for RubricBasedInstructionFollowing metric - one instance corresponds
to one row in an evaluation dataset.
Corresponds to the JSON property instance
33785 33786 33787 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33785 def instance @instance end |
#metric_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricBasedInstructionFollowingSpec
Spec for RubricBasedInstructionFollowing metric - returns rubrics and verdicts
corresponding to rubrics along with overall score.
Corresponds to the JSON property metricSpec
33791 33792 33793 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33791 def metric_spec @metric_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33798 33799 33800 33801 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33798 def update!(**args) @instance = args[:instance] if args.key?(:instance) @metric_spec = args[:metric_spec] if args.key?(:metric_spec) end |