Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricBasedInstructionFollowingInput

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Instance and metric spec for RubricBasedInstructionFollowing metric.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1RubricBasedInstructionFollowingInput

Returns a new instance of GoogleCloudAiplatformV1RubricBasedInstructionFollowingInput.



27099
27100
27101
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27099

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instanceGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricBasedInstructionFollowingInstance

Instance for RubricBasedInstructionFollowing metric - one instance corresponds to one row in an evaluation dataset. Corresponds to the JSON property instance



27091
27092
27093
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27091

def instance
  @instance
end

#metric_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricBasedInstructionFollowingSpec

Spec for RubricBasedInstructionFollowing metric - returns rubrics and verdicts corresponding to rubrics along with overall score. Corresponds to the JSON property metricSpec



27097
27098
27099
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27097

def metric_spec
  @metric_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27104
27105
27106
27107
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27104

def update!(**args)
  @instance = args[:instance] if args.key?(:instance)
  @metric_spec = args[:metric_spec] if args.key?(:metric_spec)
end