Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricGenerationSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Specification for how rubrics should be generated.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1RubricGenerationSpec

Returns a new instance of GoogleCloudAiplatformV1RubricGenerationSpec.



35905
35906
35907
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35905

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#model_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1AutoraterConfig

The configs for autorater. This is applicable to both EvaluateInstances and EvaluateDataset. Corresponds to the JSON property modelConfig



35885
35886
35887
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35885

def model_config
  @model_config
end

#prompt_templateString

Template for the prompt used to generate rubrics. The details should be updated based on the most-recent recipe requirements. Corresponds to the JSON property promptTemplate

Returns:

  • (String)


35891
35892
35893
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35891

def prompt_template
  @prompt_template
end

#rubric_content_typeString

The type of rubric content to be generated. Corresponds to the JSON property rubricContentType

Returns:

  • (String)


35896
35897
35898
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35896

def rubric_content_type
  @rubric_content_type
end

#rubric_type_ontologyArray<String>

Optional. An optional, pre-defined list of allowed types for generated rubrics. If this field is provided, it implies include_rubric_type should be true, and the generated rubric types should be chosen from this ontology. Corresponds to the JSON property rubricTypeOntology

Returns:

  • (Array<String>)


35903
35904
35905
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35903

def rubric_type_ontology
  @rubric_type_ontology
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35910
35911
35912
35913
35914
35915
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35910

def update!(**args)
  @model_config = args[:model_config] if args.key?(:model_config)
  @prompt_template = args[:prompt_template] if args.key?(:prompt_template)
  @rubric_content_type = args[:rubric_content_type] if args.key?(:rubric_content_type)
  @rubric_type_ontology = args[:rubric_type_ontology] if args.key?(:rubric_type_ontology)
end