Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A group of rubrics, used for grouping rubrics based on a metric or a version.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1RubricGroup

Returns a new instance of GoogleCloudAiplatformV1RubricGroup.



33889
33890
33891
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33889

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Human-readable name for the group. This should be unique within a given context if used for display or selection. Example: "Instruction Following V1", "Content Quality - Summarization Task". Corresponds to the JSON property displayName

Returns:

  • (String)


33877
33878
33879
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33877

def display_name
  @display_name
end

#group_idString

Unique identifier for the group. Corresponds to the JSON property groupId

Returns:

  • (String)


33882
33883
33884
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33882

def group_id
  @group_id
end

#rubricsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Rubric>

Rubrics that are part of this group. Corresponds to the JSON property rubrics



33887
33888
33889
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33887

def rubrics
  @rubrics
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33894
33895
33896
33897
33898
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33894

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @group_id = args[:group_id] if args.key?(:group_id)
  @rubrics = args[:rubrics] if args.key?(:rubrics)
end