Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A group of rubrics, used for grouping rubrics based on a metric or a version.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1RubricGroup

Returns a new instance of GoogleCloudAiplatformV1RubricGroup.



32274
32275
32276
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32274

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Human-readable name for the group. This should be unique within a given context if used for display or selection. Example: "Instruction Following V1", "Content Quality - Summarization Task". Corresponds to the JSON property displayName

Returns:

  • (String)


32262
32263
32264
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32262

def display_name
  @display_name
end

#group_idString

Unique identifier for the group. Corresponds to the JSON property groupId

Returns:

  • (String)


32267
32268
32269
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32267

def group_id
  @group_id
end

#rubricsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Rubric>

Rubrics that are part of this group. Corresponds to the JSON property rubrics



32272
32273
32274
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32272

def rubrics
  @rubrics
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32279
32280
32281
32282
32283
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32279

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @group_id = args[:group_id] if args.key?(:group_id)
  @rubrics = args[:rubrics] if args.key?(:rubrics)
end