Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RubricVerdict

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents the verdict of an evaluation against a single rubric.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1RubricVerdict

Returns a new instance of GoogleCloudAiplatformV1RubricVerdict.



34029
34030
34031
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34029

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#evaluated_rubricGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Rubric

Message representing a single testable criterion for evaluation. One input prompt could have multiple rubrics. Corresponds to the JSON property evaluatedRubric



34013
34014
34015
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34013

def evaluated_rubric
  @evaluated_rubric
end

#reasoningString

Optional. Human-readable reasoning or explanation for the verdict. This can include specific examples or details from the evaluated content that justify the given verdict. Corresponds to the JSON property reasoning

Returns:

  • (String)


34020
34021
34022
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34020

def reasoning
  @reasoning
end

#verdictBoolean Also known as: verdict?

Required. Outcome of the evaluation against the rubric, represented as a boolean. true indicates a "Pass", false indicates a "Fail". Corresponds to the JSON property verdict

Returns:

  • (Boolean)


34026
34027
34028
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34026

def verdict
  @verdict
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34034
34035
34036
34037
34038
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34034

def update!(**args)
  @evaluated_rubric = args[:evaluated_rubric] if args.key?(:evaluated_rubric)
  @reasoning = args[:reasoning] if args.key?(:reasoning)
  @verdict = args[:verdict] if args.key?(:verdict)
end