Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetyRating

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A safety rating for a piece of content. The safety rating contains the harm category and the harm probability level.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SafetyRating

Returns a new instance of GoogleCloudAiplatformV1SafetyRating.



36074
36075
36076
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36074

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blockedBoolean Also known as: blocked?

Output only. Indicates whether the content was blocked because of this rating. Corresponds to the JSON property blocked

Returns:

  • (Boolean)


36039
36040
36041
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36039

def blocked
  @blocked
end

#categoryString

Output only. The harm category of this rating. Corresponds to the JSON property category

Returns:

  • (String)


36045
36046
36047
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36045

def category
  @category
end

#overwritten_thresholdString

Output only. The overwritten threshold for the safety category of Gemini 2.0 image out. If minors are detected in the output image, the threshold of each safety category will be overwritten if user sets a lower threshold. Corresponds to the JSON property overwrittenThreshold

Returns:

  • (String)


36052
36053
36054
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36052

def overwritten_threshold
  @overwritten_threshold
end

#probabilityString

Output only. The probability of harm for this category. Corresponds to the JSON property probability

Returns:

  • (String)


36057
36058
36059
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36057

def probability
  @probability
end

#probability_scoreFloat

Output only. The probability score of harm for this category. Corresponds to the JSON property probabilityScore

Returns:

  • (Float)


36062
36063
36064
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36062

def probability_score
  @probability_score
end

#severityString

Output only. The severity of harm for this category. Corresponds to the JSON property severity

Returns:

  • (String)


36067
36068
36069
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36067

def severity
  @severity
end

#severity_scoreFloat

Output only. The severity score of harm for this category. Corresponds to the JSON property severityScore

Returns:

  • (Float)


36072
36073
36074
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36072

def severity_score
  @severity_score
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36079
36080
36081
36082
36083
36084
36085
36086
36087
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36079

def update!(**args)
  @blocked = args[:blocked] if args.key?(:blocked)
  @category = args[:category] if args.key?(:category)
  @overwritten_threshold = args[:overwritten_threshold] if args.key?(:overwritten_threshold)
  @probability = args[:probability] if args.key?(:probability)
  @probability_score = args[:probability_score] if args.key?(:probability_score)
  @severity = args[:severity] if args.key?(:severity)
  @severity_score = args[:severity_score] if args.key?(:severity_score)
end