Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetyRating

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A safety rating for a piece of content. The safety rating contains the harm category and the harm probability level.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SafetyRating

Returns a new instance of GoogleCloudAiplatformV1SafetyRating.



34128
34129
34130
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34128

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blockedBoolean Also known as: blocked?

Output only. Indicates whether the content was blocked because of this rating. Corresponds to the JSON property blocked

Returns:

  • (Boolean)


34093
34094
34095
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34093

def blocked
  @blocked
end

#categoryString

Output only. The harm category of this rating. Corresponds to the JSON property category

Returns:

  • (String)


34099
34100
34101
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34099

def category
  @category
end

#overwritten_thresholdString

Output only. The overwritten threshold for the safety category of Gemini 2.0 image out. If minors are detected in the output image, the threshold of each safety category will be overwritten if user sets a lower threshold. Corresponds to the JSON property overwrittenThreshold

Returns:

  • (String)


34106
34107
34108
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34106

def overwritten_threshold
  @overwritten_threshold
end

#probabilityString

Output only. The probability of harm for this category. Corresponds to the JSON property probability

Returns:

  • (String)


34111
34112
34113
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34111

def probability
  @probability
end

#probability_scoreFloat

Output only. The probability score of harm for this category. Corresponds to the JSON property probabilityScore

Returns:

  • (Float)


34116
34117
34118
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34116

def probability_score
  @probability_score
end

#severityString

Output only. The severity of harm for this category. Corresponds to the JSON property severity

Returns:

  • (String)


34121
34122
34123
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34121

def severity
  @severity
end

#severity_scoreFloat

Output only. The severity score of harm for this category. Corresponds to the JSON property severityScore

Returns:

  • (Float)


34126
34127
34128
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34126

def severity_score
  @severity_score
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34133
34134
34135
34136
34137
34138
34139
34140
34141
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34133

def update!(**args)
  @blocked = args[:blocked] if args.key?(:blocked)
  @category = args[:category] if args.key?(:category)
  @overwritten_threshold = args[:overwritten_threshold] if args.key?(:overwritten_threshold)
  @probability = args[:probability] if args.key?(:probability)
  @probability_score = args[:probability_score] if args.key?(:probability_score)
  @severity = args[:severity] if args.key?(:severity)
  @severity_score = args[:severity_score] if args.key?(:severity_score)
end