Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetyRating
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetyRating
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A safety rating for a piece of content. The safety rating contains the harm category and the harm probability level.
Instance Attribute Summary collapse
-
#blocked ⇒ Boolean
(also: #blocked?)
Output only.
-
#category ⇒ String
Output only.
-
#overwritten_threshold ⇒ String
Output only.
-
#probability ⇒ String
Output only.
-
#probability_score ⇒ Float
Output only.
-
#severity ⇒ String
Output only.
-
#severity_score ⇒ Float
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SafetyRating
constructor
A new instance of GoogleCloudAiplatformV1SafetyRating.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SafetyRating
Returns a new instance of GoogleCloudAiplatformV1SafetyRating.
32409 32410 32411 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32409 def initialize(**args) update!(**args) end |
Instance Attribute Details
#blocked ⇒ Boolean Also known as: blocked?
Output only. Indicates whether the content was blocked because of this rating.
Corresponds to the JSON property blocked
32374 32375 32376 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32374 def blocked @blocked end |
#category ⇒ String
Output only. The harm category of this rating.
Corresponds to the JSON property category
32380 32381 32382 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32380 def category @category end |
#overwritten_threshold ⇒ String
Output only. The overwritten threshold for the safety category of Gemini 2.0
image out. If minors are detected in the output image, the threshold of each
safety category will be overwritten if user sets a lower threshold.
Corresponds to the JSON property overwrittenThreshold
32387 32388 32389 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32387 def overwritten_threshold @overwritten_threshold end |
#probability ⇒ String
Output only. The probability of harm for this category.
Corresponds to the JSON property probability
32392 32393 32394 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32392 def probability @probability end |
#probability_score ⇒ Float
Output only. The probability score of harm for this category.
Corresponds to the JSON property probabilityScore
32397 32398 32399 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32397 def probability_score @probability_score end |
#severity ⇒ String
Output only. The severity of harm for this category.
Corresponds to the JSON property severity
32402 32403 32404 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32402 def severity @severity end |
#severity_score ⇒ Float
Output only. The severity score of harm for this category.
Corresponds to the JSON property severityScore
32407 32408 32409 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32407 def severity_score @severity_score end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32414 32415 32416 32417 32418 32419 32420 32421 32422 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32414 def update!(**args) @blocked = args[:blocked] if args.key?(:blocked) @category = args[:category] if args.key?(:category) @overwritten_threshold = args[:overwritten_threshold] if args.key?(:overwritten_threshold) @probability = args[:probability] if args.key?(:probability) @probability_score = args[:probability_score] if args.key?(:probability_score) @severity = args[:severity] if args.key?(:severity) @severity_score = args[:severity_score] if args.key?(:severity_score) end |