Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetyRating

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Safety rating corresponding to the generated content.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SafetyRating

Returns a new instance of GoogleCloudAiplatformV1SafetyRating.



27270
27271
27272
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27270

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blockedBoolean Also known as: blocked?

Output only. Indicates whether the content was filtered out because of this rating. Corresponds to the JSON property blocked

Returns:

  • (Boolean)


27235
27236
27237
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27235

def blocked
  @blocked
end

#categoryString

Output only. Harm category. Corresponds to the JSON property category

Returns:

  • (String)


27241
27242
27243
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27241

def category
  @category
end

#overwritten_thresholdString

Output only. The overwritten threshold for the safety category of Gemini 2.0 image out. If minors are detected in the output image, the threshold of each safety category will be overwritten if user sets a lower threshold. Corresponds to the JSON property overwrittenThreshold

Returns:

  • (String)


27248
27249
27250
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27248

def overwritten_threshold
  @overwritten_threshold
end

#probabilityString

Output only. Harm probability levels in the content. Corresponds to the JSON property probability

Returns:

  • (String)


27253
27254
27255
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27253

def probability
  @probability
end

#probability_scoreFloat

Output only. Harm probability score. Corresponds to the JSON property probabilityScore

Returns:

  • (Float)


27258
27259
27260
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27258

def probability_score
  @probability_score
end

#severityString

Output only. Harm severity levels in the content. Corresponds to the JSON property severity

Returns:

  • (String)


27263
27264
27265
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27263

def severity
  @severity
end

#severity_scoreFloat

Output only. Harm severity score. Corresponds to the JSON property severityScore

Returns:

  • (Float)


27268
27269
27270
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27268

def severity_score
  @severity_score
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27275
27276
27277
27278
27279
27280
27281
27282
27283
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27275

def update!(**args)
  @blocked = args[:blocked] if args.key?(:blocked)
  @category = args[:category] if args.key?(:category)
  @overwritten_threshold = args[:overwritten_threshold] if args.key?(:overwritten_threshold)
  @probability = args[:probability] if args.key?(:probability)
  @probability_score = args[:probability_score] if args.key?(:probability_score)
  @severity = args[:severity] if args.key?(:severity)
  @severity_score = args[:severity_score] if args.key?(:severity_score)
end