Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetyRating
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetyRating
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Safety rating corresponding to the generated content.
Instance Attribute Summary collapse
-
#blocked ⇒ Boolean
(also: #blocked?)
Output only.
-
#category ⇒ String
Output only.
-
#overwritten_threshold ⇒ String
Output only.
-
#probability ⇒ String
Output only.
-
#probability_score ⇒ Float
Output only.
-
#severity ⇒ String
Output only.
-
#severity_score ⇒ Float
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SafetyRating
constructor
A new instance of GoogleCloudAiplatformV1SafetyRating.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SafetyRating
Returns a new instance of GoogleCloudAiplatformV1SafetyRating.
26914 26915 26916 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26914 def initialize(**args) update!(**args) end |
Instance Attribute Details
#blocked ⇒ Boolean Also known as: blocked?
Output only. Indicates whether the content was filtered out because of this
rating.
Corresponds to the JSON property blocked
26879 26880 26881 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26879 def blocked @blocked end |
#category ⇒ String
Output only. Harm category.
Corresponds to the JSON property category
26885 26886 26887 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26885 def category @category end |
#overwritten_threshold ⇒ String
Output only. The overwritten threshold for the safety category of Gemini 2.0
image out. If minors are detected in the output image, the threshold of each
safety category will be overwritten if user sets a lower threshold.
Corresponds to the JSON property overwrittenThreshold
26892 26893 26894 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26892 def overwritten_threshold @overwritten_threshold end |
#probability ⇒ String
Output only. Harm probability levels in the content.
Corresponds to the JSON property probability
26897 26898 26899 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26897 def probability @probability end |
#probability_score ⇒ Float
Output only. Harm probability score.
Corresponds to the JSON property probabilityScore
26902 26903 26904 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26902 def probability_score @probability_score end |
#severity ⇒ String
Output only. Harm severity levels in the content.
Corresponds to the JSON property severity
26907 26908 26909 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26907 def severity @severity end |
#severity_score ⇒ Float
Output only. Harm severity score.
Corresponds to the JSON property severityScore
26912 26913 26914 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26912 def severity_score @severity_score end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26919 26920 26921 26922 26923 26924 26925 26926 26927 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26919 def update!(**args) @blocked = args[:blocked] if args.key?(:blocked) @category = args[:category] if args.key?(:category) @overwritten_threshold = args[:overwritten_threshold] if args.key?(:overwritten_threshold) @probability = args[:probability] if args.key?(:probability) @probability_score = args[:probability_score] if args.key?(:probability_score) @severity = args[:severity] if args.key?(:severity) @severity_score = args[:severity_score] if args.key?(:severity_score) end |