Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetyRating

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Safety rating corresponding to the generated content.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SafetyRating

Returns a new instance of GoogleCloudAiplatformV1SafetyRating.



26843
26844
26845
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26843

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blockedBoolean Also known as: blocked?

Output only. Indicates whether the content was filtered out because of this rating. Corresponds to the JSON property blocked

Returns:

  • (Boolean)


26808
26809
26810
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26808

def blocked
  @blocked
end

#categoryString

Output only. Harm category. Corresponds to the JSON property category

Returns:

  • (String)


26814
26815
26816
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26814

def category
  @category
end

#overwritten_thresholdString

Output only. The overwritten threshold for the safety category of Gemini 2.0 image out. If minors are detected in the output image, the threshold of each safety category will be overwritten if user sets a lower threshold. Corresponds to the JSON property overwrittenThreshold

Returns:

  • (String)


26821
26822
26823
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26821

def overwritten_threshold
  @overwritten_threshold
end

#probabilityString

Output only. Harm probability levels in the content. Corresponds to the JSON property probability

Returns:

  • (String)


26826
26827
26828
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26826

def probability
  @probability
end

#probability_scoreFloat

Output only. Harm probability score. Corresponds to the JSON property probabilityScore

Returns:

  • (Float)


26831
26832
26833
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26831

def probability_score
  @probability_score
end

#severityString

Output only. Harm severity levels in the content. Corresponds to the JSON property severity

Returns:

  • (String)


26836
26837
26838
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26836

def severity
  @severity
end

#severity_scoreFloat

Output only. Harm severity score. Corresponds to the JSON property severityScore

Returns:

  • (Float)


26841
26842
26843
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26841

def severity_score
  @severity_score
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26848
26849
26850
26851
26852
26853
26854
26855
26856
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26848

def update!(**args)
  @blocked = args[:blocked] if args.key?(:blocked)
  @category = args[:category] if args.key?(:category)
  @overwritten_threshold = args[:overwritten_threshold] if args.key?(:overwritten_threshold)
  @probability = args[:probability] if args.key?(:probability)
  @probability_score = args[:probability_score] if args.key?(:probability_score)
  @severity = args[:severity] if args.key?(:severity)
  @severity_score = args[:severity_score] if args.key?(:severity_score)
end