Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetyRating
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetyRating
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Safety rating corresponding to the generated content.
Instance Attribute Summary collapse
-
#blocked ⇒ Boolean
(also: #blocked?)
Output only.
-
#category ⇒ String
Output only.
-
#overwritten_threshold ⇒ String
Output only.
-
#probability ⇒ String
Output only.
-
#probability_score ⇒ Float
Output only.
-
#severity ⇒ String
Output only.
-
#severity_score ⇒ Float
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SafetyRating
constructor
A new instance of GoogleCloudAiplatformV1SafetyRating.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SafetyRating
Returns a new instance of GoogleCloudAiplatformV1SafetyRating.
26843 26844 26845 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26843 def initialize(**args) update!(**args) end |
Instance Attribute Details
#blocked ⇒ Boolean Also known as: blocked?
Output only. Indicates whether the content was filtered out because of this
rating.
Corresponds to the JSON property blocked
26808 26809 26810 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26808 def blocked @blocked end |
#category ⇒ String
Output only. Harm category.
Corresponds to the JSON property category
26814 26815 26816 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26814 def category @category end |
#overwritten_threshold ⇒ String
Output only. The overwritten threshold for the safety category of Gemini 2.0
image out. If minors are detected in the output image, the threshold of each
safety category will be overwritten if user sets a lower threshold.
Corresponds to the JSON property overwrittenThreshold
26821 26822 26823 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26821 def overwritten_threshold @overwritten_threshold end |
#probability ⇒ String
Output only. Harm probability levels in the content.
Corresponds to the JSON property probability
26826 26827 26828 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26826 def probability @probability end |
#probability_score ⇒ Float
Output only. Harm probability score.
Corresponds to the JSON property probabilityScore
26831 26832 26833 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26831 def probability_score @probability_score end |
#severity ⇒ String
Output only. Harm severity levels in the content.
Corresponds to the JSON property severity
26836 26837 26838 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26836 def severity @severity end |
#severity_score ⇒ Float
Output only. Harm severity score.
Corresponds to the JSON property severityScore
26841 26842 26843 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26841 def severity_score @severity_score end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26848 26849 26850 26851 26852 26853 26854 26855 26856 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26848 def update!(**args) @blocked = args[:blocked] if args.key?(:blocked) @category = args[:category] if args.key?(:category) @overwritten_threshold = args[:overwritten_threshold] if args.key?(:overwritten_threshold) @probability = args[:probability] if args.key?(:probability) @probability_score = args[:probability_score] if args.key?(:probability_score) @severity = args[:severity] if args.key?(:severity) @severity_score = args[:severity_score] if args.key?(:severity_score) end |