Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetySetting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A safety setting that affects the safety-blocking behavior. A SafetySetting consists of a harm category and a threshold for that category.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SafetySetting

Returns a new instance of GoogleCloudAiplatformV1SafetySetting.



35699
35700
35701
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35699

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#categoryString

Required. The harm category to be blocked. Corresponds to the JSON property category

Returns:

  • (String)


35685
35686
35687
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35685

def category
  @category
end

#method_propString

Optional. The method for blocking content. If not specified, the default behavior is to use the probability score. Corresponds to the JSON property method

Returns:

  • (String)


35691
35692
35693
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35691

def method_prop
  @method_prop
end

#thresholdString

Required. The threshold for blocking content. If the harm probability exceeds this threshold, the content will be blocked. Corresponds to the JSON property threshold

Returns:

  • (String)


35697
35698
35699
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35697

def threshold
  @threshold
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35704
35705
35706
35707
35708
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35704

def update!(**args)
  @category = args[:category] if args.key?(:category)
  @method_prop = args[:method_prop] if args.key?(:method_prop)
  @threshold = args[:threshold] if args.key?(:threshold)
end