Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetySetting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Safety settings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SafetySetting

Returns a new instance of GoogleCloudAiplatformV1SafetySetting.



26927
26928
26929
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26927

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#categoryString

Required. Harm category. Corresponds to the JSON property category

Returns:

  • (String)


26914
26915
26916
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26914

def category
  @category
end

#method_propString

Optional. Specify if the threshold is used for probability or severity score. If not specified, the threshold is used for probability score. Corresponds to the JSON property method

Returns:

  • (String)


26920
26921
26922
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26920

def method_prop
  @method_prop
end

#thresholdString

Required. The harm block threshold. Corresponds to the JSON property threshold

Returns:

  • (String)


26925
26926
26927
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26925

def threshold
  @threshold
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26932
26933
26934
26935
26936
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26932

def update!(**args)
  @category = args[:category] if args.key?(:category)
  @method_prop = args[:method_prop] if args.key?(:method_prop)
  @threshold = args[:threshold] if args.key?(:threshold)
end