Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetySetting
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetySetting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Safety settings.
Instance Attribute Summary collapse
-
#category ⇒ String
Required.
-
#method_prop ⇒ String
Optional.
-
#threshold ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SafetySetting
constructor
A new instance of GoogleCloudAiplatformV1SafetySetting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SafetySetting
Returns a new instance of GoogleCloudAiplatformV1SafetySetting.
26447 26448 26449 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26447 def initialize(**args) update!(**args) end |
Instance Attribute Details
#category ⇒ String
Required. Harm category.
Corresponds to the JSON property category
26434 26435 26436 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26434 def category @category end |
#method_prop ⇒ String
Optional. Specify if the threshold is used for probability or severity score.
If not specified, the threshold is used for probability score.
Corresponds to the JSON property method
26440 26441 26442 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26440 def method_prop @method_prop end |
#threshold ⇒ String
Required. The harm block threshold.
Corresponds to the JSON property threshold
26445 26446 26447 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26445 def threshold @threshold end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26452 26453 26454 26455 26456 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26452 def update!(**args) @category = args[:category] if args.key?(:category) @method_prop = args[:method_prop] if args.key?(:method_prop) @threshold = args[:threshold] if args.key?(:threshold) end |