Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetySetting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Safety settings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SafetySetting

Returns a new instance of GoogleCloudAiplatformV1SafetySetting.



26439
26440
26441
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26439

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#categoryString

Required. Harm category. Corresponds to the JSON property category

Returns:

  • (String)


26426
26427
26428
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26426

def category
  @category
end

#method_propString

Optional. Specify if the threshold is used for probability or severity score. If not specified, the threshold is used for probability score. Corresponds to the JSON property method

Returns:

  • (String)


26432
26433
26434
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26432

def method_prop
  @method_prop
end

#thresholdString

Required. The harm block threshold. Corresponds to the JSON property threshold

Returns:

  • (String)


26437
26438
26439
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26437

def threshold
  @threshold
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26444
26445
26446
26447
26448
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26444

def update!(**args)
  @category = args[:category] if args.key?(:category)
  @method_prop = args[:method_prop] if args.key?(:method_prop)
  @threshold = args[:threshold] if args.key?(:threshold)
end