Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetySetting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Safety settings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SafetySetting

Returns a new instance of GoogleCloudAiplatformV1SafetySetting.



26360
26361
26362
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26360

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#categoryString

Required. Harm category. Corresponds to the JSON property category

Returns:

  • (String)


26347
26348
26349
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26347

def category
  @category
end

#method_propString

Optional. Specify if the threshold is used for probability or severity score. If not specified, the threshold is used for probability score. Corresponds to the JSON property method

Returns:

  • (String)


26353
26354
26355
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26353

def method_prop
  @method_prop
end

#thresholdString

Required. The harm block threshold. Corresponds to the JSON property threshold

Returns:

  • (String)


26358
26359
26360
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26358

def threshold
  @threshold
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26365
26366
26367
26368
26369
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26365

def update!(**args)
  @category = args[:category] if args.key?(:category)
  @method_prop = args[:method_prop] if args.key?(:method_prop)
  @threshold = args[:threshold] if args.key?(:threshold)
end