Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetySetting
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetySetting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Safety settings.
Instance Attribute Summary collapse
-
#category ⇒ String
Required.
-
#method_prop ⇒ String
Optional.
-
#threshold ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SafetySetting
constructor
A new instance of GoogleCloudAiplatformV1SafetySetting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SafetySetting
Returns a new instance of GoogleCloudAiplatformV1SafetySetting.
25282 25283 25284 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25282 def initialize(**args) update!(**args) end |
Instance Attribute Details
#category ⇒ String
Required. Harm category.
Corresponds to the JSON property category
25269 25270 25271 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25269 def category @category end |
#method_prop ⇒ String
Optional. Specify if the threshold is used for probability or severity score.
If not specified, the threshold is used for probability score.
Corresponds to the JSON property method
25275 25276 25277 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25275 def method_prop @method_prop end |
#threshold ⇒ String
Required. The harm block threshold.
Corresponds to the JSON property threshold
25280 25281 25282 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25280 def threshold @threshold end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25287 25288 25289 25290 25291 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25287 def update!(**args) @category = args[:category] if args.key?(:category) @method_prop = args[:method_prop] if args.key?(:method_prop) @threshold = args[:threshold] if args.key?(:threshold) end |