Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetySetting
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetySetting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Safety settings.
Instance Attribute Summary collapse
-
#category ⇒ String
Required.
-
#method_prop ⇒ String
Optional.
-
#threshold ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SafetySetting
constructor
A new instance of GoogleCloudAiplatformV1SafetySetting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SafetySetting
Returns a new instance of GoogleCloudAiplatformV1SafetySetting.
25031 25032 25033 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25031 def initialize(**args) update!(**args) end |
Instance Attribute Details
#category ⇒ String
Required. Harm category.
Corresponds to the JSON property category
25018 25019 25020 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25018 def category @category end |
#method_prop ⇒ String
Optional. Specify if the threshold is used for probability or severity score.
If not specified, the threshold is used for probability score.
Corresponds to the JSON property method
25024 25025 25026 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25024 def method_prop @method_prop end |
#threshold ⇒ String
Required. The harm block threshold.
Corresponds to the JSON property threshold
25029 25030 25031 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25029 def threshold @threshold end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25036 25037 25038 25039 25040 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25036 def update!(**args) @category = args[:category] if args.key?(:category) @method_prop = args[:method_prop] if args.key?(:method_prop) @threshold = args[:threshold] if args.key?(:threshold) end |