Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetySetting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Safety settings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SafetySetting

Returns a new instance of GoogleCloudAiplatformV1SafetySetting.



20286
20287
20288
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20286

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#categoryString

Required. Harm category. Corresponds to the JSON property category

Returns:

  • (String)


20273
20274
20275
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20273

def category
  @category
end

#method_propString

Optional. Specify if the threshold is used for probability or severity score. If not specified, the threshold is used for probability score. Corresponds to the JSON property method

Returns:

  • (String)


20279
20280
20281
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20279

def method_prop
  @method_prop
end

#thresholdString

Required. The harm block threshold. Corresponds to the JSON property threshold

Returns:

  • (String)


20284
20285
20286
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20284

def threshold
  @threshold
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20291
20292
20293
20294
20295
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20291

def update!(**args)
  @category = args[:category] if args.key?(:category)
  @method_prop = args[:method_prop] if args.key?(:method_prop)
  @threshold = args[:threshold] if args.key?(:threshold)
end