Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetySetting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Safety settings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SafetySetting

Returns a new instance of GoogleCloudAiplatformV1SafetySetting.



18226
18227
18228
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18226

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#categoryString

Required. Harm category. Corresponds to the JSON property category

Returns:

  • (String)


18213
18214
18215
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18213

def category
  @category
end

#method_propString

Optional. Specify if the threshold is used for probability or severity score. If not specified, the threshold is used for probability score. Corresponds to the JSON property method

Returns:

  • (String)


18219
18220
18221
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18219

def method_prop
  @method_prop
end

#thresholdString

Required. The harm block threshold. Corresponds to the JSON property threshold

Returns:

  • (String)


18224
18225
18226
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18224

def threshold
  @threshold
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18231
18232
18233
18234
18235
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18231

def update!(**args)
  @category = args[:category] if args.key?(:category)
  @method_prop = args[:method_prop] if args.key?(:method_prop)
  @threshold = args[:threshold] if args.key?(:threshold)
end