Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SampleConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Active learning data sampling config. For every active learning labeling iteration, it will select a batch of data based on the sampling strategy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SampleConfig

Returns a new instance of GoogleCloudAiplatformV1SampleConfig.



25252
25253
25254
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25252

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#following_batch_sample_percentageFixnum

The percentage of data needed to be labeled in each following batch (except the first batch). Corresponds to the JSON property followingBatchSamplePercentage

Returns:

  • (Fixnum)


25239
25240
25241
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25239

def following_batch_sample_percentage
  @following_batch_sample_percentage
end

#initial_batch_sample_percentageFixnum

The percentage of data needed to be labeled in the first batch. Corresponds to the JSON property initialBatchSamplePercentage

Returns:

  • (Fixnum)


25244
25245
25246
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25244

def initial_batch_sample_percentage
  @initial_batch_sample_percentage
end

#sample_strategyString

Field to choose sampling strategy. Sampling strategy will decide which data should be selected for human labeling in every batch. Corresponds to the JSON property sampleStrategy

Returns:

  • (String)


25250
25251
25252
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25250

def sample_strategy
  @sample_strategy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25257
25258
25259
25260
25261
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25257

def update!(**args)
  @following_batch_sample_percentage = args[:following_batch_sample_percentage] if args.key?(:following_batch_sample_percentage)
  @initial_batch_sample_percentage = args[:initial_batch_sample_percentage] if args.key?(:initial_batch_sample_percentage)
  @sample_strategy = args[:sample_strategy] if args.key?(:sample_strategy)
end