Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SampleConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Active learning data sampling config. For every active learning labeling iteration, it will select a batch of data based on the sampling strategy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SampleConfig

Returns a new instance of GoogleCloudAiplatformV1SampleConfig.



19078
19079
19080
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19078

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#following_batch_sample_percentageFixnum

The percentage of data needed to be labeled in each following batch (except the first batch). Corresponds to the JSON property followingBatchSamplePercentage

Returns:

  • (Fixnum)


19065
19066
19067
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19065

def following_batch_sample_percentage
  @following_batch_sample_percentage
end

#initial_batch_sample_percentageFixnum

The percentage of data needed to be labeled in the first batch. Corresponds to the JSON property initialBatchSamplePercentage

Returns:

  • (Fixnum)


19070
19071
19072
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19070

def initial_batch_sample_percentage
  @initial_batch_sample_percentage
end

#sample_strategyString

Field to choose sampling strategy. Sampling strategy will decide which data should be selected for human labeling in every batch. Corresponds to the JSON property sampleStrategy

Returns:

  • (String)


19076
19077
19078
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19076

def sample_strategy
  @sample_strategy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19083
19084
19085
19086
19087
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19083

def update!(**args)
  @following_batch_sample_percentage = args[:following_batch_sample_percentage] if args.key?(:following_batch_sample_percentage)
  @initial_batch_sample_percentage = args[:initial_batch_sample_percentage] if args.key?(:initial_batch_sample_percentage)
  @sample_strategy = args[:sample_strategy] if args.key?(:sample_strategy)
end