Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SandboxEnvironment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

SandboxEnvironment is a containerized environment that provides a customizable secure execution runtime for AI agents.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SandboxEnvironment

Returns a new instance of GoogleCloudAiplatformV1SandboxEnvironment.



35905
35906
35907
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35905

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connection_infoGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SandboxEnvironmentConnectionInfo

The connection information of the SandboxEnvironment. Corresponds to the JSON property connectionInfo



35832
35833
35834
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35832

def connection_info
  @connection_info
end

#create_timeString

Output only. The timestamp when this SandboxEnvironment was created. Corresponds to the JSON property createTime

Returns:

  • (String)


35837
35838
35839
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35837

def create_time
  @create_time
end

#display_nameString

Required. The display name of the SandboxEnvironment. Corresponds to the JSON property displayName

Returns:

  • (String)


35842
35843
35844
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35842

def display_name
  @display_name
end

#expire_timeString

Optional. Timestamp in UTC of when this SandboxEnvironment is considered expired. This is always provided on output, regardless of what expiration was sent on input. Corresponds to the JSON property expireTime

Returns:

  • (String)


35849
35850
35851
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35849

def expire_time
  @expire_time
end

#latest_sandbox_environment_snapshotString

Output only. The resource name of the latest snapshot taken for this SandboxEnvironment. Corresponds to the JSON property latestSandboxEnvironmentSnapshot

Returns:

  • (String)


35855
35856
35857
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35855

def latest_sandbox_environment_snapshot
  @latest_sandbox_environment_snapshot
end

#nameString

Identifier. The name of the SandboxEnvironment. Corresponds to the JSON property name

Returns:

  • (String)


35860
35861
35862
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35860

def name
  @name
end

#ownerString

Optional. Owner information for this sandbox environment. A Sandbox can only be restored from a snapshot that belongs to the same owner. If not set, sandbox will be created as the default owner. Corresponds to the JSON property owner

Returns:

  • (String)


35867
35868
35869
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35867

def owner
  @owner
end

#sandbox_environment_snapshotString

Optional. The resource name of the SandboxEnvironmentSnapshot to use for creating this SandboxEnvironment. Format: projects/project/locations/ location/reasoningEngines/reasoning_engine/sandboxEnvironmentSnapshots/ sandbox_environment_snapshot` Corresponds to the JSON propertysandboxEnvironmentSnapshot`

Returns:

  • (String)


35875
35876
35877
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35875

def sandbox_environment_snapshot
  @sandbox_environment_snapshot
end

#sandbox_environment_templateString

Optional. The name of the SandboxEnvironmentTemplate specified in the parent Agent Engine resource that this SandboxEnvironment is created from. Corresponds to the JSON property sandboxEnvironmentTemplate

Returns:

  • (String)


35881
35882
35883
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35881

def sandbox_environment_template
  @sandbox_environment_template
end

#specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SandboxEnvironmentSpec

The specification of a SandboxEnvironment. Corresponds to the JSON property spec



35886
35887
35888
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35886

def spec
  @spec
end

#stateString

Output only. The runtime state of the SandboxEnvironment. Corresponds to the JSON property state

Returns:

  • (String)


35891
35892
35893
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35891

def state
  @state
end

#ttlString

Optional. Input only. The TTL for the sandbox environment. The expiration time is computed: now + TTL. Corresponds to the JSON property ttl

Returns:

  • (String)


35897
35898
35899
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35897

def ttl
  @ttl
end

#update_timeString

Output only. The timestamp when this SandboxEnvironment was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


35903
35904
35905
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35903

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35910
35911
35912
35913
35914
35915
35916
35917
35918
35919
35920
35921
35922
35923
35924
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35910

def update!(**args)
  @connection_info = args[:connection_info] if args.key?(:connection_info)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @latest_sandbox_environment_snapshot = args[:latest_sandbox_environment_snapshot] if args.key?(:latest_sandbox_environment_snapshot)
  @name = args[:name] if args.key?(:name)
  @owner = args[:owner] if args.key?(:owner)
  @sandbox_environment_snapshot = args[:sandbox_environment_snapshot] if args.key?(:sandbox_environment_snapshot)
  @sandbox_environment_template = args[:sandbox_environment_template] if args.key?(:sandbox_environment_template)
  @spec = args[:spec] if args.key?(:spec)
  @state = args[:state] if args.key?(:state)
  @ttl = args[:ttl] if args.key?(:ttl)
  @update_time = args[:update_time] if args.key?(:update_time)
end