Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SandboxEnvironment
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SandboxEnvironment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
SandboxEnvironment is a containerized environment that provides a customizable secure execution runtime for AI agents.
Instance Attribute Summary collapse
-
#connection_info ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SandboxEnvironmentConnectionInfo
The connection information of the SandboxEnvironment.
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Required.
-
#expire_time ⇒ String
Optional.
-
#latest_sandbox_environment_snapshot ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#owner ⇒ String
Optional.
-
#sandbox_environment_snapshot ⇒ String
Optional.
-
#sandbox_environment_template ⇒ String
Optional.
-
#spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SandboxEnvironmentSpec
The specification of a SandboxEnvironment.
-
#state ⇒ String
Output only.
-
#ttl ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SandboxEnvironment
constructor
A new instance of GoogleCloudAiplatformV1SandboxEnvironment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SandboxEnvironment
Returns a new instance of GoogleCloudAiplatformV1SandboxEnvironment.
34519 34520 34521 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34519 def initialize(**args) update!(**args) end |
Instance Attribute Details
#connection_info ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SandboxEnvironmentConnectionInfo
The connection information of the SandboxEnvironment.
Corresponds to the JSON property connectionInfo
34446 34447 34448 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34446 def connection_info @connection_info end |
#create_time ⇒ String
Output only. The timestamp when this SandboxEnvironment was created.
Corresponds to the JSON property createTime
34451 34452 34453 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34451 def create_time @create_time end |
#display_name ⇒ String
Required. The display name of the SandboxEnvironment.
Corresponds to the JSON property displayName
34456 34457 34458 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34456 def display_name @display_name end |
#expire_time ⇒ String
Optional. Timestamp in UTC of when this SandboxEnvironment is considered
expired. This is always provided on output, regardless of what expiration
was sent on input.
Corresponds to the JSON property expireTime
34463 34464 34465 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34463 def expire_time @expire_time end |
#latest_sandbox_environment_snapshot ⇒ String
Output only. The resource name of the latest snapshot taken for this
SandboxEnvironment.
Corresponds to the JSON property latestSandboxEnvironmentSnapshot
34469 34470 34471 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34469 def latest_sandbox_environment_snapshot @latest_sandbox_environment_snapshot end |
#name ⇒ String
Identifier. The name of the SandboxEnvironment.
Corresponds to the JSON property name
34474 34475 34476 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34474 def name @name end |
#owner ⇒ String
Optional. Owner information for this sandbox environment. A Sandbox can only
be restored from a snapshot that belongs to the same owner. If not set,
sandbox will be created as the default owner.
Corresponds to the JSON property owner
34481 34482 34483 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34481 def owner @owner end |
#sandbox_environment_snapshot ⇒ String
Optional. The resource name of the SandboxEnvironmentSnapshot to use for
creating this SandboxEnvironment. Format: projects/project/locations/
location/reasoningEngines/reasoning_engine/sandboxEnvironmentSnapshots/
sandbox_environment_snapshot`
Corresponds to the JSON propertysandboxEnvironmentSnapshot`
34489 34490 34491 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34489 def sandbox_environment_snapshot @sandbox_environment_snapshot end |
#sandbox_environment_template ⇒ String
Optional. The name of the SandboxEnvironmentTemplate specified in the parent
Agent Engine resource that this SandboxEnvironment is created from.
Corresponds to the JSON property sandboxEnvironmentTemplate
34495 34496 34497 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34495 def sandbox_environment_template @sandbox_environment_template end |
#spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SandboxEnvironmentSpec
The specification of a SandboxEnvironment.
Corresponds to the JSON property spec
34500 34501 34502 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34500 def spec @spec end |
#state ⇒ String
Output only. The runtime state of the SandboxEnvironment.
Corresponds to the JSON property state
34505 34506 34507 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34505 def state @state end |
#ttl ⇒ String
Optional. Input only. The TTL for the sandbox environment. The expiration time
is computed: now + TTL.
Corresponds to the JSON property ttl
34511 34512 34513 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34511 def ttl @ttl end |
#update_time ⇒ String
Output only. The timestamp when this SandboxEnvironment was most recently
updated.
Corresponds to the JSON property updateTime
34517 34518 34519 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34517 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34524 34525 34526 34527 34528 34529 34530 34531 34532 34533 34534 34535 34536 34537 34538 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34524 def update!(**args) @connection_info = args[:connection_info] if args.key?(:connection_info) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @expire_time = args[:expire_time] if args.key?(:expire_time) @latest_sandbox_environment_snapshot = args[:latest_sandbox_environment_snapshot] if args.key?(:latest_sandbox_environment_snapshot) @name = args[:name] if args.key?(:name) @owner = args[:owner] if args.key?(:owner) @sandbox_environment_snapshot = args[:sandbox_environment_snapshot] if args.key?(:sandbox_environment_snapshot) @sandbox_environment_template = args[:sandbox_environment_template] if args.key?(:sandbox_environment_template) @spec = args[:spec] if args.key?(:spec) @state = args[:state] if args.key?(:state) @ttl = args[:ttl] if args.key?(:ttl) @update_time = args[:update_time] if args.key?(:update_time) end |