Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SandboxEnvironment
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SandboxEnvironment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
SandboxEnvironment is a containerized environment that provides a customizable secure execution runtime for AI agents.
Instance Attribute Summary collapse
-
#connection_info ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SandboxEnvironmentConnectionInfo
The connection information of the SandboxEnvironment.
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Required.
-
#expire_time ⇒ String
Optional.
-
#latest_sandbox_environment_snapshot ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#owner ⇒ String
Optional.
-
#sandbox_environment_snapshot ⇒ String
Optional.
-
#sandbox_environment_template ⇒ String
Optional.
-
#spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SandboxEnvironmentSpec
The specification of a SandboxEnvironment.
-
#state ⇒ String
Output only.
-
#ttl ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SandboxEnvironment
constructor
A new instance of GoogleCloudAiplatformV1SandboxEnvironment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SandboxEnvironment
Returns a new instance of GoogleCloudAiplatformV1SandboxEnvironment.
34403 34404 34405 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34403 def initialize(**args) update!(**args) end |
Instance Attribute Details
#connection_info ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SandboxEnvironmentConnectionInfo
The connection information of the SandboxEnvironment.
Corresponds to the JSON property connectionInfo
34330 34331 34332 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34330 def connection_info @connection_info end |
#create_time ⇒ String
Output only. The timestamp when this SandboxEnvironment was created.
Corresponds to the JSON property createTime
34335 34336 34337 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34335 def create_time @create_time end |
#display_name ⇒ String
Required. The display name of the SandboxEnvironment.
Corresponds to the JSON property displayName
34340 34341 34342 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34340 def display_name @display_name end |
#expire_time ⇒ String
Optional. Timestamp in UTC of when this SandboxEnvironment is considered
expired. This is always provided on output, regardless of what expiration
was sent on input.
Corresponds to the JSON property expireTime
34347 34348 34349 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34347 def expire_time @expire_time end |
#latest_sandbox_environment_snapshot ⇒ String
Output only. The resource name of the latest snapshot taken for this
SandboxEnvironment.
Corresponds to the JSON property latestSandboxEnvironmentSnapshot
34353 34354 34355 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34353 def latest_sandbox_environment_snapshot @latest_sandbox_environment_snapshot end |
#name ⇒ String
Identifier. The name of the SandboxEnvironment.
Corresponds to the JSON property name
34358 34359 34360 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34358 def name @name end |
#owner ⇒ String
Optional. Owner information for this sandbox environment. A Sandbox can only
be restored from a snapshot that belongs to the same owner. If not set,
sandbox will be created as the default owner.
Corresponds to the JSON property owner
34365 34366 34367 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34365 def owner @owner end |
#sandbox_environment_snapshot ⇒ String
Optional. The resource name of the SandboxEnvironmentSnapshot to use for
creating this SandboxEnvironment. Format: projects/project/locations/
location/reasoningEngines/reasoning_engine/sandboxEnvironmentSnapshots/
sandbox_environment_snapshot`
Corresponds to the JSON propertysandboxEnvironmentSnapshot`
34373 34374 34375 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34373 def sandbox_environment_snapshot @sandbox_environment_snapshot end |
#sandbox_environment_template ⇒ String
Optional. The name of the SandboxEnvironmentTemplate specified in the parent
Agent Engine resource that this SandboxEnvironment is created from.
Corresponds to the JSON property sandboxEnvironmentTemplate
34379 34380 34381 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34379 def sandbox_environment_template @sandbox_environment_template end |
#spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SandboxEnvironmentSpec
The specification of a SandboxEnvironment.
Corresponds to the JSON property spec
34384 34385 34386 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34384 def spec @spec end |
#state ⇒ String
Output only. The runtime state of the SandboxEnvironment.
Corresponds to the JSON property state
34389 34390 34391 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34389 def state @state end |
#ttl ⇒ String
Optional. Input only. The TTL for the sandbox environment. The expiration time
is computed: now + TTL.
Corresponds to the JSON property ttl
34395 34396 34397 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34395 def ttl @ttl end |
#update_time ⇒ String
Output only. The timestamp when this SandboxEnvironment was most recently
updated.
Corresponds to the JSON property updateTime
34401 34402 34403 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34401 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34408 34409 34410 34411 34412 34413 34414 34415 34416 34417 34418 34419 34420 34421 34422 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34408 def update!(**args) @connection_info = args[:connection_info] if args.key?(:connection_info) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @expire_time = args[:expire_time] if args.key?(:expire_time) @latest_sandbox_environment_snapshot = args[:latest_sandbox_environment_snapshot] if args.key?(:latest_sandbox_environment_snapshot) @name = args[:name] if args.key?(:name) @owner = args[:owner] if args.key?(:owner) @sandbox_environment_snapshot = args[:sandbox_environment_snapshot] if args.key?(:sandbox_environment_snapshot) @sandbox_environment_template = args[:sandbox_environment_template] if args.key?(:sandbox_environment_template) @spec = args[:spec] if args.key?(:spec) @state = args[:state] if args.key?(:state) @ttl = args[:ttl] if args.key?(:ttl) @update_time = args[:update_time] if args.key?(:update_time) end |