Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SandboxEnvironmentSnapshot
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SandboxEnvironmentSnapshot
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
SandboxEnvironmentSnapshot is a snapshot of the SandboxEnvironment.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Required.
-
#expire_time ⇒ String
Optional.
-
#name ⇒ String
Identifier.
-
#owner ⇒ String
Optional.
-
#parent_snapshot ⇒ String
Output only.
-
#post_snapshot_action ⇒ String
Optional.
-
#size_bytes ⇒ Fixnum
Optional.
-
#source_sandbox_environment ⇒ String
Required.
-
#ttl ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SandboxEnvironmentSnapshot
constructor
A new instance of GoogleCloudAiplatformV1SandboxEnvironmentSnapshot.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SandboxEnvironmentSnapshot
Returns a new instance of GoogleCloudAiplatformV1SandboxEnvironmentSnapshot.
36467 36468 36469 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36467 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp when this SandboxEnvironmentSnapshot was created.
Corresponds to the JSON property createTime
36402 36403 36404 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36402 def create_time @create_time end |
#display_name ⇒ String
Required. The display name of the SandboxEnvironmentSnapshot.
Corresponds to the JSON property displayName
36407 36408 36409 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36407 def display_name @display_name end |
#expire_time ⇒ String
Optional. Timestamp in UTC of when this SandboxEnvironmentSnapshot is
considered expired. This is always provided on output, regardless of what
expiration was sent on input.
Corresponds to the JSON property expireTime
36414 36415 36416 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36414 def expire_time @expire_time end |
#name ⇒ String
Identifier. The resource name of the SandboxEnvironmentSnapshot. Format:
projects/project/locations/location/reasoningEngines/reasoning_engine/
sandboxEnvironmentSnapshots/sandbox_environment_snapshot`
Corresponds to the JSON propertyname`
36421 36422 36423 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36421 def name @name end |
#owner ⇒ String
Optional. Owner information for this sandbox snapshot. Different owners will
have isolations on snapshot storage and identity. If not set, snapshot will be
created as the default owner.
Corresponds to the JSON property owner
36428 36429 36430 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36428 def owner @owner end |
#parent_snapshot ⇒ String
Output only. The resource name of the parent SandboxEnvironmentSnapshot. Empty
if this is a root Snapshot (the first snapshot from a newly created sandbox).
Can be used to reconstruct the whole ancestry tree of snapshots.
Corresponds to the JSON property parentSnapshot
36435 36436 36437 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36435 def parent_snapshot @parent_snapshot end |
#post_snapshot_action ⇒ String
Optional. Input only. Action to take on the source SandboxEnvironment after
the snapshot is taken. This field is only used in
CreateSandboxEnvironmentSnapshotRequest and it is not stored in the resource.
Corresponds to the JSON property postSnapshotAction
36442 36443 36444 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36442 def post_snapshot_action @post_snapshot_action end |
#size_bytes ⇒ Fixnum
Optional. Output only. Size of the snapshot data in bytes.
Corresponds to the JSON property sizeBytes
36447 36448 36449 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36447 def size_bytes @size_bytes end |
#source_sandbox_environment ⇒ String
Required. The resource name of the source SandboxEnvironment this snapshot was
taken from.
Corresponds to the JSON property sourceSandboxEnvironment
36453 36454 36455 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36453 def source_sandbox_environment @source_sandbox_environment end |
#ttl ⇒ String
Optional. Input only. The TTL for the sandbox environment snapshot. The
expiration time is computed: now + TTL.
Corresponds to the JSON property ttl
36459 36460 36461 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36459 def ttl @ttl end |
#update_time ⇒ String
Output only. The timestamp when this SandboxEnvironment was most recently
updated.
Corresponds to the JSON property updateTime
36465 36466 36467 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36465 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36472 36473 36474 36475 36476 36477 36478 36479 36480 36481 36482 36483 36484 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36472 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @expire_time = args[:expire_time] if args.key?(:expire_time) @name = args[:name] if args.key?(:name) @owner = args[:owner] if args.key?(:owner) @parent_snapshot = args[:parent_snapshot] if args.key?(:parent_snapshot) @post_snapshot_action = args[:post_snapshot_action] if args.key?(:post_snapshot_action) @size_bytes = args[:size_bytes] if args.key?(:size_bytes) @source_sandbox_environment = args[:source_sandbox_environment] if args.key?(:source_sandbox_environment) @ttl = args[:ttl] if args.key?(:ttl) @update_time = args[:update_time] if args.key?(:update_time) end |