Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SandboxEnvironmentSnapshot
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SandboxEnvironmentSnapshot
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
SandboxEnvironmentSnapshot is a snapshot of the SandboxEnvironment.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Required.
-
#expire_time ⇒ String
Optional.
-
#name ⇒ String
Identifier.
-
#owner ⇒ String
Optional.
-
#parent_snapshot ⇒ String
Output only.
-
#post_snapshot_action ⇒ String
Optional.
-
#size_bytes ⇒ Fixnum
Optional.
-
#source_sandbox_environment ⇒ String
Required.
-
#ttl ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SandboxEnvironmentSnapshot
constructor
A new instance of GoogleCloudAiplatformV1SandboxEnvironmentSnapshot.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SandboxEnvironmentSnapshot
Returns a new instance of GoogleCloudAiplatformV1SandboxEnvironmentSnapshot.
36036 36037 36038 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36036 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp when this SandboxEnvironmentSnapshot was created.
Corresponds to the JSON property createTime
35971 35972 35973 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35971 def create_time @create_time end |
#display_name ⇒ String
Required. The display name of the SandboxEnvironmentSnapshot.
Corresponds to the JSON property displayName
35976 35977 35978 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35976 def display_name @display_name end |
#expire_time ⇒ String
Optional. Timestamp in UTC of when this SandboxEnvironmentSnapshot is
considered expired. This is always provided on output, regardless of what
expiration was sent on input.
Corresponds to the JSON property expireTime
35983 35984 35985 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35983 def expire_time @expire_time end |
#name ⇒ String
Identifier. The resource name of the SandboxEnvironmentSnapshot. Format:
projects/project/locations/location/reasoningEngines/reasoning_engine/
sandboxEnvironmentSnapshots/sandbox_environment_snapshot`
Corresponds to the JSON propertyname`
35990 35991 35992 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35990 def name @name end |
#owner ⇒ String
Optional. Owner information for this sandbox snapshot. Different owners will
have isolations on snapshot storage and identity. If not set, snapshot will be
created as the default owner.
Corresponds to the JSON property owner
35997 35998 35999 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35997 def owner @owner end |
#parent_snapshot ⇒ String
Output only. The resource name of the parent SandboxEnvironmentSnapshot. Empty
if this is a root Snapshot (the first snapshot from a newly created sandbox).
Can be used to reconstruct the whole ancestry tree of snapshots.
Corresponds to the JSON property parentSnapshot
36004 36005 36006 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36004 def parent_snapshot @parent_snapshot end |
#post_snapshot_action ⇒ String
Optional. Input only. Action to take on the source SandboxEnvironment after
the snapshot is taken. This field is only used in
CreateSandboxEnvironmentSnapshotRequest and it is not stored in the resource.
Corresponds to the JSON property postSnapshotAction
36011 36012 36013 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36011 def post_snapshot_action @post_snapshot_action end |
#size_bytes ⇒ Fixnum
Optional. Output only. Size of the snapshot data in bytes.
Corresponds to the JSON property sizeBytes
36016 36017 36018 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36016 def size_bytes @size_bytes end |
#source_sandbox_environment ⇒ String
Required. The resource name of the source SandboxEnvironment this snapshot was
taken from.
Corresponds to the JSON property sourceSandboxEnvironment
36022 36023 36024 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36022 def source_sandbox_environment @source_sandbox_environment end |
#ttl ⇒ String
Optional. Input only. The TTL for the sandbox environment snapshot. The
expiration time is computed: now + TTL.
Corresponds to the JSON property ttl
36028 36029 36030 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36028 def ttl @ttl end |
#update_time ⇒ String
Output only. The timestamp when this SandboxEnvironment was most recently
updated.
Corresponds to the JSON property updateTime
36034 36035 36036 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36034 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36041 36042 36043 36044 36045 36046 36047 36048 36049 36050 36051 36052 36053 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36041 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @expire_time = args[:expire_time] if args.key?(:expire_time) @name = args[:name] if args.key?(:name) @owner = args[:owner] if args.key?(:owner) @parent_snapshot = args[:parent_snapshot] if args.key?(:parent_snapshot) @post_snapshot_action = args[:post_snapshot_action] if args.key?(:post_snapshot_action) @size_bytes = args[:size_bytes] if args.key?(:size_bytes) @source_sandbox_environment = args[:source_sandbox_environment] if args.key?(:source_sandbox_environment) @ttl = args[:ttl] if args.key?(:ttl) @update_time = args[:update_time] if args.key?(:update_time) end |