Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SandboxEnvironmentSnapshot

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

SandboxEnvironmentSnapshot is a snapshot of the SandboxEnvironment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SandboxEnvironmentSnapshot

Returns a new instance of GoogleCloudAiplatformV1SandboxEnvironmentSnapshot.



34650
34651
34652
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34650

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The timestamp when this SandboxEnvironmentSnapshot was created. Corresponds to the JSON property createTime

Returns:

  • (String)


34585
34586
34587
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34585

def create_time
  @create_time
end

#display_nameString

Required. The display name of the SandboxEnvironmentSnapshot. Corresponds to the JSON property displayName

Returns:

  • (String)


34590
34591
34592
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34590

def display_name
  @display_name
end

#expire_timeString

Optional. Timestamp in UTC of when this SandboxEnvironmentSnapshot is considered expired. This is always provided on output, regardless of what expiration was sent on input. Corresponds to the JSON property expireTime

Returns:

  • (String)


34597
34598
34599
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34597

def expire_time
  @expire_time
end

#nameString

Identifier. The resource name of the SandboxEnvironmentSnapshot. Format: projects/project/locations/location/reasoningEngines/reasoning_engine/ sandboxEnvironmentSnapshots/sandbox_environment_snapshot` Corresponds to the JSON propertyname`

Returns:

  • (String)


34604
34605
34606
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34604

def name
  @name
end

#ownerString

Optional. Owner information for this sandbox snapshot. Different owners will have isolations on snapshot storage and identity. If not set, snapshot will be created as the default owner. Corresponds to the JSON property owner

Returns:

  • (String)


34611
34612
34613
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34611

def owner
  @owner
end

#parent_snapshotString

Output only. The resource name of the parent SandboxEnvironmentSnapshot. Empty if this is a root Snapshot (the first snapshot from a newly created sandbox). Can be used to reconstruct the whole ancestry tree of snapshots. Corresponds to the JSON property parentSnapshot

Returns:

  • (String)


34618
34619
34620
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34618

def parent_snapshot
  @parent_snapshot
end

#post_snapshot_actionString

Optional. Input only. Action to take on the source SandboxEnvironment after the snapshot is taken. This field is only used in CreateSandboxEnvironmentSnapshotRequest and it is not stored in the resource. Corresponds to the JSON property postSnapshotAction

Returns:

  • (String)


34625
34626
34627
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34625

def post_snapshot_action
  @post_snapshot_action
end

#size_bytesFixnum

Optional. Output only. Size of the snapshot data in bytes. Corresponds to the JSON property sizeBytes

Returns:

  • (Fixnum)


34630
34631
34632
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34630

def size_bytes
  @size_bytes
end

#source_sandbox_environmentString

Required. The resource name of the source SandboxEnvironment this snapshot was taken from. Corresponds to the JSON property sourceSandboxEnvironment

Returns:

  • (String)


34636
34637
34638
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34636

def source_sandbox_environment
  @source_sandbox_environment
end

#ttlString

Optional. Input only. The TTL for the sandbox environment snapshot. The expiration time is computed: now + TTL. Corresponds to the JSON property ttl

Returns:

  • (String)


34642
34643
34644
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34642

def ttl
  @ttl
end

#update_timeString

Output only. The timestamp when this SandboxEnvironment was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


34648
34649
34650
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34648

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34655
34656
34657
34658
34659
34660
34661
34662
34663
34664
34665
34666
34667
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34655

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @name = args[:name] if args.key?(:name)
  @owner = args[:owner] if args.key?(:owner)
  @parent_snapshot = args[:parent_snapshot] if args.key?(:parent_snapshot)
  @post_snapshot_action = args[:post_snapshot_action] if args.key?(:post_snapshot_action)
  @size_bytes = args[:size_bytes] if args.key?(:size_bytes)
  @source_sandbox_environment = args[:source_sandbox_environment] if args.key?(:source_sandbox_environment)
  @ttl = args[:ttl] if args.key?(:ttl)
  @update_time = args[:update_time] if args.key?(:update_time)
end