Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SandboxEnvironmentTemplate
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SandboxEnvironmentTemplate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The specification of a SandboxEnvironmentTemplate. A SandboxEnvironmentTemplate defines a template for creating SandboxEnvironments.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#custom_container_environment ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SandboxEnvironmentTemplateCustomContainerEnvironment
The customized sandbox runtime environment for BYOC.
-
#default_container_environment ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SandboxEnvironmentTemplateDefaultContainerEnvironment
The default sandbox runtime environment for default container workloads.
-
#display_name ⇒ String
Required.
-
#egress_control_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SandboxEnvironmentTemplateEgressControlConfig
Configuration for egress control of sandbox instances.
-
#ingress_control_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PrivateServiceConnectConfig
Represents configuration for private service connect.
-
#name ⇒ String
Identifier.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SandboxEnvironmentTemplate
constructor
A new instance of GoogleCloudAiplatformV1SandboxEnvironmentTemplate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SandboxEnvironmentTemplate
Returns a new instance of GoogleCloudAiplatformV1SandboxEnvironmentTemplate.
37563 37564 37565 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37563 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp when this SandboxEnvironmentTemplate was created.
Corresponds to the JSON property createTime
37518 37519 37520 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37518 def create_time @create_time end |
#custom_container_environment ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SandboxEnvironmentTemplateCustomContainerEnvironment
The customized sandbox runtime environment for BYOC.
Corresponds to the JSON property customContainerEnvironment
37523 37524 37525 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37523 def custom_container_environment @custom_container_environment end |
#default_container_environment ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SandboxEnvironmentTemplateDefaultContainerEnvironment
The default sandbox runtime environment for default container workloads.
Corresponds to the JSON property defaultContainerEnvironment
37528 37529 37530 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37528 def default_container_environment @default_container_environment end |
#display_name ⇒ String
Required. The display name of the SandboxEnvironmentTemplate.
Corresponds to the JSON property displayName
37533 37534 37535 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37533 def display_name @display_name end |
#egress_control_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SandboxEnvironmentTemplateEgressControlConfig
Configuration for egress control of sandbox instances.
Corresponds to the JSON property egressControlConfig
37538 37539 37540 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37538 def egress_control_config @egress_control_config end |
#ingress_control_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PrivateServiceConnectConfig
Represents configuration for private service connect.
Corresponds to the JSON property ingressControlConfig
37543 37544 37545 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37543 def ingress_control_config @ingress_control_config end |
#name ⇒ String
Identifier. The resource name of the SandboxEnvironmentTemplate. Format:
projects/project/locations/location/reasoningEngines/reasoning_engine/
sandboxEnvironmentTemplates/sandbox_environment_template`
Corresponds to the JSON propertyname`
37550 37551 37552 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37550 def name @name end |
#state ⇒ String
Output only. The state of the sandbox environment template.
Corresponds to the JSON property state
37555 37556 37557 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37555 def state @state end |
#update_time ⇒ String
Output only. The timestamp when this SandboxEnvironmentTemplate was most
recently updated.
Corresponds to the JSON property updateTime
37561 37562 37563 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37561 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37568 37569 37570 37571 37572 37573 37574 37575 37576 37577 37578 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37568 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @custom_container_environment = args[:custom_container_environment] if args.key?(:custom_container_environment) @default_container_environment = args[:default_container_environment] if args.key?(:default_container_environment) @display_name = args[:display_name] if args.key?(:display_name) @egress_control_config = args[:egress_control_config] if args.key?(:egress_control_config) @ingress_control_config = args[:ingress_control_config] if args.key?(:ingress_control_config) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |