Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SandboxEnvironmentTemplate
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SandboxEnvironmentTemplate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The specification of a SandboxEnvironmentTemplate. A SandboxEnvironmentTemplate defines a template for creating SandboxEnvironments.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#custom_container_environment ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SandboxEnvironmentTemplateCustomContainerEnvironment
The customized sandbox runtime environment for BYOC.
-
#default_container_environment ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SandboxEnvironmentTemplateDefaultContainerEnvironment
The default sandbox runtime environment for default container workloads.
-
#display_name ⇒ String
Required.
-
#egress_control_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SandboxEnvironmentTemplateEgressControlConfig
Configuration for egress control of sandbox instances.
-
#name ⇒ String
Identifier.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SandboxEnvironmentTemplate
constructor
A new instance of GoogleCloudAiplatformV1SandboxEnvironmentTemplate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SandboxEnvironmentTemplate
Returns a new instance of GoogleCloudAiplatformV1SandboxEnvironmentTemplate.
36579 36580 36581 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36579 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp when this SandboxEnvironmentTemplate was created.
Corresponds to the JSON property createTime
36539 36540 36541 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36539 def create_time @create_time end |
#custom_container_environment ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SandboxEnvironmentTemplateCustomContainerEnvironment
The customized sandbox runtime environment for BYOC.
Corresponds to the JSON property customContainerEnvironment
36544 36545 36546 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36544 def custom_container_environment @custom_container_environment end |
#default_container_environment ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SandboxEnvironmentTemplateDefaultContainerEnvironment
The default sandbox runtime environment for default container workloads.
Corresponds to the JSON property defaultContainerEnvironment
36549 36550 36551 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36549 def default_container_environment @default_container_environment end |
#display_name ⇒ String
Required. The display name of the SandboxEnvironmentTemplate.
Corresponds to the JSON property displayName
36554 36555 36556 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36554 def display_name @display_name end |
#egress_control_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SandboxEnvironmentTemplateEgressControlConfig
Configuration for egress control of sandbox instances.
Corresponds to the JSON property egressControlConfig
36559 36560 36561 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36559 def egress_control_config @egress_control_config end |
#name ⇒ String
Identifier. The resource name of the SandboxEnvironmentTemplate. Format:
projects/project/locations/location/reasoningEngines/reasoning_engine/
sandboxEnvironmentTemplates/sandbox_environment_template`
Corresponds to the JSON propertyname`
36566 36567 36568 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36566 def name @name end |
#state ⇒ String
Output only. The state of the sandbox environment template.
Corresponds to the JSON property state
36571 36572 36573 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36571 def state @state end |
#update_time ⇒ String
Output only. The timestamp when this SandboxEnvironmentTemplate was most
recently updated.
Corresponds to the JSON property updateTime
36577 36578 36579 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36577 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36584 36585 36586 36587 36588 36589 36590 36591 36592 36593 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36584 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @custom_container_environment = args[:custom_container_environment] if args.key?(:custom_container_environment) @default_container_environment = args[:default_container_environment] if args.key?(:default_container_environment) @display_name = args[:display_name] if args.key?(:display_name) @egress_control_config = args[:egress_control_config] if args.key?(:egress_control_config) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |