Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SandboxEnvironmentTemplateEgressControlConfigDnsPeeringConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Configuration for peering a customer's private DNS zone so that sandbox egress can resolve customer-internal domains via the customer VPC.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SandboxEnvironmentTemplateEgressControlConfigDnsPeeringConfig

Returns a new instance of GoogleCloudAiplatformV1SandboxEnvironmentTemplateEgressControlConfigDnsPeeringConfig.



37265
37266
37267
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37265

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#domainString

Required. The DNS name suffix of the zone being peered to, e.g., "my-internal- domain.corp.". Must end with a dot. Corresponds to the JSON property domain

Returns:

  • (String)


37250
37251
37252
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37250

def domain
  @domain
end

#target_networkString

Required. The VPC network name in the target_project where the DNS zone specified by 'domain' is visible. Corresponds to the JSON property targetNetwork

Returns:

  • (String)


37256
37257
37258
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37256

def target_network
  @target_network
end

#target_projectString

Required. The project ID hosting the Cloud DNS managed zone that contains the ' domain'. The Vertex AI Service Agent requires the dns.peer role on this project. Corresponds to the JSON property targetProject

Returns:

  • (String)


37263
37264
37265
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37263

def target_project
  @target_project
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37270
37271
37272
37273
37274
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37270

def update!(**args)
  @domain = args[:domain] if args.key?(:domain)
  @target_network = args[:target_network] if args.key?(:target_network)
  @target_project = args[:target_project] if args.key?(:target_project)
end