Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schedule
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schedule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
An instance of a Schedule periodically schedules runs to make API calls based on user specified time specification and API request type.
Instance Attribute Summary collapse
-
#allow_queueing ⇒ Boolean
(also: #allow_queueing?)
Optional.
-
#catch_up ⇒ Boolean
(also: #catch_up?)
Output only.
-
#create_notebook_execution_job_request ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CreateNotebookExecutionJobRequest
Request message for [NotebookService.CreateNotebookExecutionJob] Corresponds to the JSON property
createNotebookExecutionJobRequest. -
#create_pipeline_job_request ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CreatePipelineJobRequest
Request message for PipelineService.CreatePipelineJob.
-
#create_time ⇒ String
Output only.
-
#cron ⇒ String
Cron schedule (https://en.wikipedia.org/wiki/Cron) to launch scheduled runs.
-
#display_name ⇒ String
Required.
-
#end_time ⇒ String
Optional.
-
#last_pause_time ⇒ String
Output only.
-
#last_resume_time ⇒ String
Output only.
-
#last_scheduled_run_response ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ScheduleRunResponse
Status of a scheduled run.
-
#max_concurrent_active_run_count ⇒ Fixnum
Optional.
-
#max_concurrent_run_count ⇒ Fixnum
Required.
-
#max_run_count ⇒ Fixnum
Optional.
-
#name ⇒ String
Immutable.
-
#next_run_time ⇒ String
Output only.
-
#start_time ⇒ String
Optional.
-
#started_run_count ⇒ Fixnum
Output only.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Schedule
constructor
A new instance of GoogleCloudAiplatformV1Schedule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Schedule
Returns a new instance of GoogleCloudAiplatformV1Schedule.
36983 36984 36985 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36983 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allow_queueing ⇒ Boolean Also known as: allow_queueing?
Optional. Whether new scheduled runs can be queued when max_concurrent_runs
limit is reached. If set to true, new runs will be queued instead of skipped.
Default to false.
Corresponds to the JSON property allowQueueing
36860 36861 36862 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36860 def allow_queueing @allow_queueing end |
#catch_up ⇒ Boolean Also known as: catch_up?
Output only. Whether to backfill missed runs when the schedule is resumed from
PAUSED state. If set to true, all missed runs will be scheduled. New runs will
be scheduled after the backfill is complete. Default to false.
Corresponds to the JSON property catchUp
36868 36869 36870 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36868 def catch_up @catch_up end |
#create_notebook_execution_job_request ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CreateNotebookExecutionJobRequest
Request message for [NotebookService.CreateNotebookExecutionJob]
Corresponds to the JSON property createNotebookExecutionJobRequest
36874 36875 36876 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36874 def create_notebook_execution_job_request @create_notebook_execution_job_request end |
#create_pipeline_job_request ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CreatePipelineJobRequest
Request message for PipelineService.CreatePipelineJob.
Corresponds to the JSON property createPipelineJobRequest
36879 36880 36881 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36879 def create_pipeline_job_request @create_pipeline_job_request end |
#create_time ⇒ String
Output only. Timestamp when this Schedule was created.
Corresponds to the JSON property createTime
36884 36885 36886 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36884 def create_time @create_time end |
#cron ⇒ String
Cron schedule (https://en.wikipedia.org/wiki/Cron) to launch scheduled runs.
To explicitly set a timezone to the cron tab, apply a prefix in the cron tab: "
CRON_TZ=$IANA_TIME_ZONE" or "TZ=$IANA_TIME_ZONE". The $IANA_TIME_ZONE
may only be a valid string from IANA time zone database. For example, "CRON_TZ=
America/New_York 1 * * * *", or "TZ=America/New_York 1 * * * *".
Corresponds to the JSON property cron
36893 36894 36895 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36893 def cron @cron end |
#display_name ⇒ String
Required. User provided name of the Schedule. The name can be up to 128
characters long and can consist of any UTF-8 characters.
Corresponds to the JSON property displayName
36899 36900 36901 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36899 def display_name @display_name end |
#end_time ⇒ String
Optional. Timestamp after which no new runs can be scheduled. If specified,
The schedule will be completed when either end_time is reached or when
scheduled_run_count >= max_run_count. If not specified, new runs will keep
getting scheduled until this Schedule is paused or deleted. Already scheduled
runs will be allowed to complete. Unset if not specified.
Corresponds to the JSON property endTime
36908 36909 36910 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36908 def end_time @end_time end |
#last_pause_time ⇒ String
Output only. Timestamp when this Schedule was last paused. Unset if never
paused.
Corresponds to the JSON property lastPauseTime
36914 36915 36916 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36914 def last_pause_time @last_pause_time end |
#last_resume_time ⇒ String
Output only. Timestamp when this Schedule was last resumed. Unset if never
resumed from pause.
Corresponds to the JSON property lastResumeTime
36920 36921 36922 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36920 def last_resume_time @last_resume_time end |
#last_scheduled_run_response ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ScheduleRunResponse
Status of a scheduled run.
Corresponds to the JSON property lastScheduledRunResponse
36925 36926 36927 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36925 def last_scheduled_run_response @last_scheduled_run_response end |
#max_concurrent_active_run_count ⇒ Fixnum
Optional. Specifies the maximum number of active runs that can be executed
concurrently for this Schedule. This limits the number of runs that can be in
a non-terminal state at the same time. Currently, this field is only supported
for requests of type CreatePipelineJobRequest.
Corresponds to the JSON property maxConcurrentActiveRunCount
36933 36934 36935 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36933 def max_concurrent_active_run_count @max_concurrent_active_run_count end |
#max_concurrent_run_count ⇒ Fixnum
Required. Maximum number of runs that can be started concurrently for this
Schedule. This is the limit for starting the scheduled requests and not the
execution of the operations/jobs created by the requests (if applicable).
Corresponds to the JSON property maxConcurrentRunCount
36940 36941 36942 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36940 def max_concurrent_run_count @max_concurrent_run_count end |
#max_run_count ⇒ Fixnum
Optional. Maximum run count of the schedule. If specified, The schedule will
be completed when either started_run_count >= max_run_count or when end_time
is reached. If not specified, new runs will keep getting scheduled until this
Schedule is paused or deleted. Already scheduled runs will be allowed to
complete. Unset if not specified.
Corresponds to the JSON property maxRunCount
36949 36950 36951 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36949 def max_run_count @max_run_count end |
#name ⇒ String
Immutable. The resource name of the Schedule.
Corresponds to the JSON property name
36954 36955 36956 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36954 def name @name end |
#next_run_time ⇒ String
Output only. Timestamp when this Schedule should schedule the next run. Having
a next_run_time in the past means the runs are being started behind schedule.
Corresponds to the JSON property nextRunTime
36960 36961 36962 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36960 def next_run_time @next_run_time end |
#start_time ⇒ String
Optional. Timestamp after which the first run can be scheduled. Default to
Schedule create time if not specified.
Corresponds to the JSON property startTime
36966 36967 36968 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36966 def start_time @start_time end |
#started_run_count ⇒ Fixnum
Output only. The number of runs started by this schedule.
Corresponds to the JSON property startedRunCount
36971 36972 36973 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36971 def started_run_count @started_run_count end |
#state ⇒ String
Output only. The state of this Schedule.
Corresponds to the JSON property state
36976 36977 36978 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36976 def state @state end |
#update_time ⇒ String
Output only. Timestamp when this Schedule was updated.
Corresponds to the JSON property updateTime
36981 36982 36983 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36981 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36988 36989 36990 36991 36992 36993 36994 36995 36996 36997 36998 36999 37000 37001 37002 37003 37004 37005 37006 37007 37008 37009 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36988 def update!(**args) @allow_queueing = args[:allow_queueing] if args.key?(:allow_queueing) @catch_up = args[:catch_up] if args.key?(:catch_up) @create_notebook_execution_job_request = args[:create_notebook_execution_job_request] if args.key?(:create_notebook_execution_job_request) @create_pipeline_job_request = args[:create_pipeline_job_request] if args.key?(:create_pipeline_job_request) @create_time = args[:create_time] if args.key?(:create_time) @cron = args[:cron] if args.key?(:cron) @display_name = args[:display_name] if args.key?(:display_name) @end_time = args[:end_time] if args.key?(:end_time) @last_pause_time = args[:last_pause_time] if args.key?(:last_pause_time) @last_resume_time = args[:last_resume_time] if args.key?(:last_resume_time) @last_scheduled_run_response = args[:last_scheduled_run_response] if args.key?(:last_scheduled_run_response) @max_concurrent_active_run_count = args[:max_concurrent_active_run_count] if args.key?(:max_concurrent_active_run_count) @max_concurrent_run_count = args[:max_concurrent_run_count] if args.key?(:max_concurrent_run_count) @max_run_count = args[:max_run_count] if args.key?(:max_run_count) @name = args[:name] if args.key?(:name) @next_run_time = args[:next_run_time] if args.key?(:next_run_time) @start_time = args[:start_time] if args.key?(:start_time) @started_run_count = args[:started_run_count] if args.key?(:started_run_count) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |