Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schedule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

An instance of a Schedule periodically schedules runs to make API calls based on user specified time specification and API request type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Schedule

Returns a new instance of GoogleCloudAiplatformV1Schedule.



18760
18761
18762
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18760

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_queueingBoolean Also known as: allow_queueing?

Optional. Whether new scheduled runs can be queued when max_concurrent_runs limit is reached. If set to true, new runs will be queued instead of skipped. Default to false. Corresponds to the JSON property allowQueueing

Returns:

  • (Boolean)


18650
18651
18652
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18650

def allow_queueing
  @allow_queueing
end

#catch_upBoolean Also known as: catch_up?

Output only. Whether to backfill missed runs when the schedule is resumed from PAUSED state. If set to true, all missed runs will be scheduled. New runs will be scheduled after the backfill is complete. Default to false. Corresponds to the JSON property catchUp

Returns:

  • (Boolean)


18658
18659
18660
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18658

def catch_up
  @catch_up
end

#create_pipeline_job_requestGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1CreatePipelineJobRequest

Request message for PipelineService.CreatePipelineJob. Corresponds to the JSON property createPipelineJobRequest



18664
18665
18666
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18664

def create_pipeline_job_request
  @create_pipeline_job_request
end

#create_timeString

Output only. Timestamp when this Schedule was created. Corresponds to the JSON property createTime

Returns:

  • (String)


18669
18670
18671
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18669

def create_time
  @create_time
end

#cronString

Cron schedule (https://en.wikipedia.org/wiki/Cron) to launch scheduled runs. To explicitly set a timezone to the cron tab, apply a prefix in the cron tab: " CRON_TZ=$IANA_TIME_ZONE" or "TZ=$IANA_TIME_ZONE". The $IANA_TIME_ZONE may only be a valid string from IANA time zone database. For example, "CRON_TZ= America/New_York 1 * * * *", or "TZ=America/New_York 1 * * * *". Corresponds to the JSON property cron

Returns:

  • (String)


18678
18679
18680
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18678

def cron
  @cron
end

#display_nameString

Required. User provided name of the Schedule. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


18684
18685
18686
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18684

def display_name
  @display_name
end

#end_timeString

Optional. Timestamp after which no new runs can be scheduled. If specified, The schedule will be completed when either end_time is reached or when scheduled_run_count >= max_run_count. If not specified, new runs will keep getting scheduled until this Schedule is paused or deleted. Already scheduled runs will be allowed to complete. Unset if not specified. Corresponds to the JSON property endTime

Returns:

  • (String)


18693
18694
18695
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18693

def end_time
  @end_time
end

#last_pause_timeString

Output only. Timestamp when this Schedule was last paused. Unset if never paused. Corresponds to the JSON property lastPauseTime

Returns:

  • (String)


18699
18700
18701
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18699

def last_pause_time
  @last_pause_time
end

#last_resume_timeString

Output only. Timestamp when this Schedule was last resumed. Unset if never resumed from pause. Corresponds to the JSON property lastResumeTime

Returns:

  • (String)


18705
18706
18707
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18705

def last_resume_time
  @last_resume_time
end

#last_scheduled_run_responseGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ScheduleRunResponse

Status of a scheduled run. Corresponds to the JSON property lastScheduledRunResponse



18710
18711
18712
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18710

def last_scheduled_run_response
  @last_scheduled_run_response
end

#max_concurrent_run_countFixnum

Required. Maximum number of runs that can be started concurrently for this Schedule. This is the limit for starting the scheduled requests and not the execution of the operations/jobs created by the requests (if applicable). Corresponds to the JSON property maxConcurrentRunCount

Returns:

  • (Fixnum)


18717
18718
18719
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18717

def max_concurrent_run_count
  @max_concurrent_run_count
end

#max_run_countFixnum

Optional. Maximum run count of the schedule. If specified, The schedule will be completed when either started_run_count >= max_run_count or when end_time is reached. If not specified, new runs will keep getting scheduled until this Schedule is paused or deleted. Already scheduled runs will be allowed to complete. Unset if not specified. Corresponds to the JSON property maxRunCount

Returns:

  • (Fixnum)


18726
18727
18728
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18726

def max_run_count
  @max_run_count
end

#nameString

Immutable. The resource name of the Schedule. Corresponds to the JSON property name

Returns:

  • (String)


18731
18732
18733
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18731

def name
  @name
end

#next_run_timeString

Output only. Timestamp when this Schedule should schedule the next run. Having a next_run_time in the past means the runs are being started behind schedule. Corresponds to the JSON property nextRunTime

Returns:

  • (String)


18737
18738
18739
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18737

def next_run_time
  @next_run_time
end

#start_timeString

Optional. Timestamp after which the first run can be scheduled. Default to Schedule create time if not specified. Corresponds to the JSON property startTime

Returns:

  • (String)


18743
18744
18745
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18743

def start_time
  @start_time
end

#started_run_countFixnum

Output only. The number of runs started by this schedule. Corresponds to the JSON property startedRunCount

Returns:

  • (Fixnum)


18748
18749
18750
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18748

def started_run_count
  @started_run_count
end

#stateString

Output only. The state of this Schedule. Corresponds to the JSON property state

Returns:

  • (String)


18753
18754
18755
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18753

def state
  @state
end

#update_timeString

Output only. Timestamp when this Schedule was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


18758
18759
18760
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18758

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18765
18766
18767
18768
18769
18770
18771
18772
18773
18774
18775
18776
18777
18778
18779
18780
18781
18782
18783
18784
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18765

def update!(**args)
  @allow_queueing = args[:allow_queueing] if args.key?(:allow_queueing)
  @catch_up = args[:catch_up] if args.key?(:catch_up)
  @create_pipeline_job_request = args[:create_pipeline_job_request] if args.key?(:create_pipeline_job_request)
  @create_time = args[:create_time] if args.key?(:create_time)
  @cron = args[:cron] if args.key?(:cron)
  @display_name = args[:display_name] if args.key?(:display_name)
  @end_time = args[:end_time] if args.key?(:end_time)
  @last_pause_time = args[:last_pause_time] if args.key?(:last_pause_time)
  @last_resume_time = args[:last_resume_time] if args.key?(:last_resume_time)
  @last_scheduled_run_response = args[:last_scheduled_run_response] if args.key?(:last_scheduled_run_response)
  @max_concurrent_run_count = args[:max_concurrent_run_count] if args.key?(:max_concurrent_run_count)
  @max_run_count = args[:max_run_count] if args.key?(:max_run_count)
  @name = args[:name] if args.key?(:name)
  @next_run_time = args[:next_run_time] if args.key?(:next_run_time)
  @start_time = args[:start_time] if args.key?(:start_time)
  @started_run_count = args[:started_run_count] if args.key?(:started_run_count)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end