Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Scheduling

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

All parameters related to queuing and scheduling of custom jobs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Scheduling

Returns a new instance of GoogleCloudAiplatformV1Scheduling.



21315
21316
21317
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21315

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disable_retriesBoolean Also known as: disable_retries?

Optional. Indicates if the job should retry for internal errors after the job starts running. If true, overrides Scheduling.restart_job_on_worker_restart to false. Corresponds to the JSON property disableRetries

Returns:

  • (Boolean)


21294
21295
21296
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21294

def disable_retries
  @disable_retries
end

#restart_job_on_worker_restartBoolean Also known as: restart_job_on_worker_restart?

Restarts the entire CustomJob if a worker gets restarted. This feature can be used by distributed training jobs that are not resilient to workers leaving and joining a job. Corresponds to the JSON property restartJobOnWorkerRestart

Returns:

  • (Boolean)


21302
21303
21304
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21302

def restart_job_on_worker_restart
  @restart_job_on_worker_restart
end

#strategyString

Optional. This determines which type of scheduling strategy to use. Corresponds to the JSON property strategy

Returns:

  • (String)


21308
21309
21310
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21308

def strategy
  @strategy
end

#timeoutString

The maximum job running time. The default is 7 days. Corresponds to the JSON property timeout

Returns:

  • (String)


21313
21314
21315
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21313

def timeout
  @timeout
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21320
21321
21322
21323
21324
21325
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21320

def update!(**args)
  @disable_retries = args[:disable_retries] if args.key?(:disable_retries)
  @restart_job_on_worker_restart = args[:restart_job_on_worker_restart] if args.key?(:restart_job_on_worker_restart)
  @strategy = args[:strategy] if args.key?(:strategy)
  @timeout = args[:timeout] if args.key?(:timeout)
end