Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Defines the schema of input and output data. This is a subset of the OpenAPI 3.0 Schema Object.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Schema

Returns a new instance of GoogleCloudAiplatformV1Schema.



37256
37257
37258
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37256

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_propertiesObject

Optional. If type is OBJECT, specifies how to handle properties not defined in properties. If it is a boolean false, no additional properties are allowed. If it is a schema, additional properties are allowed if they conform to the schema. Corresponds to the JSON property additionalProperties

Returns:

  • (Object)


37100
37101
37102
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37100

def additional_properties
  @additional_properties
end

#any_ofArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema>

Optional. The instance must be valid against any (one or more) of the subschemas listed in any_of. Corresponds to the JSON property anyOf



37106
37107
37108
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37106

def any_of
  @any_of
end

#defaultObject

Optional. Default value to use if the field is not specified. Corresponds to the JSON property default

Returns:

  • (Object)


37111
37112
37113
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37111

def default
  @default
end

#defsHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema>

Optional. defs provides a map of schema definitions that can be reused by ref elsewhere in the schema. Only allowed at root level of the schema. Corresponds to the JSON property defs



37117
37118
37119
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37117

def defs
  @defs
end

#descriptionString

Optional. Describes the data. The model uses this field to understand the purpose of the schema and how to use it. It is a best practice to provide a clear and descriptive explanation for the schema and its properties here, rather than in the prompt. Corresponds to the JSON property description

Returns:

  • (String)


37125
37126
37127
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37125

def description
  @description
end

#enumArray<String>

Optional. Possible values of the field. This field can be used to restrict a value to a fixed set of values. To mark a field as an enum, set format to enum and provide the list of possible values in enum. For example: 1. To define directions: type:STRING, format:enum, enum:["EAST", "NORTH", "SOUTH", "WEST"] 2. To define apartment numbers: type:INTEGER, format:enum, enum:[" 101", "201", "301"] Corresponds to the JSON property enum

Returns:

  • (Array<String>)


37135
37136
37137
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37135

def enum
  @enum
end

#exampleObject

Optional. Example of an instance of this schema. Corresponds to the JSON property example

Returns:

  • (Object)


37140
37141
37142
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37140

def example
  @example
end

#formatString

Optional. The format of the data. For NUMBER type, format can be float or double. For INTEGER type, format can be int32 or int64. For STRING type, format can be email, byte, date, date-time, password, and other formats to further refine the data type. Corresponds to the JSON property format

Returns:

  • (String)


37148
37149
37150
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37148

def format
  @format
end

#itemsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema

Defines the schema of input and output data. This is a subset of the OpenAPI 3.0 Schema Object. Corresponds to the JSON property items



37154
37155
37156
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37154

def items
  @items
end

#max_itemsFixnum

Optional. If type is ARRAY, max_items specifies the maximum number of items in an array. Corresponds to the JSON property maxItems

Returns:

  • (Fixnum)


37160
37161
37162
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37160

def max_items
  @max_items
end

#max_lengthFixnum

Optional. If type is STRING, max_length specifies the maximum length of the string. Corresponds to the JSON property maxLength

Returns:

  • (Fixnum)


37166
37167
37168
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37166

def max_length
  @max_length
end

#max_propertiesFixnum

Optional. If type is OBJECT, max_properties specifies the maximum number of properties that can be provided. Corresponds to the JSON property maxProperties

Returns:

  • (Fixnum)


37172
37173
37174
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37172

def max_properties
  @max_properties
end

#maximumFloat

Optional. If type is INTEGER or NUMBER, maximum specifies the maximum allowed value. Corresponds to the JSON property maximum

Returns:

  • (Float)


37178
37179
37180
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37178

def maximum
  @maximum
end

#min_itemsFixnum

Optional. If type is ARRAY, min_items specifies the minimum number of items in an array. Corresponds to the JSON property minItems

Returns:

  • (Fixnum)


37184
37185
37186
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37184

def min_items
  @min_items
end

#min_lengthFixnum

Optional. If type is STRING, min_length specifies the minimum length of the string. Corresponds to the JSON property minLength

Returns:

  • (Fixnum)


37190
37191
37192
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37190

def min_length
  @min_length
end

#min_propertiesFixnum

Optional. If type is OBJECT, min_properties specifies the minimum number of properties that can be provided. Corresponds to the JSON property minProperties

Returns:

  • (Fixnum)


37196
37197
37198
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37196

def min_properties
  @min_properties
end

#minimumFloat

Optional. If type is INTEGER or NUMBER, minimum specifies the minimum allowed value. Corresponds to the JSON property minimum

Returns:

  • (Float)


37202
37203
37204
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37202

def minimum
  @minimum
end

#nullableBoolean Also known as: nullable?

Optional. Indicates if the value of this field can be null. Corresponds to the JSON property nullable

Returns:

  • (Boolean)


37207
37208
37209
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37207

def nullable
  @nullable
end

#patternString

Optional. If type is STRING, pattern specifies a regular expression that the string must match. Corresponds to the JSON property pattern

Returns:

  • (String)


37214
37215
37216
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37214

def pattern
  @pattern
end

#propertiesHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema>

Optional. If type is OBJECT, properties is a map of property names to schema definitions for each property of the object. Corresponds to the JSON property properties



37220
37221
37222
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37220

def properties
  @properties
end

#property_orderingArray<String>

Optional. Order of properties displayed or used where order matters. This is not a standard field in OpenAPI specification, but can be used to control the order of properties. Corresponds to the JSON property propertyOrdering

Returns:

  • (Array<String>)


37227
37228
37229
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37227

def property_ordering
  @property_ordering
end

#refString

Optional. Allows referencing another schema definition to use in place of this schema. The value must be a valid reference to a schema in defs. For example, the following schema defines a reference to a schema node named "Pet": type: object properties: pet: ref: #/defs/Pet defs: Pet: type: object properties: name: type: string The value of the "pet" property is a reference to the schema node named "Pet". See details in https://json-schema.org/understanding- json-schema/structuring Corresponds to the JSON property ref

Returns:

  • (String)


37238
37239
37240
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37238

def ref
  @ref
end

#requiredArray<String>

Optional. If type is OBJECT, required lists the names of properties that must be present. Corresponds to the JSON property required

Returns:

  • (Array<String>)


37244
37245
37246
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37244

def required
  @required
end

#titleString

Optional. Title for the schema. Corresponds to the JSON property title

Returns:

  • (String)


37249
37250
37251
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37249

def title
  @title
end

#typeString

Optional. Data type of the schema field. Corresponds to the JSON property type

Returns:

  • (String)


37254
37255
37256
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37254

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37261
37262
37263
37264
37265
37266
37267
37268
37269
37270
37271
37272
37273
37274
37275
37276
37277
37278
37279
37280
37281
37282
37283
37284
37285
37286
37287
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37261

def update!(**args)
  @additional_properties = args[:additional_properties] if args.key?(:additional_properties)
  @any_of = args[:any_of] if args.key?(:any_of)
  @default = args[:default] if args.key?(:default)
  @defs = args[:defs] if args.key?(:defs)
  @description = args[:description] if args.key?(:description)
  @enum = args[:enum] if args.key?(:enum)
  @example = args[:example] if args.key?(:example)
  @format = args[:format] if args.key?(:format)
  @items = args[:items] if args.key?(:items)
  @max_items = args[:max_items] if args.key?(:max_items)
  @max_length = args[:max_length] if args.key?(:max_length)
  @max_properties = args[:max_properties] if args.key?(:max_properties)
  @maximum = args[:maximum] if args.key?(:maximum)
  @min_items = args[:min_items] if args.key?(:min_items)
  @min_length = args[:min_length] if args.key?(:min_length)
  @min_properties = args[:min_properties] if args.key?(:min_properties)
  @minimum = args[:minimum] if args.key?(:minimum)
  @nullable = args[:nullable] if args.key?(:nullable)
  @pattern = args[:pattern] if args.key?(:pattern)
  @properties = args[:properties] if args.key?(:properties)
  @property_ordering = args[:property_ordering] if args.key?(:property_ordering)
  @ref = args[:ref] if args.key?(:ref)
  @required = args[:required] if args.key?(:required)
  @title = args[:title] if args.key?(:title)
  @type = args[:type] if args.key?(:type)
end