Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Schema is used to define the format of input/output data. Represents a select subset of an OpenAPI 3.0 schema object. More fields may be added in the future as needed.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Optional.
-
#any_of ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema>
Optional.
-
#default ⇒ Object
Optional.
-
#defs ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema>
Optional.
-
#description ⇒ String
Optional.
-
#enum ⇒ Array<String>
Optional.
-
#example ⇒ Object
Optional.
-
#format ⇒ String
Optional.
-
#items ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema
Schema is used to define the format of input/output data.
-
#max_items ⇒ Fixnum
Optional.
-
#max_length ⇒ Fixnum
Optional.
-
#max_properties ⇒ Fixnum
Optional.
-
#maximum ⇒ Float
Optional.
-
#min_items ⇒ Fixnum
Optional.
-
#min_length ⇒ Fixnum
Optional.
-
#min_properties ⇒ Fixnum
Optional.
-
#minimum ⇒ Float
Optional.
-
#nullable ⇒ Boolean
(also: #nullable?)
Optional.
-
#pattern ⇒ String
Optional.
-
#properties ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema>
Optional.
-
#property_ordering ⇒ Array<String>
Optional.
-
#ref ⇒ String
Optional.
-
#required ⇒ Array<String>
Optional.
-
#title ⇒ String
Optional.
-
#type ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Schema
constructor
A new instance of GoogleCloudAiplatformV1Schema.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Schema
Returns a new instance of GoogleCloudAiplatformV1Schema.
27535 27536 27537 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27535 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_properties ⇒ Object
Optional. Can either be a boolean or an object; controls the presence of
additional properties.
Corresponds to the JSON property additionalProperties
27393 27394 27395 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27393 def additional_properties @additional_properties end |
#any_of ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema>
Optional. The value should be validated against any (one or more) of the
subschemas in the list.
Corresponds to the JSON property anyOf
27399 27400 27401 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27399 def any_of @any_of end |
#default ⇒ Object
Optional. Default value of the data.
Corresponds to the JSON property default
27404 27405 27406 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27404 def default @default end |
#defs ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema>
Optional. A map of definitions for use by ref Only allowed at the root of
the schema.
Corresponds to the JSON property defs
27410 27411 27412 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27410 def defs @defs end |
#description ⇒ String
Optional. The description of the data.
Corresponds to the JSON property description
27415 27416 27417 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27415 def description @description end |
#enum ⇒ Array<String>
Optional. Possible values of the element of primitive type with enum format.
Examples: 1. We can define direction as : type:STRING, format:enum, enum:["
EAST", NORTH", "SOUTH", "WEST"] 2. We can define apartment number as : type:
INTEGER, format:enum, enum:["101", "201", "301"]
Corresponds to the JSON property enum
27423 27424 27425 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27423 def enum @enum end |
#example ⇒ Object
Optional. Example of the object. Will only populated when the object is the
root.
Corresponds to the JSON property example
27429 27430 27431 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27429 def example @example end |
#format ⇒ String
Optional. The format of the data. Supported formats: for NUMBER type: "float",
"double" for INTEGER type: "int32", "int64" for STRING type: "email", "byte",
etc
Corresponds to the JSON property format
27436 27437 27438 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27436 def format @format end |
#items ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema
Schema is used to define the format of input/output data. Represents a select
subset of an OpenAPI 3.0 schema object. More fields may be added in the future as needed.
Corresponds to the JSON property items
27443 27444 27445 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27443 def items @items end |
#max_items ⇒ Fixnum
Optional. Maximum number of the elements for Type.ARRAY.
Corresponds to the JSON property maxItems
27448 27449 27450 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27448 def max_items @max_items end |
#max_length ⇒ Fixnum
Optional. Maximum length of the Type.STRING
Corresponds to the JSON property maxLength
27453 27454 27455 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27453 def max_length @max_length end |
#max_properties ⇒ Fixnum
Optional. Maximum number of the properties for Type.OBJECT.
Corresponds to the JSON property maxProperties
27458 27459 27460 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27458 def max_properties @max_properties end |
#maximum ⇒ Float
Optional. Maximum value of the Type.INTEGER and Type.NUMBER
Corresponds to the JSON property maximum
27463 27464 27465 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27463 def maximum @maximum end |
#min_items ⇒ Fixnum
Optional. Minimum number of the elements for Type.ARRAY.
Corresponds to the JSON property minItems
27468 27469 27470 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27468 def min_items @min_items end |
#min_length ⇒ Fixnum
Optional. SCHEMA FIELDS FOR TYPE STRING Minimum length of the Type.STRING
Corresponds to the JSON property minLength
27473 27474 27475 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27473 def min_length @min_length end |
#min_properties ⇒ Fixnum
Optional. Minimum number of the properties for Type.OBJECT.
Corresponds to the JSON property minProperties
27478 27479 27480 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27478 def min_properties @min_properties end |
#minimum ⇒ Float
Optional. SCHEMA FIELDS FOR TYPE INTEGER and NUMBER Minimum value of the Type.
INTEGER and Type.NUMBER
Corresponds to the JSON property minimum
27484 27485 27486 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27484 def minimum @minimum end |
#nullable ⇒ Boolean Also known as: nullable?
Optional. Indicates if the value may be null.
Corresponds to the JSON property nullable
27489 27490 27491 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27489 def nullable @nullable end |
#pattern ⇒ String
Optional. Pattern of the Type.STRING to restrict a string to a regular
expression.
Corresponds to the JSON property pattern
27496 27497 27498 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27496 def pattern @pattern end |
#properties ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema>
Optional. SCHEMA FIELDS FOR TYPE OBJECT Properties of Type.OBJECT.
Corresponds to the JSON property properties
27501 27502 27503 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27501 def properties @properties end |
#property_ordering ⇒ Array<String>
Optional. The order of the properties. Not a standard field in open api spec.
Only used to support the order of the properties.
Corresponds to the JSON property propertyOrdering
27507 27508 27509 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27507 def property_ordering @property_ordering end |
#ref ⇒ String
Optional. Allows indirect references between schema nodes. The value should be
a valid reference to a child of the root defs. For example, the following
schema defines a reference to a schema node named "Pet": type: object
properties: pet: ref: #/defs/Pet defs: Pet: type: object properties: name:
type: string The value of the "pet" property is a reference to the schema node
named "Pet". See details in https://json-schema.org/understanding-json-schema/
structuring
Corresponds to the JSON property ref
27518 27519 27520 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27518 def ref @ref end |
#required ⇒ Array<String>
Optional. Required properties of Type.OBJECT.
Corresponds to the JSON property required
27523 27524 27525 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27523 def required @required end |
#title ⇒ String
Optional. The title of the Schema.
Corresponds to the JSON property title
27528 27529 27530 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27528 def title @title end |
#type ⇒ String
Optional. The type of the data.
Corresponds to the JSON property type
27533 27534 27535 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27533 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27540 27541 27542 27543 27544 27545 27546 27547 27548 27549 27550 27551 27552 27553 27554 27555 27556 27557 27558 27559 27560 27561 27562 27563 27564 27565 27566 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27540 def update!(**args) @additional_properties = args[:additional_properties] if args.key?(:additional_properties) @any_of = args[:any_of] if args.key?(:any_of) @default = args[:default] if args.key?(:default) @defs = args[:defs] if args.key?(:defs) @description = args[:description] if args.key?(:description) @enum = args[:enum] if args.key?(:enum) @example = args[:example] if args.key?(:example) @format = args[:format] if args.key?(:format) @items = args[:items] if args.key?(:items) @max_items = args[:max_items] if args.key?(:max_items) @max_length = args[:max_length] if args.key?(:max_length) @max_properties = args[:max_properties] if args.key?(:max_properties) @maximum = args[:maximum] if args.key?(:maximum) @min_items = args[:min_items] if args.key?(:min_items) @min_length = args[:min_length] if args.key?(:min_length) @min_properties = args[:min_properties] if args.key?(:min_properties) @minimum = args[:minimum] if args.key?(:minimum) @nullable = args[:nullable] if args.key?(:nullable) @pattern = args[:pattern] if args.key?(:pattern) @properties = args[:properties] if args.key?(:properties) @property_ordering = args[:property_ordering] if args.key?(:property_ordering) @ref = args[:ref] if args.key?(:ref) @required = args[:required] if args.key?(:required) @title = args[:title] if args.key?(:title) @type = args[:type] if args.key?(:type) end |