Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Schema is used to define the format of input/output data. Represents a select subset of an OpenAPI 3.0 schema object. More fields may be added in the future as needed.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Optional.
-
#any_of ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema>
Optional.
-
#default ⇒ Object
Optional.
-
#defs ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema>
Optional.
-
#description ⇒ String
Optional.
-
#enum ⇒ Array<String>
Optional.
-
#example ⇒ Object
Optional.
-
#format ⇒ String
Optional.
-
#items ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema
Schema is used to define the format of input/output data.
-
#max_items ⇒ Fixnum
Optional.
-
#max_length ⇒ Fixnum
Optional.
-
#max_properties ⇒ Fixnum
Optional.
-
#maximum ⇒ Float
Optional.
-
#min_items ⇒ Fixnum
Optional.
-
#min_length ⇒ Fixnum
Optional.
-
#min_properties ⇒ Fixnum
Optional.
-
#minimum ⇒ Float
Optional.
-
#nullable ⇒ Boolean
(also: #nullable?)
Optional.
-
#pattern ⇒ String
Optional.
-
#properties ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema>
Optional.
-
#property_ordering ⇒ Array<String>
Optional.
-
#ref ⇒ String
Optional.
-
#required ⇒ Array<String>
Optional.
-
#title ⇒ String
Optional.
-
#type ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Schema
constructor
A new instance of GoogleCloudAiplatformV1Schema.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Schema
Returns a new instance of GoogleCloudAiplatformV1Schema.
27382 27383 27384 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27382 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_properties ⇒ Object
Optional. Can either be a boolean or an object; controls the presence of
additional properties.
Corresponds to the JSON property additionalProperties
27240 27241 27242 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27240 def additional_properties @additional_properties end |
#any_of ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema>
Optional. The value should be validated against any (one or more) of the
subschemas in the list.
Corresponds to the JSON property anyOf
27246 27247 27248 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27246 def any_of @any_of end |
#default ⇒ Object
Optional. Default value of the data.
Corresponds to the JSON property default
27251 27252 27253 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27251 def default @default end |
#defs ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema>
Optional. A map of definitions for use by ref Only allowed at the root of
the schema.
Corresponds to the JSON property defs
27257 27258 27259 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27257 def defs @defs end |
#description ⇒ String
Optional. The description of the data.
Corresponds to the JSON property description
27262 27263 27264 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27262 def description @description end |
#enum ⇒ Array<String>
Optional. Possible values of the element of primitive type with enum format.
Examples: 1. We can define direction as : type:STRING, format:enum, enum:["
EAST", NORTH", "SOUTH", "WEST"] 2. We can define apartment number as : type:
INTEGER, format:enum, enum:["101", "201", "301"]
Corresponds to the JSON property enum
27270 27271 27272 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27270 def enum @enum end |
#example ⇒ Object
Optional. Example of the object. Will only populated when the object is the
root.
Corresponds to the JSON property example
27276 27277 27278 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27276 def example @example end |
#format ⇒ String
Optional. The format of the data. Supported formats: for NUMBER type: "float",
"double" for INTEGER type: "int32", "int64" for STRING type: "email", "byte",
etc
Corresponds to the JSON property format
27283 27284 27285 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27283 def format @format end |
#items ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema
Schema is used to define the format of input/output data. Represents a select
subset of an OpenAPI 3.0 schema object. More fields may be added in the future as needed.
Corresponds to the JSON property items
27290 27291 27292 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27290 def items @items end |
#max_items ⇒ Fixnum
Optional. Maximum number of the elements for Type.ARRAY.
Corresponds to the JSON property maxItems
27295 27296 27297 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27295 def max_items @max_items end |
#max_length ⇒ Fixnum
Optional. Maximum length of the Type.STRING
Corresponds to the JSON property maxLength
27300 27301 27302 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27300 def max_length @max_length end |
#max_properties ⇒ Fixnum
Optional. Maximum number of the properties for Type.OBJECT.
Corresponds to the JSON property maxProperties
27305 27306 27307 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27305 def max_properties @max_properties end |
#maximum ⇒ Float
Optional. Maximum value of the Type.INTEGER and Type.NUMBER
Corresponds to the JSON property maximum
27310 27311 27312 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27310 def maximum @maximum end |
#min_items ⇒ Fixnum
Optional. Minimum number of the elements for Type.ARRAY.
Corresponds to the JSON property minItems
27315 27316 27317 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27315 def min_items @min_items end |
#min_length ⇒ Fixnum
Optional. SCHEMA FIELDS FOR TYPE STRING Minimum length of the Type.STRING
Corresponds to the JSON property minLength
27320 27321 27322 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27320 def min_length @min_length end |
#min_properties ⇒ Fixnum
Optional. Minimum number of the properties for Type.OBJECT.
Corresponds to the JSON property minProperties
27325 27326 27327 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27325 def min_properties @min_properties end |
#minimum ⇒ Float
Optional. SCHEMA FIELDS FOR TYPE INTEGER and NUMBER Minimum value of the Type.
INTEGER and Type.NUMBER
Corresponds to the JSON property minimum
27331 27332 27333 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27331 def minimum @minimum end |
#nullable ⇒ Boolean Also known as: nullable?
Optional. Indicates if the value may be null.
Corresponds to the JSON property nullable
27336 27337 27338 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27336 def nullable @nullable end |
#pattern ⇒ String
Optional. Pattern of the Type.STRING to restrict a string to a regular
expression.
Corresponds to the JSON property pattern
27343 27344 27345 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27343 def pattern @pattern end |
#properties ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema>
Optional. SCHEMA FIELDS FOR TYPE OBJECT Properties of Type.OBJECT.
Corresponds to the JSON property properties
27348 27349 27350 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27348 def properties @properties end |
#property_ordering ⇒ Array<String>
Optional. The order of the properties. Not a standard field in open api spec.
Only used to support the order of the properties.
Corresponds to the JSON property propertyOrdering
27354 27355 27356 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27354 def property_ordering @property_ordering end |
#ref ⇒ String
Optional. Allows indirect references between schema nodes. The value should be
a valid reference to a child of the root defs. For example, the following
schema defines a reference to a schema node named "Pet": type: object
properties: pet: ref: #/defs/Pet defs: Pet: type: object properties: name:
type: string The value of the "pet" property is a reference to the schema node
named "Pet". See details in https://json-schema.org/understanding-json-schema/
structuring
Corresponds to the JSON property ref
27365 27366 27367 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27365 def ref @ref end |
#required ⇒ Array<String>
Optional. Required properties of Type.OBJECT.
Corresponds to the JSON property required
27370 27371 27372 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27370 def required @required end |
#title ⇒ String
Optional. The title of the Schema.
Corresponds to the JSON property title
27375 27376 27377 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27375 def title @title end |
#type ⇒ String
Optional. The type of the data.
Corresponds to the JSON property type
27380 27381 27382 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27380 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27387 27388 27389 27390 27391 27392 27393 27394 27395 27396 27397 27398 27399 27400 27401 27402 27403 27404 27405 27406 27407 27408 27409 27410 27411 27412 27413 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27387 def update!(**args) @additional_properties = args[:additional_properties] if args.key?(:additional_properties) @any_of = args[:any_of] if args.key?(:any_of) @default = args[:default] if args.key?(:default) @defs = args[:defs] if args.key?(:defs) @description = args[:description] if args.key?(:description) @enum = args[:enum] if args.key?(:enum) @example = args[:example] if args.key?(:example) @format = args[:format] if args.key?(:format) @items = args[:items] if args.key?(:items) @max_items = args[:max_items] if args.key?(:max_items) @max_length = args[:max_length] if args.key?(:max_length) @max_properties = args[:max_properties] if args.key?(:max_properties) @maximum = args[:maximum] if args.key?(:maximum) @min_items = args[:min_items] if args.key?(:min_items) @min_length = args[:min_length] if args.key?(:min_length) @min_properties = args[:min_properties] if args.key?(:min_properties) @minimum = args[:minimum] if args.key?(:minimum) @nullable = args[:nullable] if args.key?(:nullable) @pattern = args[:pattern] if args.key?(:pattern) @properties = args[:properties] if args.key?(:properties) @property_ordering = args[:property_ordering] if args.key?(:property_ordering) @ref = args[:ref] if args.key?(:ref) @required = args[:required] if args.key?(:required) @title = args[:title] if args.key?(:title) @type = args[:type] if args.key?(:type) end |