Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Schema is used to define the format of input/output data. Represents a select subset of an OpenAPI 3.0 schema object. More fields may be added in the future as needed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Schema

Returns a new instance of GoogleCloudAiplatformV1Schema.



26968
26969
26970
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26968

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_propertiesObject

Optional. Can either be a boolean or an object; controls the presence of additional properties. Corresponds to the JSON property additionalProperties

Returns:

  • (Object)


26826
26827
26828
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26826

def additional_properties
  @additional_properties
end

#any_ofArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema>

Optional. The value should be validated against any (one or more) of the subschemas in the list. Corresponds to the JSON property anyOf



26832
26833
26834
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26832

def any_of
  @any_of
end

#defaultObject

Optional. Default value of the data. Corresponds to the JSON property default

Returns:

  • (Object)


26837
26838
26839
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26837

def default
  @default
end

#defsHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema>

Optional. A map of definitions for use by ref Only allowed at the root of the schema. Corresponds to the JSON property defs



26843
26844
26845
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26843

def defs
  @defs
end

#descriptionString

Optional. The description of the data. Corresponds to the JSON property description

Returns:

  • (String)


26848
26849
26850
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26848

def description
  @description
end

#enumArray<String>

Optional. Possible values of the element of primitive type with enum format. Examples: 1. We can define direction as : type:STRING, format:enum, enum:[" EAST", NORTH", "SOUTH", "WEST"] 2. We can define apartment number as : type: INTEGER, format:enum, enum:["101", "201", "301"] Corresponds to the JSON property enum

Returns:

  • (Array<String>)


26856
26857
26858
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26856

def enum
  @enum
end

#exampleObject

Optional. Example of the object. Will only populated when the object is the root. Corresponds to the JSON property example

Returns:

  • (Object)


26862
26863
26864
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26862

def example
  @example
end

#formatString

Optional. The format of the data. Supported formats: for NUMBER type: "float", "double" for INTEGER type: "int32", "int64" for STRING type: "email", "byte", etc Corresponds to the JSON property format

Returns:

  • (String)


26869
26870
26871
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26869

def format
  @format
end

#itemsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema

Schema is used to define the format of input/output data. Represents a select subset of an OpenAPI 3.0 schema object. More fields may be added in the future as needed. Corresponds to the JSON property items



26876
26877
26878
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26876

def items
  @items
end

#max_itemsFixnum

Optional. Maximum number of the elements for Type.ARRAY. Corresponds to the JSON property maxItems

Returns:

  • (Fixnum)


26881
26882
26883
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26881

def max_items
  @max_items
end

#max_lengthFixnum

Optional. Maximum length of the Type.STRING Corresponds to the JSON property maxLength

Returns:

  • (Fixnum)


26886
26887
26888
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26886

def max_length
  @max_length
end

#max_propertiesFixnum

Optional. Maximum number of the properties for Type.OBJECT. Corresponds to the JSON property maxProperties

Returns:

  • (Fixnum)


26891
26892
26893
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26891

def max_properties
  @max_properties
end

#maximumFloat

Optional. Maximum value of the Type.INTEGER and Type.NUMBER Corresponds to the JSON property maximum

Returns:

  • (Float)


26896
26897
26898
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26896

def maximum
  @maximum
end

#min_itemsFixnum

Optional. Minimum number of the elements for Type.ARRAY. Corresponds to the JSON property minItems

Returns:

  • (Fixnum)


26901
26902
26903
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26901

def min_items
  @min_items
end

#min_lengthFixnum

Optional. SCHEMA FIELDS FOR TYPE STRING Minimum length of the Type.STRING Corresponds to the JSON property minLength

Returns:

  • (Fixnum)


26906
26907
26908
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26906

def min_length
  @min_length
end

#min_propertiesFixnum

Optional. Minimum number of the properties for Type.OBJECT. Corresponds to the JSON property minProperties

Returns:

  • (Fixnum)


26911
26912
26913
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26911

def min_properties
  @min_properties
end

#minimumFloat

Optional. SCHEMA FIELDS FOR TYPE INTEGER and NUMBER Minimum value of the Type. INTEGER and Type.NUMBER Corresponds to the JSON property minimum

Returns:

  • (Float)


26917
26918
26919
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26917

def minimum
  @minimum
end

#nullableBoolean Also known as: nullable?

Optional. Indicates if the value may be null. Corresponds to the JSON property nullable

Returns:

  • (Boolean)


26922
26923
26924
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26922

def nullable
  @nullable
end

#patternString

Optional. Pattern of the Type.STRING to restrict a string to a regular expression. Corresponds to the JSON property pattern

Returns:

  • (String)


26929
26930
26931
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26929

def pattern
  @pattern
end

#propertiesHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema>

Optional. SCHEMA FIELDS FOR TYPE OBJECT Properties of Type.OBJECT. Corresponds to the JSON property properties



26934
26935
26936
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26934

def properties
  @properties
end

#property_orderingArray<String>

Optional. The order of the properties. Not a standard field in open api spec. Only used to support the order of the properties. Corresponds to the JSON property propertyOrdering

Returns:

  • (Array<String>)


26940
26941
26942
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26940

def property_ordering
  @property_ordering
end

#refString

Optional. Allows indirect references between schema nodes. The value should be a valid reference to a child of the root defs. For example, the following schema defines a reference to a schema node named "Pet": type: object properties: pet: ref: #/defs/Pet defs: Pet: type: object properties: name: type: string The value of the "pet" property is a reference to the schema node named "Pet". See details in https://json-schema.org/understanding-json-schema/ structuring Corresponds to the JSON property ref

Returns:

  • (String)


26951
26952
26953
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26951

def ref
  @ref
end

#requiredArray<String>

Optional. Required properties of Type.OBJECT. Corresponds to the JSON property required

Returns:

  • (Array<String>)


26956
26957
26958
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26956

def required
  @required
end

#titleString

Optional. The title of the Schema. Corresponds to the JSON property title

Returns:

  • (String)


26961
26962
26963
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26961

def title
  @title
end

#typeString

Optional. The type of the data. Corresponds to the JSON property type

Returns:

  • (String)


26966
26967
26968
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26966

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26973
26974
26975
26976
26977
26978
26979
26980
26981
26982
26983
26984
26985
26986
26987
26988
26989
26990
26991
26992
26993
26994
26995
26996
26997
26998
26999
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26973

def update!(**args)
  @additional_properties = args[:additional_properties] if args.key?(:additional_properties)
  @any_of = args[:any_of] if args.key?(:any_of)
  @default = args[:default] if args.key?(:default)
  @defs = args[:defs] if args.key?(:defs)
  @description = args[:description] if args.key?(:description)
  @enum = args[:enum] if args.key?(:enum)
  @example = args[:example] if args.key?(:example)
  @format = args[:format] if args.key?(:format)
  @items = args[:items] if args.key?(:items)
  @max_items = args[:max_items] if args.key?(:max_items)
  @max_length = args[:max_length] if args.key?(:max_length)
  @max_properties = args[:max_properties] if args.key?(:max_properties)
  @maximum = args[:maximum] if args.key?(:maximum)
  @min_items = args[:min_items] if args.key?(:min_items)
  @min_length = args[:min_length] if args.key?(:min_length)
  @min_properties = args[:min_properties] if args.key?(:min_properties)
  @minimum = args[:minimum] if args.key?(:minimum)
  @nullable = args[:nullable] if args.key?(:nullable)
  @pattern = args[:pattern] if args.key?(:pattern)
  @properties = args[:properties] if args.key?(:properties)
  @property_ordering = args[:property_ordering] if args.key?(:property_ordering)
  @ref = args[:ref] if args.key?(:ref)
  @required = args[:required] if args.key?(:required)
  @title = args[:title] if args.key?(:title)
  @type = args[:type] if args.key?(:type)
end