Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Schema is used to define the format of input/output data. Represents a select subset of an OpenAPI 3.0 schema object. More fields may be added in the future as needed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Schema

Returns a new instance of GoogleCloudAiplatformV1Schema.



26908
26909
26910
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26908

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_propertiesObject

Optional. Can either be a boolean or an object; controls the presence of additional properties. Corresponds to the JSON property additionalProperties

Returns:

  • (Object)


26766
26767
26768
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26766

def additional_properties
  @additional_properties
end

#any_ofArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema>

Optional. The value should be validated against any (one or more) of the subschemas in the list. Corresponds to the JSON property anyOf



26772
26773
26774
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26772

def any_of
  @any_of
end

#defaultObject

Optional. Default value of the data. Corresponds to the JSON property default

Returns:

  • (Object)


26777
26778
26779
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26777

def default
  @default
end

#defsHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema>

Optional. A map of definitions for use by ref Only allowed at the root of the schema. Corresponds to the JSON property defs



26783
26784
26785
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26783

def defs
  @defs
end

#descriptionString

Optional. The description of the data. Corresponds to the JSON property description

Returns:

  • (String)


26788
26789
26790
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26788

def description
  @description
end

#enumArray<String>

Optional. Possible values of the element of primitive type with enum format. Examples: 1. We can define direction as : type:STRING, format:enum, enum:[" EAST", NORTH", "SOUTH", "WEST"] 2. We can define apartment number as : type: INTEGER, format:enum, enum:["101", "201", "301"] Corresponds to the JSON property enum

Returns:

  • (Array<String>)


26796
26797
26798
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26796

def enum
  @enum
end

#exampleObject

Optional. Example of the object. Will only populated when the object is the root. Corresponds to the JSON property example

Returns:

  • (Object)


26802
26803
26804
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26802

def example
  @example
end

#formatString

Optional. The format of the data. Supported formats: for NUMBER type: "float", "double" for INTEGER type: "int32", "int64" for STRING type: "email", "byte", etc Corresponds to the JSON property format

Returns:

  • (String)


26809
26810
26811
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26809

def format
  @format
end

#itemsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema

Schema is used to define the format of input/output data. Represents a select subset of an OpenAPI 3.0 schema object. More fields may be added in the future as needed. Corresponds to the JSON property items



26816
26817
26818
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26816

def items
  @items
end

#max_itemsFixnum

Optional. Maximum number of the elements for Type.ARRAY. Corresponds to the JSON property maxItems

Returns:

  • (Fixnum)


26821
26822
26823
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26821

def max_items
  @max_items
end

#max_lengthFixnum

Optional. Maximum length of the Type.STRING Corresponds to the JSON property maxLength

Returns:

  • (Fixnum)


26826
26827
26828
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26826

def max_length
  @max_length
end

#max_propertiesFixnum

Optional. Maximum number of the properties for Type.OBJECT. Corresponds to the JSON property maxProperties

Returns:

  • (Fixnum)


26831
26832
26833
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26831

def max_properties
  @max_properties
end

#maximumFloat

Optional. Maximum value of the Type.INTEGER and Type.NUMBER Corresponds to the JSON property maximum

Returns:

  • (Float)


26836
26837
26838
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26836

def maximum
  @maximum
end

#min_itemsFixnum

Optional. Minimum number of the elements for Type.ARRAY. Corresponds to the JSON property minItems

Returns:

  • (Fixnum)


26841
26842
26843
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26841

def min_items
  @min_items
end

#min_lengthFixnum

Optional. SCHEMA FIELDS FOR TYPE STRING Minimum length of the Type.STRING Corresponds to the JSON property minLength

Returns:

  • (Fixnum)


26846
26847
26848
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26846

def min_length
  @min_length
end

#min_propertiesFixnum

Optional. Minimum number of the properties for Type.OBJECT. Corresponds to the JSON property minProperties

Returns:

  • (Fixnum)


26851
26852
26853
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26851

def min_properties
  @min_properties
end

#minimumFloat

Optional. SCHEMA FIELDS FOR TYPE INTEGER and NUMBER Minimum value of the Type. INTEGER and Type.NUMBER Corresponds to the JSON property minimum

Returns:

  • (Float)


26857
26858
26859
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26857

def minimum
  @minimum
end

#nullableBoolean Also known as: nullable?

Optional. Indicates if the value may be null. Corresponds to the JSON property nullable

Returns:

  • (Boolean)


26862
26863
26864
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26862

def nullable
  @nullable
end

#patternString

Optional. Pattern of the Type.STRING to restrict a string to a regular expression. Corresponds to the JSON property pattern

Returns:

  • (String)


26869
26870
26871
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26869

def pattern
  @pattern
end

#propertiesHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema>

Optional. SCHEMA FIELDS FOR TYPE OBJECT Properties of Type.OBJECT. Corresponds to the JSON property properties



26874
26875
26876
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26874

def properties
  @properties
end

#property_orderingArray<String>

Optional. The order of the properties. Not a standard field in open api spec. Only used to support the order of the properties. Corresponds to the JSON property propertyOrdering

Returns:

  • (Array<String>)


26880
26881
26882
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26880

def property_ordering
  @property_ordering
end

#refString

Optional. Allows indirect references between schema nodes. The value should be a valid reference to a child of the root defs. For example, the following schema defines a reference to a schema node named "Pet": type: object properties: pet: ref: #/defs/Pet defs: Pet: type: object properties: name: type: string The value of the "pet" property is a reference to the schema node named "Pet". See details in https://json-schema.org/understanding-json-schema/ structuring Corresponds to the JSON property ref

Returns:

  • (String)


26891
26892
26893
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26891

def ref
  @ref
end

#requiredArray<String>

Optional. Required properties of Type.OBJECT. Corresponds to the JSON property required

Returns:

  • (Array<String>)


26896
26897
26898
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26896

def required
  @required
end

#titleString

Optional. The title of the Schema. Corresponds to the JSON property title

Returns:

  • (String)


26901
26902
26903
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26901

def title
  @title
end

#typeString

Optional. The type of the data. Corresponds to the JSON property type

Returns:

  • (String)


26906
26907
26908
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26906

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26913
26914
26915
26916
26917
26918
26919
26920
26921
26922
26923
26924
26925
26926
26927
26928
26929
26930
26931
26932
26933
26934
26935
26936
26937
26938
26939
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26913

def update!(**args)
  @additional_properties = args[:additional_properties] if args.key?(:additional_properties)
  @any_of = args[:any_of] if args.key?(:any_of)
  @default = args[:default] if args.key?(:default)
  @defs = args[:defs] if args.key?(:defs)
  @description = args[:description] if args.key?(:description)
  @enum = args[:enum] if args.key?(:enum)
  @example = args[:example] if args.key?(:example)
  @format = args[:format] if args.key?(:format)
  @items = args[:items] if args.key?(:items)
  @max_items = args[:max_items] if args.key?(:max_items)
  @max_length = args[:max_length] if args.key?(:max_length)
  @max_properties = args[:max_properties] if args.key?(:max_properties)
  @maximum = args[:maximum] if args.key?(:maximum)
  @min_items = args[:min_items] if args.key?(:min_items)
  @min_length = args[:min_length] if args.key?(:min_length)
  @min_properties = args[:min_properties] if args.key?(:min_properties)
  @minimum = args[:minimum] if args.key?(:minimum)
  @nullable = args[:nullable] if args.key?(:nullable)
  @pattern = args[:pattern] if args.key?(:pattern)
  @properties = args[:properties] if args.key?(:properties)
  @property_ordering = args[:property_ordering] if args.key?(:property_ordering)
  @ref = args[:ref] if args.key?(:ref)
  @required = args[:required] if args.key?(:required)
  @title = args[:title] if args.key?(:title)
  @type = args[:type] if args.key?(:type)
end