Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Schema is used to define the format of input/output data. Represents a select subset of an OpenAPI 3.0 schema object. More fields may be added in the future as needed.
Instance Attribute Summary collapse
-
#any_of ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema>
Optional.
-
#default ⇒ Object
Optional.
-
#description ⇒ String
Optional.
-
#enum ⇒ Array<String>
Optional.
-
#example ⇒ Object
Optional.
-
#format ⇒ String
Optional.
-
#items ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema
Schema is used to define the format of input/output data.
-
#max_items ⇒ Fixnum
Optional.
-
#max_length ⇒ Fixnum
Optional.
-
#max_properties ⇒ Fixnum
Optional.
-
#maximum ⇒ Float
Optional.
-
#min_items ⇒ Fixnum
Optional.
-
#min_length ⇒ Fixnum
Optional.
-
#min_properties ⇒ Fixnum
Optional.
-
#minimum ⇒ Float
Optional.
-
#nullable ⇒ Boolean
(also: #nullable?)
Optional.
-
#pattern ⇒ String
Optional.
-
#properties ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema>
Optional.
-
#property_ordering ⇒ Array<String>
Optional.
-
#required ⇒ Array<String>
Optional.
-
#title ⇒ String
Optional.
-
#type ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Schema
constructor
A new instance of GoogleCloudAiplatformV1Schema.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Schema
Returns a new instance of GoogleCloudAiplatformV1Schema.
24822 24823 24824 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24822 def initialize(**args) update!(**args) end |
Instance Attribute Details
#any_of ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema>
Optional. The value should be validated against any (one or more) of the
subschemas in the list.
Corresponds to the JSON property anyOf
24703 24704 24705 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24703 def any_of @any_of end |
#default ⇒ Object
Optional. Default value of the data.
Corresponds to the JSON property default
24708 24709 24710 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24708 def default @default end |
#description ⇒ String
Optional. The description of the data.
Corresponds to the JSON property description
24713 24714 24715 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24713 def description @description end |
#enum ⇒ Array<String>
Optional. Possible values of the element of primitive type with enum format.
Examples: 1. We can define direction as : type:STRING, format:enum, enum:["
EAST", NORTH", "SOUTH", "WEST"] 2. We can define apartment number as : type:
INTEGER, format:enum, enum:["101", "201", "301"]
Corresponds to the JSON property enum
24721 24722 24723 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24721 def enum @enum end |
#example ⇒ Object
Optional. Example of the object. Will only populated when the object is the
root.
Corresponds to the JSON property example
24727 24728 24729 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24727 def example @example end |
#format ⇒ String
Optional. The format of the data. Supported formats: for NUMBER type: "float",
"double" for INTEGER type: "int32", "int64" for STRING type: "email", "byte",
etc
Corresponds to the JSON property format
24734 24735 24736 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24734 def format @format end |
#items ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema
Schema is used to define the format of input/output data. Represents a select
subset of an OpenAPI 3.0 schema object. More fields may be added in the future as needed.
Corresponds to the JSON property items
24741 24742 24743 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24741 def items @items end |
#max_items ⇒ Fixnum
Optional. Maximum number of the elements for Type.ARRAY.
Corresponds to the JSON property maxItems
24746 24747 24748 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24746 def max_items @max_items end |
#max_length ⇒ Fixnum
Optional. Maximum length of the Type.STRING
Corresponds to the JSON property maxLength
24751 24752 24753 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24751 def max_length @max_length end |
#max_properties ⇒ Fixnum
Optional. Maximum number of the properties for Type.OBJECT.
Corresponds to the JSON property maxProperties
24756 24757 24758 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24756 def max_properties @max_properties end |
#maximum ⇒ Float
Optional. Maximum value of the Type.INTEGER and Type.NUMBER
Corresponds to the JSON property maximum
24761 24762 24763 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24761 def maximum @maximum end |
#min_items ⇒ Fixnum
Optional. Minimum number of the elements for Type.ARRAY.
Corresponds to the JSON property minItems
24766 24767 24768 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24766 def min_items @min_items end |
#min_length ⇒ Fixnum
Optional. SCHEMA FIELDS FOR TYPE STRING Minimum length of the Type.STRING
Corresponds to the JSON property minLength
24771 24772 24773 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24771 def min_length @min_length end |
#min_properties ⇒ Fixnum
Optional. Minimum number of the properties for Type.OBJECT.
Corresponds to the JSON property minProperties
24776 24777 24778 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24776 def min_properties @min_properties end |
#minimum ⇒ Float
Optional. SCHEMA FIELDS FOR TYPE INTEGER and NUMBER Minimum value of the Type.
INTEGER and Type.NUMBER
Corresponds to the JSON property minimum
24782 24783 24784 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24782 def minimum @minimum end |
#nullable ⇒ Boolean Also known as: nullable?
Optional. Indicates if the value may be null.
Corresponds to the JSON property nullable
24787 24788 24789 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24787 def nullable @nullable end |
#pattern ⇒ String
Optional. Pattern of the Type.STRING to restrict a string to a regular
expression.
Corresponds to the JSON property pattern
24794 24795 24796 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24794 def pattern @pattern end |
#properties ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema>
Optional. SCHEMA FIELDS FOR TYPE OBJECT Properties of Type.OBJECT.
Corresponds to the JSON property properties
24799 24800 24801 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24799 def properties @properties end |
#property_ordering ⇒ Array<String>
Optional. The order of the properties. Not a standard field in open api spec.
Only used to support the order of the properties.
Corresponds to the JSON property propertyOrdering
24805 24806 24807 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24805 def property_ordering @property_ordering end |
#required ⇒ Array<String>
Optional. Required properties of Type.OBJECT.
Corresponds to the JSON property required
24810 24811 24812 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24810 def required @required end |
#title ⇒ String
Optional. The title of the Schema.
Corresponds to the JSON property title
24815 24816 24817 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24815 def title @title end |
#type ⇒ String
Optional. The type of the data.
Corresponds to the JSON property type
24820 24821 24822 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24820 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24827 24828 24829 24830 24831 24832 24833 24834 24835 24836 24837 24838 24839 24840 24841 24842 24843 24844 24845 24846 24847 24848 24849 24850 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24827 def update!(**args) @any_of = args[:any_of] if args.key?(:any_of) @default = args[:default] if args.key?(:default) @description = args[:description] if args.key?(:description) @enum = args[:enum] if args.key?(:enum) @example = args[:example] if args.key?(:example) @format = args[:format] if args.key?(:format) @items = args[:items] if args.key?(:items) @max_items = args[:max_items] if args.key?(:max_items) @max_length = args[:max_length] if args.key?(:max_length) @max_properties = args[:max_properties] if args.key?(:max_properties) @maximum = args[:maximum] if args.key?(:maximum) @min_items = args[:min_items] if args.key?(:min_items) @min_length = args[:min_length] if args.key?(:min_length) @min_properties = args[:min_properties] if args.key?(:min_properties) @minimum = args[:minimum] if args.key?(:minimum) @nullable = args[:nullable] if args.key?(:nullable) @pattern = args[:pattern] if args.key?(:pattern) @properties = args[:properties] if args.key?(:properties) @property_ordering = args[:property_ordering] if args.key?(:property_ordering) @required = args[:required] if args.key?(:required) @title = args[:title] if args.key?(:title) @type = args[:type] if args.key?(:type) end |