Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Schema is used to define the format of input/output data. Represents a select subset of an OpenAPI 3.0 schema object. More fields may be added in the future as needed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Schema

Returns a new instance of GoogleCloudAiplatformV1Schema.



22562
22563
22564
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22562

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#any_ofArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema>

Optional. The value should be validated against any (one or more) of the subschemas in the list. Corresponds to the JSON property anyOf



22443
22444
22445
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22443

def any_of
  @any_of
end

#defaultObject

Optional. Default value of the data. Corresponds to the JSON property default

Returns:

  • (Object)


22448
22449
22450
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22448

def default
  @default
end

#descriptionString

Optional. The description of the data. Corresponds to the JSON property description

Returns:

  • (String)


22453
22454
22455
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22453

def description
  @description
end

#enumArray<String>

Optional. Possible values of the element of primitive type with enum format. Examples: 1. We can define direction as : type:STRING, format:enum, enum:[" EAST", NORTH", "SOUTH", "WEST"] 2. We can define apartment number as : type: INTEGER, format:enum, enum:["101", "201", "301"] Corresponds to the JSON property enum

Returns:

  • (Array<String>)


22461
22462
22463
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22461

def enum
  @enum
end

#exampleObject

Optional. Example of the object. Will only populated when the object is the root. Corresponds to the JSON property example

Returns:

  • (Object)


22467
22468
22469
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22467

def example
  @example
end

#formatString

Optional. The format of the data. Supported formats: for NUMBER type: "float", "double" for INTEGER type: "int32", "int64" for STRING type: "email", "byte", etc Corresponds to the JSON property format

Returns:

  • (String)


22474
22475
22476
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22474

def format
  @format
end

#itemsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema

Schema is used to define the format of input/output data. Represents a select subset of an OpenAPI 3.0 schema object. More fields may be added in the future as needed. Corresponds to the JSON property items



22481
22482
22483
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22481

def items
  @items
end

#max_itemsFixnum

Optional. Maximum number of the elements for Type.ARRAY. Corresponds to the JSON property maxItems

Returns:

  • (Fixnum)


22486
22487
22488
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22486

def max_items
  @max_items
end

#max_lengthFixnum

Optional. Maximum length of the Type.STRING Corresponds to the JSON property maxLength

Returns:

  • (Fixnum)


22491
22492
22493
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22491

def max_length
  @max_length
end

#max_propertiesFixnum

Optional. Maximum number of the properties for Type.OBJECT. Corresponds to the JSON property maxProperties

Returns:

  • (Fixnum)


22496
22497
22498
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22496

def max_properties
  @max_properties
end

#maximumFloat

Optional. Maximum value of the Type.INTEGER and Type.NUMBER Corresponds to the JSON property maximum

Returns:

  • (Float)


22501
22502
22503
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22501

def maximum
  @maximum
end

#min_itemsFixnum

Optional. Minimum number of the elements for Type.ARRAY. Corresponds to the JSON property minItems

Returns:

  • (Fixnum)


22506
22507
22508
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22506

def min_items
  @min_items
end

#min_lengthFixnum

Optional. SCHEMA FIELDS FOR TYPE STRING Minimum length of the Type.STRING Corresponds to the JSON property minLength

Returns:

  • (Fixnum)


22511
22512
22513
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22511

def min_length
  @min_length
end

#min_propertiesFixnum

Optional. Minimum number of the properties for Type.OBJECT. Corresponds to the JSON property minProperties

Returns:

  • (Fixnum)


22516
22517
22518
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22516

def min_properties
  @min_properties
end

#minimumFloat

Optional. SCHEMA FIELDS FOR TYPE INTEGER and NUMBER Minimum value of the Type. INTEGER and Type.NUMBER Corresponds to the JSON property minimum

Returns:

  • (Float)


22522
22523
22524
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22522

def minimum
  @minimum
end

#nullableBoolean Also known as: nullable?

Optional. Indicates if the value may be null. Corresponds to the JSON property nullable

Returns:

  • (Boolean)


22527
22528
22529
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22527

def nullable
  @nullable
end

#patternString

Optional. Pattern of the Type.STRING to restrict a string to a regular expression. Corresponds to the JSON property pattern

Returns:

  • (String)


22534
22535
22536
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22534

def pattern
  @pattern
end

#propertiesHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema>

Optional. SCHEMA FIELDS FOR TYPE OBJECT Properties of Type.OBJECT. Corresponds to the JSON property properties



22539
22540
22541
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22539

def properties
  @properties
end

#property_orderingArray<String>

Optional. The order of the properties. Not a standard field in open api spec. Only used to support the order of the properties. Corresponds to the JSON property propertyOrdering

Returns:

  • (Array<String>)


22545
22546
22547
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22545

def property_ordering
  @property_ordering
end

#requiredArray<String>

Optional. Required properties of Type.OBJECT. Corresponds to the JSON property required

Returns:

  • (Array<String>)


22550
22551
22552
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22550

def required
  @required
end

#titleString

Optional. The title of the Schema. Corresponds to the JSON property title

Returns:

  • (String)


22555
22556
22557
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22555

def title
  @title
end

#typeString

Optional. The type of the data. Corresponds to the JSON property type

Returns:

  • (String)


22560
22561
22562
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22560

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22567
22568
22569
22570
22571
22572
22573
22574
22575
22576
22577
22578
22579
22580
22581
22582
22583
22584
22585
22586
22587
22588
22589
22590
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22567

def update!(**args)
  @any_of = args[:any_of] if args.key?(:any_of)
  @default = args[:default] if args.key?(:default)
  @description = args[:description] if args.key?(:description)
  @enum = args[:enum] if args.key?(:enum)
  @example = args[:example] if args.key?(:example)
  @format = args[:format] if args.key?(:format)
  @items = args[:items] if args.key?(:items)
  @max_items = args[:max_items] if args.key?(:max_items)
  @max_length = args[:max_length] if args.key?(:max_length)
  @max_properties = args[:max_properties] if args.key?(:max_properties)
  @maximum = args[:maximum] if args.key?(:maximum)
  @min_items = args[:min_items] if args.key?(:min_items)
  @min_length = args[:min_length] if args.key?(:min_length)
  @min_properties = args[:min_properties] if args.key?(:min_properties)
  @minimum = args[:minimum] if args.key?(:minimum)
  @nullable = args[:nullable] if args.key?(:nullable)
  @pattern = args[:pattern] if args.key?(:pattern)
  @properties = args[:properties] if args.key?(:properties)
  @property_ordering = args[:property_ordering] if args.key?(:property_ordering)
  @required = args[:required] if args.key?(:required)
  @title = args[:title] if args.key?(:title)
  @type = args[:type] if args.key?(:type)
end