Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Schema is used to define the format of input/output data. Represents a select subset of an OpenAPI 3.0 schema object. More fields may be added in the future as needed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Schema

Returns a new instance of GoogleCloudAiplatformV1Schema.



22428
22429
22430
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22428

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#any_ofArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema>

Optional. The value should be validated against any (one or more) of the subschemas in the list. Corresponds to the JSON property anyOf



22310
22311
22312
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22310

def any_of
  @any_of
end

#defaultObject

Optional. Default value of the data. Corresponds to the JSON property default

Returns:

  • (Object)


22315
22316
22317
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22315

def default
  @default
end

#descriptionString

Optional. The description of the data. Corresponds to the JSON property description

Returns:

  • (String)


22320
22321
22322
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22320

def description
  @description
end

#enumArray<String>

Optional. Possible values of the element of Type.STRING with enum format. For example we can define an Enum Direction as : type:STRING, format:enum, enum:[" EAST", NORTH", "SOUTH", "WEST"] Corresponds to the JSON property enum

Returns:

  • (Array<String>)


22327
22328
22329
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22327

def enum
  @enum
end

#exampleObject

Optional. Example of the object. Will only populated when the object is the root. Corresponds to the JSON property example

Returns:

  • (Object)


22333
22334
22335
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22333

def example
  @example
end

#formatString

Optional. The format of the data. Supported formats: for NUMBER type: "float", "double" for INTEGER type: "int32", "int64" for STRING type: "email", "byte", etc Corresponds to the JSON property format

Returns:

  • (String)


22340
22341
22342
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22340

def format
  @format
end

#itemsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema

Schema is used to define the format of input/output data. Represents a select subset of an OpenAPI 3.0 schema object. More fields may be added in the future as needed. Corresponds to the JSON property items



22347
22348
22349
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22347

def items
  @items
end

#max_itemsFixnum

Optional. Maximum number of the elements for Type.ARRAY. Corresponds to the JSON property maxItems

Returns:

  • (Fixnum)


22352
22353
22354
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22352

def max_items
  @max_items
end

#max_lengthFixnum

Optional. Maximum length of the Type.STRING Corresponds to the JSON property maxLength

Returns:

  • (Fixnum)


22357
22358
22359
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22357

def max_length
  @max_length
end

#max_propertiesFixnum

Optional. Maximum number of the properties for Type.OBJECT. Corresponds to the JSON property maxProperties

Returns:

  • (Fixnum)


22362
22363
22364
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22362

def max_properties
  @max_properties
end

#maximumFloat

Optional. Maximum value of the Type.INTEGER and Type.NUMBER Corresponds to the JSON property maximum

Returns:

  • (Float)


22367
22368
22369
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22367

def maximum
  @maximum
end

#min_itemsFixnum

Optional. Minimum number of the elements for Type.ARRAY. Corresponds to the JSON property minItems

Returns:

  • (Fixnum)


22372
22373
22374
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22372

def min_items
  @min_items
end

#min_lengthFixnum

Optional. SCHEMA FIELDS FOR TYPE STRING Minimum length of the Type.STRING Corresponds to the JSON property minLength

Returns:

  • (Fixnum)


22377
22378
22379
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22377

def min_length
  @min_length
end

#min_propertiesFixnum

Optional. Minimum number of the properties for Type.OBJECT. Corresponds to the JSON property minProperties

Returns:

  • (Fixnum)


22382
22383
22384
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22382

def min_properties
  @min_properties
end

#minimumFloat

Optional. SCHEMA FIELDS FOR TYPE INTEGER and NUMBER Minimum value of the Type. INTEGER and Type.NUMBER Corresponds to the JSON property minimum

Returns:

  • (Float)


22388
22389
22390
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22388

def minimum
  @minimum
end

#nullableBoolean Also known as: nullable?

Optional. Indicates if the value may be null. Corresponds to the JSON property nullable

Returns:

  • (Boolean)


22393
22394
22395
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22393

def nullable
  @nullable
end

#patternString

Optional. Pattern of the Type.STRING to restrict a string to a regular expression. Corresponds to the JSON property pattern

Returns:

  • (String)


22400
22401
22402
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22400

def pattern
  @pattern
end

#propertiesHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema>

Optional. SCHEMA FIELDS FOR TYPE OBJECT Properties of Type.OBJECT. Corresponds to the JSON property properties



22405
22406
22407
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22405

def properties
  @properties
end

#property_orderingArray<String>

Optional. The order of the properties. Not a standard field in open api spec. Only used to support the order of the properties. Corresponds to the JSON property propertyOrdering

Returns:

  • (Array<String>)


22411
22412
22413
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22411

def property_ordering
  @property_ordering
end

#requiredArray<String>

Optional. Required properties of Type.OBJECT. Corresponds to the JSON property required

Returns:

  • (Array<String>)


22416
22417
22418
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22416

def required
  @required
end

#titleString

Optional. The title of the Schema. Corresponds to the JSON property title

Returns:

  • (String)


22421
22422
22423
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22421

def title
  @title
end

#typeString

Optional. The type of the data. Corresponds to the JSON property type

Returns:

  • (String)


22426
22427
22428
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22426

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22433
22434
22435
22436
22437
22438
22439
22440
22441
22442
22443
22444
22445
22446
22447
22448
22449
22450
22451
22452
22453
22454
22455
22456
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22433

def update!(**args)
  @any_of = args[:any_of] if args.key?(:any_of)
  @default = args[:default] if args.key?(:default)
  @description = args[:description] if args.key?(:description)
  @enum = args[:enum] if args.key?(:enum)
  @example = args[:example] if args.key?(:example)
  @format = args[:format] if args.key?(:format)
  @items = args[:items] if args.key?(:items)
  @max_items = args[:max_items] if args.key?(:max_items)
  @max_length = args[:max_length] if args.key?(:max_length)
  @max_properties = args[:max_properties] if args.key?(:max_properties)
  @maximum = args[:maximum] if args.key?(:maximum)
  @min_items = args[:min_items] if args.key?(:min_items)
  @min_length = args[:min_length] if args.key?(:min_length)
  @min_properties = args[:min_properties] if args.key?(:min_properties)
  @minimum = args[:minimum] if args.key?(:minimum)
  @nullable = args[:nullable] if args.key?(:nullable)
  @pattern = args[:pattern] if args.key?(:pattern)
  @properties = args[:properties] if args.key?(:properties)
  @property_ordering = args[:property_ordering] if args.key?(:property_ordering)
  @required = args[:required] if args.key?(:required)
  @title = args[:title] if args.key?(:title)
  @type = args[:type] if args.key?(:type)
end