Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Schema is used to define the format of input/output data. Represents a select subset of an OpenAPI 3.0 schema object. More fields may be added in the future as needed.
Instance Attribute Summary collapse
-
#default ⇒ Object
Optional.
-
#description ⇒ String
Optional.
-
#enum ⇒ Array<String>
Optional.
-
#example ⇒ Object
Optional.
-
#format ⇒ String
Optional.
-
#items ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema
Schema is used to define the format of input/output data.
-
#max_items ⇒ Fixnum
Optional.
-
#max_length ⇒ Fixnum
Optional.
-
#max_properties ⇒ Fixnum
Optional.
-
#maximum ⇒ Float
Optional.
-
#min_items ⇒ Fixnum
Optional.
-
#min_length ⇒ Fixnum
Optional.
-
#min_properties ⇒ Fixnum
Optional.
-
#minimum ⇒ Float
Optional.
-
#nullable ⇒ Boolean
(also: #nullable?)
Optional.
-
#pattern ⇒ String
Optional.
-
#properties ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema>
Optional.
-
#required ⇒ Array<String>
Optional.
-
#title ⇒ String
Optional.
-
#type ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Schema
constructor
A new instance of GoogleCloudAiplatformV1Schema.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Schema
Returns a new instance of GoogleCloudAiplatformV1Schema.
21444 21445 21446 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21444 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default ⇒ Object
Optional. Default value of the data.
Corresponds to the JSON property default
21337 21338 21339 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21337 def default @default end |
#description ⇒ String
Optional. The description of the data.
Corresponds to the JSON property description
21342 21343 21344 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21342 def description @description end |
#enum ⇒ Array<String>
Optional. Possible values of the element of Type.STRING with enum format. For
example we can define an Enum Direction as : type:STRING, format:enum, enum:["
EAST", NORTH", "SOUTH", "WEST"]
Corresponds to the JSON property enum
21349 21350 21351 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21349 def enum @enum end |
#example ⇒ Object
Optional. Example of the object. Will only populated when the object is the
root.
Corresponds to the JSON property example
21355 21356 21357 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21355 def example @example end |
#format ⇒ String
Optional. The format of the data. Supported formats: for NUMBER type: "float",
"double" for INTEGER type: "int32", "int64" for STRING type: "email", "byte",
etc
Corresponds to the JSON property format
21362 21363 21364 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21362 def format @format end |
#items ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema
Schema is used to define the format of input/output data. Represents a select
subset of an OpenAPI 3.0 schema object. More fields may be added in the future as needed.
Corresponds to the JSON property items
21369 21370 21371 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21369 def items @items end |
#max_items ⇒ Fixnum
Optional. Maximum number of the elements for Type.ARRAY.
Corresponds to the JSON property maxItems
21374 21375 21376 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21374 def max_items @max_items end |
#max_length ⇒ Fixnum
Optional. Maximum length of the Type.STRING
Corresponds to the JSON property maxLength
21379 21380 21381 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21379 def max_length @max_length end |
#max_properties ⇒ Fixnum
Optional. Maximum number of the properties for Type.OBJECT.
Corresponds to the JSON property maxProperties
21384 21385 21386 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21384 def max_properties @max_properties end |
#maximum ⇒ Float
Optional. Maximum value of the Type.INTEGER and Type.NUMBER
Corresponds to the JSON property maximum
21389 21390 21391 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21389 def maximum @maximum end |
#min_items ⇒ Fixnum
Optional. Minimum number of the elements for Type.ARRAY.
Corresponds to the JSON property minItems
21394 21395 21396 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21394 def min_items @min_items end |
#min_length ⇒ Fixnum
Optional. SCHEMA FIELDS FOR TYPE STRING Minimum length of the Type.STRING
Corresponds to the JSON property minLength
21399 21400 21401 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21399 def min_length @min_length end |
#min_properties ⇒ Fixnum
Optional. Minimum number of the properties for Type.OBJECT.
Corresponds to the JSON property minProperties
21404 21405 21406 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21404 def min_properties @min_properties end |
#minimum ⇒ Float
Optional. SCHEMA FIELDS FOR TYPE INTEGER and NUMBER Minimum value of the Type.
INTEGER and Type.NUMBER
Corresponds to the JSON property minimum
21410 21411 21412 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21410 def minimum @minimum end |
#nullable ⇒ Boolean Also known as: nullable?
Optional. Indicates if the value may be null.
Corresponds to the JSON property nullable
21415 21416 21417 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21415 def nullable @nullable end |
#pattern ⇒ String
Optional. Pattern of the Type.STRING to restrict a string to a regular
expression.
Corresponds to the JSON property pattern
21422 21423 21424 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21422 def pattern @pattern end |
#properties ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema>
Optional. SCHEMA FIELDS FOR TYPE OBJECT Properties of Type.OBJECT.
Corresponds to the JSON property properties
21427 21428 21429 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21427 def properties @properties end |
#required ⇒ Array<String>
Optional. Required properties of Type.OBJECT.
Corresponds to the JSON property required
21432 21433 21434 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21432 def required @required end |
#title ⇒ String
Optional. The title of the Schema.
Corresponds to the JSON property title
21437 21438 21439 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21437 def title @title end |
#type ⇒ String
Optional. The type of the data.
Corresponds to the JSON property type
21442 21443 21444 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21442 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21449 21450 21451 21452 21453 21454 21455 21456 21457 21458 21459 21460 21461 21462 21463 21464 21465 21466 21467 21468 21469 21470 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21449 def update!(**args) @default = args[:default] if args.key?(:default) @description = args[:description] if args.key?(:description) @enum = args[:enum] if args.key?(:enum) @example = args[:example] if args.key?(:example) @format = args[:format] if args.key?(:format) @items = args[:items] if args.key?(:items) @max_items = args[:max_items] if args.key?(:max_items) @max_length = args[:max_length] if args.key?(:max_length) @max_properties = args[:max_properties] if args.key?(:max_properties) @maximum = args[:maximum] if args.key?(:maximum) @min_items = args[:min_items] if args.key?(:min_items) @min_length = args[:min_length] if args.key?(:min_length) @min_properties = args[:min_properties] if args.key?(:min_properties) @minimum = args[:minimum] if args.key?(:minimum) @nullable = args[:nullable] if args.key?(:nullable) @pattern = args[:pattern] if args.key?(:pattern) @properties = args[:properties] if args.key?(:properties) @required = args[:required] if args.key?(:required) @title = args[:title] if args.key?(:title) @type = args[:type] if args.key?(:type) end |