Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Schema is used to define the format of input/output data. Represents a select subset of an OpenAPI 3.0 schema object. More fields may be added in the future as needed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Schema

Returns a new instance of GoogleCloudAiplatformV1Schema.



20837
20838
20839
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20837

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#defaultObject

Optional. Default value of the data. Corresponds to the JSON property default

Returns:

  • (Object)


20730
20731
20732
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20730

def default
  @default
end

#descriptionString

Optional. The description of the data. Corresponds to the JSON property description

Returns:

  • (String)


20735
20736
20737
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20735

def description
  @description
end

#enumArray<String>

Optional. Possible values of the element of Type.STRING with enum format. For example we can define an Enum Direction as : type:STRING, format:enum, enum:[" EAST", NORTH", "SOUTH", "WEST"] Corresponds to the JSON property enum

Returns:

  • (Array<String>)


20742
20743
20744
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20742

def enum
  @enum
end

#exampleObject

Optional. Example of the object. Will only populated when the object is the root. Corresponds to the JSON property example

Returns:

  • (Object)


20748
20749
20750
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20748

def example
  @example
end

#formatString

Optional. The format of the data. Supported formats: for NUMBER type: "float", "double" for INTEGER type: "int32", "int64" for STRING type: "email", "byte", etc Corresponds to the JSON property format

Returns:

  • (String)


20755
20756
20757
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20755

def format
  @format
end

#itemsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema

Schema is used to define the format of input/output data. Represents a select subset of an OpenAPI 3.0 schema object. More fields may be added in the future as needed. Corresponds to the JSON property items



20762
20763
20764
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20762

def items
  @items
end

#max_itemsFixnum

Optional. Maximum number of the elements for Type.ARRAY. Corresponds to the JSON property maxItems

Returns:

  • (Fixnum)


20767
20768
20769
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20767

def max_items
  @max_items
end

#max_lengthFixnum

Optional. Maximum length of the Type.STRING Corresponds to the JSON property maxLength

Returns:

  • (Fixnum)


20772
20773
20774
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20772

def max_length
  @max_length
end

#max_propertiesFixnum

Optional. Maximum number of the properties for Type.OBJECT. Corresponds to the JSON property maxProperties

Returns:

  • (Fixnum)


20777
20778
20779
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20777

def max_properties
  @max_properties
end

#maximumFloat

Optional. Maximum value of the Type.INTEGER and Type.NUMBER Corresponds to the JSON property maximum

Returns:

  • (Float)


20782
20783
20784
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20782

def maximum
  @maximum
end

#min_itemsFixnum

Optional. Minimum number of the elements for Type.ARRAY. Corresponds to the JSON property minItems

Returns:

  • (Fixnum)


20787
20788
20789
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20787

def min_items
  @min_items
end

#min_lengthFixnum

Optional. SCHEMA FIELDS FOR TYPE STRING Minimum length of the Type.STRING Corresponds to the JSON property minLength

Returns:

  • (Fixnum)


20792
20793
20794
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20792

def min_length
  @min_length
end

#min_propertiesFixnum

Optional. Minimum number of the properties for Type.OBJECT. Corresponds to the JSON property minProperties

Returns:

  • (Fixnum)


20797
20798
20799
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20797

def min_properties
  @min_properties
end

#minimumFloat

Optional. SCHEMA FIELDS FOR TYPE INTEGER and NUMBER Minimum value of the Type. INTEGER and Type.NUMBER Corresponds to the JSON property minimum

Returns:

  • (Float)


20803
20804
20805
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20803

def minimum
  @minimum
end

#nullableBoolean Also known as: nullable?

Optional. Indicates if the value may be null. Corresponds to the JSON property nullable

Returns:

  • (Boolean)


20808
20809
20810
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20808

def nullable
  @nullable
end

#patternString

Optional. Pattern of the Type.STRING to restrict a string to a regular expression. Corresponds to the JSON property pattern

Returns:

  • (String)


20815
20816
20817
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20815

def pattern
  @pattern
end

#propertiesHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema>

Optional. SCHEMA FIELDS FOR TYPE OBJECT Properties of Type.OBJECT. Corresponds to the JSON property properties



20820
20821
20822
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20820

def properties
  @properties
end

#requiredArray<String>

Optional. Required properties of Type.OBJECT. Corresponds to the JSON property required

Returns:

  • (Array<String>)


20825
20826
20827
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20825

def required
  @required
end

#titleString

Optional. The title of the Schema. Corresponds to the JSON property title

Returns:

  • (String)


20830
20831
20832
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20830

def title
  @title
end

#typeString

Optional. The type of the data. Corresponds to the JSON property type

Returns:

  • (String)


20835
20836
20837
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20835

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20842
20843
20844
20845
20846
20847
20848
20849
20850
20851
20852
20853
20854
20855
20856
20857
20858
20859
20860
20861
20862
20863
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20842

def update!(**args)
  @default = args[:default] if args.key?(:default)
  @description = args[:description] if args.key?(:description)
  @enum = args[:enum] if args.key?(:enum)
  @example = args[:example] if args.key?(:example)
  @format = args[:format] if args.key?(:format)
  @items = args[:items] if args.key?(:items)
  @max_items = args[:max_items] if args.key?(:max_items)
  @max_length = args[:max_length] if args.key?(:max_length)
  @max_properties = args[:max_properties] if args.key?(:max_properties)
  @maximum = args[:maximum] if args.key?(:maximum)
  @min_items = args[:min_items] if args.key?(:min_items)
  @min_length = args[:min_length] if args.key?(:min_length)
  @min_properties = args[:min_properties] if args.key?(:min_properties)
  @minimum = args[:minimum] if args.key?(:minimum)
  @nullable = args[:nullable] if args.key?(:nullable)
  @pattern = args[:pattern] if args.key?(:pattern)
  @properties = args[:properties] if args.key?(:properties)
  @required = args[:required] if args.key?(:required)
  @title = args[:title] if args.key?(:title)
  @type = args[:type] if args.key?(:type)
end