Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Schema is used to define the format of input/output data. Represents a select subset of an OpenAPI 3.0 schema object. More fields may be added in the future as needed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Schema

Returns a new instance of GoogleCloudAiplatformV1Schema.



19198
19199
19200
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19198

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#defaultObject

Optional. Default value of the data. Corresponds to the JSON property default

Returns:

  • (Object)


19091
19092
19093
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19091

def default
  @default
end

#descriptionString

Optional. The description of the data. Corresponds to the JSON property description

Returns:

  • (String)


19096
19097
19098
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19096

def description
  @description
end

#enumArray<String>

Optional. Possible values of the element of Type.STRING with enum format. For example we can define an Enum Direction as : type:STRING, format:enum, enum:[" EAST", NORTH", "SOUTH", "WEST"] Corresponds to the JSON property enum

Returns:

  • (Array<String>)


19103
19104
19105
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19103

def enum
  @enum
end

#exampleObject

Optional. Example of the object. Will only populated when the object is the root. Corresponds to the JSON property example

Returns:

  • (Object)


19109
19110
19111
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19109

def example
  @example
end

#formatString

Optional. The format of the data. Supported formats: for NUMBER type: "float", "double" for INTEGER type: "int32", "int64" for STRING type: "email", "byte", etc Corresponds to the JSON property format

Returns:

  • (String)


19116
19117
19118
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19116

def format
  @format
end

#itemsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema

Schema is used to define the format of input/output data. Represents a select subset of an OpenAPI 3.0 schema object. More fields may be added in the future as needed. Corresponds to the JSON property items



19123
19124
19125
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19123

def items
  @items
end

#max_itemsFixnum

Optional. Maximum number of the elements for Type.ARRAY. Corresponds to the JSON property maxItems

Returns:

  • (Fixnum)


19128
19129
19130
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19128

def max_items
  @max_items
end

#max_lengthFixnum

Optional. Maximum length of the Type.STRING Corresponds to the JSON property maxLength

Returns:

  • (Fixnum)


19133
19134
19135
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19133

def max_length
  @max_length
end

#max_propertiesFixnum

Optional. Maximum number of the properties for Type.OBJECT. Corresponds to the JSON property maxProperties

Returns:

  • (Fixnum)


19138
19139
19140
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19138

def max_properties
  @max_properties
end

#maximumFloat

Optional. Maximum value of the Type.INTEGER and Type.NUMBER Corresponds to the JSON property maximum

Returns:

  • (Float)


19143
19144
19145
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19143

def maximum
  @maximum
end

#min_itemsFixnum

Optional. Minimum number of the elements for Type.ARRAY. Corresponds to the JSON property minItems

Returns:

  • (Fixnum)


19148
19149
19150
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19148

def min_items
  @min_items
end

#min_lengthFixnum

Optional. SCHEMA FIELDS FOR TYPE STRING Minimum length of the Type.STRING Corresponds to the JSON property minLength

Returns:

  • (Fixnum)


19153
19154
19155
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19153

def min_length
  @min_length
end

#min_propertiesFixnum

Optional. Minimum number of the properties for Type.OBJECT. Corresponds to the JSON property minProperties

Returns:

  • (Fixnum)


19158
19159
19160
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19158

def min_properties
  @min_properties
end

#minimumFloat

Optional. SCHEMA FIELDS FOR TYPE INTEGER and NUMBER Minimum value of the Type. INTEGER and Type.NUMBER Corresponds to the JSON property minimum

Returns:

  • (Float)


19164
19165
19166
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19164

def minimum
  @minimum
end

#nullableBoolean Also known as: nullable?

Optional. Indicates if the value may be null. Corresponds to the JSON property nullable

Returns:

  • (Boolean)


19169
19170
19171
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19169

def nullable
  @nullable
end

#patternString

Optional. Pattern of the Type.STRING to restrict a string to a regular expression. Corresponds to the JSON property pattern

Returns:

  • (String)


19176
19177
19178
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19176

def pattern
  @pattern
end

#propertiesHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema>

Optional. SCHEMA FIELDS FOR TYPE OBJECT Properties of Type.OBJECT. Corresponds to the JSON property properties



19181
19182
19183
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19181

def properties
  @properties
end

#requiredArray<String>

Optional. Required properties of Type.OBJECT. Corresponds to the JSON property required

Returns:

  • (Array<String>)


19186
19187
19188
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19186

def required
  @required
end

#titleString

Optional. The title of the Schema. Corresponds to the JSON property title

Returns:

  • (String)


19191
19192
19193
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19191

def title
  @title
end

#typeString

Optional. The type of the data. Corresponds to the JSON property type

Returns:

  • (String)


19196
19197
19198
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19196

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19203
19204
19205
19206
19207
19208
19209
19210
19211
19212
19213
19214
19215
19216
19217
19218
19219
19220
19221
19222
19223
19224
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19203

def update!(**args)
  @default = args[:default] if args.key?(:default)
  @description = args[:description] if args.key?(:description)
  @enum = args[:enum] if args.key?(:enum)
  @example = args[:example] if args.key?(:example)
  @format = args[:format] if args.key?(:format)
  @items = args[:items] if args.key?(:items)
  @max_items = args[:max_items] if args.key?(:max_items)
  @max_length = args[:max_length] if args.key?(:max_length)
  @max_properties = args[:max_properties] if args.key?(:max_properties)
  @maximum = args[:maximum] if args.key?(:maximum)
  @min_items = args[:min_items] if args.key?(:min_items)
  @min_length = args[:min_length] if args.key?(:min_length)
  @min_properties = args[:min_properties] if args.key?(:min_properties)
  @minimum = args[:minimum] if args.key?(:minimum)
  @nullable = args[:nullable] if args.key?(:nullable)
  @pattern = args[:pattern] if args.key?(:pattern)
  @properties = args[:properties] if args.key?(:properties)
  @required = args[:required] if args.key?(:required)
  @title = args[:title] if args.key?(:title)
  @type = args[:type] if args.key?(:type)
end