Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Schema is used to define the format of input/output data. Represents a select subset of an OpenAPI 3.0 schema object. More fields may be added in the future as needed.
Instance Attribute Summary collapse
-
#default ⇒ Object
Optional.
-
#description ⇒ String
Optional.
-
#enum ⇒ Array<String>
Optional.
-
#example ⇒ Object
Optional.
-
#format ⇒ String
Optional.
-
#items ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema
Schema is used to define the format of input/output data.
-
#max_items ⇒ Fixnum
Optional.
-
#max_length ⇒ Fixnum
Optional.
-
#max_properties ⇒ Fixnum
Optional.
-
#maximum ⇒ Float
Optional.
-
#min_items ⇒ Fixnum
Optional.
-
#min_length ⇒ Fixnum
Optional.
-
#min_properties ⇒ Fixnum
Optional.
-
#minimum ⇒ Float
Optional.
-
#nullable ⇒ Boolean
(also: #nullable?)
Optional.
-
#pattern ⇒ String
Optional.
-
#properties ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema>
Optional.
-
#required ⇒ Array<String>
Optional.
-
#title ⇒ String
Optional.
-
#type ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Schema
constructor
A new instance of GoogleCloudAiplatformV1Schema.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Schema
Returns a new instance of GoogleCloudAiplatformV1Schema.
19649 19650 19651 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19649 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default ⇒ Object
Optional. Default value of the data.
Corresponds to the JSON property default
19542 19543 19544 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19542 def default @default end |
#description ⇒ String
Optional. The description of the data.
Corresponds to the JSON property description
19547 19548 19549 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19547 def description @description end |
#enum ⇒ Array<String>
Optional. Possible values of the element of Type.STRING with enum format. For
example we can define an Enum Direction as : type:STRING, format:enum, enum:["
EAST", NORTH", "SOUTH", "WEST"]
Corresponds to the JSON property enum
19554 19555 19556 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19554 def enum @enum end |
#example ⇒ Object
Optional. Example of the object. Will only populated when the object is the
root.
Corresponds to the JSON property example
19560 19561 19562 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19560 def example @example end |
#format ⇒ String
Optional. The format of the data. Supported formats: for NUMBER type: "float",
"double" for INTEGER type: "int32", "int64" for STRING type: "email", "byte",
etc
Corresponds to the JSON property format
19567 19568 19569 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19567 def format @format end |
#items ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema
Schema is used to define the format of input/output data. Represents a select
subset of an OpenAPI 3.0 schema object. More fields may be added in the future as needed.
Corresponds to the JSON property items
19574 19575 19576 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19574 def items @items end |
#max_items ⇒ Fixnum
Optional. Maximum number of the elements for Type.ARRAY.
Corresponds to the JSON property maxItems
19579 19580 19581 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19579 def max_items @max_items end |
#max_length ⇒ Fixnum
Optional. Maximum length of the Type.STRING
Corresponds to the JSON property maxLength
19584 19585 19586 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19584 def max_length @max_length end |
#max_properties ⇒ Fixnum
Optional. Maximum number of the properties for Type.OBJECT.
Corresponds to the JSON property maxProperties
19589 19590 19591 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19589 def max_properties @max_properties end |
#maximum ⇒ Float
Optional. Maximum value of the Type.INTEGER and Type.NUMBER
Corresponds to the JSON property maximum
19594 19595 19596 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19594 def maximum @maximum end |
#min_items ⇒ Fixnum
Optional. Minimum number of the elements for Type.ARRAY.
Corresponds to the JSON property minItems
19599 19600 19601 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19599 def min_items @min_items end |
#min_length ⇒ Fixnum
Optional. SCHEMA FIELDS FOR TYPE STRING Minimum length of the Type.STRING
Corresponds to the JSON property minLength
19604 19605 19606 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19604 def min_length @min_length end |
#min_properties ⇒ Fixnum
Optional. Minimum number of the properties for Type.OBJECT.
Corresponds to the JSON property minProperties
19609 19610 19611 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19609 def min_properties @min_properties end |
#minimum ⇒ Float
Optional. SCHEMA FIELDS FOR TYPE INTEGER and NUMBER Minimum value of the Type.
INTEGER and Type.NUMBER
Corresponds to the JSON property minimum
19615 19616 19617 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19615 def minimum @minimum end |
#nullable ⇒ Boolean Also known as: nullable?
Optional. Indicates if the value may be null.
Corresponds to the JSON property nullable
19620 19621 19622 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19620 def nullable @nullable end |
#pattern ⇒ String
Optional. Pattern of the Type.STRING to restrict a string to a regular
expression.
Corresponds to the JSON property pattern
19627 19628 19629 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19627 def pattern @pattern end |
#properties ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema>
Optional. SCHEMA FIELDS FOR TYPE OBJECT Properties of Type.OBJECT.
Corresponds to the JSON property properties
19632 19633 19634 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19632 def properties @properties end |
#required ⇒ Array<String>
Optional. Required properties of Type.OBJECT.
Corresponds to the JSON property required
19637 19638 19639 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19637 def required @required end |
#title ⇒ String
Optional. The title of the Schema.
Corresponds to the JSON property title
19642 19643 19644 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19642 def title @title end |
#type ⇒ String
Optional. The type of the data.
Corresponds to the JSON property type
19647 19648 19649 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19647 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19654 19655 19656 19657 19658 19659 19660 19661 19662 19663 19664 19665 19666 19667 19668 19669 19670 19671 19672 19673 19674 19675 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19654 def update!(**args) @default = args[:default] if args.key?(:default) @description = args[:description] if args.key?(:description) @enum = args[:enum] if args.key?(:enum) @example = args[:example] if args.key?(:example) @format = args[:format] if args.key?(:format) @items = args[:items] if args.key?(:items) @max_items = args[:max_items] if args.key?(:max_items) @max_length = args[:max_length] if args.key?(:max_length) @max_properties = args[:max_properties] if args.key?(:max_properties) @maximum = args[:maximum] if args.key?(:maximum) @min_items = args[:min_items] if args.key?(:min_items) @min_length = args[:min_length] if args.key?(:min_length) @min_properties = args[:min_properties] if args.key?(:min_properties) @minimum = args[:minimum] if args.key?(:minimum) @nullable = args[:nullable] if args.key?(:nullable) @pattern = args[:pattern] if args.key?(:pattern) @properties = args[:properties] if args.key?(:properties) @required = args[:required] if args.key?(:required) @title = args[:title] if args.key?(:title) @type = args[:type] if args.key?(:type) end |