Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Schema is used to define the format of input/output data. Represents a select subset of an OpenAPI 3.0 schema object. More fields may be added in the future as needed.
Instance Attribute Summary collapse
-
#description ⇒ String
Optional.
-
#enum ⇒ Array<String>
Optional.
-
#example ⇒ Object
Optional.
-
#format ⇒ String
Optional.
-
#items ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema
Schema is used to define the format of input/output data.
-
#nullable ⇒ Boolean
(also: #nullable?)
Optional.
-
#properties ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema>
Optional.
-
#required ⇒ Array<String>
Optional.
-
#type ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Schema
constructor
A new instance of GoogleCloudAiplatformV1Schema.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Schema
Returns a new instance of GoogleCloudAiplatformV1Schema.
18907 18908 18909 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18907 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Optional. The description of the data.
Corresponds to the JSON property description
18858 18859 18860 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18858 def description @description end |
#enum ⇒ Array<String>
Optional. Possible values of the element of Type.STRING with enum format. For
example we can define an Enum Direction as : type:STRING, format:enum, enum:["
EAST", NORTH", "SOUTH", "WEST"]
Corresponds to the JSON property enum
18865 18866 18867 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18865 def enum @enum end |
#example ⇒ Object
Optional. Example of the object. Will only populated when the object is the
root.
Corresponds to the JSON property example
18871 18872 18873 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18871 def example @example end |
#format ⇒ String
Optional. The format of the data. Supported formats: for NUMBER type: float,
double for INTEGER type: int32, int64
Corresponds to the JSON property format
18877 18878 18879 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18877 def format @format end |
#items ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema
Schema is used to define the format of input/output data. Represents a select
subset of an OpenAPI 3.0 schema object. More fields may be added in the future as needed.
Corresponds to the JSON property items
18884 18885 18886 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18884 def items @items end |
#nullable ⇒ Boolean Also known as: nullable?
Optional. Indicates if the value may be null.
Corresponds to the JSON property nullable
18889 18890 18891 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18889 def nullable @nullable end |
#properties ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema>
Optional. Properties of Type.OBJECT.
Corresponds to the JSON property properties
18895 18896 18897 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18895 def properties @properties end |
#required ⇒ Array<String>
Optional. Required properties of Type.OBJECT.
Corresponds to the JSON property required
18900 18901 18902 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18900 def required @required end |
#type ⇒ String
Optional. The type of the data.
Corresponds to the JSON property type
18905 18906 18907 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18905 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18912 18913 18914 18915 18916 18917 18918 18919 18920 18921 18922 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18912 def update!(**args) @description = args[:description] if args.key?(:description) @enum = args[:enum] if args.key?(:enum) @example = args[:example] if args.key?(:example) @format = args[:format] if args.key?(:format) @items = args[:items] if args.key?(:items) @nullable = args[:nullable] if args.key?(:nullable) @properties = args[:properties] if args.key?(:properties) @required = args[:required] if args.key?(:required) @type = args[:type] if args.key?(:type) end |