Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Schema is used to define the format of input/output data. Represents a select subset of an OpenAPI 3.0 schema object. More fields may be added in the future as needed.
Instance Attribute Summary collapse
-
#description ⇒ String
Optional.
-
#enum ⇒ Array<String>
Optional.
-
#example ⇒ Object
Optional.
-
#format ⇒ String
Optional.
-
#items ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema
Schema is used to define the format of input/output data.
-
#nullable ⇒ Boolean
(also: #nullable?)
Optional.
-
#properties ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema>
Optional.
-
#required ⇒ Array<String>
Optional.
-
#type ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Schema
constructor
A new instance of GoogleCloudAiplatformV1Schema.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Schema
Returns a new instance of GoogleCloudAiplatformV1Schema.
18507 18508 18509 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18507 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Optional. The description of the data.
Corresponds to the JSON property description
18458 18459 18460 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18458 def description @description end |
#enum ⇒ Array<String>
Optional. Possible values of the element of Type.STRING with enum format. For
example we can define an Enum Direction as : type:STRING, format:enum, enum:["
EAST", NORTH", "SOUTH", "WEST"]
Corresponds to the JSON property enum
18465 18466 18467 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18465 def enum @enum end |
#example ⇒ Object
Optional. Example of the object. Will only populated when the object is the
root.
Corresponds to the JSON property example
18471 18472 18473 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18471 def example @example end |
#format ⇒ String
Optional. The format of the data. Supported formats: for NUMBER type: float,
double for INTEGER type: int32, int64
Corresponds to the JSON property format
18477 18478 18479 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18477 def format @format end |
#items ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema
Schema is used to define the format of input/output data. Represents a select
subset of an OpenAPI 3.0 schema object. More fields may be added in the future as needed.
Corresponds to the JSON property items
18484 18485 18486 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18484 def items @items end |
#nullable ⇒ Boolean Also known as: nullable?
Optional. Indicates if the value may be null.
Corresponds to the JSON property nullable
18489 18490 18491 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18489 def nullable @nullable end |
#properties ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Schema>
Optional. Properties of Type.OBJECT.
Corresponds to the JSON property properties
18495 18496 18497 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18495 def properties @properties end |
#required ⇒ Array<String>
Optional. Required properties of Type.OBJECT.
Corresponds to the JSON property required
18500 18501 18502 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18500 def required @required end |
#type ⇒ String
Optional. The type of the data.
Corresponds to the JSON property type
18505 18506 18507 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18505 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18512 18513 18514 18515 18516 18517 18518 18519 18520 18521 18522 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 18512 def update!(**args) @description = args[:description] if args.key?(:description) @enum = args[:enum] if args.key?(:enum) @example = args[:example] if args.key?(:example) @format = args[:format] if args.key?(:format) @items = args[:items] if args.key?(:items) @nullable = args[:nullable] if args.key?(:nullable) @properties = args[:properties] if args.key?(:properties) @required = args[:required] if args.key?(:required) @type = args[:type] if args.key?(:type) end |