Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaImageSegmentationAnnotationMaskAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The mask based segmentation annotation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaImageSegmentationAnnotationMaskAnnotation

Returns a new instance of GoogleCloudAiplatformV1SchemaImageSegmentationAnnotationMaskAnnotation.



26152
26153
26154
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26152

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotation_spec_colorsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaAnnotationSpecColor>

The mapping between color and AnnotationSpec for this Annotation. Corresponds to the JSON property annotationSpecColors



26141
26142
26143
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26141

def annotation_spec_colors
  @annotation_spec_colors
end

#mask_gcs_uriString

Google Cloud Storage URI that points to the mask image. The image must be in PNG format. It must have the same size as the DataItem's image. Each pixel in the image mask represents the AnnotationSpec which the pixel in the image DataItem belong to. Each color is mapped to one AnnotationSpec based on annotation_spec_colors. Corresponds to the JSON property maskGcsUri

Returns:

  • (String)


26150
26151
26152
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26150

def mask_gcs_uri
  @mask_gcs_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26157
26158
26159
26160
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26157

def update!(**args)
  @annotation_spec_colors = args[:annotation_spec_colors] if args.key?(:annotation_spec_colors)
  @mask_gcs_uri = args[:mask_gcs_uri] if args.key?(:mask_gcs_uri)
end