Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaImageSegmentationAnnotationMaskAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The mask based segmentation annotation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaImageSegmentationAnnotationMaskAnnotation

Returns a new instance of GoogleCloudAiplatformV1SchemaImageSegmentationAnnotationMaskAnnotation.



25901
25902
25903
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25901

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotation_spec_colorsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaAnnotationSpecColor>

The mapping between color and AnnotationSpec for this Annotation. Corresponds to the JSON property annotationSpecColors



25890
25891
25892
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25890

def annotation_spec_colors
  @annotation_spec_colors
end

#mask_gcs_uriString

Google Cloud Storage URI that points to the mask image. The image must be in PNG format. It must have the same size as the DataItem's image. Each pixel in the image mask represents the AnnotationSpec which the pixel in the image DataItem belong to. Each color is mapped to one AnnotationSpec based on annotation_spec_colors. Corresponds to the JSON property maskGcsUri

Returns:

  • (String)


25899
25900
25901
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25899

def mask_gcs_uri
  @mask_gcs_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25906
25907
25908
25909
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25906

def update!(**args)
  @annotation_spec_colors = args[:annotation_spec_colors] if args.key?(:annotation_spec_colors)
  @mask_gcs_uri = args[:mask_gcs_uri] if args.key?(:mask_gcs_uri)
end