Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaImageSegmentationAnnotationPolygonAnnotation
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaImageSegmentationAnnotationPolygonAnnotation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Represents a polygon in image.
Instance Attribute Summary collapse
-
#annotation_spec_id ⇒ String
The resource Id of the AnnotationSpec that this Annotation pertains to.
-
#display_name ⇒ String
The display name of the AnnotationSpec that this Annotation pertains to.
-
#vertexes ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaVertex>
The vertexes are connected one by one and the last vertex is connected to the first one to represent a polygon.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaImageSegmentationAnnotationPolygonAnnotation
constructor
A new instance of GoogleCloudAiplatformV1SchemaImageSegmentationAnnotationPolygonAnnotation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaImageSegmentationAnnotationPolygonAnnotation
Returns a new instance of GoogleCloudAiplatformV1SchemaImageSegmentationAnnotationPolygonAnnotation.
37144 37145 37146 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37144 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotation_spec_id ⇒ String
The resource Id of the AnnotationSpec that this Annotation pertains to.
Corresponds to the JSON property annotationSpecId
37131 37132 37133 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37131 def annotation_spec_id @annotation_spec_id end |
#display_name ⇒ String
The display name of the AnnotationSpec that this Annotation pertains to.
Corresponds to the JSON property displayName
37136 37137 37138 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37136 def display_name @display_name end |
#vertexes ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaVertex>
The vertexes are connected one by one and the last vertex is connected to the
first one to represent a polygon.
Corresponds to the JSON property vertexes
37142 37143 37144 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37142 def vertexes @vertexes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37149 37150 37151 37152 37153 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37149 def update!(**args) @annotation_spec_id = args[:annotation_spec_id] if args.key?(:annotation_spec_id) @display_name = args[:display_name] if args.key?(:display_name) @vertexes = args[:vertexes] if args.key?(:vertexes) end |