Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaImageSegmentationAnnotationPolygonAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents a polygon in image.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaImageSegmentationAnnotationPolygonAnnotation

Returns a new instance of GoogleCloudAiplatformV1SchemaImageSegmentationAnnotationPolygonAnnotation.



27837
27838
27839
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27837

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotation_spec_idString

The resource Id of the AnnotationSpec that this Annotation pertains to. Corresponds to the JSON property annotationSpecId

Returns:

  • (String)


27824
27825
27826
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27824

def annotation_spec_id
  @annotation_spec_id
end

#display_nameString

The display name of the AnnotationSpec that this Annotation pertains to. Corresponds to the JSON property displayName

Returns:

  • (String)


27829
27830
27831
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27829

def display_name
  @display_name
end

#vertexesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaVertex>

The vertexes are connected one by one and the last vertex is connected to the first one to represent a polygon. Corresponds to the JSON property vertexes



27835
27836
27837
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27835

def vertexes
  @vertexes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27842
27843
27844
27845
27846
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27842

def update!(**args)
  @annotation_spec_id = args[:annotation_spec_id] if args.key?(:annotation_spec_id)
  @display_name = args[:display_name] if args.key?(:display_name)
  @vertexes = args[:vertexes] if args.key?(:vertexes)
end