Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaImageSegmentationAnnotationPolygonAnnotation
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaImageSegmentationAnnotationPolygonAnnotation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Represents a polygon in image.
Instance Attribute Summary collapse
-
#annotation_spec_id ⇒ String
The resource Id of the AnnotationSpec that this Annotation pertains to.
-
#display_name ⇒ String
The display name of the AnnotationSpec that this Annotation pertains to.
-
#vertexes ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaVertex>
The vertexes are connected one by one and the last vertex is connected to the first one to represent a polygon.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaImageSegmentationAnnotationPolygonAnnotation
constructor
A new instance of GoogleCloudAiplatformV1SchemaImageSegmentationAnnotationPolygonAnnotation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaImageSegmentationAnnotationPolygonAnnotation
Returns a new instance of GoogleCloudAiplatformV1SchemaImageSegmentationAnnotationPolygonAnnotation.
27287 27288 27289 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27287 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotation_spec_id ⇒ String
The resource Id of the AnnotationSpec that this Annotation pertains to.
Corresponds to the JSON property annotationSpecId
27274 27275 27276 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27274 def annotation_spec_id @annotation_spec_id end |
#display_name ⇒ String
The display name of the AnnotationSpec that this Annotation pertains to.
Corresponds to the JSON property displayName
27279 27280 27281 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27279 def display_name @display_name end |
#vertexes ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaVertex>
The vertexes are connected one by one and the last vertex is connected to the
first one to represent a polygon.
Corresponds to the JSON property vertexes
27285 27286 27287 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27285 def vertexes @vertexes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27292 27293 27294 27295 27296 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27292 def update!(**args) @annotation_spec_id = args[:annotation_spec_id] if args.key?(:annotation_spec_id) @display_name = args[:display_name] if args.key?(:display_name) @vertexes = args[:vertexes] if args.key?(:vertexes) end |