Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaImageSegmentationAnnotationPolygonAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents a polygon in image.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaImageSegmentationAnnotationPolygonAnnotation

Returns a new instance of GoogleCloudAiplatformV1SchemaImageSegmentationAnnotationPolygonAnnotation.



26701
26702
26703
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26701

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotation_spec_idString

The resource Id of the AnnotationSpec that this Annotation pertains to. Corresponds to the JSON property annotationSpecId

Returns:

  • (String)


26688
26689
26690
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26688

def annotation_spec_id
  @annotation_spec_id
end

#display_nameString

The display name of the AnnotationSpec that this Annotation pertains to. Corresponds to the JSON property displayName

Returns:

  • (String)


26693
26694
26695
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26693

def display_name
  @display_name
end

#vertexesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaVertex>

The vertexes are connected one by one and the last vertex is connected to the first one to represent a polygon. Corresponds to the JSON property vertexes



26699
26700
26701
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26699

def vertexes
  @vertexes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26706
26707
26708
26709
26710
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26706

def update!(**args)
  @annotation_spec_id = args[:annotation_spec_id] if args.key?(:annotation_spec_id)
  @display_name = args[:display_name] if args.key?(:display_name)
  @vertexes = args[:vertexes] if args.key?(:vertexes)
end