Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaImageSegmentationAnnotationPolygonAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents a polygon in image.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaImageSegmentationAnnotationPolygonAnnotation

Returns a new instance of GoogleCloudAiplatformV1SchemaImageSegmentationAnnotationPolygonAnnotation.



19072
19073
19074
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19072

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotation_spec_idString

The resource Id of the AnnotationSpec that this Annotation pertains to. Corresponds to the JSON property annotationSpecId

Returns:

  • (String)


19059
19060
19061
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19059

def annotation_spec_id
  @annotation_spec_id
end

#display_nameString

The display name of the AnnotationSpec that this Annotation pertains to. Corresponds to the JSON property displayName

Returns:

  • (String)


19064
19065
19066
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19064

def display_name
  @display_name
end

#vertexesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaVertex>

The vertexes are connected one by one and the last vertex is connected to the first one to represent a polygon. Corresponds to the JSON property vertexes



19070
19071
19072
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19070

def vertexes
  @vertexes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19077
19078
19079
19080
19081
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19077

def update!(**args)
  @annotation_spec_id = args[:annotation_spec_id] if args.key?(:annotation_spec_id)
  @display_name = args[:display_name] if args.key?(:display_name)
  @vertexes = args[:vertexes] if args.key?(:vertexes)
end