Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaImageSegmentationAnnotationPolylineAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents a polyline in image.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaImageSegmentationAnnotationPolylineAnnotation

Returns a new instance of GoogleCloudAiplatformV1SchemaImageSegmentationAnnotationPolylineAnnotation.



26801
26802
26803
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26801

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotation_spec_idString

The resource Id of the AnnotationSpec that this Annotation pertains to. Corresponds to the JSON property annotationSpecId

Returns:

  • (String)


26788
26789
26790
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26788

def annotation_spec_id
  @annotation_spec_id
end

#display_nameString

The display name of the AnnotationSpec that this Annotation pertains to. Corresponds to the JSON property displayName

Returns:

  • (String)


26793
26794
26795
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26793

def display_name
  @display_name
end

#vertexesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaVertex>

The vertexes are connected one by one and the last vertex in not connected to the first one. Corresponds to the JSON property vertexes



26799
26800
26801
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26799

def vertexes
  @vertexes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26806
26807
26808
26809
26810
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26806

def update!(**args)
  @annotation_spec_id = args[:annotation_spec_id] if args.key?(:annotation_spec_id)
  @display_name = args[:display_name] if args.key?(:display_name)
  @vertexes = args[:vertexes] if args.key?(:vertexes)
end