Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsBoundingBoxMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Bounding box matching model metrics for a single intersection-over-union threshold and multiple label match confidence thresholds.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaModelevaluationMetricsBoundingBoxMetrics

Returns a new instance of GoogleCloudAiplatformV1SchemaModelevaluationMetricsBoundingBoxMetrics.



33913
33914
33915
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33913

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidence_metricsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsBoundingBoxMetricsConfidenceMetrics>

Metrics for each label-match confidence_threshold from 0.05,0.10,...,0.95,0.96, 0.97,0.98,0.99. Precision-recall curve is derived from them. Corresponds to the JSON property confidenceMetrics



33901
33902
33903
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33901

def confidence_metrics
  @confidence_metrics
end

#iou_thresholdFloat

The intersection-over-union threshold value used to compute this metrics entry. Corresponds to the JSON property iouThreshold

Returns:

  • (Float)


33906
33907
33908
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33906

def iou_threshold
  @iou_threshold
end

#mean_average_precisionFloat

The mean average precision, most often close to auPrc. Corresponds to the JSON property meanAveragePrecision

Returns:

  • (Float)


33911
33912
33913
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33911

def mean_average_precision
  @mean_average_precision
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33918
33919
33920
33921
33922
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33918

def update!(**args)
  @confidence_metrics = args[:confidence_metrics] if args.key?(:confidence_metrics)
  @iou_threshold = args[:iou_threshold] if args.key?(:iou_threshold)
  @mean_average_precision = args[:mean_average_precision] if args.key?(:mean_average_precision)
end