Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsBoundingBoxMetricsConfidenceMetrics
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsBoundingBoxMetricsConfidenceMetrics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Metrics for a single confidence threshold.
Instance Attribute Summary collapse
-
#confidence_threshold ⇒ Float
The confidence threshold value used to compute the metrics.
-
#f1_score ⇒ Float
The harmonic mean of recall and precision.
-
#precision ⇒ Float
Precision under the given confidence threshold.
-
#recall ⇒ Float
Recall under the given confidence threshold.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaModelevaluationMetricsBoundingBoxMetricsConfidenceMetrics
constructor
A new instance of GoogleCloudAiplatformV1SchemaModelevaluationMetricsBoundingBoxMetricsConfidenceMetrics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaModelevaluationMetricsBoundingBoxMetricsConfidenceMetrics
Returns a new instance of GoogleCloudAiplatformV1SchemaModelevaluationMetricsBoundingBoxMetricsConfidenceMetrics.
25239 25240 25241 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25239 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence_threshold ⇒ Float
The confidence threshold value used to compute the metrics.
Corresponds to the JSON property confidenceThreshold
25222 25223 25224 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25222 def confidence_threshold @confidence_threshold end |
#f1_score ⇒ Float
The harmonic mean of recall and precision.
Corresponds to the JSON property f1Score
25227 25228 25229 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25227 def f1_score @f1_score end |
#precision ⇒ Float
Precision under the given confidence threshold.
Corresponds to the JSON property precision
25232 25233 25234 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25232 def precision @precision end |
#recall ⇒ Float
Recall under the given confidence threshold.
Corresponds to the JSON property recall
25237 25238 25239 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25237 def recall @recall end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25244 25245 25246 25247 25248 25249 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25244 def update!(**args) @confidence_threshold = args[:confidence_threshold] if args.key?(:confidence_threshold) @f1_score = args[:f1_score] if args.key?(:f1_score) @precision = args[:precision] if args.key?(:precision) @recall = args[:recall] if args.key?(:recall) end |