Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsBoundingBoxMetricsConfidenceMetrics
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsBoundingBoxMetricsConfidenceMetrics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Metrics for a single confidence threshold.
Instance Attribute Summary collapse
-
#confidence_threshold ⇒ Float
The confidence threshold value used to compute the metrics.
-
#f1_score ⇒ Float
The harmonic mean of recall and precision.
-
#precision ⇒ Float
Precision under the given confidence threshold.
-
#recall ⇒ Float
Recall under the given confidence threshold.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaModelevaluationMetricsBoundingBoxMetricsConfidenceMetrics
constructor
A new instance of GoogleCloudAiplatformV1SchemaModelevaluationMetricsBoundingBoxMetricsConfidenceMetrics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaModelevaluationMetricsBoundingBoxMetricsConfidenceMetrics
Returns a new instance of GoogleCloudAiplatformV1SchemaModelevaluationMetricsBoundingBoxMetricsConfidenceMetrics.
20064 20065 20066 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20064 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence_threshold ⇒ Float
The confidence threshold value used to compute the metrics.
Corresponds to the JSON property confidenceThreshold
20047 20048 20049 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20047 def confidence_threshold @confidence_threshold end |
#f1_score ⇒ Float
The harmonic mean of recall and precision.
Corresponds to the JSON property f1Score
20052 20053 20054 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20052 def f1_score @f1_score end |
#precision ⇒ Float
Precision under the given confidence threshold.
Corresponds to the JSON property precision
20057 20058 20059 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20057 def precision @precision end |
#recall ⇒ Float
Recall under the given confidence threshold.
Corresponds to the JSON property recall
20062 20063 20064 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20062 def recall @recall end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20069 20070 20071 20072 20073 20074 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20069 def update!(**args) @confidence_threshold = args[:confidence_threshold] if args.key?(:confidence_threshold) @f1_score = args[:f1_score] if args.key?(:f1_score) @precision = args[:precision] if args.key?(:precision) @recall = args[:recall] if args.key?(:recall) end |