Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsClassificationEvaluationMetrics
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsClassificationEvaluationMetrics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Metrics for classification evaluation results.
Instance Attribute Summary collapse
-
#au_prc ⇒ Float
The Area Under Precision-Recall Curve metric.
-
#au_roc ⇒ Float
The Area Under Receiver Operating Characteristic curve metric.
-
#confidence_metrics ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsClassificationEvaluationMetricsConfidenceMetrics>
Metrics for each
confidenceThresholdin 0.00,0.05,0.10,...,0.95,0.96,0.97,0. -
#confusion_matrix ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsConfusionMatrix
Confusion matrix of the evaluation.
-
#log_loss ⇒ Float
The Log Loss metric.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaModelevaluationMetricsClassificationEvaluationMetrics
constructor
A new instance of GoogleCloudAiplatformV1SchemaModelevaluationMetricsClassificationEvaluationMetrics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaModelevaluationMetricsClassificationEvaluationMetrics
Returns a new instance of GoogleCloudAiplatformV1SchemaModelevaluationMetricsClassificationEvaluationMetrics.
27376 27377 27378 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27376 def initialize(**args) update!(**args) end |
Instance Attribute Details
#au_prc ⇒ Float
The Area Under Precision-Recall Curve metric. Micro-averaged for the overall
evaluation.
Corresponds to the JSON property auPrc
27349 27350 27351 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27349 def au_prc @au_prc end |
#au_roc ⇒ Float
The Area Under Receiver Operating Characteristic curve metric. Micro-averaged
for the overall evaluation.
Corresponds to the JSON property auRoc
27355 27356 27357 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27355 def au_roc @au_roc end |
#confidence_metrics ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsClassificationEvaluationMetricsConfidenceMetrics>
Metrics for each confidenceThreshold in 0.00,0.05,0.10,...,0.95,0.96,0.97,0.
98,0.99 and positionThreshold = INT32_MAX_VALUE. ROC and precision-recall
curves, and other aggregated metrics are derived from them. The confidence
metrics entries may also be supplied for additional values of
positionThreshold, but from these no aggregated metrics are computed.
Corresponds to the JSON property confidenceMetrics
27364 27365 27366 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27364 def confidence_metrics @confidence_metrics end |
#confusion_matrix ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsConfusionMatrix
Confusion matrix of the evaluation.
Corresponds to the JSON property confusionMatrix
27369 27370 27371 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27369 def confusion_matrix @confusion_matrix end |
#log_loss ⇒ Float
The Log Loss metric.
Corresponds to the JSON property logLoss
27374 27375 27376 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27374 def log_loss @log_loss end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27381 27382 27383 27384 27385 27386 27387 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27381 def update!(**args) @au_prc = args[:au_prc] if args.key?(:au_prc) @au_roc = args[:au_roc] if args.key?(:au_roc) @confidence_metrics = args[:confidence_metrics] if args.key?(:confidence_metrics) @confusion_matrix = args[:confusion_matrix] if args.key?(:confusion_matrix) @log_loss = args[:log_loss] if args.key?(:log_loss) end |