Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsClassificationEvaluationMetricsConfidenceMetrics
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsClassificationEvaluationMetricsConfidenceMetrics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Instance Attribute Summary collapse
-
#confidence_threshold ⇒ Float
Metrics are computed with an assumption that the Model never returns predictions with score lower than this value.
-
#confusion_matrix ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsConfusionMatrix
Confusion matrix of the evaluation for this confidence_threshold.
-
#f1_score ⇒ Float
The harmonic mean of recall and precision.
-
#f1_score_at1 ⇒ Float
The harmonic mean of recallAt1 and precisionAt1.
-
#f1_score_macro ⇒ Float
Macro-averaged F1 Score.
-
#f1_score_micro ⇒ Float
Micro-averaged F1 Score.
-
#false_negative_count ⇒ Fixnum
The number of ground truth labels that are not matched by a Model created label.
-
#false_positive_count ⇒ Fixnum
The number of Model created labels that do not match a ground truth label.
-
#false_positive_rate ⇒ Float
False Positive Rate for the given confidence threshold.
-
#false_positive_rate_at1 ⇒ Float
The False Positive Rate when only considering the label that has the highest prediction score and not below the confidence threshold for each DataItem.
-
#max_predictions ⇒ Fixnum
Metrics are computed with an assumption that the Model always returns at most this many predictions (ordered by their score, descendingly), but they all still need to meet the
confidenceThreshold. -
#precision ⇒ Float
Precision for the given confidence threshold.
-
#precision_at1 ⇒ Float
The precision when only considering the label that has the highest prediction score and not below the confidence threshold for each DataItem.
-
#recall ⇒ Float
Recall (True Positive Rate) for the given confidence threshold.
-
#recall_at1 ⇒ Float
The Recall (True Positive Rate) when only considering the label that has the highest prediction score and not below the confidence threshold for each DataItem.
-
#true_negative_count ⇒ Fixnum
The number of labels that were not created by the Model, but if they would, they would not match a ground truth label.
-
#true_positive_count ⇒ Fixnum
The number of Model created labels that match a ground truth label.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaModelevaluationMetricsClassificationEvaluationMetricsConfidenceMetrics
constructor
A new instance of GoogleCloudAiplatformV1SchemaModelevaluationMetricsClassificationEvaluationMetricsConfidenceMetrics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaModelevaluationMetricsClassificationEvaluationMetricsConfidenceMetrics
Returns a new instance of GoogleCloudAiplatformV1SchemaModelevaluationMetricsClassificationEvaluationMetricsConfidenceMetrics.
23006 23007 23008 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23006 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence_threshold ⇒ Float
Metrics are computed with an assumption that the Model never returns
predictions with score lower than this value.
Corresponds to the JSON property confidenceThreshold
22915 22916 22917 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22915 def confidence_threshold @confidence_threshold end |
#confusion_matrix ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsConfusionMatrix
Confusion matrix of the evaluation for this confidence_threshold.
Corresponds to the JSON property confusionMatrix
22920 22921 22922 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22920 def confusion_matrix @confusion_matrix end |
#f1_score ⇒ Float
The harmonic mean of recall and precision. For summary metrics, it computes
the micro-averaged F1 score.
Corresponds to the JSON property f1Score
22926 22927 22928 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22926 def f1_score @f1_score end |
#f1_score_at1 ⇒ Float
The harmonic mean of recallAt1 and precisionAt1.
Corresponds to the JSON property f1ScoreAt1
22931 22932 22933 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22931 def f1_score_at1 @f1_score_at1 end |
#f1_score_macro ⇒ Float
Macro-averaged F1 Score.
Corresponds to the JSON property f1ScoreMacro
22936 22937 22938 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22936 def f1_score_macro @f1_score_macro end |
#f1_score_micro ⇒ Float
Micro-averaged F1 Score.
Corresponds to the JSON property f1ScoreMicro
22941 22942 22943 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22941 def f1_score_micro @f1_score_micro end |
#false_negative_count ⇒ Fixnum
The number of ground truth labels that are not matched by a Model created
label.
Corresponds to the JSON property falseNegativeCount
22947 22948 22949 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22947 def false_negative_count @false_negative_count end |
#false_positive_count ⇒ Fixnum
The number of Model created labels that do not match a ground truth label.
Corresponds to the JSON property falsePositiveCount
22952 22953 22954 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22952 def false_positive_count @false_positive_count end |
#false_positive_rate ⇒ Float
False Positive Rate for the given confidence threshold.
Corresponds to the JSON property falsePositiveRate
22957 22958 22959 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22957 def false_positive_rate @false_positive_rate end |
#false_positive_rate_at1 ⇒ Float
The False Positive Rate when only considering the label that has the highest
prediction score and not below the confidence threshold for each DataItem.
Corresponds to the JSON property falsePositiveRateAt1
22963 22964 22965 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22963 def false_positive_rate_at1 @false_positive_rate_at1 end |
#max_predictions ⇒ Fixnum
Metrics are computed with an assumption that the Model always returns at most
this many predictions (ordered by their score, descendingly), but they all
still need to meet the confidenceThreshold.
Corresponds to the JSON property maxPredictions
22970 22971 22972 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22970 def max_predictions @max_predictions end |
#precision ⇒ Float
Precision for the given confidence threshold.
Corresponds to the JSON property precision
22975 22976 22977 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22975 def precision @precision end |
#precision_at1 ⇒ Float
The precision when only considering the label that has the highest prediction
score and not below the confidence threshold for each DataItem.
Corresponds to the JSON property precisionAt1
22981 22982 22983 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22981 def precision_at1 @precision_at1 end |
#recall ⇒ Float
Recall (True Positive Rate) for the given confidence threshold.
Corresponds to the JSON property recall
22986 22987 22988 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22986 def recall @recall end |
#recall_at1 ⇒ Float
The Recall (True Positive Rate) when only considering the label that has the
highest prediction score and not below the confidence threshold for each
DataItem.
Corresponds to the JSON property recallAt1
22993 22994 22995 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22993 def recall_at1 @recall_at1 end |
#true_negative_count ⇒ Fixnum
The number of labels that were not created by the Model, but if they would,
they would not match a ground truth label.
Corresponds to the JSON property trueNegativeCount
22999 23000 23001 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22999 def true_negative_count @true_negative_count end |
#true_positive_count ⇒ Fixnum
The number of Model created labels that match a ground truth label.
Corresponds to the JSON property truePositiveCount
23004 23005 23006 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23004 def true_positive_count @true_positive_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23011 23012 23013 23014 23015 23016 23017 23018 23019 23020 23021 23022 23023 23024 23025 23026 23027 23028 23029 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23011 def update!(**args) @confidence_threshold = args[:confidence_threshold] if args.key?(:confidence_threshold) @confusion_matrix = args[:confusion_matrix] if args.key?(:confusion_matrix) @f1_score = args[:f1_score] if args.key?(:f1_score) @f1_score_at1 = args[:f1_score_at1] if args.key?(:f1_score_at1) @f1_score_macro = args[:f1_score_macro] if args.key?(:f1_score_macro) @f1_score_micro = args[:f1_score_micro] if args.key?(:f1_score_micro) @false_negative_count = args[:false_negative_count] if args.key?(:false_negative_count) @false_positive_count = args[:false_positive_count] if args.key?(:false_positive_count) @false_positive_rate = args[:false_positive_rate] if args.key?(:false_positive_rate) @false_positive_rate_at1 = args[:false_positive_rate_at1] if args.key?(:false_positive_rate_at1) @max_predictions = args[:max_predictions] if args.key?(:max_predictions) @precision = args[:precision] if args.key?(:precision) @precision_at1 = args[:precision_at1] if args.key?(:precision_at1) @recall = args[:recall] if args.key?(:recall) @recall_at1 = args[:recall_at1] if args.key?(:recall_at1) @true_negative_count = args[:true_negative_count] if args.key?(:true_negative_count) @true_positive_count = args[:true_positive_count] if args.key?(:true_positive_count) end |