Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsForecastingEvaluationMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Metrics for forecasting evaluation results.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaModelevaluationMetricsForecastingEvaluationMetrics

Returns a new instance of GoogleCloudAiplatformV1SchemaModelevaluationMetricsForecastingEvaluationMetrics.



37975
37976
37977
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37975

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#mean_absolute_errorFloat

Mean Absolute Error (MAE). Corresponds to the JSON property meanAbsoluteError

Returns:

  • (Float)


37932
37933
37934
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37932

def mean_absolute_error
  @mean_absolute_error
end

#mean_absolute_percentage_errorFloat

Mean absolute percentage error. Infinity when there are zeros in the ground truth. Corresponds to the JSON property meanAbsolutePercentageError

Returns:

  • (Float)


37938
37939
37940
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37938

def mean_absolute_percentage_error
  @mean_absolute_percentage_error
end

#quantile_metricsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsForecastingEvaluationMetricsQuantileMetricsEntry>

The quantile metrics entries for each quantile. Corresponds to the JSON property quantileMetrics



37943
37944
37945
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37943

def quantile_metrics
  @quantile_metrics
end

#r_squaredFloat

Coefficient of determination as Pearson correlation coefficient. Undefined when ground truth or predictions are constant or near constant. Corresponds to the JSON property rSquared

Returns:

  • (Float)


37949
37950
37951
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37949

def r_squared
  @r_squared
end

#root_mean_squared_errorFloat

Root Mean Squared Error (RMSE). Corresponds to the JSON property rootMeanSquaredError

Returns:

  • (Float)


37954
37955
37956
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37954

def root_mean_squared_error
  @root_mean_squared_error
end

#root_mean_squared_log_errorFloat

Root mean squared log error. Undefined when there are negative ground truth values or predictions. Corresponds to the JSON property rootMeanSquaredLogError

Returns:

  • (Float)


37960
37961
37962
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37960

def root_mean_squared_log_error
  @root_mean_squared_log_error
end

#root_mean_squared_percentage_errorFloat

Root Mean Square Percentage Error. Square root of MSPE. Undefined/imaginary when MSPE is negative. Corresponds to the JSON property rootMeanSquaredPercentageError

Returns:

  • (Float)


37966
37967
37968
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37966

def root_mean_squared_percentage_error
  @root_mean_squared_percentage_error
end

#weighted_absolute_percentage_errorFloat

Weighted Absolute Percentage Error. Does not use weights, this is just what the metric is called. Undefined if actual values sum to zero. Will be very large if actual values sum to a very small number. Corresponds to the JSON property weightedAbsolutePercentageError

Returns:

  • (Float)


37973
37974
37975
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37973

def weighted_absolute_percentage_error
  @weighted_absolute_percentage_error
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37980
37981
37982
37983
37984
37985
37986
37987
37988
37989
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37980

def update!(**args)
  @mean_absolute_error = args[:mean_absolute_error] if args.key?(:mean_absolute_error)
  @mean_absolute_percentage_error = args[:mean_absolute_percentage_error] if args.key?(:mean_absolute_percentage_error)
  @quantile_metrics = args[:quantile_metrics] if args.key?(:quantile_metrics)
  @r_squared = args[:r_squared] if args.key?(:r_squared)
  @root_mean_squared_error = args[:root_mean_squared_error] if args.key?(:root_mean_squared_error)
  @root_mean_squared_log_error = args[:root_mean_squared_log_error] if args.key?(:root_mean_squared_log_error)
  @root_mean_squared_percentage_error = args[:root_mean_squared_percentage_error] if args.key?(:root_mean_squared_percentage_error)
  @weighted_absolute_percentage_error = args[:weighted_absolute_percentage_error] if args.key?(:weighted_absolute_percentage_error)
end