Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsForecastingEvaluationMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Metrics for forecasting evaluation results.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaModelevaluationMetricsForecastingEvaluationMetrics

Returns a new instance of GoogleCloudAiplatformV1SchemaModelevaluationMetricsForecastingEvaluationMetrics.



27101
27102
27103
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27101

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#mean_absolute_errorFloat

Mean Absolute Error (MAE). Corresponds to the JSON property meanAbsoluteError

Returns:

  • (Float)


27058
27059
27060
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27058

def mean_absolute_error
  @mean_absolute_error
end

#mean_absolute_percentage_errorFloat

Mean absolute percentage error. Infinity when there are zeros in the ground truth. Corresponds to the JSON property meanAbsolutePercentageError

Returns:

  • (Float)


27064
27065
27066
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27064

def mean_absolute_percentage_error
  @mean_absolute_percentage_error
end

#quantile_metricsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsForecastingEvaluationMetricsQuantileMetricsEntry>

The quantile metrics entries for each quantile. Corresponds to the JSON property quantileMetrics



27069
27070
27071
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27069

def quantile_metrics
  @quantile_metrics
end

#r_squaredFloat

Coefficient of determination as Pearson correlation coefficient. Undefined when ground truth or predictions are constant or near constant. Corresponds to the JSON property rSquared

Returns:

  • (Float)


27075
27076
27077
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27075

def r_squared
  @r_squared
end

#root_mean_squared_errorFloat

Root Mean Squared Error (RMSE). Corresponds to the JSON property rootMeanSquaredError

Returns:

  • (Float)


27080
27081
27082
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27080

def root_mean_squared_error
  @root_mean_squared_error
end

#root_mean_squared_log_errorFloat

Root mean squared log error. Undefined when there are negative ground truth values or predictions. Corresponds to the JSON property rootMeanSquaredLogError

Returns:

  • (Float)


27086
27087
27088
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27086

def root_mean_squared_log_error
  @root_mean_squared_log_error
end

#root_mean_squared_percentage_errorFloat

Root Mean Square Percentage Error. Square root of MSPE. Undefined/imaginary when MSPE is negative. Corresponds to the JSON property rootMeanSquaredPercentageError

Returns:

  • (Float)


27092
27093
27094
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27092

def root_mean_squared_percentage_error
  @root_mean_squared_percentage_error
end

#weighted_absolute_percentage_errorFloat

Weighted Absolute Percentage Error. Does not use weights, this is just what the metric is called. Undefined if actual values sum to zero. Will be very large if actual values sum to a very small number. Corresponds to the JSON property weightedAbsolutePercentageError

Returns:

  • (Float)


27099
27100
27101
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27099

def weighted_absolute_percentage_error
  @weighted_absolute_percentage_error
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27106
27107
27108
27109
27110
27111
27112
27113
27114
27115
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27106

def update!(**args)
  @mean_absolute_error = args[:mean_absolute_error] if args.key?(:mean_absolute_error)
  @mean_absolute_percentage_error = args[:mean_absolute_percentage_error] if args.key?(:mean_absolute_percentage_error)
  @quantile_metrics = args[:quantile_metrics] if args.key?(:quantile_metrics)
  @r_squared = args[:r_squared] if args.key?(:r_squared)
  @root_mean_squared_error = args[:root_mean_squared_error] if args.key?(:root_mean_squared_error)
  @root_mean_squared_log_error = args[:root_mean_squared_log_error] if args.key?(:root_mean_squared_log_error)
  @root_mean_squared_percentage_error = args[:root_mean_squared_percentage_error] if args.key?(:root_mean_squared_percentage_error)
  @weighted_absolute_percentage_error = args[:weighted_absolute_percentage_error] if args.key?(:weighted_absolute_percentage_error)
end