Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsForecastingEvaluationMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Metrics for forecasting evaluation results.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaModelevaluationMetricsForecastingEvaluationMetrics

Returns a new instance of GoogleCloudAiplatformV1SchemaModelevaluationMetricsForecastingEvaluationMetrics.



20290
20291
20292
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20290

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#mean_absolute_errorFloat

Mean Absolute Error (MAE). Corresponds to the JSON property meanAbsoluteError

Returns:

  • (Float)


20247
20248
20249
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20247

def mean_absolute_error
  @mean_absolute_error
end

#mean_absolute_percentage_errorFloat

Mean absolute percentage error. Infinity when there are zeros in the ground truth. Corresponds to the JSON property meanAbsolutePercentageError

Returns:

  • (Float)


20253
20254
20255
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20253

def mean_absolute_percentage_error
  @mean_absolute_percentage_error
end

#quantile_metricsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsForecastingEvaluationMetricsQuantileMetricsEntry>

The quantile metrics entries for each quantile. Corresponds to the JSON property quantileMetrics



20258
20259
20260
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20258

def quantile_metrics
  @quantile_metrics
end

#r_squaredFloat

Coefficient of determination as Pearson correlation coefficient. Undefined when ground truth or predictions are constant or near constant. Corresponds to the JSON property rSquared

Returns:

  • (Float)


20264
20265
20266
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20264

def r_squared
  @r_squared
end

#root_mean_squared_errorFloat

Root Mean Squared Error (RMSE). Corresponds to the JSON property rootMeanSquaredError

Returns:

  • (Float)


20269
20270
20271
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20269

def root_mean_squared_error
  @root_mean_squared_error
end

#root_mean_squared_log_errorFloat

Root mean squared log error. Undefined when there are negative ground truth values or predictions. Corresponds to the JSON property rootMeanSquaredLogError

Returns:

  • (Float)


20275
20276
20277
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20275

def root_mean_squared_log_error
  @root_mean_squared_log_error
end

#root_mean_squared_percentage_errorFloat

Root Mean Square Percentage Error. Square root of MSPE. Undefined/imaginary when MSPE is negative. Corresponds to the JSON property rootMeanSquaredPercentageError

Returns:

  • (Float)


20281
20282
20283
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20281

def root_mean_squared_percentage_error
  @root_mean_squared_percentage_error
end

#weighted_absolute_percentage_errorFloat

Weighted Absolute Percentage Error. Does not use weights, this is just what the metric is called. Undefined if actual values sum to zero. Will be very large if actual values sum to a very small number. Corresponds to the JSON property weightedAbsolutePercentageError

Returns:

  • (Float)


20288
20289
20290
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20288

def weighted_absolute_percentage_error
  @weighted_absolute_percentage_error
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20295
20296
20297
20298
20299
20300
20301
20302
20303
20304
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20295

def update!(**args)
  @mean_absolute_error = args[:mean_absolute_error] if args.key?(:mean_absolute_error)
  @mean_absolute_percentage_error = args[:mean_absolute_percentage_error] if args.key?(:mean_absolute_percentage_error)
  @quantile_metrics = args[:quantile_metrics] if args.key?(:quantile_metrics)
  @r_squared = args[:r_squared] if args.key?(:r_squared)
  @root_mean_squared_error = args[:root_mean_squared_error] if args.key?(:root_mean_squared_error)
  @root_mean_squared_log_error = args[:root_mean_squared_log_error] if args.key?(:root_mean_squared_log_error)
  @root_mean_squared_percentage_error = args[:root_mean_squared_percentage_error] if args.key?(:root_mean_squared_percentage_error)
  @weighted_absolute_percentage_error = args[:weighted_absolute_percentage_error] if args.key?(:weighted_absolute_percentage_error)
end