Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsForecastingEvaluationMetrics
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsForecastingEvaluationMetrics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Metrics for forecasting evaluation results.
Instance Attribute Summary collapse
-
#mean_absolute_error ⇒ Float
Mean Absolute Error (MAE).
-
#mean_absolute_percentage_error ⇒ Float
Mean absolute percentage error.
-
#quantile_metrics ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsForecastingEvaluationMetricsQuantileMetricsEntry>
The quantile metrics entries for each quantile.
-
#r_squared ⇒ Float
Coefficient of determination as Pearson correlation coefficient.
-
#root_mean_squared_error ⇒ Float
Root Mean Squared Error (RMSE).
-
#root_mean_squared_log_error ⇒ Float
Root mean squared log error.
-
#root_mean_squared_percentage_error ⇒ Float
Root Mean Square Percentage Error.
-
#weighted_absolute_percentage_error ⇒ Float
Weighted Absolute Percentage Error.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaModelevaluationMetricsForecastingEvaluationMetrics
constructor
A new instance of GoogleCloudAiplatformV1SchemaModelevaluationMetricsForecastingEvaluationMetrics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaModelevaluationMetricsForecastingEvaluationMetrics
Returns a new instance of GoogleCloudAiplatformV1SchemaModelevaluationMetricsForecastingEvaluationMetrics.
19210 19211 19212 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19210 def initialize(**args) update!(**args) end |
Instance Attribute Details
#mean_absolute_error ⇒ Float
Mean Absolute Error (MAE).
Corresponds to the JSON property meanAbsoluteError
19167 19168 19169 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19167 def mean_absolute_error @mean_absolute_error end |
#mean_absolute_percentage_error ⇒ Float
Mean absolute percentage error. Infinity when there are zeros in the ground
truth.
Corresponds to the JSON property meanAbsolutePercentageError
19173 19174 19175 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19173 def mean_absolute_percentage_error @mean_absolute_percentage_error end |
#quantile_metrics ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsForecastingEvaluationMetricsQuantileMetricsEntry>
The quantile metrics entries for each quantile.
Corresponds to the JSON property quantileMetrics
19178 19179 19180 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19178 def quantile_metrics @quantile_metrics end |
#r_squared ⇒ Float
Coefficient of determination as Pearson correlation coefficient. Undefined
when ground truth or predictions are constant or near constant.
Corresponds to the JSON property rSquared
19184 19185 19186 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19184 def r_squared @r_squared end |
#root_mean_squared_error ⇒ Float
Root Mean Squared Error (RMSE).
Corresponds to the JSON property rootMeanSquaredError
19189 19190 19191 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19189 def root_mean_squared_error @root_mean_squared_error end |
#root_mean_squared_log_error ⇒ Float
Root mean squared log error. Undefined when there are negative ground truth
values or predictions.
Corresponds to the JSON property rootMeanSquaredLogError
19195 19196 19197 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19195 def root_mean_squared_log_error @root_mean_squared_log_error end |
#root_mean_squared_percentage_error ⇒ Float
Root Mean Square Percentage Error. Square root of MSPE. Undefined/imaginary
when MSPE is negative.
Corresponds to the JSON property rootMeanSquaredPercentageError
19201 19202 19203 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19201 def root_mean_squared_percentage_error @root_mean_squared_percentage_error end |
#weighted_absolute_percentage_error ⇒ Float
Weighted Absolute Percentage Error. Does not use weights, this is just what
the metric is called. Undefined if actual values sum to zero. Will be very
large if actual values sum to a very small number.
Corresponds to the JSON property weightedAbsolutePercentageError
19208 19209 19210 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19208 def weighted_absolute_percentage_error @weighted_absolute_percentage_error end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19215 19216 19217 19218 19219 19220 19221 19222 19223 19224 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19215 def update!(**args) @mean_absolute_error = args[:mean_absolute_error] if args.key?(:mean_absolute_error) @mean_absolute_percentage_error = args[:mean_absolute_percentage_error] if args.key?(:mean_absolute_percentage_error) @quantile_metrics = args[:quantile_metrics] if args.key?(:quantile_metrics) @r_squared = args[:r_squared] if args.key?(:r_squared) @root_mean_squared_error = args[:root_mean_squared_error] if args.key?(:root_mean_squared_error) @root_mean_squared_log_error = args[:root_mean_squared_log_error] if args.key?(:root_mean_squared_log_error) @root_mean_squared_percentage_error = args[:root_mean_squared_percentage_error] if args.key?(:root_mean_squared_percentage_error) @weighted_absolute_percentage_error = args[:weighted_absolute_percentage_error] if args.key?(:weighted_absolute_percentage_error) end |