Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsForecastingEvaluationMetricsQuantileMetricsEntry

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Entry for the Quantiles loss type optimization objective.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaModelevaluationMetricsForecastingEvaluationMetricsQuantileMetricsEntry

Returns a new instance of GoogleCloudAiplatformV1SchemaModelevaluationMetricsForecastingEvaluationMetricsQuantileMetricsEntry.



38015
38016
38017
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38015

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#observed_quantileFloat

This is a custom metric that calculates the percentage of true values that were less than the predicted value for that quantile. Only populated when optimization_objective is minimize-quantile-loss and each entry corresponds to an entry in quantiles The percent value can be used to compare with the quantile value, which is the target value. Corresponds to the JSON property observedQuantile

Returns:

  • (Float)


38003
38004
38005
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38003

def observed_quantile
  @observed_quantile
end

#quantileFloat

The quantile for this entry. Corresponds to the JSON property quantile

Returns:

  • (Float)


38008
38009
38010
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38008

def quantile
  @quantile
end

#scaled_pinball_lossFloat

The scaled pinball loss of this quantile. Corresponds to the JSON property scaledPinballLoss

Returns:

  • (Float)


38013
38014
38015
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38013

def scaled_pinball_loss
  @scaled_pinball_loss
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38020
38021
38022
38023
38024
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38020

def update!(**args)
  @observed_quantile = args[:observed_quantile] if args.key?(:observed_quantile)
  @quantile = args[:quantile] if args.key?(:quantile)
  @scaled_pinball_loss = args[:scaled_pinball_loss] if args.key?(:scaled_pinball_loss)
end