Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsForecastingEvaluationMetricsQuantileMetricsEntry
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsForecastingEvaluationMetricsQuantileMetricsEntry
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Entry for the Quantiles loss type optimization objective.
Instance Attribute Summary collapse
-
#observed_quantile ⇒ Float
This is a custom metric that calculates the percentage of true values that were less than the predicted value for that quantile.
-
#quantile ⇒ Float
The quantile for this entry.
-
#scaled_pinball_loss ⇒ Float
The scaled pinball loss of this quantile.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaModelevaluationMetricsForecastingEvaluationMetricsQuantileMetricsEntry
constructor
A new instance of GoogleCloudAiplatformV1SchemaModelevaluationMetricsForecastingEvaluationMetricsQuantileMetricsEntry.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaModelevaluationMetricsForecastingEvaluationMetricsQuantileMetricsEntry
Returns a new instance of GoogleCloudAiplatformV1SchemaModelevaluationMetricsForecastingEvaluationMetricsQuantileMetricsEntry.
36198 36199 36200 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36198 def initialize(**args) update!(**args) end |
Instance Attribute Details
#observed_quantile ⇒ Float
This is a custom metric that calculates the percentage of true values that
were less than the predicted value for that quantile. Only populated when
optimization_objective is minimize-quantile-loss and each entry corresponds to
an entry in quantiles The percent value can be used to compare with the
quantile value, which is the target value.
Corresponds to the JSON property observedQuantile
36186 36187 36188 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36186 def observed_quantile @observed_quantile end |
#quantile ⇒ Float
The quantile for this entry.
Corresponds to the JSON property quantile
36191 36192 36193 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36191 def quantile @quantile end |
#scaled_pinball_loss ⇒ Float
The scaled pinball loss of this quantile.
Corresponds to the JSON property scaledPinballLoss
36196 36197 36198 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36196 def scaled_pinball_loss @scaled_pinball_loss end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36203 36204 36205 36206 36207 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36203 def update!(**args) @observed_quantile = args[:observed_quantile] if args.key?(:observed_quantile) @quantile = args[:quantile] if args.key?(:quantile) @scaled_pinball_loss = args[:scaled_pinball_loss] if args.key?(:scaled_pinball_loss) end |