Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsImageSegmentationEvaluationMetricsConfidenceMetricsEntry

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaModelevaluationMetricsImageSegmentationEvaluationMetricsConfidenceMetricsEntry

Returns a new instance of GoogleCloudAiplatformV1SchemaModelevaluationMetricsImageSegmentationEvaluationMetricsConfidenceMetricsEntry.



37713
37714
37715
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37713

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidence_thresholdFloat

Metrics are computed with an assumption that the model never returns predictions with score lower than this value. Corresponds to the JSON property confidenceThreshold

Returns:

  • (Float)


37685
37686
37687
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37685

def confidence_threshold
  @confidence_threshold
end

#confusion_matrixGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsConfusionMatrix

Confusion matrix for the given confidence threshold. Corresponds to the JSON property confusionMatrix



37690
37691
37692
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37690

def confusion_matrix
  @confusion_matrix
end

#dice_score_coefficientFloat

DSC or the F1 score, The harmonic mean of recall and precision. Corresponds to the JSON property diceScoreCoefficient

Returns:

  • (Float)


37695
37696
37697
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37695

def dice_score_coefficient
  @dice_score_coefficient
end

#iou_scoreFloat

The intersection-over-union score. The measure of overlap of the annotation's category mask with ground truth category mask on the DataItem. Corresponds to the JSON property iouScore

Returns:

  • (Float)


37701
37702
37703
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37701

def iou_score
  @iou_score
end

#precisionFloat

Precision for the given confidence threshold. Corresponds to the JSON property precision

Returns:

  • (Float)


37706
37707
37708
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37706

def precision
  @precision
end

#recallFloat

Recall (True Positive Rate) for the given confidence threshold. Corresponds to the JSON property recall

Returns:

  • (Float)


37711
37712
37713
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37711

def recall
  @recall
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37718
37719
37720
37721
37722
37723
37724
37725
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37718

def update!(**args)
  @confidence_threshold = args[:confidence_threshold] if args.key?(:confidence_threshold)
  @confusion_matrix = args[:confusion_matrix] if args.key?(:confusion_matrix)
  @dice_score_coefficient = args[:dice_score_coefficient] if args.key?(:dice_score_coefficient)
  @iou_score = args[:iou_score] if args.key?(:iou_score)
  @precision = args[:precision] if args.key?(:precision)
  @recall = args[:recall] if args.key?(:recall)
end