Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsImageSegmentationEvaluationMetricsConfidenceMetricsEntry

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaModelevaluationMetricsImageSegmentationEvaluationMetricsConfidenceMetricsEntry

Returns a new instance of GoogleCloudAiplatformV1SchemaModelevaluationMetricsImageSegmentationEvaluationMetricsConfidenceMetricsEntry.



27856
27857
27858
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27856

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidence_thresholdFloat

Metrics are computed with an assumption that the model never returns predictions with score lower than this value. Corresponds to the JSON property confidenceThreshold

Returns:

  • (Float)


27828
27829
27830
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27828

def confidence_threshold
  @confidence_threshold
end

#confusion_matrixGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsConfusionMatrix

Confusion matrix for the given confidence threshold. Corresponds to the JSON property confusionMatrix



27833
27834
27835
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27833

def confusion_matrix
  @confusion_matrix
end

#dice_score_coefficientFloat

DSC or the F1 score, The harmonic mean of recall and precision. Corresponds to the JSON property diceScoreCoefficient

Returns:

  • (Float)


27838
27839
27840
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27838

def dice_score_coefficient
  @dice_score_coefficient
end

#iou_scoreFloat

The intersection-over-union score. The measure of overlap of the annotation's category mask with ground truth category mask on the DataItem. Corresponds to the JSON property iouScore

Returns:

  • (Float)


27844
27845
27846
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27844

def iou_score
  @iou_score
end

#precisionFloat

Precision for the given confidence threshold. Corresponds to the JSON property precision

Returns:

  • (Float)


27849
27850
27851
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27849

def precision
  @precision
end

#recallFloat

Recall (True Positive Rate) for the given confidence threshold. Corresponds to the JSON property recall

Returns:

  • (Float)


27854
27855
27856
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27854

def recall
  @recall
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27861
27862
27863
27864
27865
27866
27867
27868
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27861

def update!(**args)
  @confidence_threshold = args[:confidence_threshold] if args.key?(:confidence_threshold)
  @confusion_matrix = args[:confusion_matrix] if args.key?(:confusion_matrix)
  @dice_score_coefficient = args[:dice_score_coefficient] if args.key?(:dice_score_coefficient)
  @iou_score = args[:iou_score] if args.key?(:iou_score)
  @precision = args[:precision] if args.key?(:precision)
  @recall = args[:recall] if args.key?(:recall)
end