Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsImageSegmentationEvaluationMetricsConfidenceMetricsEntry
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsImageSegmentationEvaluationMetricsConfidenceMetricsEntry
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Instance Attribute Summary collapse
-
#confidence_threshold ⇒ Float
Metrics are computed with an assumption that the model never returns predictions with score lower than this value.
-
#confusion_matrix ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsConfusionMatrix
Confusion matrix for the given confidence threshold.
-
#dice_score_coefficient ⇒ Float
DSC or the F1 score, The harmonic mean of recall and precision.
-
#iou_score ⇒ Float
The intersection-over-union score.
-
#precision ⇒ Float
Precision for the given confidence threshold.
-
#recall ⇒ Float
Recall (True Positive Rate) for the given confidence threshold.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaModelevaluationMetricsImageSegmentationEvaluationMetricsConfidenceMetricsEntry
constructor
A new instance of GoogleCloudAiplatformV1SchemaModelevaluationMetricsImageSegmentationEvaluationMetricsConfidenceMetricsEntry.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaModelevaluationMetricsImageSegmentationEvaluationMetricsConfidenceMetricsEntry
Returns a new instance of GoogleCloudAiplatformV1SchemaModelevaluationMetricsImageSegmentationEvaluationMetricsConfidenceMetricsEntry.
27338 27339 27340 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27338 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence_threshold ⇒ Float
Metrics are computed with an assumption that the model never returns
predictions with score lower than this value.
Corresponds to the JSON property confidenceThreshold
27310 27311 27312 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27310 def confidence_threshold @confidence_threshold end |
#confusion_matrix ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsConfusionMatrix
Confusion matrix for the given confidence threshold.
Corresponds to the JSON property confusionMatrix
27315 27316 27317 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27315 def confusion_matrix @confusion_matrix end |
#dice_score_coefficient ⇒ Float
DSC or the F1 score, The harmonic mean of recall and precision.
Corresponds to the JSON property diceScoreCoefficient
27320 27321 27322 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27320 def dice_score_coefficient @dice_score_coefficient end |
#iou_score ⇒ Float
The intersection-over-union score. The measure of overlap of the annotation's
category mask with ground truth category mask on the DataItem.
Corresponds to the JSON property iouScore
27326 27327 27328 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27326 def iou_score @iou_score end |
#precision ⇒ Float
Precision for the given confidence threshold.
Corresponds to the JSON property precision
27331 27332 27333 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27331 def precision @precision end |
#recall ⇒ Float
Recall (True Positive Rate) for the given confidence threshold.
Corresponds to the JSON property recall
27336 27337 27338 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27336 def recall @recall end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27343 27344 27345 27346 27347 27348 27349 27350 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27343 def update!(**args) @confidence_threshold = args[:confidence_threshold] if args.key?(:confidence_threshold) @confusion_matrix = args[:confusion_matrix] if args.key?(:confusion_matrix) @dice_score_coefficient = args[:dice_score_coefficient] if args.key?(:dice_score_coefficient) @iou_score = args[:iou_score] if args.key?(:iou_score) @precision = args[:precision] if args.key?(:precision) @recall = args[:recall] if args.key?(:recall) end |