Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsImageSegmentationEvaluationMetricsConfidenceMetricsEntry

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaModelevaluationMetricsImageSegmentationEvaluationMetricsConfidenceMetricsEntry

Returns a new instance of GoogleCloudAiplatformV1SchemaModelevaluationMetricsImageSegmentationEvaluationMetricsConfidenceMetricsEntry.



25707
25708
25709
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25707

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidence_thresholdFloat

Metrics are computed with an assumption that the model never returns predictions with score lower than this value. Corresponds to the JSON property confidenceThreshold

Returns:

  • (Float)


25679
25680
25681
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25679

def confidence_threshold
  @confidence_threshold
end

#confusion_matrixGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsConfusionMatrix

Confusion matrix for the given confidence threshold. Corresponds to the JSON property confusionMatrix



25684
25685
25686
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25684

def confusion_matrix
  @confusion_matrix
end

#dice_score_coefficientFloat

DSC or the F1 score, The harmonic mean of recall and precision. Corresponds to the JSON property diceScoreCoefficient

Returns:

  • (Float)


25689
25690
25691
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25689

def dice_score_coefficient
  @dice_score_coefficient
end

#iou_scoreFloat

The intersection-over-union score. The measure of overlap of the annotation's category mask with ground truth category mask on the DataItem. Corresponds to the JSON property iouScore

Returns:

  • (Float)


25695
25696
25697
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25695

def iou_score
  @iou_score
end

#precisionFloat

Precision for the given confidence threshold. Corresponds to the JSON property precision

Returns:

  • (Float)


25700
25701
25702
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25700

def precision
  @precision
end

#recallFloat

Recall (True Positive Rate) for the given confidence threshold. Corresponds to the JSON property recall

Returns:

  • (Float)


25705
25706
25707
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25705

def recall
  @recall
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25712
25713
25714
25715
25716
25717
25718
25719
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25712

def update!(**args)
  @confidence_threshold = args[:confidence_threshold] if args.key?(:confidence_threshold)
  @confusion_matrix = args[:confusion_matrix] if args.key?(:confusion_matrix)
  @dice_score_coefficient = args[:dice_score_coefficient] if args.key?(:dice_score_coefficient)
  @iou_score = args[:iou_score] if args.key?(:iou_score)
  @precision = args[:precision] if args.key?(:precision)
  @recall = args[:recall] if args.key?(:recall)
end