Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsPairwiseTextGenerationEvaluationMetrics
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsPairwiseTextGenerationEvaluationMetrics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Metrics for general pairwise text generation evaluation results.
Instance Attribute Summary collapse
-
#accuracy ⇒ Float
Fraction of cases where the autorater agreed with the human raters.
-
#baseline_model_win_rate ⇒ Float
Percentage of time the autorater decided the baseline model had the better response.
-
#cohens_kappa ⇒ Float
A measurement of agreement between the autorater and human raters that takes the likelihood of random agreement into account.
-
#f1_score ⇒ Float
Harmonic mean of precision and recall.
-
#false_negative_count ⇒ Fixnum
Number of examples where the autorater chose the baseline model, but humans preferred the model.
-
#false_positive_count ⇒ Fixnum
Number of examples where the autorater chose the model, but humans preferred the baseline model.
-
#human_preference_baseline_model_win_rate ⇒ Float
Percentage of time humans decided the baseline model had the better response.
-
#human_preference_model_win_rate ⇒ Float
Percentage of time humans decided the model had the better response.
-
#model_win_rate ⇒ Float
Percentage of time the autorater decided the model had the better response.
-
#precision ⇒ Float
Fraction of cases where the autorater and humans thought the model had a better response out of all cases where the autorater thought the model had a better response.
-
#recall ⇒ Float
Fraction of cases where the autorater and humans thought the model had a better response out of all cases where the humans thought the model had a better response.
-
#true_negative_count ⇒ Fixnum
Number of examples where both the autorater and humans decided that the model had the worse response.
-
#true_positive_count ⇒ Fixnum
Number of examples where both the autorater and humans decided that the model had the better response.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaModelevaluationMetricsPairwiseTextGenerationEvaluationMetrics
constructor
A new instance of GoogleCloudAiplatformV1SchemaModelevaluationMetricsPairwiseTextGenerationEvaluationMetrics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaModelevaluationMetricsPairwiseTextGenerationEvaluationMetrics
Returns a new instance of GoogleCloudAiplatformV1SchemaModelevaluationMetricsPairwiseTextGenerationEvaluationMetrics.
28571 28572 28573 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28571 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accuracy ⇒ Float
Fraction of cases where the autorater agreed with the human raters.
Corresponds to the JSON property accuracy
28499 28500 28501 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28499 def accuracy @accuracy end |
#baseline_model_win_rate ⇒ Float
Percentage of time the autorater decided the baseline model had the better
response.
Corresponds to the JSON property baselineModelWinRate
28505 28506 28507 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28505 def baseline_model_win_rate @baseline_model_win_rate end |
#cohens_kappa ⇒ Float
A measurement of agreement between the autorater and human raters that takes
the likelihood of random agreement into account.
Corresponds to the JSON property cohensKappa
28511 28512 28513 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28511 def cohens_kappa @cohens_kappa end |
#f1_score ⇒ Float
Harmonic mean of precision and recall.
Corresponds to the JSON property f1Score
28516 28517 28518 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28516 def f1_score @f1_score end |
#false_negative_count ⇒ Fixnum
Number of examples where the autorater chose the baseline model, but humans
preferred the model.
Corresponds to the JSON property falseNegativeCount
28522 28523 28524 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28522 def false_negative_count @false_negative_count end |
#false_positive_count ⇒ Fixnum
Number of examples where the autorater chose the model, but humans preferred
the baseline model.
Corresponds to the JSON property falsePositiveCount
28528 28529 28530 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28528 def false_positive_count @false_positive_count end |
#human_preference_baseline_model_win_rate ⇒ Float
Percentage of time humans decided the baseline model had the better response.
Corresponds to the JSON property humanPreferenceBaselineModelWinRate
28533 28534 28535 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28533 def human_preference_baseline_model_win_rate @human_preference_baseline_model_win_rate end |
#human_preference_model_win_rate ⇒ Float
Percentage of time humans decided the model had the better response.
Corresponds to the JSON property humanPreferenceModelWinRate
28538 28539 28540 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28538 def human_preference_model_win_rate @human_preference_model_win_rate end |
#model_win_rate ⇒ Float
Percentage of time the autorater decided the model had the better response.
Corresponds to the JSON property modelWinRate
28543 28544 28545 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28543 def model_win_rate @model_win_rate end |
#precision ⇒ Float
Fraction of cases where the autorater and humans thought the model had a
better response out of all cases where the autorater thought the model had a
better response. True positive divided by all positive.
Corresponds to the JSON property precision
28550 28551 28552 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28550 def precision @precision end |
#recall ⇒ Float
Fraction of cases where the autorater and humans thought the model had a
better response out of all cases where the humans thought the model had a
better response.
Corresponds to the JSON property recall
28557 28558 28559 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28557 def recall @recall end |
#true_negative_count ⇒ Fixnum
Number of examples where both the autorater and humans decided that the model
had the worse response.
Corresponds to the JSON property trueNegativeCount
28563 28564 28565 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28563 def true_negative_count @true_negative_count end |
#true_positive_count ⇒ Fixnum
Number of examples where both the autorater and humans decided that the model
had the better response.
Corresponds to the JSON property truePositiveCount
28569 28570 28571 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28569 def true_positive_count @true_positive_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28576 28577 28578 28579 28580 28581 28582 28583 28584 28585 28586 28587 28588 28589 28590 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28576 def update!(**args) @accuracy = args[:accuracy] if args.key?(:accuracy) @baseline_model_win_rate = args[:baseline_model_win_rate] if args.key?(:baseline_model_win_rate) @cohens_kappa = args[:cohens_kappa] if args.key?(:cohens_kappa) @f1_score = args[:f1_score] if args.key?(:f1_score) @false_negative_count = args[:false_negative_count] if args.key?(:false_negative_count) @false_positive_count = args[:false_positive_count] if args.key?(:false_positive_count) @human_preference_baseline_model_win_rate = args[:human_preference_baseline_model_win_rate] if args.key?(:human_preference_baseline_model_win_rate) @human_preference_model_win_rate = args[:human_preference_model_win_rate] if args.key?(:human_preference_model_win_rate) @model_win_rate = args[:model_win_rate] if args.key?(:model_win_rate) @precision = args[:precision] if args.key?(:precision) @recall = args[:recall] if args.key?(:recall) @true_negative_count = args[:true_negative_count] if args.key?(:true_negative_count) @true_positive_count = args[:true_positive_count] if args.key?(:true_positive_count) end |