Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsTextExtractionEvaluationMetricsConfidenceMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaModelevaluationMetricsTextExtractionEvaluationMetricsConfidenceMetrics

Returns a new instance of GoogleCloudAiplatformV1SchemaModelevaluationMetricsTextExtractionEvaluationMetricsConfidenceMetrics.



28523
28524
28525
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28523

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidence_thresholdFloat

Metrics are computed with an assumption that the Model never returns predictions with score lower than this value. Corresponds to the JSON property confidenceThreshold

Returns:

  • (Float)


28506
28507
28508
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28506

def confidence_threshold
  @confidence_threshold
end

#f1_scoreFloat

The harmonic mean of recall and precision. Corresponds to the JSON property f1Score

Returns:

  • (Float)


28511
28512
28513
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28511

def f1_score
  @f1_score
end

#precisionFloat

Precision for the given confidence threshold. Corresponds to the JSON property precision

Returns:

  • (Float)


28516
28517
28518
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28516

def precision
  @precision
end

#recallFloat

Recall (True Positive Rate) for the given confidence threshold. Corresponds to the JSON property recall

Returns:

  • (Float)


28521
28522
28523
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28521

def recall
  @recall
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28528
28529
28530
28531
28532
28533
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28528

def update!(**args)
  @confidence_threshold = args[:confidence_threshold] if args.key?(:confidence_threshold)
  @f1_score = args[:f1_score] if args.key?(:f1_score)
  @precision = args[:precision] if args.key?(:precision)
  @recall = args[:recall] if args.key?(:recall)
end