Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsTextExtractionEvaluationMetricsConfidenceMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaModelevaluationMetricsTextExtractionEvaluationMetricsConfidenceMetrics

Returns a new instance of GoogleCloudAiplatformV1SchemaModelevaluationMetricsTextExtractionEvaluationMetricsConfidenceMetrics.



22580
22581
22582
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22580

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidence_thresholdFloat

Metrics are computed with an assumption that the Model never returns predictions with score lower than this value. Corresponds to the JSON property confidenceThreshold

Returns:

  • (Float)


22563
22564
22565
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22563

def confidence_threshold
  @confidence_threshold
end

#f1_scoreFloat

The harmonic mean of recall and precision. Corresponds to the JSON property f1Score

Returns:

  • (Float)


22568
22569
22570
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22568

def f1_score
  @f1_score
end

#precisionFloat

Precision for the given confidence threshold. Corresponds to the JSON property precision

Returns:

  • (Float)


22573
22574
22575
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22573

def precision
  @precision
end

#recallFloat

Recall (True Positive Rate) for the given confidence threshold. Corresponds to the JSON property recall

Returns:

  • (Float)


22578
22579
22580
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22578

def recall
  @recall
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22585
22586
22587
22588
22589
22590
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22585

def update!(**args)
  @confidence_threshold = args[:confidence_threshold] if args.key?(:confidence_threshold)
  @f1_score = args[:f1_score] if args.key?(:f1_score)
  @precision = args[:precision] if args.key?(:precision)
  @recall = args[:recall] if args.key?(:recall)
end