Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsTextExtractionEvaluationMetricsConfidenceMetrics
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsTextExtractionEvaluationMetricsConfidenceMetrics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Instance Attribute Summary collapse
-
#confidence_threshold ⇒ Float
Metrics are computed with an assumption that the Model never returns predictions with score lower than this value.
-
#f1_score ⇒ Float
The harmonic mean of recall and precision.
-
#precision ⇒ Float
Precision for the given confidence threshold.
-
#recall ⇒ Float
Recall (True Positive Rate) for the given confidence threshold.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaModelevaluationMetricsTextExtractionEvaluationMetricsConfidenceMetrics
constructor
A new instance of GoogleCloudAiplatformV1SchemaModelevaluationMetricsTextExtractionEvaluationMetricsConfidenceMetrics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaModelevaluationMetricsTextExtractionEvaluationMetricsConfidenceMetrics
Returns a new instance of GoogleCloudAiplatformV1SchemaModelevaluationMetricsTextExtractionEvaluationMetricsConfidenceMetrics.
21973 21974 21975 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21973 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence_threshold ⇒ Float
Metrics are computed with an assumption that the Model never returns
predictions with score lower than this value.
Corresponds to the JSON property confidenceThreshold
21956 21957 21958 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21956 def confidence_threshold @confidence_threshold end |
#f1_score ⇒ Float
The harmonic mean of recall and precision.
Corresponds to the JSON property f1Score
21961 21962 21963 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21961 def f1_score @f1_score end |
#precision ⇒ Float
Precision for the given confidence threshold.
Corresponds to the JSON property precision
21966 21967 21968 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21966 def precision @precision end |
#recall ⇒ Float
Recall (True Positive Rate) for the given confidence threshold.
Corresponds to the JSON property recall
21971 21972 21973 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21971 def recall @recall end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21978 21979 21980 21981 21982 21983 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21978 def update!(**args) @confidence_threshold = args[:confidence_threshold] if args.key?(:confidence_threshold) @f1_score = args[:f1_score] if args.key?(:f1_score) @precision = args[:precision] if args.key?(:precision) @recall = args[:recall] if args.key?(:recall) end |