Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsTextExtractionEvaluationMetricsConfidenceMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaModelevaluationMetricsTextExtractionEvaluationMetricsConfidenceMetrics

Returns a new instance of GoogleCloudAiplatformV1SchemaModelevaluationMetricsTextExtractionEvaluationMetricsConfidenceMetrics.



19894
19895
19896
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19894

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidence_thresholdFloat

Metrics are computed with an assumption that the Model never returns predictions with score lower than this value. Corresponds to the JSON property confidenceThreshold

Returns:

  • (Float)


19877
19878
19879
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19877

def confidence_threshold
  @confidence_threshold
end

#f1_scoreFloat

The harmonic mean of recall and precision. Corresponds to the JSON property f1Score

Returns:

  • (Float)


19882
19883
19884
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19882

def f1_score
  @f1_score
end

#precisionFloat

Precision for the given confidence threshold. Corresponds to the JSON property precision

Returns:

  • (Float)


19887
19888
19889
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19887

def precision
  @precision
end

#recallFloat

Recall (True Positive Rate) for the given confidence threshold. Corresponds to the JSON property recall

Returns:

  • (Float)


19892
19893
19894
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19892

def recall
  @recall
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19899
19900
19901
19902
19903
19904
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19899

def update!(**args)
  @confidence_threshold = args[:confidence_threshold] if args.key?(:confidence_threshold)
  @f1_score = args[:f1_score] if args.key?(:f1_score)
  @precision = args[:precision] if args.key?(:precision)
  @recall = args[:recall] if args.key?(:recall)
end