Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsTrackMetricsConfidenceMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Metrics for a single confidence threshold.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaModelevaluationMetricsTrackMetricsConfidenceMetrics

Returns a new instance of GoogleCloudAiplatformV1SchemaModelevaluationMetricsTrackMetricsConfidenceMetrics.



36614
36615
36616
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36614

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bounding_box_iouFloat

Bounding box intersection-over-union precision. Measures how well the bounding boxes overlap between each other (e.g. complete overlap or just barely above iou_threshold). Corresponds to the JSON property boundingBoxIou

Returns:

  • (Float)


36591
36592
36593
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36591

def bounding_box_iou
  @bounding_box_iou
end

#confidence_thresholdFloat

The confidence threshold value used to compute the metrics. Corresponds to the JSON property confidenceThreshold

Returns:

  • (Float)


36596
36597
36598
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36596

def confidence_threshold
  @confidence_threshold
end

#mismatch_rateFloat

Mismatch rate, which measures the tracking consistency, i.e. correctness of instance ID continuity. Corresponds to the JSON property mismatchRate

Returns:

  • (Float)


36602
36603
36604
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36602

def mismatch_rate
  @mismatch_rate
end

#tracking_precisionFloat

Tracking precision. Corresponds to the JSON property trackingPrecision

Returns:

  • (Float)


36607
36608
36609
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36607

def tracking_precision
  @tracking_precision
end

#tracking_recallFloat

Tracking recall. Corresponds to the JSON property trackingRecall

Returns:

  • (Float)


36612
36613
36614
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36612

def tracking_recall
  @tracking_recall
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36619
36620
36621
36622
36623
36624
36625
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36619

def update!(**args)
  @bounding_box_iou = args[:bounding_box_iou] if args.key?(:bounding_box_iou)
  @confidence_threshold = args[:confidence_threshold] if args.key?(:confidence_threshold)
  @mismatch_rate = args[:mismatch_rate] if args.key?(:mismatch_rate)
  @tracking_precision = args[:tracking_precision] if args.key?(:tracking_precision)
  @tracking_recall = args[:tracking_recall] if args.key?(:tracking_recall)
end