Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoActionMetrics
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoActionMetrics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The Evaluation metrics given a specific precision_window_length.
Instance Attribute Summary collapse
-
#confidence_metrics ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoActionMetricsConfidenceMetrics>
Metrics for each label-match confidence_threshold from 0.05,0.10,...,0.95,0.96, 0.97,0.98,0.99.
-
#mean_average_precision ⇒ Float
The mean average precision.
-
#precision_window_length ⇒ String
This VideoActionMetrics is calculated based on this prediction window length.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoActionMetrics
constructor
A new instance of GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoActionMetrics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoActionMetrics
Returns a new instance of GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoActionMetrics.
39632 39633 39634 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39632 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence_metrics ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoActionMetricsConfidenceMetrics>
Metrics for each label-match confidence_threshold from 0.05,0.10,...,0.95,0.96,
0.97,0.98,0.99.
Corresponds to the JSON property confidenceMetrics
39617 39618 39619 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39617 def confidence_metrics @confidence_metrics end |
#mean_average_precision ⇒ Float
The mean average precision.
Corresponds to the JSON property meanAveragePrecision
39622 39623 39624 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39622 def mean_average_precision @mean_average_precision end |
#precision_window_length ⇒ String
This VideoActionMetrics is calculated based on this prediction window length.
If the predicted action's timestamp is inside the time window whose center is
the ground truth action's timestamp with this specific length, the prediction
result is treated as a true positive.
Corresponds to the JSON property precisionWindowLength
39630 39631 39632 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39630 def precision_window_length @precision_window_length end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39637 39638 39639 39640 39641 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39637 def update!(**args) @confidence_metrics = args[:confidence_metrics] if args.key?(:confidence_metrics) @mean_average_precision = args[:mean_average_precision] if args.key?(:mean_average_precision) @precision_window_length = args[:precision_window_length] if args.key?(:precision_window_length) end |