Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoActionMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The Evaluation metrics given a specific precision_window_length.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoActionMetrics

Returns a new instance of GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoActionMetrics.



27785
27786
27787
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27785

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidence_metricsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoActionMetricsConfidenceMetrics>

Metrics for each label-match confidence_threshold from 0.05,0.10,...,0.95,0.96, 0.97,0.98,0.99. Corresponds to the JSON property confidenceMetrics



27770
27771
27772
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27770

def confidence_metrics
  @confidence_metrics
end

#mean_average_precisionFloat

The mean average precision. Corresponds to the JSON property meanAveragePrecision

Returns:

  • (Float)


27775
27776
27777
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27775

def mean_average_precision
  @mean_average_precision
end

#precision_window_lengthString

This VideoActionMetrics is calculated based on this prediction window length. If the predicted action's timestamp is inside the time window whose center is the ground truth action's timestamp with this specific length, the prediction result is treated as a true positive. Corresponds to the JSON property precisionWindowLength

Returns:

  • (String)


27783
27784
27785
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27783

def precision_window_length
  @precision_window_length
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27790
27791
27792
27793
27794
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27790

def update!(**args)
  @confidence_metrics = args[:confidence_metrics] if args.key?(:confidence_metrics)
  @mean_average_precision = args[:mean_average_precision] if args.key?(:mean_average_precision)
  @precision_window_length = args[:precision_window_length] if args.key?(:precision_window_length)
end