Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoObjectTrackingMetrics
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoObjectTrackingMetrics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Model evaluation metrics for video object tracking problems. Evaluates prediction quality of both labeled bounding boxes and labeled tracks (i.e. series of bounding boxes sharing same label and instance ID).
Instance Attribute Summary collapse
-
#bounding_box_mean_average_precision ⇒ Float
The single metric for bounding boxes evaluation: the
meanAveragePrecisionaveraged over allboundingBoxMetrics. -
#bounding_box_metrics ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsBoundingBoxMetrics>
The bounding boxes match metrics for each intersection-over-union threshold 0.
-
#evaluated_bounding_box_count ⇒ Fixnum
UNIMPLEMENTED.
-
#evaluated_frame_count ⇒ Fixnum
UNIMPLEMENTED.
-
#evaluated_track_count ⇒ Fixnum
UNIMPLEMENTED.
-
#track_mean_average_precision ⇒ Float
UNIMPLEMENTED.
-
#track_mean_bounding_box_iou ⇒ Float
UNIMPLEMENTED.
-
#track_mean_mismatch_rate ⇒ Float
UNIMPLEMENTED.
-
#track_metrics ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsTrackMetrics>
UNIMPLEMENTED.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoObjectTrackingMetrics
constructor
A new instance of GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoObjectTrackingMetrics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoObjectTrackingMetrics
Returns a new instance of GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoObjectTrackingMetrics.
39973 39974 39975 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39973 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bounding_box_mean_average_precision ⇒ Float
The single metric for bounding boxes evaluation: the meanAveragePrecision
averaged over all boundingBoxMetrics.
Corresponds to the JSON property boundingBoxMeanAveragePrecision
39922 39923 39924 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39922 def bounding_box_mean_average_precision @bounding_box_mean_average_precision end |
#bounding_box_metrics ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsBoundingBoxMetrics>
The bounding boxes match metrics for each intersection-over-union threshold 0.
05,0.10,...,0.95,0.96,0.97,0.98,0.99 and each label confidence threshold 0.05,
0.10,...,0.95,0.96,0.97,0.98,0.99 pair.
Corresponds to the JSON property boundingBoxMetrics
39929 39930 39931 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39929 def bounding_box_metrics @bounding_box_metrics end |
#evaluated_bounding_box_count ⇒ Fixnum
UNIMPLEMENTED. The total number of bounding boxes (i.e. summed over all frames)
the ground truth used to create this evaluation had.
Corresponds to the JSON property evaluatedBoundingBoxCount
39935 39936 39937 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39935 def evaluated_bounding_box_count @evaluated_bounding_box_count end |
#evaluated_frame_count ⇒ Fixnum
UNIMPLEMENTED. The number of video frames used to create this evaluation.
Corresponds to the JSON property evaluatedFrameCount
39940 39941 39942 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39940 def evaluated_frame_count @evaluated_frame_count end |
#evaluated_track_count ⇒ Fixnum
UNIMPLEMENTED. The total number of tracks (i.e. as seen across all frames) the
ground truth used to create this evaluation had.
Corresponds to the JSON property evaluatedTrackCount
39946 39947 39948 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39946 def evaluated_track_count @evaluated_track_count end |
#track_mean_average_precision ⇒ Float
UNIMPLEMENTED. The single metric for tracks accuracy evaluation: the
meanAveragePrecision averaged over all trackMetrics.
Corresponds to the JSON property trackMeanAveragePrecision
39952 39953 39954 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39952 def track_mean_average_precision @track_mean_average_precision end |
#track_mean_bounding_box_iou ⇒ Float
UNIMPLEMENTED. The single metric for tracks bounding box iou evaluation: the
meanBoundingBoxIou averaged over all trackMetrics.
Corresponds to the JSON property trackMeanBoundingBoxIou
39958 39959 39960 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39958 def track_mean_bounding_box_iou @track_mean_bounding_box_iou end |
#track_mean_mismatch_rate ⇒ Float
UNIMPLEMENTED. The single metric for tracking consistency evaluation: the
meanMismatchRate averaged over all trackMetrics.
Corresponds to the JSON property trackMeanMismatchRate
39964 39965 39966 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39964 def track_mean_mismatch_rate @track_mean_mismatch_rate end |
#track_metrics ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsTrackMetrics>
UNIMPLEMENTED. The tracks match metrics for each intersection-over-union
threshold 0.05,0.10,...,0.95,0.96,0.97,0.98,0.99 and each label confidence
threshold 0.05,0.10,...,0.95,0.96,0.97,0.98,0.99 pair.
Corresponds to the JSON property trackMetrics
39971 39972 39973 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39971 def track_metrics @track_metrics end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39978 39979 39980 39981 39982 39983 39984 39985 39986 39987 39988 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39978 def update!(**args) @bounding_box_mean_average_precision = args[:bounding_box_mean_average_precision] if args.key?(:bounding_box_mean_average_precision) @bounding_box_metrics = args[:bounding_box_metrics] if args.key?(:bounding_box_metrics) @evaluated_bounding_box_count = args[:evaluated_bounding_box_count] if args.key?(:evaluated_bounding_box_count) @evaluated_frame_count = args[:evaluated_frame_count] if args.key?(:evaluated_frame_count) @evaluated_track_count = args[:evaluated_track_count] if args.key?(:evaluated_track_count) @track_mean_average_precision = args[:track_mean_average_precision] if args.key?(:track_mean_average_precision) @track_mean_bounding_box_iou = args[:track_mean_bounding_box_iou] if args.key?(:track_mean_bounding_box_iou) @track_mean_mismatch_rate = args[:track_mean_mismatch_rate] if args.key?(:track_mean_mismatch_rate) @track_metrics = args[:track_metrics] if args.key?(:track_metrics) end |