Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoObjectTrackingMetrics
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoObjectTrackingMetrics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Model evaluation metrics for video object tracking problems. Evaluates prediction quality of both labeled bounding boxes and labeled tracks (i.e. series of bounding boxes sharing same label and instance ID).
Instance Attribute Summary collapse
-
#bounding_box_mean_average_precision ⇒ Float
The single metric for bounding boxes evaluation: the
meanAveragePrecisionaveraged over allboundingBoxMetrics. -
#bounding_box_metrics ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsBoundingBoxMetrics>
The bounding boxes match metrics for each intersection-over-union threshold 0.
-
#evaluated_bounding_box_count ⇒ Fixnum
UNIMPLEMENTED.
-
#evaluated_frame_count ⇒ Fixnum
UNIMPLEMENTED.
-
#evaluated_track_count ⇒ Fixnum
UNIMPLEMENTED.
-
#track_mean_average_precision ⇒ Float
UNIMPLEMENTED.
-
#track_mean_bounding_box_iou ⇒ Float
UNIMPLEMENTED.
-
#track_mean_mismatch_rate ⇒ Float
UNIMPLEMENTED.
-
#track_metrics ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsTrackMetrics>
UNIMPLEMENTED.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoObjectTrackingMetrics
constructor
A new instance of GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoObjectTrackingMetrics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoObjectTrackingMetrics
Returns a new instance of GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoObjectTrackingMetrics.
38739 38740 38741 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38739 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bounding_box_mean_average_precision ⇒ Float
The single metric for bounding boxes evaluation: the meanAveragePrecision
averaged over all boundingBoxMetrics.
Corresponds to the JSON property boundingBoxMeanAveragePrecision
38688 38689 38690 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38688 def bounding_box_mean_average_precision @bounding_box_mean_average_precision end |
#bounding_box_metrics ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsBoundingBoxMetrics>
The bounding boxes match metrics for each intersection-over-union threshold 0.
05,0.10,...,0.95,0.96,0.97,0.98,0.99 and each label confidence threshold 0.05,
0.10,...,0.95,0.96,0.97,0.98,0.99 pair.
Corresponds to the JSON property boundingBoxMetrics
38695 38696 38697 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38695 def bounding_box_metrics @bounding_box_metrics end |
#evaluated_bounding_box_count ⇒ Fixnum
UNIMPLEMENTED. The total number of bounding boxes (i.e. summed over all frames)
the ground truth used to create this evaluation had.
Corresponds to the JSON property evaluatedBoundingBoxCount
38701 38702 38703 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38701 def evaluated_bounding_box_count @evaluated_bounding_box_count end |
#evaluated_frame_count ⇒ Fixnum
UNIMPLEMENTED. The number of video frames used to create this evaluation.
Corresponds to the JSON property evaluatedFrameCount
38706 38707 38708 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38706 def evaluated_frame_count @evaluated_frame_count end |
#evaluated_track_count ⇒ Fixnum
UNIMPLEMENTED. The total number of tracks (i.e. as seen across all frames) the
ground truth used to create this evaluation had.
Corresponds to the JSON property evaluatedTrackCount
38712 38713 38714 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38712 def evaluated_track_count @evaluated_track_count end |
#track_mean_average_precision ⇒ Float
UNIMPLEMENTED. The single metric for tracks accuracy evaluation: the
meanAveragePrecision averaged over all trackMetrics.
Corresponds to the JSON property trackMeanAveragePrecision
38718 38719 38720 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38718 def track_mean_average_precision @track_mean_average_precision end |
#track_mean_bounding_box_iou ⇒ Float
UNIMPLEMENTED. The single metric for tracks bounding box iou evaluation: the
meanBoundingBoxIou averaged over all trackMetrics.
Corresponds to the JSON property trackMeanBoundingBoxIou
38724 38725 38726 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38724 def track_mean_bounding_box_iou @track_mean_bounding_box_iou end |
#track_mean_mismatch_rate ⇒ Float
UNIMPLEMENTED. The single metric for tracking consistency evaluation: the
meanMismatchRate averaged over all trackMetrics.
Corresponds to the JSON property trackMeanMismatchRate
38730 38731 38732 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38730 def track_mean_mismatch_rate @track_mean_mismatch_rate end |
#track_metrics ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsTrackMetrics>
UNIMPLEMENTED. The tracks match metrics for each intersection-over-union
threshold 0.05,0.10,...,0.95,0.96,0.97,0.98,0.99 and each label confidence
threshold 0.05,0.10,...,0.95,0.96,0.97,0.98,0.99 pair.
Corresponds to the JSON property trackMetrics
38737 38738 38739 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38737 def track_metrics @track_metrics end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38744 38745 38746 38747 38748 38749 38750 38751 38752 38753 38754 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38744 def update!(**args) @bounding_box_mean_average_precision = args[:bounding_box_mean_average_precision] if args.key?(:bounding_box_mean_average_precision) @bounding_box_metrics = args[:bounding_box_metrics] if args.key?(:bounding_box_metrics) @evaluated_bounding_box_count = args[:evaluated_bounding_box_count] if args.key?(:evaluated_bounding_box_count) @evaluated_frame_count = args[:evaluated_frame_count] if args.key?(:evaluated_frame_count) @evaluated_track_count = args[:evaluated_track_count] if args.key?(:evaluated_track_count) @track_mean_average_precision = args[:track_mean_average_precision] if args.key?(:track_mean_average_precision) @track_mean_bounding_box_iou = args[:track_mean_bounding_box_iou] if args.key?(:track_mean_bounding_box_iou) @track_mean_mismatch_rate = args[:track_mean_mismatch_rate] if args.key?(:track_mean_mismatch_rate) @track_metrics = args[:track_metrics] if args.key?(:track_metrics) end |