Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoObjectTrackingMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Model evaluation metrics for video object tracking problems. Evaluates prediction quality of both labeled bounding boxes and labeled tracks (i.e. series of bounding boxes sharing same label and instance ID).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoObjectTrackingMetrics

Returns a new instance of GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoObjectTrackingMetrics.



29430
29431
29432
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29430

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bounding_box_mean_average_precisionFloat

The single metric for bounding boxes evaluation: the meanAveragePrecision averaged over all boundingBoxMetrics. Corresponds to the JSON property boundingBoxMeanAveragePrecision

Returns:

  • (Float)


29379
29380
29381
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29379

def bounding_box_mean_average_precision
  @bounding_box_mean_average_precision
end

#bounding_box_metricsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsBoundingBoxMetrics>

The bounding boxes match metrics for each intersection-over-union threshold 0. 05,0.10,...,0.95,0.96,0.97,0.98,0.99 and each label confidence threshold 0.05, 0.10,...,0.95,0.96,0.97,0.98,0.99 pair. Corresponds to the JSON property boundingBoxMetrics



29386
29387
29388
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29386

def bounding_box_metrics
  @bounding_box_metrics
end

#evaluated_bounding_box_countFixnum

UNIMPLEMENTED. The total number of bounding boxes (i.e. summed over all frames) the ground truth used to create this evaluation had. Corresponds to the JSON property evaluatedBoundingBoxCount

Returns:

  • (Fixnum)


29392
29393
29394
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29392

def evaluated_bounding_box_count
  @evaluated_bounding_box_count
end

#evaluated_frame_countFixnum

UNIMPLEMENTED. The number of video frames used to create this evaluation. Corresponds to the JSON property evaluatedFrameCount

Returns:

  • (Fixnum)


29397
29398
29399
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29397

def evaluated_frame_count
  @evaluated_frame_count
end

#evaluated_track_countFixnum

UNIMPLEMENTED. The total number of tracks (i.e. as seen across all frames) the ground truth used to create this evaluation had. Corresponds to the JSON property evaluatedTrackCount

Returns:

  • (Fixnum)


29403
29404
29405
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29403

def evaluated_track_count
  @evaluated_track_count
end

#track_mean_average_precisionFloat

UNIMPLEMENTED. The single metric for tracks accuracy evaluation: the meanAveragePrecision averaged over all trackMetrics. Corresponds to the JSON property trackMeanAveragePrecision

Returns:

  • (Float)


29409
29410
29411
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29409

def track_mean_average_precision
  @track_mean_average_precision
end

#track_mean_bounding_box_iouFloat

UNIMPLEMENTED. The single metric for tracks bounding box iou evaluation: the meanBoundingBoxIou averaged over all trackMetrics. Corresponds to the JSON property trackMeanBoundingBoxIou

Returns:

  • (Float)


29415
29416
29417
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29415

def track_mean_bounding_box_iou
  @track_mean_bounding_box_iou
end

#track_mean_mismatch_rateFloat

UNIMPLEMENTED. The single metric for tracking consistency evaluation: the meanMismatchRate averaged over all trackMetrics. Corresponds to the JSON property trackMeanMismatchRate

Returns:

  • (Float)


29421
29422
29423
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29421

def track_mean_mismatch_rate
  @track_mean_mismatch_rate
end

#track_metricsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsTrackMetrics>

UNIMPLEMENTED. The tracks match metrics for each intersection-over-union threshold 0.05,0.10,...,0.95,0.96,0.97,0.98,0.99 and each label confidence threshold 0.05,0.10,...,0.95,0.96,0.97,0.98,0.99 pair. Corresponds to the JSON property trackMetrics



29428
29429
29430
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29428

def track_metrics
  @track_metrics
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29435
29436
29437
29438
29439
29440
29441
29442
29443
29444
29445
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29435

def update!(**args)
  @bounding_box_mean_average_precision = args[:bounding_box_mean_average_precision] if args.key?(:bounding_box_mean_average_precision)
  @bounding_box_metrics = args[:bounding_box_metrics] if args.key?(:bounding_box_metrics)
  @evaluated_bounding_box_count = args[:evaluated_bounding_box_count] if args.key?(:evaluated_bounding_box_count)
  @evaluated_frame_count = args[:evaluated_frame_count] if args.key?(:evaluated_frame_count)
  @evaluated_track_count = args[:evaluated_track_count] if args.key?(:evaluated_track_count)
  @track_mean_average_precision = args[:track_mean_average_precision] if args.key?(:track_mean_average_precision)
  @track_mean_bounding_box_iou = args[:track_mean_bounding_box_iou] if args.key?(:track_mean_bounding_box_iou)
  @track_mean_mismatch_rate = args[:track_mean_mismatch_rate] if args.key?(:track_mean_mismatch_rate)
  @track_metrics = args[:track_metrics] if args.key?(:track_metrics)
end