Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoObjectTrackingMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Model evaluation metrics for video object tracking problems. Evaluates prediction quality of both labeled bounding boxes and labeled tracks (i.e. series of bounding boxes sharing same label and instance ID).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoObjectTrackingMetrics

Returns a new instance of GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoObjectTrackingMetrics.



28378
28379
28380
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28378

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bounding_box_mean_average_precisionFloat

The single metric for bounding boxes evaluation: the meanAveragePrecision averaged over all boundingBoxMetrics. Corresponds to the JSON property boundingBoxMeanAveragePrecision

Returns:

  • (Float)


28327
28328
28329
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28327

def bounding_box_mean_average_precision
  @bounding_box_mean_average_precision
end

#bounding_box_metricsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsBoundingBoxMetrics>

The bounding boxes match metrics for each intersection-over-union threshold 0. 05,0.10,...,0.95,0.96,0.97,0.98,0.99 and each label confidence threshold 0.05, 0.10,...,0.95,0.96,0.97,0.98,0.99 pair. Corresponds to the JSON property boundingBoxMetrics



28334
28335
28336
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28334

def bounding_box_metrics
  @bounding_box_metrics
end

#evaluated_bounding_box_countFixnum

UNIMPLEMENTED. The total number of bounding boxes (i.e. summed over all frames) the ground truth used to create this evaluation had. Corresponds to the JSON property evaluatedBoundingBoxCount

Returns:

  • (Fixnum)


28340
28341
28342
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28340

def evaluated_bounding_box_count
  @evaluated_bounding_box_count
end

#evaluated_frame_countFixnum

UNIMPLEMENTED. The number of video frames used to create this evaluation. Corresponds to the JSON property evaluatedFrameCount

Returns:

  • (Fixnum)


28345
28346
28347
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28345

def evaluated_frame_count
  @evaluated_frame_count
end

#evaluated_track_countFixnum

UNIMPLEMENTED. The total number of tracks (i.e. as seen across all frames) the ground truth used to create this evaluation had. Corresponds to the JSON property evaluatedTrackCount

Returns:

  • (Fixnum)


28351
28352
28353
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28351

def evaluated_track_count
  @evaluated_track_count
end

#track_mean_average_precisionFloat

UNIMPLEMENTED. The single metric for tracks accuracy evaluation: the meanAveragePrecision averaged over all trackMetrics. Corresponds to the JSON property trackMeanAveragePrecision

Returns:

  • (Float)


28357
28358
28359
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28357

def track_mean_average_precision
  @track_mean_average_precision
end

#track_mean_bounding_box_iouFloat

UNIMPLEMENTED. The single metric for tracks bounding box iou evaluation: the meanBoundingBoxIou averaged over all trackMetrics. Corresponds to the JSON property trackMeanBoundingBoxIou

Returns:

  • (Float)


28363
28364
28365
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28363

def track_mean_bounding_box_iou
  @track_mean_bounding_box_iou
end

#track_mean_mismatch_rateFloat

UNIMPLEMENTED. The single metric for tracking consistency evaluation: the meanMismatchRate averaged over all trackMetrics. Corresponds to the JSON property trackMeanMismatchRate

Returns:

  • (Float)


28369
28370
28371
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28369

def track_mean_mismatch_rate
  @track_mean_mismatch_rate
end

#track_metricsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsTrackMetrics>

UNIMPLEMENTED. The tracks match metrics for each intersection-over-union threshold 0.05,0.10,...,0.95,0.96,0.97,0.98,0.99 and each label confidence threshold 0.05,0.10,...,0.95,0.96,0.97,0.98,0.99 pair. Corresponds to the JSON property trackMetrics



28376
28377
28378
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28376

def track_metrics
  @track_metrics
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28383
28384
28385
28386
28387
28388
28389
28390
28391
28392
28393
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28383

def update!(**args)
  @bounding_box_mean_average_precision = args[:bounding_box_mean_average_precision] if args.key?(:bounding_box_mean_average_precision)
  @bounding_box_metrics = args[:bounding_box_metrics] if args.key?(:bounding_box_metrics)
  @evaluated_bounding_box_count = args[:evaluated_bounding_box_count] if args.key?(:evaluated_bounding_box_count)
  @evaluated_frame_count = args[:evaluated_frame_count] if args.key?(:evaluated_frame_count)
  @evaluated_track_count = args[:evaluated_track_count] if args.key?(:evaluated_track_count)
  @track_mean_average_precision = args[:track_mean_average_precision] if args.key?(:track_mean_average_precision)
  @track_mean_bounding_box_iou = args[:track_mean_bounding_box_iou] if args.key?(:track_mean_bounding_box_iou)
  @track_mean_mismatch_rate = args[:track_mean_mismatch_rate] if args.key?(:track_mean_mismatch_rate)
  @track_metrics = args[:track_metrics] if args.key?(:track_metrics)
end