Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoObjectTrackingMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Model evaluation metrics for video object tracking problems. Evaluates prediction quality of both labeled bounding boxes and labeled tracks (i.e. series of bounding boxes sharing same label and instance ID).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoObjectTrackingMetrics

Returns a new instance of GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoObjectTrackingMetrics.



24029
24030
24031
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24029

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bounding_box_mean_average_precisionFloat

The single metric for bounding boxes evaluation: the meanAveragePrecision averaged over all boundingBoxMetrics. Corresponds to the JSON property boundingBoxMeanAveragePrecision

Returns:

  • (Float)


23978
23979
23980
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23978

def bounding_box_mean_average_precision
  @bounding_box_mean_average_precision
end

#bounding_box_metricsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsBoundingBoxMetrics>

The bounding boxes match metrics for each intersection-over-union threshold 0. 05,0.10,...,0.95,0.96,0.97,0.98,0.99 and each label confidence threshold 0.05, 0.10,...,0.95,0.96,0.97,0.98,0.99 pair. Corresponds to the JSON property boundingBoxMetrics



23985
23986
23987
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23985

def bounding_box_metrics
  @bounding_box_metrics
end

#evaluated_bounding_box_countFixnum

UNIMPLEMENTED. The total number of bounding boxes (i.e. summed over all frames) the ground truth used to create this evaluation had. Corresponds to the JSON property evaluatedBoundingBoxCount

Returns:

  • (Fixnum)


23991
23992
23993
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23991

def evaluated_bounding_box_count
  @evaluated_bounding_box_count
end

#evaluated_frame_countFixnum

UNIMPLEMENTED. The number of video frames used to create this evaluation. Corresponds to the JSON property evaluatedFrameCount

Returns:

  • (Fixnum)


23996
23997
23998
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23996

def evaluated_frame_count
  @evaluated_frame_count
end

#evaluated_track_countFixnum

UNIMPLEMENTED. The total number of tracks (i.e. as seen across all frames) the ground truth used to create this evaluation had. Corresponds to the JSON property evaluatedTrackCount

Returns:

  • (Fixnum)


24002
24003
24004
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24002

def evaluated_track_count
  @evaluated_track_count
end

#track_mean_average_precisionFloat

UNIMPLEMENTED. The single metric for tracks accuracy evaluation: the meanAveragePrecision averaged over all trackMetrics. Corresponds to the JSON property trackMeanAveragePrecision

Returns:

  • (Float)


24008
24009
24010
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24008

def track_mean_average_precision
  @track_mean_average_precision
end

#track_mean_bounding_box_iouFloat

UNIMPLEMENTED. The single metric for tracks bounding box iou evaluation: the meanBoundingBoxIou averaged over all trackMetrics. Corresponds to the JSON property trackMeanBoundingBoxIou

Returns:

  • (Float)


24014
24015
24016
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24014

def track_mean_bounding_box_iou
  @track_mean_bounding_box_iou
end

#track_mean_mismatch_rateFloat

UNIMPLEMENTED. The single metric for tracking consistency evaluation: the meanMismatchRate averaged over all trackMetrics. Corresponds to the JSON property trackMeanMismatchRate

Returns:

  • (Float)


24020
24021
24022
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24020

def track_mean_mismatch_rate
  @track_mean_mismatch_rate
end

#track_metricsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsTrackMetrics>

UNIMPLEMENTED. The tracks match metrics for each intersection-over-union threshold 0.05,0.10,...,0.95,0.96,0.97,0.98,0.99 and each label confidence threshold 0.05,0.10,...,0.95,0.96,0.97,0.98,0.99 pair. Corresponds to the JSON property trackMetrics



24027
24028
24029
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24027

def track_metrics
  @track_metrics
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24034
24035
24036
24037
24038
24039
24040
24041
24042
24043
24044
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24034

def update!(**args)
  @bounding_box_mean_average_precision = args[:bounding_box_mean_average_precision] if args.key?(:bounding_box_mean_average_precision)
  @bounding_box_metrics = args[:bounding_box_metrics] if args.key?(:bounding_box_metrics)
  @evaluated_bounding_box_count = args[:evaluated_bounding_box_count] if args.key?(:evaluated_bounding_box_count)
  @evaluated_frame_count = args[:evaluated_frame_count] if args.key?(:evaluated_frame_count)
  @evaluated_track_count = args[:evaluated_track_count] if args.key?(:evaluated_track_count)
  @track_mean_average_precision = args[:track_mean_average_precision] if args.key?(:track_mean_average_precision)
  @track_mean_bounding_box_iou = args[:track_mean_bounding_box_iou] if args.key?(:track_mean_bounding_box_iou)
  @track_mean_mismatch_rate = args[:track_mean_mismatch_rate] if args.key?(:track_mean_mismatch_rate)
  @track_metrics = args[:track_metrics] if args.key?(:track_metrics)
end