Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoObjectTrackingMetrics
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoObjectTrackingMetrics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Model evaluation metrics for video object tracking problems. Evaluates prediction quality of both labeled bounding boxes and labeled tracks (i.e. series of bounding boxes sharing same label and instance ID).
Instance Attribute Summary collapse
-
#bounding_box_mean_average_precision ⇒ Float
The single metric for bounding boxes evaluation: the
meanAveragePrecisionaveraged over allboundingBoxMetrics. -
#bounding_box_metrics ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsBoundingBoxMetrics>
The bounding boxes match metrics for each intersection-over-union threshold 0.
-
#evaluated_bounding_box_count ⇒ Fixnum
UNIMPLEMENTED.
-
#evaluated_frame_count ⇒ Fixnum
UNIMPLEMENTED.
-
#evaluated_track_count ⇒ Fixnum
UNIMPLEMENTED.
-
#track_mean_average_precision ⇒ Float
UNIMPLEMENTED.
-
#track_mean_bounding_box_iou ⇒ Float
UNIMPLEMENTED.
-
#track_mean_mismatch_rate ⇒ Float
UNIMPLEMENTED.
-
#track_metrics ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsTrackMetrics>
UNIMPLEMENTED.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoObjectTrackingMetrics
constructor
A new instance of GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoObjectTrackingMetrics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoObjectTrackingMetrics
Returns a new instance of GoogleCloudAiplatformV1SchemaModelevaluationMetricsVideoObjectTrackingMetrics.
21060 21061 21062 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21060 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bounding_box_mean_average_precision ⇒ Float
The single metric for bounding boxes evaluation: the meanAveragePrecision
averaged over all boundingBoxMetrics.
Corresponds to the JSON property boundingBoxMeanAveragePrecision
21009 21010 21011 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21009 def bounding_box_mean_average_precision @bounding_box_mean_average_precision end |
#bounding_box_metrics ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsBoundingBoxMetrics>
The bounding boxes match metrics for each intersection-over-union threshold 0.
05,0.10,...,0.95,0.96,0.97,0.98,0.99 and each label confidence threshold 0.05,
0.10,...,0.95,0.96,0.97,0.98,0.99 pair.
Corresponds to the JSON property boundingBoxMetrics
21016 21017 21018 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21016 def bounding_box_metrics @bounding_box_metrics end |
#evaluated_bounding_box_count ⇒ Fixnum
UNIMPLEMENTED. The total number of bounding boxes (i.e. summed over all frames)
the ground truth used to create this evaluation had.
Corresponds to the JSON property evaluatedBoundingBoxCount
21022 21023 21024 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21022 def evaluated_bounding_box_count @evaluated_bounding_box_count end |
#evaluated_frame_count ⇒ Fixnum
UNIMPLEMENTED. The number of video frames used to create this evaluation.
Corresponds to the JSON property evaluatedFrameCount
21027 21028 21029 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21027 def evaluated_frame_count @evaluated_frame_count end |
#evaluated_track_count ⇒ Fixnum
UNIMPLEMENTED. The total number of tracks (i.e. as seen across all frames) the
ground truth used to create this evaluation had.
Corresponds to the JSON property evaluatedTrackCount
21033 21034 21035 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21033 def evaluated_track_count @evaluated_track_count end |
#track_mean_average_precision ⇒ Float
UNIMPLEMENTED. The single metric for tracks accuracy evaluation: the
meanAveragePrecision averaged over all trackMetrics.
Corresponds to the JSON property trackMeanAveragePrecision
21039 21040 21041 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21039 def track_mean_average_precision @track_mean_average_precision end |
#track_mean_bounding_box_iou ⇒ Float
UNIMPLEMENTED. The single metric for tracks bounding box iou evaluation: the
meanBoundingBoxIou averaged over all trackMetrics.
Corresponds to the JSON property trackMeanBoundingBoxIou
21045 21046 21047 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21045 def track_mean_bounding_box_iou @track_mean_bounding_box_iou end |
#track_mean_mismatch_rate ⇒ Float
UNIMPLEMENTED. The single metric for tracking consistency evaluation: the
meanMismatchRate averaged over all trackMetrics.
Corresponds to the JSON property trackMeanMismatchRate
21051 21052 21053 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21051 def track_mean_mismatch_rate @track_mean_mismatch_rate end |
#track_metrics ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaModelevaluationMetricsTrackMetrics>
UNIMPLEMENTED. The tracks match metrics for each intersection-over-union
threshold 0.05,0.10,...,0.95,0.96,0.97,0.98,0.99 and each label confidence
threshold 0.05,0.10,...,0.95,0.96,0.97,0.98,0.99 pair.
Corresponds to the JSON property trackMetrics
21058 21059 21060 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21058 def track_metrics @track_metrics end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21065 21066 21067 21068 21069 21070 21071 21072 21073 21074 21075 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21065 def update!(**args) @bounding_box_mean_average_precision = args[:bounding_box_mean_average_precision] if args.key?(:bounding_box_mean_average_precision) @bounding_box_metrics = args[:bounding_box_metrics] if args.key?(:bounding_box_metrics) @evaluated_bounding_box_count = args[:evaluated_bounding_box_count] if args.key?(:evaluated_bounding_box_count) @evaluated_frame_count = args[:evaluated_frame_count] if args.key?(:evaluated_frame_count) @evaluated_track_count = args[:evaluated_track_count] if args.key?(:evaluated_track_count) @track_mean_average_precision = args[:track_mean_average_precision] if args.key?(:track_mean_average_precision) @track_mean_bounding_box_iou = args[:track_mean_bounding_box_iou] if args.key?(:track_mean_bounding_box_iou) @track_mean_mismatch_rate = args[:track_mean_mismatch_rate] if args.key?(:track_mean_mismatch_rate) @track_metrics = args[:track_metrics] if args.key?(:track_metrics) end |