Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictInstanceTextExtractionPredictionInstance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Prediction input format for Text Extraction.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictInstanceTextExtractionPredictionInstance

Returns a new instance of GoogleCloudAiplatformV1SchemaPredictInstanceTextExtractionPredictionInstance.



28586
28587
28588
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28586

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentString

The text snippet to make the predictions on. Corresponds to the JSON property content

Returns:

  • (String)


28569
28570
28571
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28569

def content
  @content
end

#keyString

This field is only used for batch prediction. If a key is provided, the batch prediction result will by mapped to this key. If omitted, then the batch prediction result will contain the entire input instance. Vertex AI will not check if keys in the request are duplicates, so it is up to the caller to ensure the keys are unique. Corresponds to the JSON property key

Returns:

  • (String)


28578
28579
28580
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28578

def key
  @key
end

#mime_typeString

The MIME type of the text snippet. The supported MIME types are listed below. - text/plain Corresponds to the JSON property mimeType

Returns:

  • (String)


28584
28585
28586
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28584

def mime_type
  @mime_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28591
28592
28593
28594
28595
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28591

def update!(**args)
  @content = args[:content] if args.key?(:content)
  @key = args[:key] if args.key?(:key)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
end