Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictInstanceTextExtractionPredictionInstance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Prediction input format for Text Extraction.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictInstanceTextExtractionPredictionInstance

Returns a new instance of GoogleCloudAiplatformV1SchemaPredictInstanceTextExtractionPredictionInstance.



20008
20009
20010
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20008

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentString

The text snippet to make the predictions on. Corresponds to the JSON property content

Returns:

  • (String)


19991
19992
19993
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 19991

def content
  @content
end

#keyString

This field is only used for batch prediction. If a key is provided, the batch prediction result will by mapped to this key. If omitted, then the batch prediction result will contain the entire input instance. Vertex AI will not check if keys in the request are duplicates, so it is up to the caller to ensure the keys are unique. Corresponds to the JSON property key

Returns:

  • (String)


20000
20001
20002
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20000

def key
  @key
end

#mime_typeString

The MIME type of the text snippet. The supported MIME types are listed below. - text/plain Corresponds to the JSON property mimeType

Returns:

  • (String)


20006
20007
20008
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20006

def mime_type
  @mime_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20013
20014
20015
20016
20017
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20013

def update!(**args)
  @content = args[:content] if args.key?(:content)
  @key = args[:key] if args.key?(:key)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
end