Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictInstanceVideoActionRecognitionPredictionInstance
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictInstanceVideoActionRecognitionPredictionInstance
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Prediction input format for Video Action Recognition.
Instance Attribute Summary collapse
-
#content ⇒ String
The Google Cloud Storage location of the video on which to perform the prediction.
-
#mime_type ⇒ String
The MIME type of the content of the video.
-
#time_segment_end ⇒ String
The end, exclusive, of the video's time segment on which to perform the prediction.
-
#time_segment_start ⇒ String
The beginning, inclusive, of the video's time segment on which to perform the prediction.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictInstanceVideoActionRecognitionPredictionInstance
constructor
A new instance of GoogleCloudAiplatformV1SchemaPredictInstanceVideoActionRecognitionPredictionInstance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictInstanceVideoActionRecognitionPredictionInstance
Returns a new instance of GoogleCloudAiplatformV1SchemaPredictInstanceVideoActionRecognitionPredictionInstance.
37128 37129 37130 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37128 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content ⇒ String
The Google Cloud Storage location of the video on which to perform the
prediction.
Corresponds to the JSON property content
37103 37104 37105 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37103 def content @content end |
#mime_type ⇒ String
The MIME type of the content of the video. Only the following are supported:
video/mp4 video/avi video/quicktime
Corresponds to the JSON property mimeType
37109 37110 37111 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37109 def mime_type @mime_type end |
#time_segment_end ⇒ String
The end, exclusive, of the video's time segment on which to perform the
prediction. Expressed as a number of seconds as measured from the start of the
video, with "s" appended at the end. Fractions are allowed, up to a
microsecond precision, and "inf" or "Infinity" is allowed, which means the end
of the video.
Corresponds to the JSON property timeSegmentEnd
37118 37119 37120 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37118 def time_segment_end @time_segment_end end |
#time_segment_start ⇒ String
The beginning, inclusive, of the video's time segment on which to perform the
prediction. Expressed as a number of seconds as measured from the start of the
video, with "s" appended at the end. Fractions are allowed, up to a
microsecond precision.
Corresponds to the JSON property timeSegmentStart
37126 37127 37128 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37126 def time_segment_start @time_segment_start end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37133 37134 37135 37136 37137 37138 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37133 def update!(**args) @content = args[:content] if args.key?(:content) @mime_type = args[:mime_type] if args.key?(:mime_type) @time_segment_end = args[:time_segment_end] if args.key?(:time_segment_end) @time_segment_start = args[:time_segment_start] if args.key?(:time_segment_start) end |