Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictInstanceVideoObjectTrackingPredictionInstance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Prediction input format for Video Object Tracking.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictInstanceVideoObjectTrackingPredictionInstance

Returns a new instance of GoogleCloudAiplatformV1SchemaPredictInstanceVideoObjectTrackingPredictionInstance.



39050
39051
39052
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39050

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentString

The Google Cloud Storage location of the video on which to perform the prediction. Corresponds to the JSON property content

Returns:

  • (String)


39025
39026
39027
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39025

def content
  @content
end

#mime_typeString

The MIME type of the content of the video. Only the following are supported: video/mp4 video/avi video/quicktime Corresponds to the JSON property mimeType

Returns:

  • (String)


39031
39032
39033
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39031

def mime_type
  @mime_type
end

#time_segment_endString

The end, exclusive, of the video's time segment on which to perform the prediction. Expressed as a number of seconds as measured from the start of the video, with "s" appended at the end. Fractions are allowed, up to a microsecond precision, and "inf" or "Infinity" is allowed, which means the end of the video. Corresponds to the JSON property timeSegmentEnd

Returns:

  • (String)


39040
39041
39042
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39040

def time_segment_end
  @time_segment_end
end

#time_segment_startString

The beginning, inclusive, of the video's time segment on which to perform the prediction. Expressed as a number of seconds as measured from the start of the video, with "s" appended at the end. Fractions are allowed, up to a microsecond precision. Corresponds to the JSON property timeSegmentStart

Returns:

  • (String)


39048
39049
39050
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39048

def time_segment_start
  @time_segment_start
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39055
39056
39057
39058
39059
39060
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39055

def update!(**args)
  @content = args[:content] if args.key?(:content)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
  @time_segment_end = args[:time_segment_end] if args.key?(:time_segment_end)
  @time_segment_start = args[:time_segment_start] if args.key?(:time_segment_start)
end