Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictInstanceVideoObjectTrackingPredictionInstance
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictInstanceVideoObjectTrackingPredictionInstance
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Prediction input format for Video Object Tracking.
Instance Attribute Summary collapse
-
#content ⇒ String
The Google Cloud Storage location of the video on which to perform the prediction.
-
#mime_type ⇒ String
The MIME type of the content of the video.
-
#time_segment_end ⇒ String
The end, exclusive, of the video's time segment on which to perform the prediction.
-
#time_segment_start ⇒ String
The beginning, inclusive, of the video's time segment on which to perform the prediction.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictInstanceVideoObjectTrackingPredictionInstance
constructor
A new instance of GoogleCloudAiplatformV1SchemaPredictInstanceVideoObjectTrackingPredictionInstance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictInstanceVideoObjectTrackingPredictionInstance
Returns a new instance of GoogleCloudAiplatformV1SchemaPredictInstanceVideoObjectTrackingPredictionInstance.
29741 29742 29743 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29741 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content ⇒ String
The Google Cloud Storage location of the video on which to perform the
prediction.
Corresponds to the JSON property content
29716 29717 29718 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29716 def content @content end |
#mime_type ⇒ String
The MIME type of the content of the video. Only the following are supported:
video/mp4 video/avi video/quicktime
Corresponds to the JSON property mimeType
29722 29723 29724 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29722 def mime_type @mime_type end |
#time_segment_end ⇒ String
The end, exclusive, of the video's time segment on which to perform the
prediction. Expressed as a number of seconds as measured from the start of the
video, with "s" appended at the end. Fractions are allowed, up to a
microsecond precision, and "inf" or "Infinity" is allowed, which means the end
of the video.
Corresponds to the JSON property timeSegmentEnd
29731 29732 29733 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29731 def time_segment_end @time_segment_end end |
#time_segment_start ⇒ String
The beginning, inclusive, of the video's time segment on which to perform the
prediction. Expressed as a number of seconds as measured from the start of the
video, with "s" appended at the end. Fractions are allowed, up to a
microsecond precision.
Corresponds to the JSON property timeSegmentStart
29739 29740 29741 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29739 def time_segment_start @time_segment_start end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29746 29747 29748 29749 29750 29751 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29746 def update!(**args) @content = args[:content] if args.key?(:content) @mime_type = args[:mime_type] if args.key?(:mime_type) @time_segment_end = args[:time_segment_end] if args.key?(:time_segment_end) @time_segment_start = args[:time_segment_start] if args.key?(:time_segment_start) end |