Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictParamsGroundingConfigSourceEntry
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictParamsGroundingConfigSourceEntry
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Single source entry for the grounding checking.
Instance Attribute Summary collapse
-
#enterprise_datastore ⇒ String
The uri of the Vertex AI Search data source.
-
#inline_context ⇒ String
The grounding text passed inline with the Predict API.
-
#type ⇒ String
The type of the grounding checking source.
-
#vertex_ai_search_datastore ⇒ String
The uri of the Vertex AI Search data source.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictParamsGroundingConfigSourceEntry
constructor
A new instance of GoogleCloudAiplatformV1SchemaPredictParamsGroundingConfigSourceEntry.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictParamsGroundingConfigSourceEntry
Returns a new instance of GoogleCloudAiplatformV1SchemaPredictParamsGroundingConfigSourceEntry.
20636 20637 20638 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20636 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enterprise_datastore ⇒ String
The uri of the Vertex AI Search data source. Deprecated. Use
vertex_ai_search_datastore instead.
Corresponds to the JSON property enterpriseDatastore
20618 20619 20620 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20618 def enterprise_datastore @enterprise_datastore end |
#inline_context ⇒ String
The grounding text passed inline with the Predict API. It can support up to 1
million bytes.
Corresponds to the JSON property inlineContext
20624 20625 20626 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20624 def inline_context @inline_context end |
#type ⇒ String
The type of the grounding checking source.
Corresponds to the JSON property type
20629 20630 20631 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20629 def type @type end |
#vertex_ai_search_datastore ⇒ String
The uri of the Vertex AI Search data source.
Corresponds to the JSON property vertexAiSearchDatastore
20634 20635 20636 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20634 def vertex_ai_search_datastore @vertex_ai_search_datastore end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20641 20642 20643 20644 20645 20646 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20641 def update!(**args) @enterprise_datastore = args[:enterprise_datastore] if args.key?(:enterprise_datastore) @inline_context = args[:inline_context] if args.key?(:inline_context) @type = args[:type] if args.key?(:type) @vertex_ai_search_datastore = args[:vertex_ai_search_datastore] if args.key?(:vertex_ai_search_datastore) end |