Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictParamsImageClassificationPredictionParams
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictParamsImageClassificationPredictionParams
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Prediction model parameters for Image Classification.
Instance Attribute Summary collapse
-
#confidence_threshold ⇒ Float
The Model only returns predictions with at least this confidence score.
-
#max_predictions ⇒ Fixnum
The Model only returns up to that many top, by confidence score, predictions per instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictParamsImageClassificationPredictionParams
constructor
A new instance of GoogleCloudAiplatformV1SchemaPredictParamsImageClassificationPredictionParams.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictParamsImageClassificationPredictionParams
Returns a new instance of GoogleCloudAiplatformV1SchemaPredictParamsImageClassificationPredictionParams.
39714 39715 39716 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39714 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence_threshold ⇒ Float
The Model only returns predictions with at least this confidence score.
Default value is 0.0
Corresponds to the JSON property confidenceThreshold
39705 39706 39707 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39705 def confidence_threshold @confidence_threshold end |
#max_predictions ⇒ Fixnum
The Model only returns up to that many top, by confidence score, predictions
per instance. If this number is very high, the Model may return fewer
predictions. Default value is 10.
Corresponds to the JSON property maxPredictions
39712 39713 39714 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39712 def max_predictions @max_predictions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39719 39720 39721 39722 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39719 def update!(**args) @confidence_threshold = args[:confidence_threshold] if args.key?(:confidence_threshold) @max_predictions = args[:max_predictions] if args.key?(:max_predictions) end |