Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictParamsImageClassificationPredictionParams
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictParamsImageClassificationPredictionParams
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Prediction model parameters for Image Classification.
Instance Attribute Summary collapse
-
#confidence_threshold ⇒ Float
The Model only returns predictions with at least this confidence score.
-
#max_predictions ⇒ Fixnum
The Model only returns up to that many top, by confidence score, predictions per instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictParamsImageClassificationPredictionParams
constructor
A new instance of GoogleCloudAiplatformV1SchemaPredictParamsImageClassificationPredictionParams.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictParamsImageClassificationPredictionParams
Returns a new instance of GoogleCloudAiplatformV1SchemaPredictParamsImageClassificationPredictionParams.
28258 28259 28260 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28258 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence_threshold ⇒ Float
The Model only returns predictions with at least this confidence score.
Default value is 0.0
Corresponds to the JSON property confidenceThreshold
28249 28250 28251 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28249 def confidence_threshold @confidence_threshold end |
#max_predictions ⇒ Fixnum
The Model only returns up to that many top, by confidence score, predictions
per instance. If this number is very high, the Model may return fewer
predictions. Default value is 10.
Corresponds to the JSON property maxPredictions
28256 28257 28258 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28256 def max_predictions @max_predictions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28263 28264 28265 28266 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28263 def update!(**args) @confidence_threshold = args[:confidence_threshold] if args.key?(:confidence_threshold) @max_predictions = args[:max_predictions] if args.key?(:max_predictions) end |