Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictParamsImageClassificationPredictionParams

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Prediction model parameters for Image Classification.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictParamsImageClassificationPredictionParams

Returns a new instance of GoogleCloudAiplatformV1SchemaPredictParamsImageClassificationPredictionParams.



26695
26696
26697
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26695

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidence_thresholdFloat

The Model only returns predictions with at least this confidence score. Default value is 0.0 Corresponds to the JSON property confidenceThreshold

Returns:

  • (Float)


26686
26687
26688
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26686

def confidence_threshold
  @confidence_threshold
end

#max_predictionsFixnum

The Model only returns up to that many top, by confidence score, predictions per instance. If this number is very high, the Model may return fewer predictions. Default value is 10. Corresponds to the JSON property maxPredictions

Returns:

  • (Fixnum)


26693
26694
26695
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26693

def max_predictions
  @max_predictions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26700
26701
26702
26703
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26700

def update!(**args)
  @confidence_threshold = args[:confidence_threshold] if args.key?(:confidence_threshold)
  @max_predictions = args[:max_predictions] if args.key?(:max_predictions)
end