Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictParamsImageObjectDetectionPredictionParams
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictParamsImageObjectDetectionPredictionParams
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Prediction model parameters for Image Object Detection.
Instance Attribute Summary collapse
-
#confidence_threshold ⇒ Float
The Model only returns predictions with at least this confidence score.
-
#max_predictions ⇒ Fixnum
The Model only returns up to that many top, by confidence score, predictions per instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictParamsImageObjectDetectionPredictionParams
constructor
A new instance of GoogleCloudAiplatformV1SchemaPredictParamsImageObjectDetectionPredictionParams.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictParamsImageObjectDetectionPredictionParams
Returns a new instance of GoogleCloudAiplatformV1SchemaPredictParamsImageObjectDetectionPredictionParams.
39173 39174 39175 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39173 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence_threshold ⇒ Float
The Model only returns predictions with at least this confidence score.
Default value is 0.0
Corresponds to the JSON property confidenceThreshold
39164 39165 39166 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39164 def confidence_threshold @confidence_threshold end |
#max_predictions ⇒ Fixnum
The Model only returns up to that many top, by confidence score, predictions
per instance. Note that number of returned predictions is also limited by
metadata's predictionsLimit. Default value is 10.
Corresponds to the JSON property maxPredictions
39171 39172 39173 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39171 def max_predictions @max_predictions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39178 39179 39180 39181 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39178 def update!(**args) @confidence_threshold = args[:confidence_threshold] if args.key?(:confidence_threshold) @max_predictions = args[:max_predictions] if args.key?(:max_predictions) end |