Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictParamsImageObjectDetectionPredictionParams
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictParamsImageObjectDetectionPredictionParams
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Prediction model parameters for Image Object Detection.
Instance Attribute Summary collapse
-
#confidence_threshold ⇒ Float
The Model only returns predictions with at least this confidence score.
-
#max_predictions ⇒ Fixnum
The Model only returns up to that many top, by confidence score, predictions per instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictParamsImageObjectDetectionPredictionParams
constructor
A new instance of GoogleCloudAiplatformV1SchemaPredictParamsImageObjectDetectionPredictionParams.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictParamsImageObjectDetectionPredictionParams
Returns a new instance of GoogleCloudAiplatformV1SchemaPredictParamsImageObjectDetectionPredictionParams.
38729 38730 38731 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38729 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence_threshold ⇒ Float
The Model only returns predictions with at least this confidence score.
Default value is 0.0
Corresponds to the JSON property confidenceThreshold
38720 38721 38722 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38720 def confidence_threshold @confidence_threshold end |
#max_predictions ⇒ Fixnum
The Model only returns up to that many top, by confidence score, predictions
per instance. Note that number of returned predictions is also limited by
metadata's predictionsLimit. Default value is 10.
Corresponds to the JSON property maxPredictions
38727 38728 38729 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38727 def max_predictions @max_predictions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38734 38735 38736 38737 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38734 def update!(**args) @confidence_threshold = args[:confidence_threshold] if args.key?(:confidence_threshold) @max_predictions = args[:max_predictions] if args.key?(:max_predictions) end |