Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictParamsImageObjectDetectionPredictionParams
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictParamsImageObjectDetectionPredictionParams
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Prediction model parameters for Image Object Detection.
Instance Attribute Summary collapse
-
#confidence_threshold ⇒ Float
The Model only returns predictions with at least this confidence score.
-
#max_predictions ⇒ Fixnum
The Model only returns up to that many top, by confidence score, predictions per instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictParamsImageObjectDetectionPredictionParams
constructor
A new instance of GoogleCloudAiplatformV1SchemaPredictParamsImageObjectDetectionPredictionParams.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictParamsImageObjectDetectionPredictionParams
Returns a new instance of GoogleCloudAiplatformV1SchemaPredictParamsImageObjectDetectionPredictionParams.
28354 28355 28356 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28354 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence_threshold ⇒ Float
The Model only returns predictions with at least this confidence score.
Default value is 0.0
Corresponds to the JSON property confidenceThreshold
28345 28346 28347 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28345 def confidence_threshold @confidence_threshold end |
#max_predictions ⇒ Fixnum
The Model only returns up to that many top, by confidence score, predictions
per instance. Note that number of returned predictions is also limited by
metadata's predictionsLimit. Default value is 10.
Corresponds to the JSON property maxPredictions
28352 28353 28354 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28352 def max_predictions @max_predictions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28359 28360 28361 28362 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28359 def update!(**args) @confidence_threshold = args[:confidence_threshold] if args.key?(:confidence_threshold) @max_predictions = args[:max_predictions] if args.key?(:max_predictions) end |