Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictParamsImageObjectDetectionPredictionParams

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Prediction model parameters for Image Object Detection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictParamsImageObjectDetectionPredictionParams

Returns a new instance of GoogleCloudAiplatformV1SchemaPredictParamsImageObjectDetectionPredictionParams.



20294
20295
20296
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20294

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidence_thresholdFloat

The Model only returns predictions with at least this confidence score. Default value is 0.0 Corresponds to the JSON property confidenceThreshold

Returns:

  • (Float)


20285
20286
20287
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20285

def confidence_threshold
  @confidence_threshold
end

#max_predictionsFixnum

The Model only returns up to that many top, by confidence score, predictions per instance. Note that number of returned predictions is also limited by metadata's predictionsLimit. Default value is 10. Corresponds to the JSON property maxPredictions

Returns:

  • (Fixnum)


20292
20293
20294
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20292

def max_predictions
  @max_predictions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20299
20300
20301
20302
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20299

def update!(**args)
  @confidence_threshold = args[:confidence_threshold] if args.key?(:confidence_threshold)
  @max_predictions = args[:max_predictions] if args.key?(:max_predictions)
end