Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictParamsImageSegmentationPredictionParams

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Prediction model parameters for Image Segmentation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictParamsImageSegmentationPredictionParams

Returns a new instance of GoogleCloudAiplatformV1SchemaPredictParamsImageSegmentationPredictionParams.



39182
39183
39184
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39182

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidence_thresholdFloat

When the model predicts category of pixels of the image, it will only provide predictions for pixels that it is at least this much confident about. All other pixels will be classified as background. Default value is 0.5. Corresponds to the JSON property confidenceThreshold

Returns:

  • (Float)


39180
39181
39182
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39180

def confidence_threshold
  @confidence_threshold
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39187
39188
39189
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39187

def update!(**args)
  @confidence_threshold = args[:confidence_threshold] if args.key?(:confidence_threshold)
end