Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictParamsImageSegmentationPredictionParams
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictParamsImageSegmentationPredictionParams
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Prediction model parameters for Image Segmentation.
Instance Attribute Summary collapse
-
#confidence_threshold ⇒ Float
When the model predicts category of pixels of the image, it will only provide predictions for pixels that it is at least this much confident about.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictParamsImageSegmentationPredictionParams
constructor
A new instance of GoogleCloudAiplatformV1SchemaPredictParamsImageSegmentationPredictionParams.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictParamsImageSegmentationPredictionParams
Returns a new instance of GoogleCloudAiplatformV1SchemaPredictParamsImageSegmentationPredictionParams.
21119 21120 21121 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21119 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence_threshold ⇒ Float
When the model predicts category of pixels of the image, it will only provide
predictions for pixels that it is at least this much confident about. All
other pixels will be classified as background. Default value is 0.5.
Corresponds to the JSON property confidenceThreshold
21117 21118 21119 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21117 def confidence_threshold @confidence_threshold end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21124 21125 21126 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21124 def update!(**args) @confidence_threshold = args[:confidence_threshold] if args.key?(:confidence_threshold) end |