Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictParamsVideoActionRecognitionPredictionParams
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictParamsVideoActionRecognitionPredictionParams
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Prediction model parameters for Video Action Recognition.
Instance Attribute Summary collapse
-
#confidence_threshold ⇒ Float
The Model only returns predictions with at least this confidence score.
-
#max_predictions ⇒ Fixnum
The model only returns up to that many top, by confidence score, predictions per frame of the video.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictParamsVideoActionRecognitionPredictionParams
constructor
A new instance of GoogleCloudAiplatformV1SchemaPredictParamsVideoActionRecognitionPredictionParams.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictParamsVideoActionRecognitionPredictionParams
Returns a new instance of GoogleCloudAiplatformV1SchemaPredictParamsVideoActionRecognitionPredictionParams.
28403 28404 28405 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28403 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence_threshold ⇒ Float
The Model only returns predictions with at least this confidence score.
Default value is 0.0
Corresponds to the JSON property confidenceThreshold
28394 28395 28396 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28394 def confidence_threshold @confidence_threshold end |
#max_predictions ⇒ Fixnum
The model only returns up to that many top, by confidence score, predictions
per frame of the video. If this number is very high, the Model may return
fewer predictions per frame. Default value is 50.
Corresponds to the JSON property maxPredictions
28401 28402 28403 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28401 def max_predictions @max_predictions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28408 28409 28410 28411 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28408 def update!(**args) @confidence_threshold = args[:confidence_threshold] if args.key?(:confidence_threshold) @max_predictions = args[:max_predictions] if args.key?(:max_predictions) end |