Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictParamsVideoClassificationPredictionParams
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictParamsVideoClassificationPredictionParams
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Prediction model parameters for Video Classification.
Instance Attribute Summary collapse
-
#confidence_threshold ⇒ Float
The Model only returns predictions with at least this confidence score.
-
#max_predictions ⇒ Fixnum
The Model only returns up to that many top, by confidence score, predictions per instance.
-
#one_sec_interval_classification ⇒ Boolean
(also: #one_sec_interval_classification?)
Set to true to request classification for a video at one-second intervals.
-
#segment_classification ⇒ Boolean
(also: #segment_classification?)
Set to true to request segment-level classification.
-
#shot_classification ⇒ Boolean
(also: #shot_classification?)
Set to true to request shot-level classification.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictParamsVideoClassificationPredictionParams
constructor
A new instance of GoogleCloudAiplatformV1SchemaPredictParamsVideoClassificationPredictionParams.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictParamsVideoClassificationPredictionParams
Returns a new instance of GoogleCloudAiplatformV1SchemaPredictParamsVideoClassificationPredictionParams.
39850 39851 39852 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39850 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence_threshold ⇒ Float
The Model only returns predictions with at least this confidence score.
Default value is 0.0
Corresponds to the JSON property confidenceThreshold
39810 39811 39812 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39810 def confidence_threshold @confidence_threshold end |
#max_predictions ⇒ Fixnum
The Model only returns up to that many top, by confidence score, predictions
per instance. If this number is very high, the Model may return fewer
predictions. Default value is 10,000.
Corresponds to the JSON property maxPredictions
39817 39818 39819 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39817 def max_predictions @max_predictions end |
#one_sec_interval_classification ⇒ Boolean Also known as: one_sec_interval_classification?
Set to true to request classification for a video at one-second intervals.
Vertex AI returns labels and their confidence scores for each second of the
entire time segment of the video that user specified in the input WARNING:
Model evaluation is not done for this classification type, the quality of it
depends on the training data, but there are no metrics provided to describe
that quality. Default value is false
Corresponds to the JSON property oneSecIntervalClassification
39827 39828 39829 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39827 def one_sec_interval_classification @one_sec_interval_classification end |
#segment_classification ⇒ Boolean Also known as: segment_classification?
Set to true to request segment-level classification. Vertex AI returns labels
and their confidence scores for the entire time segment of the video that user
specified in the input instance. Default value is true
Corresponds to the JSON property segmentClassification
39835 39836 39837 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39835 def segment_classification @segment_classification end |
#shot_classification ⇒ Boolean Also known as: shot_classification?
Set to true to request shot-level classification. Vertex AI determines the
boundaries for each camera shot in the entire time segment of the video that
user specified in the input instance. Vertex AI then returns labels and their
confidence scores for each detected shot, along with the start and end time of
the shot. WARNING: Model evaluation is not done for this classification type,
the quality of it depends on the training data, but there are no metrics
provided to describe that quality. Default value is false
Corresponds to the JSON property shotClassification
39847 39848 39849 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39847 def shot_classification @shot_classification end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39855 39856 39857 39858 39859 39860 39861 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39855 def update!(**args) @confidence_threshold = args[:confidence_threshold] if args.key?(:confidence_threshold) @max_predictions = args[:max_predictions] if args.key?(:max_predictions) @one_sec_interval_classification = args[:one_sec_interval_classification] if args.key?(:one_sec_interval_classification) @segment_classification = args[:segment_classification] if args.key?(:segment_classification) @shot_classification = args[:shot_classification] if args.key?(:shot_classification) end |