Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictParamsVideoClassificationPredictionParams

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Prediction model parameters for Video Classification.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictParamsVideoClassificationPredictionParams

Returns a new instance of GoogleCloudAiplatformV1SchemaPredictParamsVideoClassificationPredictionParams.



39281
39282
39283
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39281

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidence_thresholdFloat

The Model only returns predictions with at least this confidence score. Default value is 0.0 Corresponds to the JSON property confidenceThreshold

Returns:

  • (Float)


39241
39242
39243
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39241

def confidence_threshold
  @confidence_threshold
end

#max_predictionsFixnum

The Model only returns up to that many top, by confidence score, predictions per instance. If this number is very high, the Model may return fewer predictions. Default value is 10,000. Corresponds to the JSON property maxPredictions

Returns:

  • (Fixnum)


39248
39249
39250
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39248

def max_predictions
  @max_predictions
end

#one_sec_interval_classificationBoolean Also known as: one_sec_interval_classification?

Set to true to request classification for a video at one-second intervals. Vertex AI returns labels and their confidence scores for each second of the entire time segment of the video that user specified in the input WARNING: Model evaluation is not done for this classification type, the quality of it depends on the training data, but there are no metrics provided to describe that quality. Default value is false Corresponds to the JSON property oneSecIntervalClassification

Returns:

  • (Boolean)


39258
39259
39260
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39258

def one_sec_interval_classification
  @one_sec_interval_classification
end

#segment_classificationBoolean Also known as: segment_classification?

Set to true to request segment-level classification. Vertex AI returns labels and their confidence scores for the entire time segment of the video that user specified in the input instance. Default value is true Corresponds to the JSON property segmentClassification

Returns:

  • (Boolean)


39266
39267
39268
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39266

def segment_classification
  @segment_classification
end

#shot_classificationBoolean Also known as: shot_classification?

Set to true to request shot-level classification. Vertex AI determines the boundaries for each camera shot in the entire time segment of the video that user specified in the input instance. Vertex AI then returns labels and their confidence scores for each detected shot, along with the start and end time of the shot. WARNING: Model evaluation is not done for this classification type, the quality of it depends on the training data, but there are no metrics provided to describe that quality. Default value is false Corresponds to the JSON property shotClassification

Returns:

  • (Boolean)


39278
39279
39280
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39278

def shot_classification
  @shot_classification
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39286
39287
39288
39289
39290
39291
39292
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39286

def update!(**args)
  @confidence_threshold = args[:confidence_threshold] if args.key?(:confidence_threshold)
  @max_predictions = args[:max_predictions] if args.key?(:max_predictions)
  @one_sec_interval_classification = args[:one_sec_interval_classification] if args.key?(:one_sec_interval_classification)
  @segment_classification = args[:segment_classification] if args.key?(:segment_classification)
  @shot_classification = args[:shot_classification] if args.key?(:shot_classification)
end