Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictParamsVideoObjectTrackingPredictionParams
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictParamsVideoObjectTrackingPredictionParams
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Prediction model parameters for Video Object Tracking.
Instance Attribute Summary collapse
-
#confidence_threshold ⇒ Float
The Model only returns predictions with at least this confidence score.
-
#max_predictions ⇒ Fixnum
The model only returns up to that many top, by confidence score, predictions per frame of the video.
-
#min_bounding_box_size ⇒ Float
Only bounding boxes with shortest edge at least that long as a relative value of video frame size are returned.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictParamsVideoObjectTrackingPredictionParams
constructor
A new instance of GoogleCloudAiplatformV1SchemaPredictParamsVideoObjectTrackingPredictionParams.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictParamsVideoObjectTrackingPredictionParams
Returns a new instance of GoogleCloudAiplatformV1SchemaPredictParamsVideoObjectTrackingPredictionParams.
39318 39319 39320 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39318 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence_threshold ⇒ Float
The Model only returns predictions with at least this confidence score.
Default value is 0.0
Corresponds to the JSON property confidenceThreshold
39303 39304 39305 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39303 def confidence_threshold @confidence_threshold end |
#max_predictions ⇒ Fixnum
The model only returns up to that many top, by confidence score, predictions
per frame of the video. If this number is very high, the Model may return
fewer predictions per frame. Default value is 50.
Corresponds to the JSON property maxPredictions
39310 39311 39312 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39310 def max_predictions @max_predictions end |
#min_bounding_box_size ⇒ Float
Only bounding boxes with shortest edge at least that long as a relative value
of video frame size are returned. Default value is 0.0.
Corresponds to the JSON property minBoundingBoxSize
39316 39317 39318 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39316 def min_bounding_box_size @min_bounding_box_size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39323 39324 39325 39326 39327 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39323 def update!(**args) @confidence_threshold = args[:confidence_threshold] if args.key?(:confidence_threshold) @max_predictions = args[:max_predictions] if args.key?(:max_predictions) @min_bounding_box_size = args[:min_bounding_box_size] if args.key?(:min_bounding_box_size) end |