Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictParamsVideoObjectTrackingPredictionParams
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictParamsVideoObjectTrackingPredictionParams
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Prediction model parameters for Video Object Tracking.
Instance Attribute Summary collapse
-
#confidence_threshold ⇒ Float
The Model only returns predictions with at least this confidence score.
-
#max_predictions ⇒ Fixnum
The model only returns up to that many top, by confidence score, predictions per frame of the video.
-
#min_bounding_box_size ⇒ Float
Only bounding boxes with shortest edge at least that long as a relative value of video frame size are returned.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictParamsVideoObjectTrackingPredictionParams
constructor
A new instance of GoogleCloudAiplatformV1SchemaPredictParamsVideoObjectTrackingPredictionParams.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictParamsVideoObjectTrackingPredictionParams
Returns a new instance of GoogleCloudAiplatformV1SchemaPredictParamsVideoObjectTrackingPredictionParams.
28281 28282 28283 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28281 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence_threshold ⇒ Float
The Model only returns predictions with at least this confidence score.
Default value is 0.0
Corresponds to the JSON property confidenceThreshold
28266 28267 28268 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28266 def confidence_threshold @confidence_threshold end |
#max_predictions ⇒ Fixnum
The model only returns up to that many top, by confidence score, predictions
per frame of the video. If this number is very high, the Model may return
fewer predictions per frame. Default value is 50.
Corresponds to the JSON property maxPredictions
28273 28274 28275 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28273 def max_predictions @max_predictions end |
#min_bounding_box_size ⇒ Float
Only bounding boxes with shortest edge at least that long as a relative value
of video frame size are returned. Default value is 0.0.
Corresponds to the JSON property minBoundingBoxSize
28279 28280 28281 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28279 def min_bounding_box_size @min_bounding_box_size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28286 28287 28288 28289 28290 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28286 def update!(**args) @confidence_threshold = args[:confidence_threshold] if args.key?(:confidence_threshold) @max_predictions = args[:max_predictions] if args.key?(:max_predictions) @min_bounding_box_size = args[:min_bounding_box_size] if args.key?(:min_bounding_box_size) end |