Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictPredictionImageObjectDetectionPredictionResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Prediction output format for Image Object Detection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictPredictionImageObjectDetectionPredictionResult

Returns a new instance of GoogleCloudAiplatformV1SchemaPredictPredictionImageObjectDetectionPredictionResult.



37391
37392
37393
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37391

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bboxesArray<Array<Object>>

Bounding boxes, i.e. the rectangles over the image, that pinpoint the found AnnotationSpecs. Given in order that matches the IDs. Each bounding box is an array of 4 numbers xMin, xMax, yMin, and yMax, which represent the extremal coordinates of the box. They are relative to the image size, and the point 0,0 is in the top left of the image. Corresponds to the JSON property bboxes

Returns:

  • (Array<Array<Object>>)


37371
37372
37373
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37371

def bboxes
  @bboxes
end

#confidencesArray<Float>

The Model's confidences in correctness of the predicted IDs, higher value means higher confidence. Order matches the Ids. Corresponds to the JSON property confidences

Returns:

  • (Array<Float>)


37377
37378
37379
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37377

def confidences
  @confidences
end

#display_namesArray<String>

The display names of the AnnotationSpecs that had been identified, order matches the IDs. Corresponds to the JSON property displayNames

Returns:

  • (Array<String>)


37383
37384
37385
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37383

def display_names
  @display_names
end

#idsArray<Fixnum>

The resource IDs of the AnnotationSpecs that had been identified, ordered by the confidence score descendingly. Corresponds to the JSON property ids

Returns:

  • (Array<Fixnum>)


37389
37390
37391
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37389

def ids
  @ids
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37396
37397
37398
37399
37400
37401
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37396

def update!(**args)
  @bboxes = args[:bboxes] if args.key?(:bboxes)
  @confidences = args[:confidences] if args.key?(:confidences)
  @display_names = args[:display_names] if args.key?(:display_names)
  @ids = args[:ids] if args.key?(:ids)
end