Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictPredictionImageObjectDetectionPredictionResult
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictPredictionImageObjectDetectionPredictionResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Prediction output format for Image Object Detection.
Instance Attribute Summary collapse
-
#bboxes ⇒ Array<Array<Object>>
Bounding boxes, i.e.
-
#confidences ⇒ Array<Float>
The Model's confidences in correctness of the predicted IDs, higher value means higher confidence.
-
#display_names ⇒ Array<String>
The display names of the AnnotationSpecs that had been identified, order matches the IDs.
-
#ids ⇒ Array<Fixnum>
The resource IDs of the AnnotationSpecs that had been identified, ordered by the confidence score descendingly.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictPredictionImageObjectDetectionPredictionResult
constructor
A new instance of GoogleCloudAiplatformV1SchemaPredictPredictionImageObjectDetectionPredictionResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictPredictionImageObjectDetectionPredictionResult
Returns a new instance of GoogleCloudAiplatformV1SchemaPredictPredictionImageObjectDetectionPredictionResult.
35654 35655 35656 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35654 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bboxes ⇒ Array<Array<Object>>
Bounding boxes, i.e. the rectangles over the image, that pinpoint the found
AnnotationSpecs. Given in order that matches the IDs. Each bounding box is an
array of 4 numbers xMin, xMax, yMin, and yMax, which represent the
extremal coordinates of the box. They are relative to the image size, and the
point 0,0 is in the top left of the image.
Corresponds to the JSON property bboxes
35634 35635 35636 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35634 def bboxes @bboxes end |
#confidences ⇒ Array<Float>
The Model's confidences in correctness of the predicted IDs, higher value
means higher confidence. Order matches the Ids.
Corresponds to the JSON property confidences
35640 35641 35642 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35640 def confidences @confidences end |
#display_names ⇒ Array<String>
The display names of the AnnotationSpecs that had been identified, order
matches the IDs.
Corresponds to the JSON property displayNames
35646 35647 35648 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35646 def display_names @display_names end |
#ids ⇒ Array<Fixnum>
The resource IDs of the AnnotationSpecs that had been identified, ordered by
the confidence score descendingly.
Corresponds to the JSON property ids
35652 35653 35654 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35652 def ids @ids end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35659 35660 35661 35662 35663 35664 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35659 def update!(**args) @bboxes = args[:bboxes] if args.key?(:bboxes) @confidences = args[:confidences] if args.key?(:confidences) @display_names = args[:display_names] if args.key?(:display_names) @ids = args[:ids] if args.key?(:ids) end |