Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictPredictionImageObjectDetectionPredictionResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Prediction output format for Image Object Detection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictPredictionImageObjectDetectionPredictionResult

Returns a new instance of GoogleCloudAiplatformV1SchemaPredictPredictionImageObjectDetectionPredictionResult.



29507
29508
29509
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29507

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bboxesArray<Array<Object>>

Bounding boxes, i.e. the rectangles over the image, that pinpoint the found AnnotationSpecs. Given in order that matches the IDs. Each bounding box is an array of 4 numbers xMin, xMax, yMin, and yMax, which represent the extremal coordinates of the box. They are relative to the image size, and the point 0,0 is in the top left of the image. Corresponds to the JSON property bboxes

Returns:

  • (Array<Array<Object>>)


29487
29488
29489
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29487

def bboxes
  @bboxes
end

#confidencesArray<Float>

The Model's confidences in correctness of the predicted IDs, higher value means higher confidence. Order matches the Ids. Corresponds to the JSON property confidences

Returns:

  • (Array<Float>)


29493
29494
29495
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29493

def confidences
  @confidences
end

#display_namesArray<String>

The display names of the AnnotationSpecs that had been identified, order matches the IDs. Corresponds to the JSON property displayNames

Returns:

  • (Array<String>)


29499
29500
29501
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29499

def display_names
  @display_names
end

#idsArray<Fixnum>

The resource IDs of the AnnotationSpecs that had been identified, ordered by the confidence score descendingly. Corresponds to the JSON property ids

Returns:

  • (Array<Fixnum>)


29505
29506
29507
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29505

def ids
  @ids
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29512
29513
29514
29515
29516
29517
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29512

def update!(**args)
  @bboxes = args[:bboxes] if args.key?(:bboxes)
  @confidences = args[:confidences] if args.key?(:confidences)
  @display_names = args[:display_names] if args.key?(:display_names)
  @ids = args[:ids] if args.key?(:ids)
end