Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictPredictionImageObjectDetectionPredictionResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Prediction output format for Image Object Detection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictPredictionImageObjectDetectionPredictionResult

Returns a new instance of GoogleCloudAiplatformV1SchemaPredictPredictionImageObjectDetectionPredictionResult.



20515
20516
20517
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20515

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bboxesArray<Array<Object>>

Bounding boxes, i.e. the rectangles over the image, that pinpoint the found AnnotationSpecs. Given in order that matches the IDs. Each bounding box is an array of 4 numbers xMin, xMax, yMin, and yMax, which represent the extremal coordinates of the box. They are relative to the image size, and the point 0,0 is in the top left of the image. Corresponds to the JSON property bboxes

Returns:

  • (Array<Array<Object>>)


20495
20496
20497
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20495

def bboxes
  @bboxes
end

#confidencesArray<Float>

The Model's confidences in correctness of the predicted IDs, higher value means higher confidence. Order matches the Ids. Corresponds to the JSON property confidences

Returns:

  • (Array<Float>)


20501
20502
20503
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20501

def confidences
  @confidences
end

#display_namesArray<String>

The display names of the AnnotationSpecs that had been identified, order matches the IDs. Corresponds to the JSON property displayNames

Returns:

  • (Array<String>)


20507
20508
20509
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20507

def display_names
  @display_names
end

#idsArray<Fixnum>

The resource IDs of the AnnotationSpecs that had been identified, ordered by the confidence score descendingly. Corresponds to the JSON property ids

Returns:

  • (Array<Fixnum>)


20513
20514
20515
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20513

def ids
  @ids
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20520
20521
20522
20523
20524
20525
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20520

def update!(**args)
  @bboxes = args[:bboxes] if args.key?(:bboxes)
  @confidences = args[:confidences] if args.key?(:confidences)
  @display_names = args[:display_names] if args.key?(:display_names)
  @ids = args[:ids] if args.key?(:ids)
end