Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictPredictionImageSegmentationPredictionResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Prediction output format for Image Segmentation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictPredictionImageSegmentationPredictionResult

Returns a new instance of GoogleCloudAiplatformV1SchemaPredictPredictionImageSegmentationPredictionResult.



37600
37601
37602
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37600

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#category_maskString

A PNG image where each pixel in the mask represents the category in which the pixel in the original image was predicted to belong to. The size of this image will be the same as the original image. The mapping between the AnntoationSpec and the color can be found in model's metadata. The model will choose the most likely category and if none of the categories reach the confidence threshold, the pixel will be marked as background. Corresponds to the JSON property categoryMask

Returns:

  • (String)


37589
37590
37591
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37589

def category_mask
  @category_mask
end

#confidence_maskString

A one channel image which is encoded as an 8bit lossless PNG. The size of the image will be the same as the original image. For a specific pixel, darker color means less confidence in correctness of the cateogry in the categoryMask for the corresponding pixel. Black means no confidence and white means complete confidence. Corresponds to the JSON property confidenceMask

Returns:

  • (String)


37598
37599
37600
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37598

def confidence_mask
  @confidence_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37605
37606
37607
37608
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37605

def update!(**args)
  @category_mask = args[:category_mask] if args.key?(:category_mask)
  @confidence_mask = args[:confidence_mask] if args.key?(:confidence_mask)
end