Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictPredictionImageSegmentationPredictionResult
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictPredictionImageSegmentationPredictionResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Prediction output format for Image Segmentation.
Instance Attribute Summary collapse
-
#category_mask ⇒ String
A PNG image where each pixel in the mask represents the category in which the pixel in the original image was predicted to belong to.
-
#confidence_mask ⇒ String
A one channel image which is encoded as an 8bit lossless PNG.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictPredictionImageSegmentationPredictionResult
constructor
A new instance of GoogleCloudAiplatformV1SchemaPredictPredictionImageSegmentationPredictionResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictPredictionImageSegmentationPredictionResult
Returns a new instance of GoogleCloudAiplatformV1SchemaPredictPredictionImageSegmentationPredictionResult.
37427 37428 37429 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37427 def initialize(**args) update!(**args) end |
Instance Attribute Details
#category_mask ⇒ String
A PNG image where each pixel in the mask represents the category in which the
pixel in the original image was predicted to belong to. The size of this image
will be the same as the original image. The mapping between the AnntoationSpec
and the color can be found in model's metadata. The model will choose the most
likely category and if none of the categories reach the confidence threshold,
the pixel will be marked as background.
Corresponds to the JSON property categoryMask
37416 37417 37418 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37416 def category_mask @category_mask end |
#confidence_mask ⇒ String
A one channel image which is encoded as an 8bit lossless PNG. The size of the
image will be the same as the original image. For a specific pixel, darker
color means less confidence in correctness of the cateogry in the categoryMask
for the corresponding pixel. Black means no confidence and white means
complete confidence.
Corresponds to the JSON property confidenceMask
37425 37426 37427 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37425 def confidence_mask @confidence_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37432 37433 37434 37435 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37432 def update!(**args) @category_mask = args[:category_mask] if args.key?(:category_mask) @confidence_mask = args[:confidence_mask] if args.key?(:confidence_mask) end |