Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictPredictionTextExtractionPredictionResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Prediction output format for Text Extraction.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictPredictionTextExtractionPredictionResult

Returns a new instance of GoogleCloudAiplatformV1SchemaPredictPredictionTextExtractionPredictionResult.



40116
40117
40118
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40116

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidencesArray<Float>

The Model's confidences in correctness of the predicted IDs, higher value means higher confidence. Order matches the Ids. Corresponds to the JSON property confidences

Returns:

  • (Array<Float>)


40088
40089
40090
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40088

def confidences
  @confidences
end

#display_namesArray<String>

The display names of the AnnotationSpecs that had been identified, order matches the IDs. Corresponds to the JSON property displayNames

Returns:

  • (Array<String>)


40094
40095
40096
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40094

def display_names
  @display_names
end

#idsArray<Fixnum>

The resource IDs of the AnnotationSpecs that had been identified, ordered by the confidence score descendingly. Corresponds to the JSON property ids

Returns:

  • (Array<Fixnum>)


40100
40101
40102
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40100

def ids
  @ids
end

#text_segment_end_offsetsArray<Fixnum>

The end offsets, inclusive, of the text segment in which the AnnotationSpec has been identified. Expressed as a zero-based number of characters as measured from the start of the text snippet. Corresponds to the JSON property textSegmentEndOffsets

Returns:

  • (Array<Fixnum>)


40107
40108
40109
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40107

def text_segment_end_offsets
  @text_segment_end_offsets
end

#text_segment_start_offsetsArray<Fixnum>

The start offsets, inclusive, of the text segment in which the AnnotationSpec has been identified. Expressed as a zero-based number of characters as measured from the start of the text snippet. Corresponds to the JSON property textSegmentStartOffsets

Returns:

  • (Array<Fixnum>)


40114
40115
40116
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40114

def text_segment_start_offsets
  @text_segment_start_offsets
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40121
40122
40123
40124
40125
40126
40127
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40121

def update!(**args)
  @confidences = args[:confidences] if args.key?(:confidences)
  @display_names = args[:display_names] if args.key?(:display_names)
  @ids = args[:ids] if args.key?(:ids)
  @text_segment_end_offsets = args[:text_segment_end_offsets] if args.key?(:text_segment_end_offsets)
  @text_segment_start_offsets = args[:text_segment_start_offsets] if args.key?(:text_segment_start_offsets)
end