Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictPredictionTextExtractionPredictionResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Prediction output format for Text Extraction.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictPredictionTextExtractionPredictionResult

Returns a new instance of GoogleCloudAiplatformV1SchemaPredictPredictionTextExtractionPredictionResult.



29867
29868
29869
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29867

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidencesArray<Float>

The Model's confidences in correctness of the predicted IDs, higher value means higher confidence. Order matches the Ids. Corresponds to the JSON property confidences

Returns:

  • (Array<Float>)


29839
29840
29841
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29839

def confidences
  @confidences
end

#display_namesArray<String>

The display names of the AnnotationSpecs that had been identified, order matches the IDs. Corresponds to the JSON property displayNames

Returns:

  • (Array<String>)


29845
29846
29847
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29845

def display_names
  @display_names
end

#idsArray<Fixnum>

The resource IDs of the AnnotationSpecs that had been identified, ordered by the confidence score descendingly. Corresponds to the JSON property ids

Returns:

  • (Array<Fixnum>)


29851
29852
29853
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29851

def ids
  @ids
end

#text_segment_end_offsetsArray<Fixnum>

The end offsets, inclusive, of the text segment in which the AnnotationSpec has been identified. Expressed as a zero-based number of characters as measured from the start of the text snippet. Corresponds to the JSON property textSegmentEndOffsets

Returns:

  • (Array<Fixnum>)


29858
29859
29860
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29858

def text_segment_end_offsets
  @text_segment_end_offsets
end

#text_segment_start_offsetsArray<Fixnum>

The start offsets, inclusive, of the text segment in which the AnnotationSpec has been identified. Expressed as a zero-based number of characters as measured from the start of the text snippet. Corresponds to the JSON property textSegmentStartOffsets

Returns:

  • (Array<Fixnum>)


29865
29866
29867
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29865

def text_segment_start_offsets
  @text_segment_start_offsets
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29872
29873
29874
29875
29876
29877
29878
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29872

def update!(**args)
  @confidences = args[:confidences] if args.key?(:confidences)
  @display_names = args[:display_names] if args.key?(:display_names)
  @ids = args[:ids] if args.key?(:ids)
  @text_segment_end_offsets = args[:text_segment_end_offsets] if args.key?(:text_segment_end_offsets)
  @text_segment_start_offsets = args[:text_segment_start_offsets] if args.key?(:text_segment_start_offsets)
end