Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictPredictionTextExtractionPredictionResult
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictPredictionTextExtractionPredictionResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Prediction output format for Text Extraction.
Instance Attribute Summary collapse
-
#confidences ⇒ Array<Float>
The Model's confidences in correctness of the predicted IDs, higher value means higher confidence.
-
#display_names ⇒ Array<String>
The display names of the AnnotationSpecs that had been identified, order matches the IDs.
-
#ids ⇒ Array<Fixnum>
The resource IDs of the AnnotationSpecs that had been identified, ordered by the confidence score descendingly.
-
#text_segment_end_offsets ⇒ Array<Fixnum>
The end offsets, inclusive, of the text segment in which the AnnotationSpec has been identified.
-
#text_segment_start_offsets ⇒ Array<Fixnum>
The start offsets, inclusive, of the text segment in which the AnnotationSpec has been identified.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictPredictionTextExtractionPredictionResult
constructor
A new instance of GoogleCloudAiplatformV1SchemaPredictPredictionTextExtractionPredictionResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictPredictionTextExtractionPredictionResult
Returns a new instance of GoogleCloudAiplatformV1SchemaPredictPredictionTextExtractionPredictionResult.
28142 28143 28144 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28142 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidences ⇒ Array<Float>
The Model's confidences in correctness of the predicted IDs, higher value
means higher confidence. Order matches the Ids.
Corresponds to the JSON property confidences
28114 28115 28116 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28114 def confidences @confidences end |
#display_names ⇒ Array<String>
The display names of the AnnotationSpecs that had been identified, order
matches the IDs.
Corresponds to the JSON property displayNames
28120 28121 28122 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28120 def display_names @display_names end |
#ids ⇒ Array<Fixnum>
The resource IDs of the AnnotationSpecs that had been identified, ordered by
the confidence score descendingly.
Corresponds to the JSON property ids
28126 28127 28128 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28126 def ids @ids end |
#text_segment_end_offsets ⇒ Array<Fixnum>
The end offsets, inclusive, of the text segment in which the AnnotationSpec
has been identified. Expressed as a zero-based number of characters as
measured from the start of the text snippet.
Corresponds to the JSON property textSegmentEndOffsets
28133 28134 28135 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28133 def text_segment_end_offsets @text_segment_end_offsets end |
#text_segment_start_offsets ⇒ Array<Fixnum>
The start offsets, inclusive, of the text segment in which the AnnotationSpec
has been identified. Expressed as a zero-based number of characters as
measured from the start of the text snippet.
Corresponds to the JSON property textSegmentStartOffsets
28140 28141 28142 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28140 def text_segment_start_offsets @text_segment_start_offsets end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28147 28148 28149 28150 28151 28152 28153 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28147 def update!(**args) @confidences = args[:confidences] if args.key?(:confidences) @display_names = args[:display_names] if args.key?(:display_names) @ids = args[:ids] if args.key?(:ids) @text_segment_end_offsets = args[:text_segment_end_offsets] if args.key?(:text_segment_end_offsets) @text_segment_start_offsets = args[:text_segment_start_offsets] if args.key?(:text_segment_start_offsets) end |