Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictPredictionTextExtractionPredictionResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Prediction output format for Text Extraction.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictPredictionTextExtractionPredictionResult

Returns a new instance of GoogleCloudAiplatformV1SchemaPredictPredictionTextExtractionPredictionResult.



24837
24838
24839
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24837

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidencesArray<Float>

The Model's confidences in correctness of the predicted IDs, higher value means higher confidence. Order matches the Ids. Corresponds to the JSON property confidences

Returns:

  • (Array<Float>)


24809
24810
24811
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24809

def confidences
  @confidences
end

#display_namesArray<String>

The display names of the AnnotationSpecs that had been identified, order matches the IDs. Corresponds to the JSON property displayNames

Returns:

  • (Array<String>)


24815
24816
24817
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24815

def display_names
  @display_names
end

#idsArray<Fixnum>

The resource IDs of the AnnotationSpecs that had been identified, ordered by the confidence score descendingly. Corresponds to the JSON property ids

Returns:

  • (Array<Fixnum>)


24821
24822
24823
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24821

def ids
  @ids
end

#text_segment_end_offsetsArray<Fixnum>

The end offsets, inclusive, of the text segment in which the AnnotationSpec has been identified. Expressed as a zero-based number of characters as measured from the start of the text snippet. Corresponds to the JSON property textSegmentEndOffsets

Returns:

  • (Array<Fixnum>)


24828
24829
24830
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24828

def text_segment_end_offsets
  @text_segment_end_offsets
end

#text_segment_start_offsetsArray<Fixnum>

The start offsets, inclusive, of the text segment in which the AnnotationSpec has been identified. Expressed as a zero-based number of characters as measured from the start of the text snippet. Corresponds to the JSON property textSegmentStartOffsets

Returns:

  • (Array<Fixnum>)


24835
24836
24837
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24835

def text_segment_start_offsets
  @text_segment_start_offsets
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24842
24843
24844
24845
24846
24847
24848
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24842

def update!(**args)
  @confidences = args[:confidences] if args.key?(:confidences)
  @display_names = args[:display_names] if args.key?(:display_names)
  @ids = args[:ids] if args.key?(:ids)
  @text_segment_end_offsets = args[:text_segment_end_offsets] if args.key?(:text_segment_end_offsets)
  @text_segment_start_offsets = args[:text_segment_start_offsets] if args.key?(:text_segment_start_offsets)
end