Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictPredictionVideoActionRecognitionPredictionResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Prediction output format for Video Action Recognition.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictPredictionVideoActionRecognitionPredictionResult

Returns a new instance of GoogleCloudAiplatformV1SchemaPredictPredictionVideoActionRecognitionPredictionResult.



29973
29974
29975
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29973

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidenceFloat

The Model's confidence in correction of this prediction, higher value means higher confidence. Corresponds to the JSON property confidence

Returns:

  • (Float)


29945
29946
29947
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29945

def confidence
  @confidence
end

#display_nameString

The display name of the AnnotationSpec that had been identified. Corresponds to the JSON property displayName

Returns:

  • (String)


29950
29951
29952
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29950

def display_name
  @display_name
end

#idString

The resource ID of the AnnotationSpec that had been identified. Corresponds to the JSON property id

Returns:

  • (String)


29955
29956
29957
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29955

def id
  @id
end

#time_segment_endString

The end, exclusive, of the video's time segment in which the AnnotationSpec has been identified. Expressed as a number of seconds as measured from the start of the video, with fractions up to a microsecond precision, and with "s" appended at the end. Corresponds to the JSON property timeSegmentEnd

Returns:

  • (String)


29963
29964
29965
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29963

def time_segment_end
  @time_segment_end
end

#time_segment_startString

The beginning, inclusive, of the video's time segment in which the AnnotationSpec has been identified. Expressed as a number of seconds as measured from the start of the video, with fractions up to a microsecond precision, and with "s" appended at the end. Corresponds to the JSON property timeSegmentStart

Returns:

  • (String)


29971
29972
29973
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29971

def time_segment_start
  @time_segment_start
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29978
29979
29980
29981
29982
29983
29984
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29978

def update!(**args)
  @confidence = args[:confidence] if args.key?(:confidence)
  @display_name = args[:display_name] if args.key?(:display_name)
  @id = args[:id] if args.key?(:id)
  @time_segment_end = args[:time_segment_end] if args.key?(:time_segment_end)
  @time_segment_start = args[:time_segment_start] if args.key?(:time_segment_start)
end