Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictPredictionVideoActionRecognitionPredictionResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Prediction output format for Video Action Recognition.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictPredictionVideoActionRecognitionPredictionResult

Returns a new instance of GoogleCloudAiplatformV1SchemaPredictPredictionVideoActionRecognitionPredictionResult.



28051
28052
28053
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28051

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidenceFloat

The Model's confidence in correction of this prediction, higher value means higher confidence. Corresponds to the JSON property confidence

Returns:

  • (Float)


28023
28024
28025
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28023

def confidence
  @confidence
end

#display_nameString

The display name of the AnnotationSpec that had been identified. Corresponds to the JSON property displayName

Returns:

  • (String)


28028
28029
28030
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28028

def display_name
  @display_name
end

#idString

The resource ID of the AnnotationSpec that had been identified. Corresponds to the JSON property id

Returns:

  • (String)


28033
28034
28035
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28033

def id
  @id
end

#time_segment_endString

The end, exclusive, of the video's time segment in which the AnnotationSpec has been identified. Expressed as a number of seconds as measured from the start of the video, with fractions up to a microsecond precision, and with "s" appended at the end. Corresponds to the JSON property timeSegmentEnd

Returns:

  • (String)


28041
28042
28043
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28041

def time_segment_end
  @time_segment_end
end

#time_segment_startString

The beginning, inclusive, of the video's time segment in which the AnnotationSpec has been identified. Expressed as a number of seconds as measured from the start of the video, with fractions up to a microsecond precision, and with "s" appended at the end. Corresponds to the JSON property timeSegmentStart

Returns:

  • (String)


28049
28050
28051
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28049

def time_segment_start
  @time_segment_start
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28056
28057
28058
28059
28060
28061
28062
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28056

def update!(**args)
  @confidence = args[:confidence] if args.key?(:confidence)
  @display_name = args[:display_name] if args.key?(:display_name)
  @id = args[:id] if args.key?(:id)
  @time_segment_end = args[:time_segment_end] if args.key?(:time_segment_end)
  @time_segment_start = args[:time_segment_start] if args.key?(:time_segment_start)
end