Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictPredictionVideoActionRecognitionPredictionResult
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictPredictionVideoActionRecognitionPredictionResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Prediction output format for Video Action Recognition.
Instance Attribute Summary collapse
-
#confidence ⇒ Float
The Model's confidence in correction of this prediction, higher value means higher confidence.
-
#display_name ⇒ String
The display name of the AnnotationSpec that had been identified.
-
#id ⇒ String
The resource ID of the AnnotationSpec that had been identified.
-
#time_segment_end ⇒ String
The end, exclusive, of the video's time segment in which the AnnotationSpec has been identified.
-
#time_segment_start ⇒ String
The beginning, inclusive, of the video's time segment in which the AnnotationSpec has been identified.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictPredictionVideoActionRecognitionPredictionResult
constructor
A new instance of GoogleCloudAiplatformV1SchemaPredictPredictionVideoActionRecognitionPredictionResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictPredictionVideoActionRecognitionPredictionResult
Returns a new instance of GoogleCloudAiplatformV1SchemaPredictPredictionVideoActionRecognitionPredictionResult.
20828 20829 20830 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20828 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence ⇒ Float
The Model's confidence in correction of this prediction, higher value means
higher confidence.
Corresponds to the JSON property confidence
20800 20801 20802 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20800 def confidence @confidence end |
#display_name ⇒ String
The display name of the AnnotationSpec that had been identified.
Corresponds to the JSON property displayName
20805 20806 20807 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20805 def display_name @display_name end |
#id ⇒ String
The resource ID of the AnnotationSpec that had been identified.
Corresponds to the JSON property id
20810 20811 20812 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20810 def id @id end |
#time_segment_end ⇒ String
The end, exclusive, of the video's time segment in which the AnnotationSpec
has been identified. Expressed as a number of seconds as measured from the
start of the video, with fractions up to a microsecond precision, and with "s"
appended at the end.
Corresponds to the JSON property timeSegmentEnd
20818 20819 20820 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20818 def time_segment_end @time_segment_end end |
#time_segment_start ⇒ String
The beginning, inclusive, of the video's time segment in which the
AnnotationSpec has been identified. Expressed as a number of seconds as
measured from the start of the video, with fractions up to a microsecond
precision, and with "s" appended at the end.
Corresponds to the JSON property timeSegmentStart
20826 20827 20828 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20826 def time_segment_start @time_segment_start end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20833 20834 20835 20836 20837 20838 20839 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20833 def update!(**args) @confidence = args[:confidence] if args.key?(:confidence) @display_name = args[:display_name] if args.key?(:display_name) @id = args[:id] if args.key?(:id) @time_segment_end = args[:time_segment_end] if args.key?(:time_segment_end) @time_segment_start = args[:time_segment_start] if args.key?(:time_segment_start) end |