Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictPredictionVideoObjectTrackingPredictionResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Prediction output format for Video Object Tracking.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictPredictionVideoObjectTrackingPredictionResult

Returns a new instance of GoogleCloudAiplatformV1SchemaPredictPredictionVideoObjectTrackingPredictionResult.



30502
30503
30504
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30502

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidenceFloat

The Model's confidence in correction of this prediction, higher value means higher confidence. Corresponds to the JSON property confidence

Returns:

  • (Float)


30468
30469
30470
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30468

def confidence
  @confidence
end

#display_nameString

The display name of the AnnotationSpec that had been identified. Corresponds to the JSON property displayName

Returns:

  • (String)


30473
30474
30475
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30473

def display_name
  @display_name
end

#framesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictPredictionVideoObjectTrackingPredictionResultFrame>

All of the frames of the video in which a single object instance has been detected. The bounding boxes in the frames identify the same object. Corresponds to the JSON property frames



30479
30480
30481
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30479

def frames
  @frames
end

#idString

The resource ID of the AnnotationSpec that had been identified. Corresponds to the JSON property id

Returns:

  • (String)


30484
30485
30486
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30484

def id
  @id
end

#time_segment_endString

The end, inclusive, of the video's time segment in which the object instance has been detected. Expressed as a number of seconds as measured from the start of the video, with fractions up to a microsecond precision, and with "s" appended at the end. Corresponds to the JSON property timeSegmentEnd

Returns:

  • (String)


30492
30493
30494
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30492

def time_segment_end
  @time_segment_end
end

#time_segment_startString

The beginning, inclusive, of the video's time segment in which the object instance has been detected. Expressed as a number of seconds as measured from the start of the video, with fractions up to a microsecond precision, and with "s" appended at the end. Corresponds to the JSON property timeSegmentStart

Returns:

  • (String)


30500
30501
30502
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30500

def time_segment_start
  @time_segment_start
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30507
30508
30509
30510
30511
30512
30513
30514
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30507

def update!(**args)
  @confidence = args[:confidence] if args.key?(:confidence)
  @display_name = args[:display_name] if args.key?(:display_name)
  @frames = args[:frames] if args.key?(:frames)
  @id = args[:id] if args.key?(:id)
  @time_segment_end = args[:time_segment_end] if args.key?(:time_segment_end)
  @time_segment_start = args[:time_segment_start] if args.key?(:time_segment_start)
end