Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictPredictionVideoObjectTrackingPredictionResult
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictPredictionVideoObjectTrackingPredictionResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Prediction output format for Video Object Tracking.
Instance Attribute Summary collapse
-
#confidence ⇒ Float
The Model's confidence in correction of this prediction, higher value means higher confidence.
-
#display_name ⇒ String
The display name of the AnnotationSpec that had been identified.
-
#frames ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictPredictionVideoObjectTrackingPredictionResultFrame>
All of the frames of the video in which a single object instance has been detected.
-
#id ⇒ String
The resource ID of the AnnotationSpec that had been identified.
-
#time_segment_end ⇒ String
The end, inclusive, of the video's time segment in which the object instance has been detected.
-
#time_segment_start ⇒ String
The beginning, inclusive, of the video's time segment in which the object instance has been detected.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictPredictionVideoObjectTrackingPredictionResult
constructor
A new instance of GoogleCloudAiplatformV1SchemaPredictPredictionVideoObjectTrackingPredictionResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictPredictionVideoObjectTrackingPredictionResult
Returns a new instance of GoogleCloudAiplatformV1SchemaPredictPredictionVideoObjectTrackingPredictionResult.
23389 23390 23391 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23389 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence ⇒ Float
The Model's confidence in correction of this prediction, higher value means
higher confidence.
Corresponds to the JSON property confidence
23355 23356 23357 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23355 def confidence @confidence end |
#display_name ⇒ String
The display name of the AnnotationSpec that had been identified.
Corresponds to the JSON property displayName
23360 23361 23362 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23360 def display_name @display_name end |
#frames ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictPredictionVideoObjectTrackingPredictionResultFrame>
All of the frames of the video in which a single object instance has been
detected. The bounding boxes in the frames identify the same object.
Corresponds to the JSON property frames
23366 23367 23368 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23366 def frames @frames end |
#id ⇒ String
The resource ID of the AnnotationSpec that had been identified.
Corresponds to the JSON property id
23371 23372 23373 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23371 def id @id end |
#time_segment_end ⇒ String
The end, inclusive, of the video's time segment in which the object instance
has been detected. Expressed as a number of seconds as measured from the start
of the video, with fractions up to a microsecond precision, and with "s"
appended at the end.
Corresponds to the JSON property timeSegmentEnd
23379 23380 23381 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23379 def time_segment_end @time_segment_end end |
#time_segment_start ⇒ String
The beginning, inclusive, of the video's time segment in which the object
instance has been detected. Expressed as a number of seconds as measured from
the start of the video, with fractions up to a microsecond precision, and with
"s" appended at the end.
Corresponds to the JSON property timeSegmentStart
23387 23388 23389 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23387 def time_segment_start @time_segment_start end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23394 23395 23396 23397 23398 23399 23400 23401 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23394 def update!(**args) @confidence = args[:confidence] if args.key?(:confidence) @display_name = args[:display_name] if args.key?(:display_name) @frames = args[:frames] if args.key?(:frames) @id = args[:id] if args.key?(:id) @time_segment_end = args[:time_segment_end] if args.key?(:time_segment_end) @time_segment_start = args[:time_segment_start] if args.key?(:time_segment_start) end |