Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictPredictionVideoObjectTrackingPredictionResultFrame

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The fields xMin, xMax, yMin, and yMax refer to a bounding box, i.e. the rectangle over the video frame pinpointing the found AnnotationSpec. The coordinates are relative to the frame size, and the point 0,0 is in the top left of the frame.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictPredictionVideoObjectTrackingPredictionResultFrame

Returns a new instance of GoogleCloudAiplatformV1SchemaPredictPredictionVideoObjectTrackingPredictionResultFrame.



37850
37851
37852
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37850

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#time_offsetString

A time (frame) of a video in which the object has been detected. Expressed as a number of seconds as measured from the start of the video, with fractions up to a microsecond precision, and with "s" appended at the end. Corresponds to the JSON property timeOffset

Returns:

  • (String)


37828
37829
37830
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37828

def time_offset
  @time_offset
end

#x_maxFloat

The rightmost coordinate of the bounding box. Corresponds to the JSON property xMax

Returns:

  • (Float)


37833
37834
37835
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37833

def x_max
  @x_max
end

#x_minFloat

The leftmost coordinate of the bounding box. Corresponds to the JSON property xMin

Returns:

  • (Float)


37838
37839
37840
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37838

def x_min
  @x_min
end

#y_maxFloat

The bottommost coordinate of the bounding box. Corresponds to the JSON property yMax

Returns:

  • (Float)


37843
37844
37845
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37843

def y_max
  @y_max
end

#y_minFloat

The topmost coordinate of the bounding box. Corresponds to the JSON property yMin

Returns:

  • (Float)


37848
37849
37850
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37848

def y_min
  @y_min
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37855
37856
37857
37858
37859
37860
37861
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37855

def update!(**args)
  @time_offset = args[:time_offset] if args.key?(:time_offset)
  @x_max = args[:x_max] if args.key?(:x_max)
  @x_min = args[:x_min] if args.key?(:x_min)
  @y_max = args[:y_max] if args.key?(:y_max)
  @y_min = args[:y_min] if args.key?(:y_min)
end