Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictPredictionVideoObjectTrackingPredictionResultFrame
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictPredictionVideoObjectTrackingPredictionResultFrame
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The fields xMin, xMax, yMin, and yMax refer to a bounding box, i.e.
the rectangle over the video frame pinpointing the found AnnotationSpec. The
coordinates are relative to the frame size, and the point 0,0 is in the top
left of the frame.
Instance Attribute Summary collapse
-
#time_offset ⇒ String
A time (frame) of a video in which the object has been detected.
-
#x_max ⇒ Float
The rightmost coordinate of the bounding box.
-
#x_min ⇒ Float
The leftmost coordinate of the bounding box.
-
#y_max ⇒ Float
The bottommost coordinate of the bounding box.
-
#y_min ⇒ Float
The topmost coordinate of the bounding box.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictPredictionVideoObjectTrackingPredictionResultFrame
constructor
A new instance of GoogleCloudAiplatformV1SchemaPredictPredictionVideoObjectTrackingPredictionResultFrame.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictPredictionVideoObjectTrackingPredictionResultFrame
Returns a new instance of GoogleCloudAiplatformV1SchemaPredictPredictionVideoObjectTrackingPredictionResultFrame.
28452 28453 28454 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28452 def initialize(**args) update!(**args) end |
Instance Attribute Details
#time_offset ⇒ String
A time (frame) of a video in which the object has been detected. Expressed as
a number of seconds as measured from the start of the video, with fractions up
to a microsecond precision, and with "s" appended at the end.
Corresponds to the JSON property timeOffset
28430 28431 28432 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28430 def time_offset @time_offset end |
#x_max ⇒ Float
The rightmost coordinate of the bounding box.
Corresponds to the JSON property xMax
28435 28436 28437 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28435 def x_max @x_max end |
#x_min ⇒ Float
The leftmost coordinate of the bounding box.
Corresponds to the JSON property xMin
28440 28441 28442 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28440 def x_min @x_min end |
#y_max ⇒ Float
The bottommost coordinate of the bounding box.
Corresponds to the JSON property yMax
28445 28446 28447 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28445 def y_max @y_max end |
#y_min ⇒ Float
The topmost coordinate of the bounding box.
Corresponds to the JSON property yMin
28450 28451 28452 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28450 def y_min @y_min end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28457 28458 28459 28460 28461 28462 28463 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28457 def update!(**args) @time_offset = args[:time_offset] if args.key?(:time_offset) @x_max = args[:x_max] if args.key?(:x_max) @x_min = args[:x_min] if args.key?(:x_min) @y_max = args[:y_max] if args.key?(:y_max) @y_min = args[:y_min] if args.key?(:y_min) end |