Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictPredictionVideoObjectTrackingPredictionResultFrame
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictPredictionVideoObjectTrackingPredictionResultFrame
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The fields xMin, xMax, yMin, and yMax refer to a bounding box, i.e.
the rectangle over the video frame pinpointing the found AnnotationSpec. The
coordinates are relative to the frame size, and the point 0,0 is in the top
left of the frame.
Instance Attribute Summary collapse
-
#time_offset ⇒ String
A time (frame) of a video in which the object has been detected.
-
#x_max ⇒ Float
The rightmost coordinate of the bounding box.
-
#x_min ⇒ Float
The leftmost coordinate of the bounding box.
-
#y_max ⇒ Float
The bottommost coordinate of the bounding box.
-
#y_min ⇒ Float
The topmost coordinate of the bounding box.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictPredictionVideoObjectTrackingPredictionResultFrame
constructor
A new instance of GoogleCloudAiplatformV1SchemaPredictPredictionVideoObjectTrackingPredictionResultFrame.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictPredictionVideoObjectTrackingPredictionResultFrame
Returns a new instance of GoogleCloudAiplatformV1SchemaPredictPredictionVideoObjectTrackingPredictionResultFrame.
25165 25166 25167 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25165 def initialize(**args) update!(**args) end |
Instance Attribute Details
#time_offset ⇒ String
A time (frame) of a video in which the object has been detected. Expressed as
a number of seconds as measured from the start of the video, with fractions up
to a microsecond precision, and with "s" appended at the end.
Corresponds to the JSON property timeOffset
25143 25144 25145 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25143 def time_offset @time_offset end |
#x_max ⇒ Float
The rightmost coordinate of the bounding box.
Corresponds to the JSON property xMax
25148 25149 25150 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25148 def x_max @x_max end |
#x_min ⇒ Float
The leftmost coordinate of the bounding box.
Corresponds to the JSON property xMin
25153 25154 25155 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25153 def x_min @x_min end |
#y_max ⇒ Float
The bottommost coordinate of the bounding box.
Corresponds to the JSON property yMax
25158 25159 25160 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25158 def y_max @y_max end |
#y_min ⇒ Float
The topmost coordinate of the bounding box.
Corresponds to the JSON property yMin
25163 25164 25165 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25163 def y_min @y_min end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25170 25171 25172 25173 25174 25175 25176 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25170 def update!(**args) @time_offset = args[:time_offset] if args.key?(:time_offset) @x_max = args[:x_max] if args.key?(:x_max) @x_min = args[:x_min] if args.key?(:x_min) @y_max = args[:y_max] if args.key?(:y_max) @y_min = args[:y_min] if args.key?(:y_min) end |