Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictPredictionVideoObjectTrackingPredictionResultFrame

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The fields xMin, xMax, yMin, and yMax refer to a bounding box, i.e. the rectangle over the video frame pinpointing the found AnnotationSpec. The coordinates are relative to the frame size, and the point 0,0 is in the top left of the frame.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictPredictionVideoObjectTrackingPredictionResultFrame

Returns a new instance of GoogleCloudAiplatformV1SchemaPredictPredictionVideoObjectTrackingPredictionResultFrame.



20996
20997
20998
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20996

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#time_offsetString

A time (frame) of a video in which the object has been detected. Expressed as a number of seconds as measured from the start of the video, with fractions up to a microsecond precision, and with "s" appended at the end. Corresponds to the JSON property timeOffset

Returns:

  • (String)


20974
20975
20976
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20974

def time_offset
  @time_offset
end

#x_maxFloat

The rightmost coordinate of the bounding box. Corresponds to the JSON property xMax

Returns:

  • (Float)


20979
20980
20981
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20979

def x_max
  @x_max
end

#x_minFloat

The leftmost coordinate of the bounding box. Corresponds to the JSON property xMin

Returns:

  • (Float)


20984
20985
20986
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20984

def x_min
  @x_min
end

#y_maxFloat

The bottommost coordinate of the bounding box. Corresponds to the JSON property yMax

Returns:

  • (Float)


20989
20990
20991
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20989

def y_max
  @y_max
end

#y_minFloat

The topmost coordinate of the bounding box. Corresponds to the JSON property yMin

Returns:

  • (Float)


20994
20995
20996
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 20994

def y_min
  @y_min
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21001
21002
21003
21004
21005
21006
21007
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21001

def update!(**args)
  @time_offset = args[:time_offset] if args.key?(:time_offset)
  @x_max = args[:x_max] if args.key?(:x_max)
  @x_min = args[:x_min] if args.key?(:x_min)
  @y_max = args[:y_max] if args.key?(:y_max)
  @y_min = args[:y_min] if args.key?(:y_min)
end