Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictionResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents a line of JSONL in the batch prediction output file.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictionResult

Returns a new instance of GoogleCloudAiplatformV1SchemaPredictionResult.



38086
38087
38088
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38086

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictionResultError

The error result. Do not set prediction if this is set. Corresponds to the JSON property error



38066
38067
38068
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38066

def error
  @error
end

#instanceHash<String,Object>

User's input instance. Struct is used here instead of Any so that JsonFormat does not append an extra "@type" field when we convert the proto to JSON. Corresponds to the JSON property instance

Returns:

  • (Hash<String,Object>)


38072
38073
38074
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38072

def instance
  @instance
end

#keyString

Optional user-provided key from the input instance. Corresponds to the JSON property key

Returns:

  • (String)


38077
38078
38079
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38077

def key
  @key
end

#predictionObject

The prediction result. Value is used here instead of Any so that JsonFormat does not append an extra "@type" field when we convert the proto to JSON and so we can represent array of objects. Do not set error if this is set. Corresponds to the JSON property prediction

Returns:

  • (Object)


38084
38085
38086
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38084

def prediction
  @prediction
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38091
38092
38093
38094
38095
38096
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38091

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @instance = args[:instance] if args.key?(:instance)
  @key = args[:key] if args.key?(:key)
  @prediction = args[:prediction] if args.key?(:prediction)
end