Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictionResult
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictionResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Represents a line of JSONL in the batch prediction output file.
Instance Attribute Summary collapse
-
#error ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictionResultError
The error result.
-
#instance ⇒ Hash<String,Object>
User's input instance.
-
#key ⇒ String
Optional user-provided key from the input instance.
-
#prediction ⇒ Object
The prediction result.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictionResult
constructor
A new instance of GoogleCloudAiplatformV1SchemaPredictionResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictionResult
Returns a new instance of GoogleCloudAiplatformV1SchemaPredictionResult.
37913 37914 37915 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37913 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictionResultError
The error result. Do not set prediction if this is set.
Corresponds to the JSON property error
37893 37894 37895 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37893 def error @error end |
#instance ⇒ Hash<String,Object>
User's input instance. Struct is used here instead of Any so that JsonFormat
does not append an extra "@type" field when we convert the proto to JSON.
Corresponds to the JSON property instance
37899 37900 37901 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37899 def instance @instance end |
#key ⇒ String
Optional user-provided key from the input instance.
Corresponds to the JSON property key
37904 37905 37906 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37904 def key @key end |
#prediction ⇒ Object
The prediction result. Value is used here instead of Any so that JsonFormat
does not append an extra "@type" field when we convert the proto to JSON and
so we can represent array of objects. Do not set error if this is set.
Corresponds to the JSON property prediction
37911 37912 37913 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37911 def prediction @prediction end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37918 37919 37920 37921 37922 37923 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37918 def update!(**args) @error = args[:error] if args.key?(:error) @instance = args[:instance] if args.key?(:instance) @key = args[:key] if args.key?(:key) @prediction = args[:prediction] if args.key?(:prediction) end |