Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictionResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents a line of JSONL in the batch prediction output file.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictionResult

Returns a new instance of GoogleCloudAiplatformV1SchemaPredictionResult.



36176
36177
36178
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36176

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictionResultError

The error result. Do not set prediction if this is set. Corresponds to the JSON property error



36156
36157
36158
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36156

def error
  @error
end

#instanceHash<String,Object>

User's input instance. Struct is used here instead of Any so that JsonFormat does not append an extra "@type" field when we convert the proto to JSON. Corresponds to the JSON property instance

Returns:

  • (Hash<String,Object>)


36162
36163
36164
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36162

def instance
  @instance
end

#keyString

Optional user-provided key from the input instance. Corresponds to the JSON property key

Returns:

  • (String)


36167
36168
36169
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36167

def key
  @key
end

#predictionObject

The prediction result. Value is used here instead of Any so that JsonFormat does not append an extra "@type" field when we convert the proto to JSON and so we can represent array of objects. Do not set error if this is set. Corresponds to the JSON property prediction

Returns:

  • (Object)


36174
36175
36176
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36174

def prediction
  @prediction
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36181
36182
36183
36184
36185
36186
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36181

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @instance = args[:instance] if args.key?(:instance)
  @key = args[:key] if args.key?(:key)
  @prediction = args[:prediction] if args.key?(:prediction)
end