Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictionResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents a line of JSONL in the batch prediction output file.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPredictionResult

Returns a new instance of GoogleCloudAiplatformV1SchemaPredictionResult.



21400
21401
21402
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21400

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictionResultError

The error result. Do not set prediction if this is set. Corresponds to the JSON property error



21380
21381
21382
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21380

def error
  @error
end

#instanceHash<String,Object>

User's input instance. Struct is used here instead of Any so that JsonFormat does not append an extra "@type" field when we convert the proto to JSON. Corresponds to the JSON property instance

Returns:

  • (Hash<String,Object>)


21386
21387
21388
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21386

def instance
  @instance
end

#keyString

Optional user-provided key from the input instance. Corresponds to the JSON property key

Returns:

  • (String)


21391
21392
21393
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21391

def key
  @key
end

#predictionObject

The prediction result. Value is used here instead of Any so that JsonFormat does not append an extra "@type" field when we convert the proto to JSON and so we can represent array of objects. Do not set error if this is set. Corresponds to the JSON property prediction

Returns:

  • (Object)


21398
21399
21400
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21398

def prediction
  @prediction
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21405
21406
21407
21408
21409
21410
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21405

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @instance = args[:instance] if args.key?(:instance)
  @key = args[:key] if args.key?(:key)
  @prediction = args[:prediction] if args.key?(:prediction)
end