Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptApiSchema
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptApiSchema
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The A2 schema of a prompt.
Instance Attribute Summary collapse
-
#api_schema_version ⇒ String
The Schema version that represents changes to the API behavior.
-
#executions ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptInstancePromptExecution>
A list of execution instances for constructing a ready-to-use prompt.
-
#multimodal_prompt ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecMultimodalPrompt
Prompt variation that embeds preambles to prompt string.
-
#structured_prompt ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecStructuredPrompt
Prompt variation that stores preambles in separate fields.
-
#translation_prompt ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecTranslationPrompt
Prompt variation for Translation use case.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPromptApiSchema
constructor
A new instance of GoogleCloudAiplatformV1SchemaPromptApiSchema.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPromptApiSchema
Returns a new instance of GoogleCloudAiplatformV1SchemaPromptApiSchema.
41217 41218 41219 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41217 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_schema_version ⇒ String
The Schema version that represents changes to the API behavior.
Corresponds to the JSON property apiSchemaVersion
41195 41196 41197 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41195 def api_schema_version @api_schema_version end |
#executions ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptInstancePromptExecution>
A list of execution instances for constructing a ready-to-use prompt.
Corresponds to the JSON property executions
41200 41201 41202 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41200 def executions @executions end |
#multimodal_prompt ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecMultimodalPrompt
Prompt variation that embeds preambles to prompt string.
Corresponds to the JSON property multimodalPrompt
41205 41206 41207 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41205 def multimodal_prompt @multimodal_prompt end |
#structured_prompt ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecStructuredPrompt
Prompt variation that stores preambles in separate fields.
Corresponds to the JSON property structuredPrompt
41210 41211 41212 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41210 def structured_prompt @structured_prompt end |
#translation_prompt ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecTranslationPrompt
Prompt variation for Translation use case.
Corresponds to the JSON property translationPrompt
41215 41216 41217 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41215 def translation_prompt @translation_prompt end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41222 41223 41224 41225 41226 41227 41228 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41222 def update!(**args) @api_schema_version = args[:api_schema_version] if args.key?(:api_schema_version) @executions = args[:executions] if args.key?(:executions) @multimodal_prompt = args[:multimodal_prompt] if args.key?(:multimodal_prompt) @structured_prompt = args[:structured_prompt] if args.key?(:structured_prompt) @translation_prompt = args[:translation_prompt] if args.key?(:translation_prompt) end |