Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptApiSchema

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The A2 schema of a prompt.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPromptApiSchema

Returns a new instance of GoogleCloudAiplatformV1SchemaPromptApiSchema.



38153
38154
38155
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38153

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_schema_versionString

The Schema version that represents changes to the API behavior. Corresponds to the JSON property apiSchemaVersion

Returns:

  • (String)


38131
38132
38133
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38131

def api_schema_version
  @api_schema_version
end

#executionsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptInstancePromptExecution>

A list of execution instances for constructing a ready-to-use prompt. Corresponds to the JSON property executions



38136
38137
38138
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38136

def executions
  @executions
end

#multimodal_promptGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecMultimodalPrompt

Prompt variation that embeds preambles to prompt string. Corresponds to the JSON property multimodalPrompt



38141
38142
38143
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38141

def multimodal_prompt
  @multimodal_prompt
end

#structured_promptGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecStructuredPrompt

Prompt variation that stores preambles in separate fields. Corresponds to the JSON property structuredPrompt



38146
38147
38148
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38146

def structured_prompt
  @structured_prompt
end

#translation_promptGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecTranslationPrompt

Prompt variation for Translation use case. Corresponds to the JSON property translationPrompt



38151
38152
38153
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38151

def translation_prompt
  @translation_prompt
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38158
38159
38160
38161
38162
38163
38164
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38158

def update!(**args)
  @api_schema_version = args[:api_schema_version] if args.key?(:api_schema_version)
  @executions = args[:executions] if args.key?(:executions)
  @multimodal_prompt = args[:multimodal_prompt] if args.key?(:multimodal_prompt)
  @structured_prompt = args[:structured_prompt] if args.key?(:structured_prompt)
  @translation_prompt = args[:translation_prompt] if args.key?(:translation_prompt)
end