Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptApiSchema

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The A2 schema of a prompt.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPromptApiSchema

Returns a new instance of GoogleCloudAiplatformV1SchemaPromptApiSchema.



35959
35960
35961
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35959

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_schema_versionString

The Schema version that represents changes to the API behavior. Corresponds to the JSON property apiSchemaVersion

Returns:

  • (String)


35937
35938
35939
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35937

def api_schema_version
  @api_schema_version
end

#executionsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptInstancePromptExecution>

A list of execution instances for constructing a ready-to-use prompt. Corresponds to the JSON property executions



35942
35943
35944
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35942

def executions
  @executions
end

#multimodal_promptGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecMultimodalPrompt

Prompt variation that embeds preambles to prompt string. Corresponds to the JSON property multimodalPrompt



35947
35948
35949
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35947

def multimodal_prompt
  @multimodal_prompt
end

#structured_promptGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecStructuredPrompt

Prompt variation that stores preambles in separate fields. Corresponds to the JSON property structuredPrompt



35952
35953
35954
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35952

def structured_prompt
  @structured_prompt
end

#translation_promptGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecTranslationPrompt

Prompt variation for Translation use case. Corresponds to the JSON property translationPrompt



35957
35958
35959
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35957

def translation_prompt
  @translation_prompt
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35964
35965
35966
35967
35968
35969
35970
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35964

def update!(**args)
  @api_schema_version = args[:api_schema_version] if args.key?(:api_schema_version)
  @executions = args[:executions] if args.key?(:executions)
  @multimodal_prompt = args[:multimodal_prompt] if args.key?(:multimodal_prompt)
  @structured_prompt = args[:structured_prompt] if args.key?(:structured_prompt)
  @translation_prompt = args[:translation_prompt] if args.key?(:translation_prompt)
end