Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptApiSchema

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The A2 schema of a prompt.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPromptApiSchema

Returns a new instance of GoogleCloudAiplatformV1SchemaPromptApiSchema.



30096
30097
30098
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30096

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_schema_versionString

The Schema version that represents changes to the API behavior. Corresponds to the JSON property apiSchemaVersion

Returns:

  • (String)


30074
30075
30076
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30074

def api_schema_version
  @api_schema_version
end

#executionsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptInstancePromptExecution>

A list of execution instances for constructing a ready-to-use prompt. Corresponds to the JSON property executions



30079
30080
30081
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30079

def executions
  @executions
end

#multimodal_promptGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecMultimodalPrompt

Prompt variation that embeds preambles to prompt string. Corresponds to the JSON property multimodalPrompt



30084
30085
30086
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30084

def multimodal_prompt
  @multimodal_prompt
end

#structured_promptGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecStructuredPrompt

Prompt variation that stores preambles in separate fields. Corresponds to the JSON property structuredPrompt



30089
30090
30091
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30089

def structured_prompt
  @structured_prompt
end

#translation_promptGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecTranslationPrompt

Prompt variation for Translation use case. Corresponds to the JSON property translationPrompt



30094
30095
30096
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30094

def translation_prompt
  @translation_prompt
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30101
30102
30103
30104
30105
30106
30107
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30101

def update!(**args)
  @api_schema_version = args[:api_schema_version] if args.key?(:api_schema_version)
  @executions = args[:executions] if args.key?(:executions)
  @multimodal_prompt = args[:multimodal_prompt] if args.key?(:multimodal_prompt)
  @structured_prompt = args[:structured_prompt] if args.key?(:structured_prompt)
  @translation_prompt = args[:translation_prompt] if args.key?(:translation_prompt)
end