Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecAppBuilderData
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecAppBuilderData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Defines data for an application builder.
Instance Attribute Summary collapse
-
#code_repository_state ⇒ String
Serialized state of the code repository.
-
#framework ⇒ String
Optional.
-
#linked_resources ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecAppBuilderDataLinkedResource>
Linked resources attached to the application by the user.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPromptSpecAppBuilderData
constructor
A new instance of GoogleCloudAiplatformV1SchemaPromptSpecAppBuilderData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPromptSpecAppBuilderData
Returns a new instance of GoogleCloudAiplatformV1SchemaPromptSpecAppBuilderData.
38104 38105 38106 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38104 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code_repository_state ⇒ String
Serialized state of the code repository. This string will typically contain a
JSON representation of the UI's CodeRepositoryService state (files, folders,
content, and any metadata). The UI is responsible for serialization and
deserialization.
Corresponds to the JSON property codeRepositoryState
38092 38093 38094 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38092 def code_repository_state @code_repository_state end |
#framework ⇒ String
Optional. Framework used to build the application.
Corresponds to the JSON property framework
38097 38098 38099 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38097 def framework @framework end |
#linked_resources ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecAppBuilderDataLinkedResource>
Linked resources attached to the application by the user.
Corresponds to the JSON property linkedResources
38102 38103 38104 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38102 def linked_resources @linked_resources end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38109 38110 38111 38112 38113 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38109 def update!(**args) @code_repository_state = args[:code_repository_state] if args.key?(:code_repository_state) @framework = args[:framework] if args.key?(:framework) @linked_resources = args[:linked_resources] if args.key?(:linked_resources) end |