Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecAppBuilderData
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecAppBuilderData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Defines data for an application builder.
Instance Attribute Summary collapse
-
#code_repository_state ⇒ String
Serialized state of the code repository.
-
#framework ⇒ String
Optional.
-
#linked_resources ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecAppBuilderDataLinkedResource>
Linked resources attached to the application by the user.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPromptSpecAppBuilderData
constructor
A new instance of GoogleCloudAiplatformV1SchemaPromptSpecAppBuilderData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPromptSpecAppBuilderData
Returns a new instance of GoogleCloudAiplatformV1SchemaPromptSpecAppBuilderData.
38054 38055 38056 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38054 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code_repository_state ⇒ String
Serialized state of the code repository. This string will typically contain a
JSON representation of the UI's CodeRepositoryService state (files, folders,
content, and any metadata). The UI is responsible for serialization and
deserialization.
Corresponds to the JSON property codeRepositoryState
38042 38043 38044 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38042 def code_repository_state @code_repository_state end |
#framework ⇒ String
Optional. Framework used to build the application.
Corresponds to the JSON property framework
38047 38048 38049 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38047 def framework @framework end |
#linked_resources ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecAppBuilderDataLinkedResource>
Linked resources attached to the application by the user.
Corresponds to the JSON property linkedResources
38052 38053 38054 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38052 def linked_resources @linked_resources end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38059 38060 38061 38062 38063 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38059 def update!(**args) @code_repository_state = args[:code_repository_state] if args.key?(:code_repository_state) @framework = args[:framework] if args.key?(:framework) @linked_resources = args[:linked_resources] if args.key?(:linked_resources) end |