Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecAppBuilderData
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecAppBuilderData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Defines data for an application builder.
Instance Attribute Summary collapse
-
#code_repository_state ⇒ String
Serialized state of the code repository.
-
#framework ⇒ String
Optional.
-
#linked_resources ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecAppBuilderDataLinkedResource>
Linked resources attached to the application by the user.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPromptSpecAppBuilderData
constructor
A new instance of GoogleCloudAiplatformV1SchemaPromptSpecAppBuilderData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPromptSpecAppBuilderData
Returns a new instance of GoogleCloudAiplatformV1SchemaPromptSpecAppBuilderData.
36033 36034 36035 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36033 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code_repository_state ⇒ String
Serialized state of the code repository. This string will typically contain a
JSON representation of the UI's CodeRepositoryService state (files, folders,
content, and any metadata). The UI is responsible for serialization and
deserialization.
Corresponds to the JSON property codeRepositoryState
36021 36022 36023 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36021 def code_repository_state @code_repository_state end |
#framework ⇒ String
Optional. Framework used to build the application.
Corresponds to the JSON property framework
36026 36027 36028 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36026 def framework @framework end |
#linked_resources ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecAppBuilderDataLinkedResource>
Linked resources attached to the application by the user.
Corresponds to the JSON property linkedResources
36031 36032 36033 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36031 def linked_resources @linked_resources end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36038 36039 36040 36041 36042 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36038 def update!(**args) @code_repository_state = args[:code_repository_state] if args.key?(:code_repository_state) @framework = args[:framework] if args.key?(:framework) @linked_resources = args[:linked_resources] if args.key?(:linked_resources) end |