Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecPartList
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecPartList
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A list of elements and information that make up a portion of prompt.
Instance Attribute Summary collapse
-
#parts ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Part>
A list of elements that can be part of a prompt.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPromptSpecPartList
constructor
A new instance of GoogleCloudAiplatformV1SchemaPromptSpecPartList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPromptSpecPartList
Returns a new instance of GoogleCloudAiplatformV1SchemaPromptSpecPartList.
39712 39713 39714 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39712 def initialize(**args) update!(**args) end |
Instance Attribute Details
#parts ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Part>
A list of elements that can be part of a prompt.
Corresponds to the JSON property parts
39710 39711 39712 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39710 def parts @parts end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39717 39718 39719 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39717 def update!(**args) @parts = args[:parts] if args.key?(:parts) end |