Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecPartList

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A list of elements and information that make up a portion of prompt.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPromptSpecPartList

Returns a new instance of GoogleCloudAiplatformV1SchemaPromptSpecPartList.



36395
36396
36397
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36395

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#partsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Part>

A list of elements that can be part of a prompt. Corresponds to the JSON property parts



36393
36394
36395
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36393

def parts
  @parts
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36400
36401
36402
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36400

def update!(**args)
  @parts = args[:parts] if args.key?(:parts)
end