Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecPartList

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A list of elements and information that make up a portion of prompt.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPromptSpecPartList

Returns a new instance of GoogleCloudAiplatformV1SchemaPromptSpecPartList.



29245
29246
29247
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29245

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#partsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Part>

A list of elements that can be part of a prompt. Corresponds to the JSON property parts



29243
29244
29245
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29243

def parts
  @parts
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29250
29251
29252
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29250

def update!(**args)
  @parts = args[:parts] if args.key?(:parts)
end