Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecPartList

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A list of elements and information that make up a portion of prompt.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPromptSpecPartList

Returns a new instance of GoogleCloudAiplatformV1SchemaPromptSpecPartList.



28576
28577
28578
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28576

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#partsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Part>

A list of elements that can be part of a prompt. Corresponds to the JSON property parts



28574
28575
28576
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28574

def parts
  @parts
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28581
28582
28583
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28581

def update!(**args)
  @parts = args[:parts] if args.key?(:parts)
end