Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecPromptMessage
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecPromptMessage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The prompt message that aligns with the prompt message in google.cloud. aiplatform.master.GenerateContentRequest.
Instance Attribute Summary collapse
-
#contents ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content>
The content of the current conversation with the model.
-
#generation_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfig
Configuration for content generation.
-
#model ⇒ String
The model name.
-
#safety_settings ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetySetting>
Per request settings for blocking unsafe content.
-
#system_instruction ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content
The structured data content of a message.
-
#tool_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolConfig
Tool config.
-
#tools ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tool>
A list of
Toolsthe model may use to generate the next response.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPromptSpecPromptMessage
constructor
A new instance of GoogleCloudAiplatformV1SchemaPromptSpecPromptMessage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPromptSpecPromptMessage
Returns a new instance of GoogleCloudAiplatformV1SchemaPromptSpecPromptMessage.
39772 39773 39774 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39772 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contents ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content>
The content of the current conversation with the model. For single-turn
queries, this is a single instance. For multi-turn queries, this is a repeated
field that contains conversation history + latest request.
Corresponds to the JSON property contents
39732 39733 39734 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39732 def contents @contents end |
#generation_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfig
Configuration for content generation. This message contains all the parameters
that control how the model generates content. It allows you to influence the
randomness, length, and structure of the output.
Corresponds to the JSON property generationConfig
39739 39740 39741 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39739 def generation_config @generation_config end |
#model ⇒ String
The model name.
Corresponds to the JSON property model
39744 39745 39746 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39744 def model @model end |
#safety_settings ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetySetting>
Per request settings for blocking unsafe content. Enforced on
GenerateContentResponse.candidates.
Corresponds to the JSON property safetySettings
39750 39751 39752 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39750 def safety_settings @safety_settings end |
#system_instruction ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content
The structured data content of a message. A Content message contains a role
field, which indicates the producer of the content, and a parts field, which
contains the multi-part data of the message.
Corresponds to the JSON property systemInstruction
39757 39758 39759 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39757 def system_instruction @system_instruction end |
#tool_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolConfig
Tool config. This config is shared for all tools provided in the request.
Corresponds to the JSON property toolConfig
39762 39763 39764 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39762 def tool_config @tool_config end |
#tools ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tool>
A list of Tools the model may use to generate the next response. A Tool is
a piece of code that enables the system to interact with external systems to
perform an action, or set of actions, outside of knowledge and scope of the
model.
Corresponds to the JSON property tools
39770 39771 39772 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39770 def tools @tools end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39777 39778 39779 39780 39781 39782 39783 39784 39785 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39777 def update!(**args) @contents = args[:contents] if args.key?(:contents) @generation_config = args[:generation_config] if args.key?(:generation_config) @model = args[:model] if args.key?(:model) @safety_settings = args[:safety_settings] if args.key?(:safety_settings) @system_instruction = args[:system_instruction] if args.key?(:system_instruction) @tool_config = args[:tool_config] if args.key?(:tool_config) @tools = args[:tools] if args.key?(:tools) end |