Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecPromptMessage
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecPromptMessage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The prompt message that aligns with the prompt message in google.cloud. aiplatform.master.GenerateContentRequest.
Instance Attribute Summary collapse
-
#contents ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content>
The content of the current conversation with the model.
-
#generation_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfig
Configuration for content generation.
-
#model ⇒ String
The model name.
-
#safety_settings ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetySetting>
Per request settings for blocking unsafe content.
-
#system_instruction ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content
The structured data content of a message.
-
#tool_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolConfig
Tool config.
-
#tools ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tool>
A list of
Toolsthe model may use to generate the next response.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPromptSpecPromptMessage
constructor
A new instance of GoogleCloudAiplatformV1SchemaPromptSpecPromptMessage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPromptSpecPromptMessage
Returns a new instance of GoogleCloudAiplatformV1SchemaPromptSpecPromptMessage.
38263 38264 38265 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38263 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contents ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content>
The content of the current conversation with the model. For single-turn
queries, this is a single instance. For multi-turn queries, this is a repeated
field that contains conversation history + latest request.
Corresponds to the JSON property contents
38223 38224 38225 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38223 def contents @contents end |
#generation_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfig
Configuration for content generation. This message contains all the parameters
that control how the model generates content. It allows you to influence the
randomness, length, and structure of the output.
Corresponds to the JSON property generationConfig
38230 38231 38232 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38230 def generation_config @generation_config end |
#model ⇒ String
The model name.
Corresponds to the JSON property model
38235 38236 38237 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38235 def model @model end |
#safety_settings ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetySetting>
Per request settings for blocking unsafe content. Enforced on
GenerateContentResponse.candidates.
Corresponds to the JSON property safetySettings
38241 38242 38243 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38241 def safety_settings @safety_settings end |
#system_instruction ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content
The structured data content of a message. A Content message contains a role
field, which indicates the producer of the content, and a parts field, which
contains the multi-part data of the message.
Corresponds to the JSON property systemInstruction
38248 38249 38250 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38248 def system_instruction @system_instruction end |
#tool_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolConfig
Tool config. This config is shared for all tools provided in the request.
Corresponds to the JSON property toolConfig
38253 38254 38255 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38253 def tool_config @tool_config end |
#tools ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tool>
A list of Tools the model may use to generate the next response. A Tool is
a piece of code that enables the system to interact with external systems to
perform an action, or set of actions, outside of knowledge and scope of the
model.
Corresponds to the JSON property tools
38261 38262 38263 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38261 def tools @tools end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38268 38269 38270 38271 38272 38273 38274 38275 38276 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38268 def update!(**args) @contents = args[:contents] if args.key?(:contents) @generation_config = args[:generation_config] if args.key?(:generation_config) @model = args[:model] if args.key?(:model) @safety_settings = args[:safety_settings] if args.key?(:safety_settings) @system_instruction = args[:system_instruction] if args.key?(:system_instruction) @tool_config = args[:tool_config] if args.key?(:tool_config) @tools = args[:tools] if args.key?(:tools) end |