Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecPromptMessage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The prompt message that aligns with the prompt message in google.cloud. aiplatform.master.GenerateContentRequest.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPromptSpecPromptMessage

Returns a new instance of GoogleCloudAiplatformV1SchemaPromptSpecPromptMessage.



38213
38214
38215
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38213

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content>

The content of the current conversation with the model. For single-turn queries, this is a single instance. For multi-turn queries, this is a repeated field that contains conversation history + latest request. Corresponds to the JSON property contents



38173
38174
38175
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38173

def contents
  @contents
end

#generation_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfig

Configuration for content generation. This message contains all the parameters that control how the model generates content. It allows you to influence the randomness, length, and structure of the output. Corresponds to the JSON property generationConfig



38180
38181
38182
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38180

def generation_config
  @generation_config
end

#modelString

The model name. Corresponds to the JSON property model

Returns:

  • (String)


38185
38186
38187
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38185

def model
  @model
end

#safety_settingsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetySetting>

Per request settings for blocking unsafe content. Enforced on GenerateContentResponse.candidates. Corresponds to the JSON property safetySettings



38191
38192
38193
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38191

def safety_settings
  @safety_settings
end

#system_instructionGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Content

The structured data content of a message. A Content message contains a role field, which indicates the producer of the content, and a parts field, which contains the multi-part data of the message. Corresponds to the JSON property systemInstruction



38198
38199
38200
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38198

def system_instruction
  @system_instruction
end

#tool_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolConfig

Tool config. This config is shared for all tools provided in the request. Corresponds to the JSON property toolConfig



38203
38204
38205
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38203

def tool_config
  @tool_config
end

#toolsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tool>

A list of Tools the model may use to generate the next response. A Tool is a piece of code that enables the system to interact with external systems to perform an action, or set of actions, outside of knowledge and scope of the model. Corresponds to the JSON property tools



38211
38212
38213
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38211

def tools
  @tools
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38218
38219
38220
38221
38222
38223
38224
38225
38226
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38218

def update!(**args)
  @contents = args[:contents] if args.key?(:contents)
  @generation_config = args[:generation_config] if args.key?(:generation_config)
  @model = args[:model] if args.key?(:model)
  @safety_settings = args[:safety_settings] if args.key?(:safety_settings)
  @system_instruction = args[:system_instruction] if args.key?(:system_instruction)
  @tool_config = args[:tool_config] if args.key?(:tool_config)
  @tools = args[:tools] if args.key?(:tools)
end