Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecPromptMessage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The prompt message that aligns with the prompt message in google.cloud. aiplatform.master.GenerateContentRequest.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPromptSpecPromptMessage

Returns a new instance of GoogleCloudAiplatformV1SchemaPromptSpecPromptMessage.



30443
30444
30445
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30443

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content>

The content of the current conversation with the model. For single-turn queries, this is a single instance. For multi-turn queries, this is a repeated field that contains conversation history + latest request. Corresponds to the JSON property contents



30404
30405
30406
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30404

def contents
  @contents
end

#generation_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfig

Generation config. Corresponds to the JSON property generationConfig



30409
30410
30411
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30409

def generation_config
  @generation_config
end

#modelString

The model name. Corresponds to the JSON property model

Returns:

  • (String)


30414
30415
30416
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30414

def model
  @model
end

#safety_settingsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetySetting>

Per request settings for blocking unsafe content. Enforced on GenerateContentResponse.candidates. Corresponds to the JSON property safetySettings



30420
30421
30422
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30420

def safety_settings
  @safety_settings
end

#system_instructionGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Content

The base structured datatype containing multi-part content of a message. A Content includes a role field designating the producer of the Content and a parts field containing multi-part data that contains the content of the message turn. Corresponds to the JSON property systemInstruction



30428
30429
30430
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30428

def system_instruction
  @system_instruction
end

#tool_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolConfig

Tool config. This config is shared for all tools provided in the request. Corresponds to the JSON property toolConfig



30433
30434
30435
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30433

def tool_config
  @tool_config
end

#toolsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tool>

A list of Tools the model may use to generate the next response. A Tool is a piece of code that enables the system to interact with external systems to perform an action, or set of actions, outside of knowledge and scope of the model. Corresponds to the JSON property tools



30441
30442
30443
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30441

def tools
  @tools
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30448
30449
30450
30451
30452
30453
30454
30455
30456
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30448

def update!(**args)
  @contents = args[:contents] if args.key?(:contents)
  @generation_config = args[:generation_config] if args.key?(:generation_config)
  @model = args[:model] if args.key?(:model)
  @safety_settings = args[:safety_settings] if args.key?(:safety_settings)
  @system_instruction = args[:system_instruction] if args.key?(:system_instruction)
  @tool_config = args[:tool_config] if args.key?(:tool_config)
  @tools = args[:tools] if args.key?(:tools)
end