Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecPromptMessage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The prompt message that aligns with the prompt message in google.cloud. aiplatform.master.GenerateContentRequest.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPromptSpecPromptMessage

Returns a new instance of GoogleCloudAiplatformV1SchemaPromptSpecPromptMessage.



29086
29087
29088
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29086

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content>

The content of the current conversation with the model. For single-turn queries, this is a single instance. For multi-turn queries, this is a repeated field that contains conversation history + latest request. Corresponds to the JSON property contents



29047
29048
29049
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29047

def contents
  @contents
end

#generation_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GenerationConfig

Generation config. Corresponds to the JSON property generationConfig



29052
29053
29054
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29052

def generation_config
  @generation_config
end

#modelString

The model name. Corresponds to the JSON property model

Returns:

  • (String)


29057
29058
29059
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29057

def model
  @model
end

#safety_settingsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SafetySetting>

Per request settings for blocking unsafe content. Enforced on GenerateContentResponse.candidates. Corresponds to the JSON property safetySettings



29063
29064
29065
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29063

def safety_settings
  @safety_settings
end

#system_instructionGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Content

The base structured datatype containing multi-part content of a message. A Content includes a role field designating the producer of the Content and a parts field containing multi-part data that contains the content of the message turn. Corresponds to the JSON property systemInstruction



29071
29072
29073
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29071

def system_instruction
  @system_instruction
end

#tool_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolConfig

Tool config. This config is shared for all tools provided in the request. Corresponds to the JSON property toolConfig



29076
29077
29078
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29076

def tool_config
  @tool_config
end

#toolsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tool>

A list of Tools the model may use to generate the next response. A Tool is a piece of code that enables the system to interact with external systems to perform an action, or set of actions, outside of knowledge and scope of the model. Corresponds to the JSON property tools



29084
29085
29086
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29084

def tools
  @tools
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29091
29092
29093
29094
29095
29096
29097
29098
29099
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29091

def update!(**args)
  @contents = args[:contents] if args.key?(:contents)
  @generation_config = args[:generation_config] if args.key?(:generation_config)
  @model = args[:model] if args.key?(:model)
  @safety_settings = args[:safety_settings] if args.key?(:safety_settings)
  @system_instruction = args[:system_instruction] if args.key?(:system_instruction)
  @tool_config = args[:tool_config] if args.key?(:tool_config)
  @tools = args[:tools] if args.key?(:tools)
end