Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecStructuredPrompt
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecStructuredPrompt
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Prompt variation that stores preambles in separate fields.
Instance Attribute Summary collapse
-
#app_builder_data ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecAppBuilderData
Defines data for an application builder.
-
#context ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content
The structured data content of a message.
-
#examples ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecPartList>
Preamble: A set of examples for expected model response.
-
#infill_prefix ⇒ String
Preamble: For infill prompt, the prefix before expected model response.
-
#infill_suffix ⇒ String
Preamble: For infill prompt, the suffix after expected model response.
-
#input_prefixes ⇒ Array<String>
Preamble: The input prefixes before each example input.
-
#interaction_data ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecInteractionData
Defines data for an interaction prompt.
-
#output_prefixes ⇒ Array<String>
Preamble: The output prefixes before each example output.
-
#prediction_inputs ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecPartList>
Preamble: The input test data for prediction.
-
#prompt_message ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecPromptMessage
The prompt message that aligns with the prompt message in google.cloud.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPromptSpecStructuredPrompt
constructor
A new instance of GoogleCloudAiplatformV1SchemaPromptSpecStructuredPrompt.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPromptSpecStructuredPrompt
Returns a new instance of GoogleCloudAiplatformV1SchemaPromptSpecStructuredPrompt.
38381 38382 38383 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38381 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_builder_data ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecAppBuilderData
Defines data for an application builder.
Corresponds to the JSON property appBuilderData
38330 38331 38332 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38330 def app_builder_data @app_builder_data end |
#context ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content
The structured data content of a message. A Content message contains a role
field, which indicates the producer of the content, and a parts field, which
contains the multi-part data of the message.
Corresponds to the JSON property context
38337 38338 38339 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38337 def context @context end |
#examples ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecPartList>
Preamble: A set of examples for expected model response.
Corresponds to the JSON property examples
38342 38343 38344 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38342 def examples @examples end |
#infill_prefix ⇒ String
Preamble: For infill prompt, the prefix before expected model response.
Corresponds to the JSON property infillPrefix
38347 38348 38349 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38347 def infill_prefix @infill_prefix end |
#infill_suffix ⇒ String
Preamble: For infill prompt, the suffix after expected model response.
Corresponds to the JSON property infillSuffix
38352 38353 38354 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38352 def infill_suffix @infill_suffix end |
#input_prefixes ⇒ Array<String>
Preamble: The input prefixes before each example input.
Corresponds to the JSON property inputPrefixes
38357 38358 38359 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38357 def input_prefixes @input_prefixes end |
#interaction_data ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecInteractionData
Defines data for an interaction prompt.
Corresponds to the JSON property interactionData
38362 38363 38364 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38362 def interaction_data @interaction_data end |
#output_prefixes ⇒ Array<String>
Preamble: The output prefixes before each example output.
Corresponds to the JSON property outputPrefixes
38367 38368 38369 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38367 def output_prefixes @output_prefixes end |
#prediction_inputs ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecPartList>
Preamble: The input test data for prediction. Each PartList in this field
represents one text-only input set for a single model request.
Corresponds to the JSON property predictionInputs
38373 38374 38375 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38373 def prediction_inputs @prediction_inputs end |
#prompt_message ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecPromptMessage
The prompt message that aligns with the prompt message in google.cloud.
aiplatform.master.GenerateContentRequest.
Corresponds to the JSON property promptMessage
38379 38380 38381 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38379 def @prompt_message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38386 38387 38388 38389 38390 38391 38392 38393 38394 38395 38396 38397 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38386 def update!(**args) @app_builder_data = args[:app_builder_data] if args.key?(:app_builder_data) @context = args[:context] if args.key?(:context) @examples = args[:examples] if args.key?(:examples) @infill_prefix = args[:infill_prefix] if args.key?(:infill_prefix) @infill_suffix = args[:infill_suffix] if args.key?(:infill_suffix) @input_prefixes = args[:input_prefixes] if args.key?(:input_prefixes) @interaction_data = args[:interaction_data] if args.key?(:interaction_data) @output_prefixes = args[:output_prefixes] if args.key?(:output_prefixes) @prediction_inputs = args[:prediction_inputs] if args.key?(:prediction_inputs) @prompt_message = args[:prompt_message] if args.key?(:prompt_message) end |