Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecStructuredPrompt
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecStructuredPrompt
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Prompt variation that stores preambles in separate fields.
Instance Attribute Summary collapse
-
#app_builder_data ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecAppBuilderData
Defines data for an application builder.
-
#context ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content
The structured data content of a message.
-
#examples ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecPartList>
Preamble: A set of examples for expected model response.
-
#infill_prefix ⇒ String
Preamble: For infill prompt, the prefix before expected model response.
-
#infill_suffix ⇒ String
Preamble: For infill prompt, the suffix after expected model response.
-
#input_prefixes ⇒ Array<String>
Preamble: The input prefixes before each example input.
-
#output_prefixes ⇒ Array<String>
Preamble: The output prefixes before each example output.
-
#prediction_inputs ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecPartList>
Preamble: The input test data for prediction.
-
#prompt_message ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecPromptMessage
The prompt message that aligns with the prompt message in google.cloud.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPromptSpecStructuredPrompt
constructor
A new instance of GoogleCloudAiplatformV1SchemaPromptSpecStructuredPrompt.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPromptSpecStructuredPrompt
Returns a new instance of GoogleCloudAiplatformV1SchemaPromptSpecStructuredPrompt.
36568 36569 36570 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36568 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_builder_data ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecAppBuilderData
Defines data for an application builder.
Corresponds to the JSON property appBuilderData
36522 36523 36524 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36522 def app_builder_data @app_builder_data end |
#context ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content
The structured data content of a message. A Content message contains a role
field, which indicates the producer of the content, and a parts field, which
contains the multi-part data of the message.
Corresponds to the JSON property context
36529 36530 36531 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36529 def context @context end |
#examples ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecPartList>
Preamble: A set of examples for expected model response.
Corresponds to the JSON property examples
36534 36535 36536 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36534 def examples @examples end |
#infill_prefix ⇒ String
Preamble: For infill prompt, the prefix before expected model response.
Corresponds to the JSON property infillPrefix
36539 36540 36541 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36539 def infill_prefix @infill_prefix end |
#infill_suffix ⇒ String
Preamble: For infill prompt, the suffix after expected model response.
Corresponds to the JSON property infillSuffix
36544 36545 36546 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36544 def infill_suffix @infill_suffix end |
#input_prefixes ⇒ Array<String>
Preamble: The input prefixes before each example input.
Corresponds to the JSON property inputPrefixes
36549 36550 36551 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36549 def input_prefixes @input_prefixes end |
#output_prefixes ⇒ Array<String>
Preamble: The output prefixes before each example output.
Corresponds to the JSON property outputPrefixes
36554 36555 36556 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36554 def output_prefixes @output_prefixes end |
#prediction_inputs ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecPartList>
Preamble: The input test data for prediction. Each PartList in this field
represents one text-only input set for a single model request.
Corresponds to the JSON property predictionInputs
36560 36561 36562 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36560 def prediction_inputs @prediction_inputs end |
#prompt_message ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecPromptMessage
The prompt message that aligns with the prompt message in google.cloud.
aiplatform.master.GenerateContentRequest.
Corresponds to the JSON property promptMessage
36566 36567 36568 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36566 def @prompt_message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36573 36574 36575 36576 36577 36578 36579 36580 36581 36582 36583 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36573 def update!(**args) @app_builder_data = args[:app_builder_data] if args.key?(:app_builder_data) @context = args[:context] if args.key?(:context) @examples = args[:examples] if args.key?(:examples) @infill_prefix = args[:infill_prefix] if args.key?(:infill_prefix) @infill_suffix = args[:infill_suffix] if args.key?(:infill_suffix) @input_prefixes = args[:input_prefixes] if args.key?(:input_prefixes) @output_prefixes = args[:output_prefixes] if args.key?(:output_prefixes) @prediction_inputs = args[:prediction_inputs] if args.key?(:prediction_inputs) @prompt_message = args[:prompt_message] if args.key?(:prompt_message) end |