Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecStructuredPrompt

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Prompt variation that stores preambles in separate fields.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPromptSpecStructuredPrompt

Returns a new instance of GoogleCloudAiplatformV1SchemaPromptSpecStructuredPrompt.



36284
36285
36286
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36284

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_builder_dataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecAppBuilderData

Defines data for an application builder. Corresponds to the JSON property appBuilderData



36238
36239
36240
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36238

def app_builder_data
  @app_builder_data
end

#contextGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Content

The structured data content of a message. A Content message contains a role field, which indicates the producer of the content, and a parts field, which contains the multi-part data of the message. Corresponds to the JSON property context



36245
36246
36247
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36245

def context
  @context
end

#examplesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecPartList>

Preamble: A set of examples for expected model response. Corresponds to the JSON property examples



36250
36251
36252
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36250

def examples
  @examples
end

#infill_prefixString

Preamble: For infill prompt, the prefix before expected model response. Corresponds to the JSON property infillPrefix

Returns:

  • (String)


36255
36256
36257
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36255

def infill_prefix
  @infill_prefix
end

#infill_suffixString

Preamble: For infill prompt, the suffix after expected model response. Corresponds to the JSON property infillSuffix

Returns:

  • (String)


36260
36261
36262
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36260

def infill_suffix
  @infill_suffix
end

#input_prefixesArray<String>

Preamble: The input prefixes before each example input. Corresponds to the JSON property inputPrefixes

Returns:

  • (Array<String>)


36265
36266
36267
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36265

def input_prefixes
  @input_prefixes
end

#output_prefixesArray<String>

Preamble: The output prefixes before each example output. Corresponds to the JSON property outputPrefixes

Returns:

  • (Array<String>)


36270
36271
36272
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36270

def output_prefixes
  @output_prefixes
end

#prediction_inputsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecPartList>

Preamble: The input test data for prediction. Each PartList in this field represents one text-only input set for a single model request. Corresponds to the JSON property predictionInputs



36276
36277
36278
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36276

def prediction_inputs
  @prediction_inputs
end

#prompt_messageGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecPromptMessage

The prompt message that aligns with the prompt message in google.cloud. aiplatform.master.GenerateContentRequest. Corresponds to the JSON property promptMessage



36282
36283
36284
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36282

def prompt_message
  @prompt_message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36289
36290
36291
36292
36293
36294
36295
36296
36297
36298
36299
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36289

def update!(**args)
  @app_builder_data = args[:app_builder_data] if args.key?(:app_builder_data)
  @context = args[:context] if args.key?(:context)
  @examples = args[:examples] if args.key?(:examples)
  @infill_prefix = args[:infill_prefix] if args.key?(:infill_prefix)
  @infill_suffix = args[:infill_suffix] if args.key?(:infill_suffix)
  @input_prefixes = args[:input_prefixes] if args.key?(:input_prefixes)
  @output_prefixes = args[:output_prefixes] if args.key?(:output_prefixes)
  @prediction_inputs = args[:prediction_inputs] if args.key?(:prediction_inputs)
  @prompt_message = args[:prompt_message] if args.key?(:prompt_message)
end