Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecTranslationPrompt
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecTranslationPrompt
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Prompt variation for Translation use case.
Instance Attribute Summary collapse
-
#example ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecTranslationExample
The translation example that contains reference sentences from various sources.
-
#option ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecTranslationOption
Optional settings for translation prompt.
-
#prompt_message ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecPromptMessage
The prompt message that aligns with the prompt message in google.cloud.
-
#source_language_code ⇒ String
The source language code.
-
#target_language_code ⇒ String
The target language code.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPromptSpecTranslationPrompt
constructor
A new instance of GoogleCloudAiplatformV1SchemaPromptSpecTranslationPrompt.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPromptSpecTranslationPrompt
Returns a new instance of GoogleCloudAiplatformV1SchemaPromptSpecTranslationPrompt.
31049 31050 31051 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31049 def initialize(**args) update!(**args) end |
Instance Attribute Details
#example ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecTranslationExample
The translation example that contains reference sentences from various sources.
Corresponds to the JSON property example
31026 31027 31028 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31026 def example @example end |
#option ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecTranslationOption
Optional settings for translation prompt.
Corresponds to the JSON property option
31031 31032 31033 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31031 def option @option end |
#prompt_message ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecPromptMessage
The prompt message that aligns with the prompt message in google.cloud.
aiplatform.master.GenerateContentRequest.
Corresponds to the JSON property promptMessage
31037 31038 31039 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31037 def @prompt_message end |
#source_language_code ⇒ String
The source language code.
Corresponds to the JSON property sourceLanguageCode
31042 31043 31044 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31042 def source_language_code @source_language_code end |
#target_language_code ⇒ String
The target language code.
Corresponds to the JSON property targetLanguageCode
31047 31048 31049 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31047 def target_language_code @target_language_code end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31054 31055 31056 31057 31058 31059 31060 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31054 def update!(**args) @example = args[:example] if args.key?(:example) @option = args[:option] if args.key?(:option) @prompt_message = args[:prompt_message] if args.key?(:prompt_message) @source_language_code = args[:source_language_code] if args.key?(:source_language_code) @target_language_code = args[:target_language_code] if args.key?(:target_language_code) end |