Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecTranslationPrompt

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Prompt variation for Translation use case.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPromptSpecTranslationPrompt

Returns a new instance of GoogleCloudAiplatformV1SchemaPromptSpecTranslationPrompt.



30159
30160
30161
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30159

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#exampleGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecTranslationExample

The translation example that contains reference sentences from various sources. Corresponds to the JSON property example



30136
30137
30138
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30136

def example
  @example
end

#optionGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecTranslationOption

Optional settings for translation prompt. Corresponds to the JSON property option



30141
30142
30143
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30141

def option
  @option
end

#prompt_messageGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecPromptMessage

The prompt message that aligns with the prompt message in google.cloud. aiplatform.master.GenerateContentRequest. Corresponds to the JSON property promptMessage



30147
30148
30149
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30147

def prompt_message
  @prompt_message
end

#source_language_codeString

The source language code. Corresponds to the JSON property sourceLanguageCode

Returns:

  • (String)


30152
30153
30154
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30152

def source_language_code
  @source_language_code
end

#target_language_codeString

The target language code. Corresponds to the JSON property targetLanguageCode

Returns:

  • (String)


30157
30158
30159
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30157

def target_language_code
  @target_language_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30164
30165
30166
30167
30168
30169
30170
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30164

def update!(**args)
  @example = args[:example] if args.key?(:example)
  @option = args[:option] if args.key?(:option)
  @prompt_message = args[:prompt_message] if args.key?(:prompt_message)
  @source_language_code = args[:source_language_code] if args.key?(:source_language_code)
  @target_language_code = args[:target_language_code] if args.key?(:target_language_code)
end