Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecTranslationPrompt
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecTranslationPrompt
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Prompt variation for Translation use case.
Instance Attribute Summary collapse
-
#example ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecTranslationExample
The translation example that contains reference sentences from various sources.
-
#option ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecTranslationOption
Optional settings for translation prompt.
-
#prompt_message ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecPromptMessage
The prompt message that aligns with the prompt message in google.cloud.
-
#source_language_code ⇒ String
The source language code.
-
#target_language_code ⇒ String
The target language code.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPromptSpecTranslationPrompt
constructor
A new instance of GoogleCloudAiplatformV1SchemaPromptSpecTranslationPrompt.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPromptSpecTranslationPrompt
Returns a new instance of GoogleCloudAiplatformV1SchemaPromptSpecTranslationPrompt.
29617 29618 29619 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29617 def initialize(**args) update!(**args) end |
Instance Attribute Details
#example ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecTranslationExample
The translation example that contains reference sentences from various sources.
Corresponds to the JSON property example
29594 29595 29596 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29594 def example @example end |
#option ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecTranslationOption
Optional settings for translation prompt.
Corresponds to the JSON property option
29599 29600 29601 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29599 def option @option end |
#prompt_message ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecPromptMessage
The prompt message that aligns with the prompt message in google.cloud.
aiplatform.master.GenerateContentRequest.
Corresponds to the JSON property promptMessage
29605 29606 29607 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29605 def @prompt_message end |
#source_language_code ⇒ String
The source language code.
Corresponds to the JSON property sourceLanguageCode
29610 29611 29612 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29610 def source_language_code @source_language_code end |
#target_language_code ⇒ String
The target language code.
Corresponds to the JSON property targetLanguageCode
29615 29616 29617 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29615 def target_language_code @target_language_code end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29622 29623 29624 29625 29626 29627 29628 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29622 def update!(**args) @example = args[:example] if args.key?(:example) @option = args[:option] if args.key?(:option) @prompt_message = args[:prompt_message] if args.key?(:prompt_message) @source_language_code = args[:source_language_code] if args.key?(:source_language_code) @target_language_code = args[:target_language_code] if args.key?(:target_language_code) end |