Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecTranslationPrompt
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecTranslationPrompt
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Prompt variation for Translation use case.
Instance Attribute Summary collapse
-
#example ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecTranslationExample
The translation example that contains reference sentences from various sources.
-
#option ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecTranslationOption
Optional settings for translation prompt.
-
#prompt_message ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecPromptMessage
The prompt message that aligns with the prompt message in google.cloud.
-
#source_language_code ⇒ String
The source language code.
-
#target_language_code ⇒ String
The target language code.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPromptSpecTranslationPrompt
constructor
A new instance of GoogleCloudAiplatformV1SchemaPromptSpecTranslationPrompt.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPromptSpecTranslationPrompt
Returns a new instance of GoogleCloudAiplatformV1SchemaPromptSpecTranslationPrompt.
29336 29337 29338 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29336 def initialize(**args) update!(**args) end |
Instance Attribute Details
#example ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecTranslationExample
The translation example that contains reference sentences from various sources.
Corresponds to the JSON property example
29313 29314 29315 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29313 def example @example end |
#option ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecTranslationOption
Optional settings for translation prompt.
Corresponds to the JSON property option
29318 29319 29320 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29318 def option @option end |
#prompt_message ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecPromptMessage
The prompt message that aligns with the prompt message in google.cloud.
aiplatform.master.GenerateContentRequest.
Corresponds to the JSON property promptMessage
29324 29325 29326 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29324 def @prompt_message end |
#source_language_code ⇒ String
The source language code.
Corresponds to the JSON property sourceLanguageCode
29329 29330 29331 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29329 def source_language_code @source_language_code end |
#target_language_code ⇒ String
The target language code.
Corresponds to the JSON property targetLanguageCode
29334 29335 29336 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29334 def target_language_code @target_language_code end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29341 29342 29343 29344 29345 29346 29347 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29341 def update!(**args) @example = args[:example] if args.key?(:example) @option = args[:option] if args.key?(:option) @prompt_message = args[:prompt_message] if args.key?(:prompt_message) @source_language_code = args[:source_language_code] if args.key?(:source_language_code) @target_language_code = args[:target_language_code] if args.key?(:target_language_code) end |