Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecTranslationPrompt

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Prompt variation for Translation use case.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaPromptSpecTranslationPrompt

Returns a new instance of GoogleCloudAiplatformV1SchemaPromptSpecTranslationPrompt.



29068
29069
29070
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29068

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#exampleGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecTranslationExample

The translation example that contains reference sentences from various sources. Corresponds to the JSON property example



29045
29046
29047
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29045

def example
  @example
end

#optionGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecTranslationOption

Optional settings for translation prompt. Corresponds to the JSON property option



29050
29051
29052
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29050

def option
  @option
end

#prompt_messageGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptSpecPromptMessage

The prompt message that aligns with the prompt message in google.cloud. aiplatform.master.GenerateContentRequest. Corresponds to the JSON property promptMessage



29056
29057
29058
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29056

def prompt_message
  @prompt_message
end

#source_language_codeString

The source language code. Corresponds to the JSON property sourceLanguageCode

Returns:

  • (String)


29061
29062
29063
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29061

def source_language_code
  @source_language_code
end

#target_language_codeString

The target language code. Corresponds to the JSON property targetLanguageCode

Returns:

  • (String)


29066
29067
29068
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29066

def target_language_code
  @target_language_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29073
29074
29075
29076
29077
29078
29079
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29073

def update!(**args)
  @example = args[:example] if args.key?(:example)
  @option = args[:option] if args.key?(:option)
  @prompt_message = args[:prompt_message] if args.key?(:prompt_message)
  @source_language_code = args[:source_language_code] if args.key?(:source_language_code)
  @target_language_code = args[:target_language_code] if args.key?(:target_language_code)
end