Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTextDatasetMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTextDatasetMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The metadata of Datasets that contain Text DataItems.
Instance Attribute Summary collapse
-
#data_item_schema_uri ⇒ String
Points to a YAML file stored on Google Cloud Storage describing payload of the Text DataItems that belong to this Dataset.
-
#gcs_bucket ⇒ String
Google Cloud Storage Bucket name that contains the blob data of this Dataset.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTextDatasetMetadata
constructor
A new instance of GoogleCloudAiplatformV1SchemaTextDatasetMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTextDatasetMetadata
Returns a new instance of GoogleCloudAiplatformV1SchemaTextDatasetMetadata.
29155 29156 29157 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29155 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_item_schema_uri ⇒ String
Points to a YAML file stored on Google Cloud Storage describing payload of the
Text DataItems that belong to this Dataset.
Corresponds to the JSON property dataItemSchemaUri
29148 29149 29150 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29148 def data_item_schema_uri @data_item_schema_uri end |
#gcs_bucket ⇒ String
Google Cloud Storage Bucket name that contains the blob data of this Dataset.
Corresponds to the JSON property gcsBucket
29153 29154 29155 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29153 def gcs_bucket @gcs_bucket end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29160 29161 29162 29163 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29160 def update!(**args) @data_item_schema_uri = args[:data_item_schema_uri] if args.key?(:data_item_schema_uri) @gcs_bucket = args[:gcs_bucket] if args.key?(:gcs_bucket) end |