Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTextPromptDatasetMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTextPromptDatasetMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The metadata of Datasets that contain Text Prompt data.
Instance Attribute Summary collapse
-
#candidate_count ⇒ Fixnum
Number of candidates.
-
#gcs_uri ⇒ String
The Google Cloud Storage URI that stores the prompt data.
-
#grounding_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictParamsGroundingConfig
The configuration for grounding checking.
-
#has_prompt_variable ⇒ Boolean
(also: #has_prompt_variable?)
Whether the prompt dataset has prompt variable.
-
#logprobs ⇒ Boolean
(also: #logprobs?)
Whether or not the user has enabled logit probabilities in the model parameters.
-
#max_output_tokens ⇒ Fixnum
Value of the maximum number of tokens generated set when the dataset was saved.
-
#note ⇒ String
User-created prompt note.
-
#prompt_api_schema ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptApiSchema
The A2 schema of a prompt.
-
#prompt_type ⇒ String
Type of the prompt dataset.
-
#seed_enabled ⇒ Boolean
(also: #seed_enabled?)
Seeding enables model to return a deterministic response on a best effort basis.
-
#seed_value ⇒ Fixnum
The actual value of the seed.
-
#stop_sequences ⇒ Array<String>
Customized stop sequences.
-
#system_instruction ⇒ String
The content of the prompt dataset system instruction.
-
#system_instruction_gcs_uri ⇒ String
The Google Cloud Storage URI that stores the system instruction, starting with gs://.
-
#temperature ⇒ Float
Temperature value used for sampling set when the dataset was saved.
-
#text ⇒ String
The content of the prompt dataset.
-
#top_k ⇒ Fixnum
Top K value set when the dataset was saved.
-
#top_p ⇒ Float
Top P value set when the dataset was saved.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTextPromptDatasetMetadata
constructor
A new instance of GoogleCloudAiplatformV1SchemaTextPromptDatasetMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTextPromptDatasetMetadata
Returns a new instance of GoogleCloudAiplatformV1SchemaTextPromptDatasetMetadata.
42053 42054 42055 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42053 def initialize(**args) update!(**args) end |
Instance Attribute Details
#candidate_count ⇒ Fixnum
Number of candidates.
Corresponds to the JSON property candidateCount
41955 41956 41957 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41955 def candidate_count @candidate_count end |
#gcs_uri ⇒ String
The Google Cloud Storage URI that stores the prompt data.
Corresponds to the JSON property gcsUri
41960 41961 41962 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41960 def gcs_uri @gcs_uri end |
#grounding_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictParamsGroundingConfig
The configuration for grounding checking.
Corresponds to the JSON property groundingConfig
41965 41966 41967 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41965 def grounding_config @grounding_config end |
#has_prompt_variable ⇒ Boolean Also known as: has_prompt_variable?
Whether the prompt dataset has prompt variable.
Corresponds to the JSON property hasPromptVariable
41970 41971 41972 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41970 def has_prompt_variable @has_prompt_variable end |
#logprobs ⇒ Boolean Also known as: logprobs?
Whether or not the user has enabled logit probabilities in the model
parameters.
Corresponds to the JSON property logprobs
41977 41978 41979 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41977 def logprobs @logprobs end |
#max_output_tokens ⇒ Fixnum
Value of the maximum number of tokens generated set when the dataset was saved.
Corresponds to the JSON property maxOutputTokens
41983 41984 41985 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41983 def max_output_tokens @max_output_tokens end |
#note ⇒ String
User-created prompt note. Note size limit is 2KB.
Corresponds to the JSON property note
41988 41989 41990 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41988 def note @note end |
#prompt_api_schema ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptApiSchema
The A2 schema of a prompt.
Corresponds to the JSON property promptApiSchema
41993 41994 41995 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41993 def prompt_api_schema @prompt_api_schema end |
#prompt_type ⇒ String
Type of the prompt dataset.
Corresponds to the JSON property promptType
41998 41999 42000 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41998 def prompt_type @prompt_type end |
#seed_enabled ⇒ Boolean Also known as: seed_enabled?
Seeding enables model to return a deterministic response on a best effort
basis. Determinism isn't guaranteed. This field determines whether or not
seeding is enabled.
Corresponds to the JSON property seedEnabled
42005 42006 42007 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42005 def seed_enabled @seed_enabled end |
#seed_value ⇒ Fixnum
The actual value of the seed.
Corresponds to the JSON property seedValue
42011 42012 42013 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42011 def seed_value @seed_value end |
#stop_sequences ⇒ Array<String>
Customized stop sequences.
Corresponds to the JSON property stopSequences
42016 42017 42018 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42016 def stop_sequences @stop_sequences end |
#system_instruction ⇒ String
The content of the prompt dataset system instruction.
Corresponds to the JSON property systemInstruction
42021 42022 42023 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42021 def system_instruction @system_instruction end |
#system_instruction_gcs_uri ⇒ String
The Google Cloud Storage URI that stores the system instruction, starting with
gs://.
Corresponds to the JSON property systemInstructionGcsUri
42027 42028 42029 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42027 def system_instruction_gcs_uri @system_instruction_gcs_uri end |
#temperature ⇒ Float
Temperature value used for sampling set when the dataset was saved. This value
is used to tune the degree of randomness.
Corresponds to the JSON property temperature
42033 42034 42035 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42033 def temperature @temperature end |
#text ⇒ String
The content of the prompt dataset.
Corresponds to the JSON property text
42038 42039 42040 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42038 def text @text end |
#top_k ⇒ Fixnum
Top K value set when the dataset was saved. This value determines how many
candidates with highest probability from the vocab would be selected for each
decoding step.
Corresponds to the JSON property topK
42045 42046 42047 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42045 def top_k @top_k end |
#top_p ⇒ Float
Top P value set when the dataset was saved. Given topK tokens for decoding,
top candidates will be selected until the sum of their probabilities is topP.
Corresponds to the JSON property topP
42051 42052 42053 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42051 def top_p @top_p end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42058 42059 42060 42061 42062 42063 42064 42065 42066 42067 42068 42069 42070 42071 42072 42073 42074 42075 42076 42077 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42058 def update!(**args) @candidate_count = args[:candidate_count] if args.key?(:candidate_count) @gcs_uri = args[:gcs_uri] if args.key?(:gcs_uri) @grounding_config = args[:grounding_config] if args.key?(:grounding_config) @has_prompt_variable = args[:has_prompt_variable] if args.key?(:has_prompt_variable) @logprobs = args[:logprobs] if args.key?(:logprobs) @max_output_tokens = args[:max_output_tokens] if args.key?(:max_output_tokens) @note = args[:note] if args.key?(:note) @prompt_api_schema = args[:prompt_api_schema] if args.key?(:prompt_api_schema) @prompt_type = args[:prompt_type] if args.key?(:prompt_type) @seed_enabled = args[:seed_enabled] if args.key?(:seed_enabled) @seed_value = args[:seed_value] if args.key?(:seed_value) @stop_sequences = args[:stop_sequences] if args.key?(:stop_sequences) @system_instruction = args[:system_instruction] if args.key?(:system_instruction) @system_instruction_gcs_uri = args[:system_instruction_gcs_uri] if args.key?(:system_instruction_gcs_uri) @temperature = args[:temperature] if args.key?(:temperature) @text = args[:text] if args.key?(:text) @top_k = args[:top_k] if args.key?(:top_k) @top_p = args[:top_p] if args.key?(:top_p) end |