Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTextPromptDatasetMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The metadata of Datasets that contain Text Prompt data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTextPromptDatasetMetadata

Returns a new instance of GoogleCloudAiplatformV1SchemaTextPromptDatasetMetadata.



41380
41381
41382
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41380

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#candidate_countFixnum

Number of candidates. Corresponds to the JSON property candidateCount

Returns:

  • (Fixnum)


41282
41283
41284
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41282

def candidate_count
  @candidate_count
end

#gcs_uriString

The Google Cloud Storage URI that stores the prompt data. Corresponds to the JSON property gcsUri

Returns:

  • (String)


41287
41288
41289
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41287

def gcs_uri
  @gcs_uri
end

#grounding_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictParamsGroundingConfig

The configuration for grounding checking. Corresponds to the JSON property groundingConfig



41292
41293
41294
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41292

def grounding_config
  @grounding_config
end

#has_prompt_variableBoolean Also known as: has_prompt_variable?

Whether the prompt dataset has prompt variable. Corresponds to the JSON property hasPromptVariable

Returns:

  • (Boolean)


41297
41298
41299
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41297

def has_prompt_variable
  @has_prompt_variable
end

#logprobsBoolean Also known as: logprobs?

Whether or not the user has enabled logit probabilities in the model parameters. Corresponds to the JSON property logprobs

Returns:

  • (Boolean)


41304
41305
41306
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41304

def logprobs
  @logprobs
end

#max_output_tokensFixnum

Value of the maximum number of tokens generated set when the dataset was saved. Corresponds to the JSON property maxOutputTokens

Returns:

  • (Fixnum)


41310
41311
41312
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41310

def max_output_tokens
  @max_output_tokens
end

#noteString

User-created prompt note. Note size limit is 2KB. Corresponds to the JSON property note

Returns:

  • (String)


41315
41316
41317
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41315

def note
  @note
end

#prompt_api_schemaGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptApiSchema

The A2 schema of a prompt. Corresponds to the JSON property promptApiSchema



41320
41321
41322
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41320

def prompt_api_schema
  @prompt_api_schema
end

#prompt_typeString

Type of the prompt dataset. Corresponds to the JSON property promptType

Returns:

  • (String)


41325
41326
41327
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41325

def prompt_type
  @prompt_type
end

#seed_enabledBoolean Also known as: seed_enabled?

Seeding enables model to return a deterministic response on a best effort basis. Determinism isn't guaranteed. This field determines whether or not seeding is enabled. Corresponds to the JSON property seedEnabled

Returns:

  • (Boolean)


41332
41333
41334
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41332

def seed_enabled
  @seed_enabled
end

#seed_valueFixnum

The actual value of the seed. Corresponds to the JSON property seedValue

Returns:

  • (Fixnum)


41338
41339
41340
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41338

def seed_value
  @seed_value
end

#stop_sequencesArray<String>

Customized stop sequences. Corresponds to the JSON property stopSequences

Returns:

  • (Array<String>)


41343
41344
41345
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41343

def stop_sequences
  @stop_sequences
end

#system_instructionString

The content of the prompt dataset system instruction. Corresponds to the JSON property systemInstruction

Returns:

  • (String)


41348
41349
41350
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41348

def system_instruction
  @system_instruction
end

#system_instruction_gcs_uriString

The Google Cloud Storage URI that stores the system instruction, starting with gs://. Corresponds to the JSON property systemInstructionGcsUri

Returns:

  • (String)


41354
41355
41356
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41354

def system_instruction_gcs_uri
  @system_instruction_gcs_uri
end

#temperatureFloat

Temperature value used for sampling set when the dataset was saved. This value is used to tune the degree of randomness. Corresponds to the JSON property temperature

Returns:

  • (Float)


41360
41361
41362
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41360

def temperature
  @temperature
end

#textString

The content of the prompt dataset. Corresponds to the JSON property text

Returns:

  • (String)


41365
41366
41367
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41365

def text
  @text
end

#top_kFixnum

Top K value set when the dataset was saved. This value determines how many candidates with highest probability from the vocab would be selected for each decoding step. Corresponds to the JSON property topK

Returns:

  • (Fixnum)


41372
41373
41374
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41372

def top_k
  @top_k
end

#top_pFloat

Top P value set when the dataset was saved. Given topK tokens for decoding, top candidates will be selected until the sum of their probabilities is topP. Corresponds to the JSON property topP

Returns:

  • (Float)


41378
41379
41380
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41378

def top_p
  @top_p
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41385
41386
41387
41388
41389
41390
41391
41392
41393
41394
41395
41396
41397
41398
41399
41400
41401
41402
41403
41404
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41385

def update!(**args)
  @candidate_count = args[:candidate_count] if args.key?(:candidate_count)
  @gcs_uri = args[:gcs_uri] if args.key?(:gcs_uri)
  @grounding_config = args[:grounding_config] if args.key?(:grounding_config)
  @has_prompt_variable = args[:has_prompt_variable] if args.key?(:has_prompt_variable)
  @logprobs = args[:logprobs] if args.key?(:logprobs)
  @max_output_tokens = args[:max_output_tokens] if args.key?(:max_output_tokens)
  @note = args[:note] if args.key?(:note)
  @prompt_api_schema = args[:prompt_api_schema] if args.key?(:prompt_api_schema)
  @prompt_type = args[:prompt_type] if args.key?(:prompt_type)
  @seed_enabled = args[:seed_enabled] if args.key?(:seed_enabled)
  @seed_value = args[:seed_value] if args.key?(:seed_value)
  @stop_sequences = args[:stop_sequences] if args.key?(:stop_sequences)
  @system_instruction = args[:system_instruction] if args.key?(:system_instruction)
  @system_instruction_gcs_uri = args[:system_instruction_gcs_uri] if args.key?(:system_instruction_gcs_uri)
  @temperature = args[:temperature] if args.key?(:temperature)
  @text = args[:text] if args.key?(:text)
  @top_k = args[:top_k] if args.key?(:top_k)
  @top_p = args[:top_p] if args.key?(:top_p)
end