Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTextPromptDatasetMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The metadata of Datasets that contain Text Prompt data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTextPromptDatasetMetadata

Returns a new instance of GoogleCloudAiplatformV1SchemaTextPromptDatasetMetadata.



38808
38809
38810
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38808

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#candidate_countFixnum

Number of candidates. Corresponds to the JSON property candidateCount

Returns:

  • (Fixnum)


38710
38711
38712
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38710

def candidate_count
  @candidate_count
end

#gcs_uriString

The Google Cloud Storage URI that stores the prompt data. Corresponds to the JSON property gcsUri

Returns:

  • (String)


38715
38716
38717
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38715

def gcs_uri
  @gcs_uri
end

#grounding_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictParamsGroundingConfig

The configuration for grounding checking. Corresponds to the JSON property groundingConfig



38720
38721
38722
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38720

def grounding_config
  @grounding_config
end

#has_prompt_variableBoolean Also known as: has_prompt_variable?

Whether the prompt dataset has prompt variable. Corresponds to the JSON property hasPromptVariable

Returns:

  • (Boolean)


38725
38726
38727
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38725

def has_prompt_variable
  @has_prompt_variable
end

#logprobsBoolean Also known as: logprobs?

Whether or not the user has enabled logit probabilities in the model parameters. Corresponds to the JSON property logprobs

Returns:

  • (Boolean)


38732
38733
38734
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38732

def logprobs
  @logprobs
end

#max_output_tokensFixnum

Value of the maximum number of tokens generated set when the dataset was saved. Corresponds to the JSON property maxOutputTokens

Returns:

  • (Fixnum)


38738
38739
38740
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38738

def max_output_tokens
  @max_output_tokens
end

#noteString

User-created prompt note. Note size limit is 2KB. Corresponds to the JSON property note

Returns:

  • (String)


38743
38744
38745
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38743

def note
  @note
end

#prompt_api_schemaGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPromptApiSchema

The A2 schema of a prompt. Corresponds to the JSON property promptApiSchema



38748
38749
38750
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38748

def prompt_api_schema
  @prompt_api_schema
end

#prompt_typeString

Type of the prompt dataset. Corresponds to the JSON property promptType

Returns:

  • (String)


38753
38754
38755
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38753

def prompt_type
  @prompt_type
end

#seed_enabledBoolean Also known as: seed_enabled?

Seeding enables model to return a deterministic response on a best effort basis. Determinism isn't guaranteed. This field determines whether or not seeding is enabled. Corresponds to the JSON property seedEnabled

Returns:

  • (Boolean)


38760
38761
38762
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38760

def seed_enabled
  @seed_enabled
end

#seed_valueFixnum

The actual value of the seed. Corresponds to the JSON property seedValue

Returns:

  • (Fixnum)


38766
38767
38768
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38766

def seed_value
  @seed_value
end

#stop_sequencesArray<String>

Customized stop sequences. Corresponds to the JSON property stopSequences

Returns:

  • (Array<String>)


38771
38772
38773
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38771

def stop_sequences
  @stop_sequences
end

#system_instructionString

The content of the prompt dataset system instruction. Corresponds to the JSON property systemInstruction

Returns:

  • (String)


38776
38777
38778
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38776

def system_instruction
  @system_instruction
end

#system_instruction_gcs_uriString

The Google Cloud Storage URI that stores the system instruction, starting with gs://. Corresponds to the JSON property systemInstructionGcsUri

Returns:

  • (String)


38782
38783
38784
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38782

def system_instruction_gcs_uri
  @system_instruction_gcs_uri
end

#temperatureFloat

Temperature value used for sampling set when the dataset was saved. This value is used to tune the degree of randomness. Corresponds to the JSON property temperature

Returns:

  • (Float)


38788
38789
38790
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38788

def temperature
  @temperature
end

#textString

The content of the prompt dataset. Corresponds to the JSON property text

Returns:

  • (String)


38793
38794
38795
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38793

def text
  @text
end

#top_kFixnum

Top K value set when the dataset was saved. This value determines how many candidates with highest probability from the vocab would be selected for each decoding step. Corresponds to the JSON property topK

Returns:

  • (Fixnum)


38800
38801
38802
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38800

def top_k
  @top_k
end

#top_pFloat

Top P value set when the dataset was saved. Given topK tokens for decoding, top candidates will be selected until the sum of their probabilities is topP. Corresponds to the JSON property topP

Returns:

  • (Float)


38806
38807
38808
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38806

def top_p
  @top_p
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38813
38814
38815
38816
38817
38818
38819
38820
38821
38822
38823
38824
38825
38826
38827
38828
38829
38830
38831
38832
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38813

def update!(**args)
  @candidate_count = args[:candidate_count] if args.key?(:candidate_count)
  @gcs_uri = args[:gcs_uri] if args.key?(:gcs_uri)
  @grounding_config = args[:grounding_config] if args.key?(:grounding_config)
  @has_prompt_variable = args[:has_prompt_variable] if args.key?(:has_prompt_variable)
  @logprobs = args[:logprobs] if args.key?(:logprobs)
  @max_output_tokens = args[:max_output_tokens] if args.key?(:max_output_tokens)
  @note = args[:note] if args.key?(:note)
  @prompt_api_schema = args[:prompt_api_schema] if args.key?(:prompt_api_schema)
  @prompt_type = args[:prompt_type] if args.key?(:prompt_type)
  @seed_enabled = args[:seed_enabled] if args.key?(:seed_enabled)
  @seed_value = args[:seed_value] if args.key?(:seed_value)
  @stop_sequences = args[:stop_sequences] if args.key?(:stop_sequences)
  @system_instruction = args[:system_instruction] if args.key?(:system_instruction)
  @system_instruction_gcs_uri = args[:system_instruction_gcs_uri] if args.key?(:system_instruction_gcs_uri)
  @temperature = args[:temperature] if args.key?(:temperature)
  @text = args[:text] if args.key?(:text)
  @top_k = args[:top_k] if args.key?(:top_k)
  @top_p = args[:top_p] if args.key?(:top_p)
end