Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTextPromptDatasetMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The metadata of Datasets that contain Text Prompt data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTextPromptDatasetMetadata

Returns a new instance of GoogleCloudAiplatformV1SchemaTextPromptDatasetMetadata.



22533
22534
22535
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22533

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#candidate_countFixnum

Number of candidates. Corresponds to the JSON property candidateCount

Returns:

  • (Fixnum)


22471
22472
22473
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22471

def candidate_count
  @candidate_count
end

#gcs_uriString

The Google Cloud Storage URI that stores the prompt data. Corresponds to the JSON property gcsUri

Returns:

  • (String)


22476
22477
22478
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22476

def gcs_uri
  @gcs_uri
end

#grounding_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictParamsGroundingConfig

The configuration for grounding checking. Corresponds to the JSON property groundingConfig



22481
22482
22483
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22481

def grounding_config
  @grounding_config
end

#max_output_tokensFixnum

Value of the maximum number of tokens generated set when the dataset was saved. Corresponds to the JSON property maxOutputTokens

Returns:

  • (Fixnum)


22486
22487
22488
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22486

def max_output_tokens
  @max_output_tokens
end

#noteString

User-created prompt note. Note size limit is 2KB. Corresponds to the JSON property note

Returns:

  • (String)


22491
22492
22493
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22491

def note
  @note
end

#prompt_typeString

Type of the prompt dataset. Corresponds to the JSON property promptType

Returns:

  • (String)


22496
22497
22498
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22496

def prompt_type
  @prompt_type
end

#stop_sequencesArray<String>

Customized stop sequences. Corresponds to the JSON property stopSequences

Returns:

  • (Array<String>)


22501
22502
22503
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22501

def stop_sequences
  @stop_sequences
end

#system_instruction_gcs_uriString

The Google Cloud Storage URI that stores the system instruction, starting with gs://. Corresponds to the JSON property systemInstructionGcsUri

Returns:

  • (String)


22507
22508
22509
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22507

def system_instruction_gcs_uri
  @system_instruction_gcs_uri
end

#temperatureFloat

Temperature value used for sampling set when the dataset was saved. This value is used to tune the degree of randomness. Corresponds to the JSON property temperature

Returns:

  • (Float)


22513
22514
22515
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22513

def temperature
  @temperature
end

#textString

The content of the prompt dataset. Corresponds to the JSON property text

Returns:

  • (String)


22518
22519
22520
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22518

def text
  @text
end

#top_kFixnum

Top K value set when the dataset was saved. This value determines how many candidates with highest probability from the vocab would be selected for each decoding step. Corresponds to the JSON property topK

Returns:

  • (Fixnum)


22525
22526
22527
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22525

def top_k
  @top_k
end

#top_pFloat

Top P value set when the dataset was saved. Given topK tokens for decoding, top candidates will be selected until the sum of their probabilities is topP. Corresponds to the JSON property topP

Returns:

  • (Float)


22531
22532
22533
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22531

def top_p
  @top_p
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22538
22539
22540
22541
22542
22543
22544
22545
22546
22547
22548
22549
22550
22551
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22538

def update!(**args)
  @candidate_count = args[:candidate_count] if args.key?(:candidate_count)
  @gcs_uri = args[:gcs_uri] if args.key?(:gcs_uri)
  @grounding_config = args[:grounding_config] if args.key?(:grounding_config)
  @max_output_tokens = args[:max_output_tokens] if args.key?(:max_output_tokens)
  @note = args[:note] if args.key?(:note)
  @prompt_type = args[:prompt_type] if args.key?(:prompt_type)
  @stop_sequences = args[:stop_sequences] if args.key?(:stop_sequences)
  @system_instruction_gcs_uri = args[:system_instruction_gcs_uri] if args.key?(:system_instruction_gcs_uri)
  @temperature = args[:temperature] if args.key?(:temperature)
  @text = args[:text] if args.key?(:text)
  @top_k = args[:top_k] if args.key?(:top_k)
  @top_p = args[:top_p] if args.key?(:top_p)
end