Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTextPromptDatasetMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTextPromptDatasetMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The metadata of Datasets that contain Text Prompt data.
Instance Attribute Summary collapse
-
#candidate_count ⇒ Fixnum
Number of candidates.
-
#gcs_uri ⇒ String
The Google Cloud Storage URI that stores the prompt data.
-
#grounding_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictParamsGroundingConfig
The configuration for grounding checking.
-
#max_output_tokens ⇒ Fixnum
Value of the maximum number of tokens generated set when the dataset was saved.
-
#note ⇒ String
User-created prompt note.
-
#prompt_type ⇒ String
Type of the prompt dataset.
-
#stop_sequences ⇒ Array<String>
Customized stop sequences.
-
#temperature ⇒ Float
Temperature value used for sampling set when the dataset was saved.
-
#text ⇒ String
The content of the prompt dataset.
-
#top_k ⇒ Fixnum
Top K value set when the dataset was saved.
-
#top_p ⇒ Float
Top P value set when the dataset was saved.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTextPromptDatasetMetadata
constructor
A new instance of GoogleCloudAiplatformV1SchemaTextPromptDatasetMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTextPromptDatasetMetadata
Returns a new instance of GoogleCloudAiplatformV1SchemaTextPromptDatasetMetadata.
22581 22582 22583 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22581 def initialize(**args) update!(**args) end |
Instance Attribute Details
#candidate_count ⇒ Fixnum
Number of candidates.
Corresponds to the JSON property candidateCount
22525 22526 22527 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22525 def candidate_count @candidate_count end |
#gcs_uri ⇒ String
The Google Cloud Storage URI that stores the prompt data.
Corresponds to the JSON property gcsUri
22530 22531 22532 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22530 def gcs_uri @gcs_uri end |
#grounding_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictParamsGroundingConfig
The configuration for grounding checking.
Corresponds to the JSON property groundingConfig
22535 22536 22537 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22535 def grounding_config @grounding_config end |
#max_output_tokens ⇒ Fixnum
Value of the maximum number of tokens generated set when the dataset was saved.
Corresponds to the JSON property maxOutputTokens
22540 22541 22542 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22540 def max_output_tokens @max_output_tokens end |
#note ⇒ String
User-created prompt note. Note size limit is 2KB.
Corresponds to the JSON property note
22545 22546 22547 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22545 def note @note end |
#prompt_type ⇒ String
Type of the prompt dataset.
Corresponds to the JSON property promptType
22550 22551 22552 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22550 def prompt_type @prompt_type end |
#stop_sequences ⇒ Array<String>
Customized stop sequences.
Corresponds to the JSON property stopSequences
22555 22556 22557 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22555 def stop_sequences @stop_sequences end |
#temperature ⇒ Float
Temperature value used for sampling set when the dataset was saved. This value
is used to tune the degree of randomness.
Corresponds to the JSON property temperature
22561 22562 22563 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22561 def temperature @temperature end |
#text ⇒ String
The content of the prompt dataset.
Corresponds to the JSON property text
22566 22567 22568 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22566 def text @text end |
#top_k ⇒ Fixnum
Top K value set when the dataset was saved. This value determines how many
candidates with highest probability from the vocab would be selected for each
decoding step.
Corresponds to the JSON property topK
22573 22574 22575 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22573 def top_k @top_k end |
#top_p ⇒ Float
Top P value set when the dataset was saved. Given topK tokens for decoding,
top candidates will be selected until the sum of their probabilities is topP.
Corresponds to the JSON property topP
22579 22580 22581 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22579 def top_p @top_p end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22586 22587 22588 22589 22590 22591 22592 22593 22594 22595 22596 22597 22598 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22586 def update!(**args) @candidate_count = args[:candidate_count] if args.key?(:candidate_count) @gcs_uri = args[:gcs_uri] if args.key?(:gcs_uri) @grounding_config = args[:grounding_config] if args.key?(:grounding_config) @max_output_tokens = args[:max_output_tokens] if args.key?(:max_output_tokens) @note = args[:note] if args.key?(:note) @prompt_type = args[:prompt_type] if args.key?(:prompt_type) @stop_sequences = args[:stop_sequences] if args.key?(:stop_sequences) @temperature = args[:temperature] if args.key?(:temperature) @text = args[:text] if args.key?(:text) @top_k = args[:top_k] if args.key?(:top_k) @top_p = args[:top_p] if args.key?(:top_p) end |