Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTextPromptDatasetMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTextPromptDatasetMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The metadata of Datasets that contain Text Prompt data.
Instance Attribute Summary collapse
-
#candidate_count ⇒ Fixnum
Number of candidates.
-
#gcs_uri ⇒ String
The Google Cloud Storage URI that stores the prompt data.
-
#grounding_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictParamsGroundingConfig
The configuration for grounding checking.
-
#max_output_tokens ⇒ Fixnum
Value of the maximum number of tokens generated set when the dataset was saved.
-
#note ⇒ String
User-created prompt note.
-
#prompt_type ⇒ String
Type of the prompt dataset.
-
#stop_sequences ⇒ Array<String>
Customized stop sequences.
-
#temperature ⇒ Float
Temperature value used for sampling set when the dataset was saved.
-
#text ⇒ String
The content of the prompt dataset.
-
#top_k ⇒ Fixnum
Top K value set when the dataset was saved.
-
#top_p ⇒ Float
Top P value set when the dataset was saved.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTextPromptDatasetMetadata
constructor
A new instance of GoogleCloudAiplatformV1SchemaTextPromptDatasetMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTextPromptDatasetMetadata
Returns a new instance of GoogleCloudAiplatformV1SchemaTextPromptDatasetMetadata.
21327 21328 21329 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21327 def initialize(**args) update!(**args) end |
Instance Attribute Details
#candidate_count ⇒ Fixnum
Number of candidates.
Corresponds to the JSON property candidateCount
21271 21272 21273 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21271 def candidate_count @candidate_count end |
#gcs_uri ⇒ String
The Google Cloud Storage URI that stores the prompt data.
Corresponds to the JSON property gcsUri
21276 21277 21278 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21276 def gcs_uri @gcs_uri end |
#grounding_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaPredictParamsGroundingConfig
The configuration for grounding checking.
Corresponds to the JSON property groundingConfig
21281 21282 21283 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21281 def grounding_config @grounding_config end |
#max_output_tokens ⇒ Fixnum
Value of the maximum number of tokens generated set when the dataset was saved.
Corresponds to the JSON property maxOutputTokens
21286 21287 21288 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21286 def max_output_tokens @max_output_tokens end |
#note ⇒ String
User-created prompt note. Note size limit is 2KB.
Corresponds to the JSON property note
21291 21292 21293 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21291 def note @note end |
#prompt_type ⇒ String
Type of the prompt dataset.
Corresponds to the JSON property promptType
21296 21297 21298 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21296 def prompt_type @prompt_type end |
#stop_sequences ⇒ Array<String>
Customized stop sequences.
Corresponds to the JSON property stopSequences
21301 21302 21303 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21301 def stop_sequences @stop_sequences end |
#temperature ⇒ Float
Temperature value used for sampling set when the dataset was saved. This value
is used to tune the degree of randomness.
Corresponds to the JSON property temperature
21307 21308 21309 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21307 def temperature @temperature end |
#text ⇒ String
The content of the prompt dataset.
Corresponds to the JSON property text
21312 21313 21314 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21312 def text @text end |
#top_k ⇒ Fixnum
Top K value set when the dataset was saved. This value determines how many
candidates with highest probability from the vocab would be selected for each
decoding step.
Corresponds to the JSON property topK
21319 21320 21321 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21319 def top_k @top_k end |
#top_p ⇒ Float
Top P value set when the dataset was saved. Given topK tokens for decoding,
top candidates will be selected until the sum of their probabilities is topP.
Corresponds to the JSON property topP
21325 21326 21327 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21325 def top_p @top_p end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21332 21333 21334 21335 21336 21337 21338 21339 21340 21341 21342 21343 21344 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21332 def update!(**args) @candidate_count = args[:candidate_count] if args.key?(:candidate_count) @gcs_uri = args[:gcs_uri] if args.key?(:gcs_uri) @grounding_config = args[:grounding_config] if args.key?(:grounding_config) @max_output_tokens = args[:max_output_tokens] if args.key?(:max_output_tokens) @note = args[:note] if args.key?(:note) @prompt_type = args[:prompt_type] if args.key?(:prompt_type) @stop_sequences = args[:stop_sequences] if args.key?(:stop_sequences) @temperature = args[:temperature] if args.key?(:temperature) @text = args[:text] if args.key?(:text) @top_k = args[:top_k] if args.key?(:top_k) @top_p = args[:top_p] if args.key?(:top_p) end |