Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTextSegment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The text segment inside of DataItem.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTextSegment

Returns a new instance of GoogleCloudAiplatformV1SchemaTextSegment.



30000
30001
30002
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30000

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentString

The text content in the segment for output only. Corresponds to the JSON property content

Returns:

  • (String)


29985
29986
29987
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29985

def content
  @content
end

#end_offsetFixnum

Zero-based character index of the first character past the end of the text segment (counting character from the beginning of the text). The character at the end_offset is NOT included in the text segment. Corresponds to the JSON property endOffset

Returns:

  • (Fixnum)


29992
29993
29994
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29992

def end_offset
  @end_offset
end

#start_offsetFixnum

Zero-based character index of the first character of the text segment ( counting characters from the beginning of the text). Corresponds to the JSON property startOffset

Returns:

  • (Fixnum)


29998
29999
30000
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29998

def start_offset
  @start_offset
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30005
30006
30007
30008
30009
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30005

def update!(**args)
  @content = args[:content] if args.key?(:content)
  @end_offset = args[:end_offset] if args.key?(:end_offset)
  @start_offset = args[:start_offset] if args.key?(:start_offset)
end