Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTextSegment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The text segment inside of DataItem.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTextSegment

Returns a new instance of GoogleCloudAiplatformV1SchemaTextSegment.



21739
21740
21741
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21739

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentString

The text content in the segment for output only. Corresponds to the JSON property content

Returns:

  • (String)


21724
21725
21726
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21724

def content
  @content
end

#end_offsetFixnum

Zero-based character index of the first character past the end of the text segment (counting character from the beginning of the text). The character at the end_offset is NOT included in the text segment. Corresponds to the JSON property endOffset

Returns:

  • (Fixnum)


21731
21732
21733
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21731

def end_offset
  @end_offset
end

#start_offsetFixnum

Zero-based character index of the first character of the text segment ( counting characters from the beginning of the text). Corresponds to the JSON property startOffset

Returns:

  • (Fixnum)


21737
21738
21739
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21737

def start_offset
  @start_offset
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21744
21745
21746
21747
21748
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21744

def update!(**args)
  @content = args[:content] if args.key?(:content)
  @end_offset = args[:end_offset] if args.key?(:end_offset)
  @start_offset = args[:start_offset] if args.key?(:start_offset)
end