Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTimeSegment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A time period inside of a DataItem that has a time dimension (e.g. video).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTimeSegment

Returns a new instance of GoogleCloudAiplatformV1SchemaTimeSegment.



31160
31161
31162
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31160

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_time_offsetString

End of the time segment (exclusive), represented as the duration since the start of the DataItem. Corresponds to the JSON property endTimeOffset

Returns:

  • (String)


31152
31153
31154
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31152

def end_time_offset
  @end_time_offset
end

#start_time_offsetString

Start of the time segment (inclusive), represented as the duration since the start of the DataItem. Corresponds to the JSON property startTimeOffset

Returns:

  • (String)


31158
31159
31160
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31158

def start_time_offset
  @start_time_offset
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31165
31166
31167
31168
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31165

def update!(**args)
  @end_time_offset = args[:end_time_offset] if args.key?(:end_time_offset)
  @start_time_offset = args[:start_time_offset] if args.key?(:start_time_offset)
end