Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTimeSegment
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTimeSegment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A time period inside of a DataItem that has a time dimension (e.g. video).
Instance Attribute Summary collapse
-
#end_time_offset ⇒ String
End of the time segment (exclusive), represented as the duration since the start of the DataItem.
-
#start_time_offset ⇒ String
Start of the time segment (inclusive), represented as the duration since the start of the DataItem.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTimeSegment
constructor
A new instance of GoogleCloudAiplatformV1SchemaTimeSegment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTimeSegment
Returns a new instance of GoogleCloudAiplatformV1SchemaTimeSegment.
22660 22661 22662 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22660 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time_offset ⇒ String
End of the time segment (exclusive), represented as the duration since the
start of the DataItem.
Corresponds to the JSON property endTimeOffset
22652 22653 22654 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22652 def end_time_offset @end_time_offset end |
#start_time_offset ⇒ String
Start of the time segment (inclusive), represented as the duration since the
start of the DataItem.
Corresponds to the JSON property startTimeOffset
22658 22659 22660 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22658 def start_time_offset @start_time_offset end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22665 22666 22667 22668 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 22665 def update!(**args) @end_time_offset = args[:end_time_offset] if args.key?(:end_time_offset) @start_time_offset = args[:start_time_offset] if args.key?(:start_time_offset) end |