Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformation
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Instance Attribute Summary collapse
-
#auto ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformationAutoTransformation
Training pipeline will infer the proper transformation based on the statistic of dataset.
-
#categorical ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformationCategoricalTransformation
Training pipeline will perform following transformation functions.
-
#numeric ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformationNumericTransformation
Training pipeline will perform following transformation functions.
-
#text ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformationTextTransformation
Training pipeline will perform following transformation functions.
-
#timestamp ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformationTimestampTransformation
Training pipeline will perform following transformation functions.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformation
constructor
A new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformation
Returns a new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformation.
41346 41347 41348 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41346 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformationAutoTransformation
Training pipeline will infer the proper transformation based on the statistic
of dataset.
Corresponds to the JSON property auto
41305 41306 41307 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41305 def auto @auto end |
#categorical ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformationCategoricalTransformation
Training pipeline will perform following transformation functions. * The
categorical string as is--no change to case, punctuation, spelling, tense, and
so on. * Convert the category name to a dictionary lookup index and generate
an embedding for each index. * Categories that appear less than 5 times in the
training dataset are treated as the "unknown" category. The "unknown" category
gets its own special lookup index and resulting embedding.
Corresponds to the JSON property categorical
41315 41316 41317 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41315 def categorical @categorical end |
#numeric ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformationNumericTransformation
Training pipeline will perform following transformation functions. * The value
converted to float32. * The z_score of the value. * log(value+1) when the
value is greater than or equal to 0. Otherwise, this transformation is not
applied and the value is considered a missing value. * z_score of log(value+1)
when the value is greater than or equal to 0. Otherwise, this transformation
is not applied and the value is considered a missing value. * A boolean value
that indicates whether the value is valid.
Corresponds to the JSON property numeric
41326 41327 41328 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41326 def numeric @numeric end |
#text ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformationTextTransformation
Training pipeline will perform following transformation functions. * The text
as is--no change to case, punctuation, spelling, tense, and so on. * Convert
the category name to a dictionary lookup index and generate an embedding for
each index.
Corresponds to the JSON property text
41334 41335 41336 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41334 def text @text end |
#timestamp ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformationTimestampTransformation
Training pipeline will perform following transformation functions. * Apply the
transformation functions for Numerical columns. * Determine the year, month,
day,and weekday. Treat each value from the timestamp as a Categorical column. *
Invalid numerical values (for example, values that fall outside of a typical
timestamp range, or are extreme values) receive no special treatment and are
not removed.
Corresponds to the JSON property timestamp
41344 41345 41346 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41344 def @timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41351 41352 41353 41354 41355 41356 41357 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41351 def update!(**args) @auto = args[:auto] if args.key?(:auto) @categorical = args[:categorical] if args.key?(:categorical) @numeric = args[:numeric] if args.key?(:numeric) @text = args[:text] if args.key?(:text) @timestamp = args[:timestamp] if args.key?(:timestamp) end |