Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformation
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Instance Attribute Summary collapse
-
#auto ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformationAutoTransformation
Training pipeline will infer the proper transformation based on the statistic of dataset.
-
#categorical ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformationCategoricalTransformation
Training pipeline will perform following transformation functions.
-
#numeric ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformationNumericTransformation
Training pipeline will perform following transformation functions.
-
#text ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformationTextTransformation
Training pipeline will perform following transformation functions.
-
#timestamp ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformationTimestampTransformation
Training pipeline will perform following transformation functions.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformation
constructor
A new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformation
Returns a new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformation.
26312 26313 26314 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26312 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformationAutoTransformation
Training pipeline will infer the proper transformation based on the statistic
of dataset.
Corresponds to the JSON property auto
26271 26272 26273 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26271 def auto @auto end |
#categorical ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformationCategoricalTransformation
Training pipeline will perform following transformation functions. * The
categorical string as is--no change to case, punctuation, spelling, tense, and
so on. * Convert the category name to a dictionary lookup index and generate
an embedding for each index. * Categories that appear less than 5 times in the
training dataset are treated as the "unknown" category. The "unknown" category
gets its own special lookup index and resulting embedding.
Corresponds to the JSON property categorical
26281 26282 26283 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26281 def categorical @categorical end |
#numeric ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformationNumericTransformation
Training pipeline will perform following transformation functions. * The value
converted to float32. * The z_score of the value. * log(value+1) when the
value is greater than or equal to 0. Otherwise, this transformation is not
applied and the value is considered a missing value. * z_score of log(value+1)
when the value is greater than or equal to 0. Otherwise, this transformation
is not applied and the value is considered a missing value. * A boolean value
that indicates whether the value is valid.
Corresponds to the JSON property numeric
26292 26293 26294 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26292 def numeric @numeric end |
#text ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformationTextTransformation
Training pipeline will perform following transformation functions. * The text
as is--no change to case, punctuation, spelling, tense, and so on. * Convert
the category name to a dictionary lookup index and generate an embedding for
each index.
Corresponds to the JSON property text
26300 26301 26302 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26300 def text @text end |
#timestamp ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlForecastingInputsTransformationTimestampTransformation
Training pipeline will perform following transformation functions. * Apply the
transformation functions for Numerical columns. * Determine the year, month,
day,and weekday. Treat each value from the timestamp as a Categorical column. *
Invalid numerical values (for example, values that fall outside of a typical
timestamp range, or are extreme values) receive no special treatment and are
not removed.
Corresponds to the JSON property timestamp
26310 26311 26312 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26310 def @timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26317 26318 26319 26320 26321 26322 26323 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26317 def update!(**args) @auto = args[:auto] if args.key?(:auto) @categorical = args[:categorical] if args.key?(:categorical) @numeric = args[:numeric] if args.key?(:numeric) @text = args[:text] if args.key?(:text) @timestamp = args[:timestamp] if args.key?(:timestamp) end |