Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageClassificationInputs

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageClassificationInputs

Returns a new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageClassificationInputs.



23334
23335
23336
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23334

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_model_idString

The ID of the base model. If it is specified, the new model will be trained based on the base model. Otherwise, the new model will be trained from scratch. The base model must be in the same Project and Location as the new Model to train, and have the same modelType. Corresponds to the JSON property baseModelId

Returns:

  • (String)


23278
23279
23280
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23278

def base_model_id
  @base_model_id
end

#budget_milli_node_hoursFixnum

The training budget of creating this model, expressed in milli node hours i.e. 1,000 value in this field means 1 node hour. The actual metadata. costMilliNodeHours will be equal or less than this value. If further model training ceases to provide any improvements, it will stop without using the full budget and the metadata.successfulStopReason will be model-converged. Note, node_hour = actual_hour * number_of_nodes_involved. For modelType cloud (default), the budget must be between 8,000 and 800,000 milli node hours, inclusive. The default value is 192,000 which represents one day in wall time, considering 8 nodes are used. For model types mobile-tf-low-latency-1, mobile-tf-versatile-1, mobile-tf-high-accuracy-1, the training budget must be between 1,000 and 100,000 milli node hours, inclusive. The default value is 24,000 which represents one day in wall time on a single node that is used. Corresponds to the JSON property budgetMilliNodeHours

Returns:

  • (Fixnum)


23294
23295
23296
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23294

def budget_milli_node_hours
  @budget_milli_node_hours
end

#disable_early_stoppingBoolean Also known as: disable_early_stopping?

Use the entire training budget. This disables the early stopping feature. When false the early stopping feature is enabled, which means that AutoML Image Classification might stop training before the entire training budget has been used. Corresponds to the JSON property disableEarlyStopping

Returns:

  • (Boolean)


23302
23303
23304
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23302

def disable_early_stopping
  @disable_early_stopping
end

#model_typeString

Corresponds to the JSON property modelType

Returns:

  • (String)


23308
23309
23310
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23308

def model_type
  @model_type
end

#multi_labelBoolean Also known as: multi_label?

If false, a single-label (multi-class) Model will be trained (i.e. assuming that for each image just up to one annotation may be applicable). If true, a multi-label Model will be trained (i.e. assuming that for each image multiple annotations may be applicable). Corresponds to the JSON property multiLabel

Returns:

  • (Boolean)


23316
23317
23318
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23316

def multi_label
  @multi_label
end

#tunable_parameterGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutomlImageTrainingTunableParameter

A wrapper class which contains the tunable parameters in an AutoML Image training job. Corresponds to the JSON property tunableParameter



23323
23324
23325
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23323

def tunable_parameter
  @tunable_parameter
end

#uptrain_base_model_idString

The ID of base model for upTraining. If it is specified, the new model will be upTrained based on the base model for upTraining. Otherwise, the new model will be trained from scratch. The base model for upTraining must be in the same Project and Location as the new Model to train, and have the same modelType. Corresponds to the JSON property uptrainBaseModelId

Returns:

  • (String)


23332
23333
23334
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23332

def uptrain_base_model_id
  @uptrain_base_model_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23339
23340
23341
23342
23343
23344
23345
23346
23347
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23339

def update!(**args)
  @base_model_id = args[:base_model_id] if args.key?(:base_model_id)
  @budget_milli_node_hours = args[:budget_milli_node_hours] if args.key?(:budget_milli_node_hours)
  @disable_early_stopping = args[:disable_early_stopping] if args.key?(:disable_early_stopping)
  @model_type = args[:model_type] if args.key?(:model_type)
  @multi_label = args[:multi_label] if args.key?(:multi_label)
  @tunable_parameter = args[:tunable_parameter] if args.key?(:tunable_parameter)
  @uptrain_base_model_id = args[:uptrain_base_model_id] if args.key?(:uptrain_base_model_id)
end