Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageObjectDetectionInputs

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageObjectDetectionInputs

Returns a new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageObjectDetectionInputs.



39732
39733
39734
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39732

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#budget_milli_node_hoursFixnum

The training budget of creating this model, expressed in milli node hours i.e. 1,000 value in this field means 1 node hour. The actual metadata. costMilliNodeHours will be equal or less than this value. If further model training ceases to provide any improvements, it will stop without using the full budget and the metadata.successfulStopReason will be model-converged. Note, node_hour = actual_hour * number_of_nodes_involved. For modelType cloud (default), the budget must be between 20,000 and 900,000 milli node hours, inclusive. The default value is 216,000 which represents one day in wall time, considering 9 nodes are used. For model types mobile-tf-low-latency-1, mobile-tf-versatile-1, mobile-tf-high-accuracy-1 the training budget must be between 1,000 and 100,000 milli node hours, inclusive. The default value is 24,000 which represents one day in wall time on a single node that is used. Corresponds to the JSON property budgetMilliNodeHours

Returns:

  • (Fixnum)


39701
39702
39703
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39701

def budget_milli_node_hours
  @budget_milli_node_hours
end

#disable_early_stoppingBoolean Also known as: disable_early_stopping?

Use the entire training budget. This disables the early stopping feature. When false the early stopping feature is enabled, which means that AutoML Image Object Detection might stop training before the entire training budget has been used. Corresponds to the JSON property disableEarlyStopping

Returns:

  • (Boolean)


39709
39710
39711
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39709

def disable_early_stopping
  @disable_early_stopping
end

#model_typeString

Corresponds to the JSON property modelType

Returns:

  • (String)


39715
39716
39717
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39715

def model_type
  @model_type
end

#tunable_parameterGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutomlImageTrainingTunableParameter

A wrapper class which contains the tunable parameters in an AutoML Image training job. Corresponds to the JSON property tunableParameter



39721
39722
39723
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39721

def tunable_parameter
  @tunable_parameter
end

#uptrain_base_model_idString

The ID of base model for upTraining. If it is specified, the new model will be upTrained based on the base model for upTraining. Otherwise, the new model will be trained from scratch. The base model for upTraining must be in the same Project and Location as the new Model to train, and have the same modelType. Corresponds to the JSON property uptrainBaseModelId

Returns:

  • (String)


39730
39731
39732
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39730

def uptrain_base_model_id
  @uptrain_base_model_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39737
39738
39739
39740
39741
39742
39743
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39737

def update!(**args)
  @budget_milli_node_hours = args[:budget_milli_node_hours] if args.key?(:budget_milli_node_hours)
  @disable_early_stopping = args[:disable_early_stopping] if args.key?(:disable_early_stopping)
  @model_type = args[:model_type] if args.key?(:model_type)
  @tunable_parameter = args[:tunable_parameter] if args.key?(:tunable_parameter)
  @uptrain_base_model_id = args[:uptrain_base_model_id] if args.key?(:uptrain_base_model_id)
end