Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageObjectDetectionInputs
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageObjectDetectionInputs
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Instance Attribute Summary collapse
-
#budget_milli_node_hours ⇒ Fixnum
The training budget of creating this model, expressed in milli node hours i.e.
-
#disable_early_stopping ⇒ Boolean
(also: #disable_early_stopping?)
Use the entire training budget.
-
#model_type ⇒ String
Corresponds to the JSON property
modelType. -
#tunable_parameter ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutomlImageTrainingTunableParameter
A wrapper class which contains the tunable parameters in an AutoML Image training job.
-
#uptrain_base_model_id ⇒ String
The ID of
basemodel for upTraining.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageObjectDetectionInputs
constructor
A new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageObjectDetectionInputs.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageObjectDetectionInputs
Returns a new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageObjectDetectionInputs.
31330 31331 31332 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31330 def initialize(**args) update!(**args) end |
Instance Attribute Details
#budget_milli_node_hours ⇒ Fixnum
The training budget of creating this model, expressed in milli node hours i.e.
1,000 value in this field means 1 node hour. The actual metadata.
costMilliNodeHours will be equal or less than this value. If further model
training ceases to provide any improvements, it will stop without using the
full budget and the metadata.successfulStopReason will be model-converged.
Note, node_hour = actual_hour * number_of_nodes_involved. For modelType cloud
(default), the budget must be between 20,000 and 900,000 milli node hours,
inclusive. The default value is 216,000 which represents one day in wall time,
considering 9 nodes are used. For model types mobile-tf-low-latency-1,
mobile-tf-versatile-1, mobile-tf-high-accuracy-1 the training budget must
be between 1,000 and 100,000 milli node hours, inclusive. The default value is
24,000 which represents one day in wall time on a single node that is used.
Corresponds to the JSON property budgetMilliNodeHours
31299 31300 31301 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31299 def budget_milli_node_hours @budget_milli_node_hours end |
#disable_early_stopping ⇒ Boolean Also known as: disable_early_stopping?
Use the entire training budget. This disables the early stopping feature. When
false the early stopping feature is enabled, which means that AutoML Image
Object Detection might stop training before the entire training budget has
been used.
Corresponds to the JSON property disableEarlyStopping
31307 31308 31309 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31307 def disable_early_stopping @disable_early_stopping end |
#model_type ⇒ String
Corresponds to the JSON property modelType
31313 31314 31315 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31313 def model_type @model_type end |
#tunable_parameter ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutomlImageTrainingTunableParameter
A wrapper class which contains the tunable parameters in an AutoML Image
training job.
Corresponds to the JSON property tunableParameter
31319 31320 31321 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31319 def tunable_parameter @tunable_parameter end |
#uptrain_base_model_id ⇒ String
The ID of base model for upTraining. If it is specified, the new model will
be upTrained based on the base model for upTraining. Otherwise, the new
model will be trained from scratch. The base model for upTraining must be in
the same Project and Location as the new Model to train, and have the same
modelType.
Corresponds to the JSON property uptrainBaseModelId
31328 31329 31330 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31328 def uptrain_base_model_id @uptrain_base_model_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31335 31336 31337 31338 31339 31340 31341 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31335 def update!(**args) @budget_milli_node_hours = args[:budget_milli_node_hours] if args.key?(:budget_milli_node_hours) @disable_early_stopping = args[:disable_early_stopping] if args.key?(:disable_early_stopping) @model_type = args[:model_type] if args.key?(:model_type) @tunable_parameter = args[:tunable_parameter] if args.key?(:tunable_parameter) @uptrain_base_model_id = args[:uptrain_base_model_id] if args.key?(:uptrain_base_model_id) end |