Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageSegmentationInputs

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageSegmentationInputs

Returns a new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlImageSegmentationInputs.



21102
21103
21104
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21102

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_model_idString

The ID of the base model. If it is specified, the new model will be trained based on the base model. Otherwise, the new model will be trained from scratch. The base model must be in the same Project and Location as the new Model to train, and have the same modelType. Corresponds to the JSON property baseModelId

Returns:

  • (String)


21080
21081
21082
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21080

def base_model_id
  @base_model_id
end

#budget_milli_node_hoursFixnum

The training budget of creating this model, expressed in milli node hours i.e. 1,000 value in this field means 1 node hour. The actual metadata. costMilliNodeHours will be equal or less than this value. If further model training ceases to provide any improvements, it will stop without using the full budget and the metadata.successfulStopReason will be model-converged. Note, node_hour = actual_hour * number_of_nodes_involved. Or actual_wall_clock_hours = train_budget_milli_node_hours / ( number_of_nodes_involved * 1000) For modelType cloud-high-accuracy-1(default) , the budget must be between 20,000 and 2,000,000 milli node hours, inclusive. The default value is 192,000 which represents one day in wall time (1000 milli

  • 24 hours * 8 nodes). Corresponds to the JSON property budgetMilliNodeHours

Returns:

  • (Fixnum)


21095
21096
21097
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21095

def budget_milli_node_hours
  @budget_milli_node_hours
end

#model_typeString

Corresponds to the JSON property modelType

Returns:

  • (String)


21100
21101
21102
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21100

def model_type
  @model_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21107
21108
21109
21110
21111
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 21107

def update!(**args)
  @base_model_id = args[:base_model_id] if args.key?(:base_model_id)
  @budget_milli_node_hours = args[:budget_milli_node_hours] if args.key?(:budget_milli_node_hours)
  @model_type = args[:model_type] if args.key?(:model_type)
end