Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputs

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputs

Returns a new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputs.



41992
41993
41994
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41992

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_experimentsArray<String>

Additional experiment flags for the Tables training pipeline. Corresponds to the JSON property additionalExperiments

Returns:

  • (Array<String>)


41904
41905
41906
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41904

def additional_experiments
  @additional_experiments
end

#disable_early_stoppingBoolean Also known as: disable_early_stopping?

Use the entire training budget. This disables the early stopping feature. By default, the early stopping feature is enabled, which means that AutoML Tables might stop training before the entire training budget has been used. Corresponds to the JSON property disableEarlyStopping

Returns:

  • (Boolean)


41911
41912
41913
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41911

def disable_early_stopping
  @disable_early_stopping
end

#export_evaluated_data_items_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionExportEvaluatedDataItemsConfig

Configuration for exporting test set predictions to a BigQuery table. Corresponds to the JSON property exportEvaluatedDataItemsConfig



41917
41918
41919
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41917

def export_evaluated_data_items_config
  @export_evaluated_data_items_config
end

#optimization_objectiveString

Objective function the model is optimizing towards. The training process creates a model that maximizes/minimizes the value of the objective function over the validation set. The supported optimization objectives depend on the prediction type. If the field is not set, a default objective function is used. classification (binary): "maximize-au-roc" (default) - Maximize the area under the receiver operating characteristic (ROC) curve. "minimize-log-loss" - Minimize log loss. "maximize-au-prc" - Maximize the area under the precision- recall curve. "maximize-precision-at-recall" - Maximize precision for a specified recall value. "maximize-recall-at-precision" - Maximize recall for a specified precision value. classification (multi-class): "minimize-log-loss" ( default) - Minimize log loss. regression: "minimize-rmse" (default) - Minimize root-mean-squared error (RMSE). "minimize-mae" - Minimize mean-absolute error ( MAE). "minimize-rmsle" - Minimize root-mean-squared log error (RMSLE). Corresponds to the JSON property optimizationObjective

Returns:

  • (String)


41934
41935
41936
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41934

def optimization_objective
  @optimization_objective
end

#optimization_objective_precision_valueFloat

Required when optimization_objective is "maximize-recall-at-precision". Must be between 0 and 1, inclusive. Corresponds to the JSON property optimizationObjectivePrecisionValue

Returns:

  • (Float)


41940
41941
41942
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41940

def optimization_objective_precision_value
  @optimization_objective_precision_value
end

#optimization_objective_recall_valueFloat

Required when optimization_objective is "maximize-precision-at-recall". Must be between 0 and 1, inclusive. Corresponds to the JSON property optimizationObjectiveRecallValue

Returns:

  • (Float)


41946
41947
41948
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41946

def optimization_objective_recall_value
  @optimization_objective_recall_value
end

#prediction_typeString

The type of prediction the Model is to produce. "classification" - Predict one out of multiple target values is picked for each row. "regression" - Predict a value based on its relation to other values. This type is available only to columns that contain semantically numeric values, i.e. integers or floating point number, even if stored as e.g. strings. Corresponds to the JSON property predictionType

Returns:

  • (String)


41955
41956
41957
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41955

def prediction_type
  @prediction_type
end

#target_columnString

The column name of the target column that the model is to predict. Corresponds to the JSON property targetColumn

Returns:

  • (String)


41960
41961
41962
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41960

def target_column
  @target_column
end

#train_budget_milli_node_hoursFixnum

Required. The train budget of creating this model, expressed in milli node hours i.e. 1,000 value in this field means 1 node hour. The training cost of the model will not exceed this budget. The final cost will be attempted to be close to the budget, though may end up being (even) noticeably smaller - at the backend's discretion. This especially may happen when further model training ceases to provide any improvements. If the budget is set to a value known to be insufficient to train a model for the given dataset, the training won't be attempted and will error. The train budget must be between 1,000 and 72,000 milli node hours, inclusive. Corresponds to the JSON property trainBudgetMilliNodeHours

Returns:

  • (Fixnum)


41973
41974
41975
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41973

def train_budget_milli_node_hours
  @train_budget_milli_node_hours
end

#transformationsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformation>

Each transformation will apply transform function to given input column. And the result will be used for training. When creating transformation for BigQuery Struct column, the column should be flattened using "." as the delimiter. Corresponds to the JSON property transformations



41981
41982
41983
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41981

def transformations
  @transformations
end

#weight_column_nameString

Column name that should be used as the weight column. Higher values in this column give more importance to the row during model training. The column must have numeric values between 0 and 10000 inclusively; 0 means the row is ignored for training. If weight column field is not set, then all rows are assumed to have equal weight of 1. Corresponds to the JSON property weightColumnName

Returns:

  • (String)


41990
41991
41992
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41990

def weight_column_name
  @weight_column_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41997
41998
41999
42000
42001
42002
42003
42004
42005
42006
42007
42008
42009
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41997

def update!(**args)
  @additional_experiments = args[:additional_experiments] if args.key?(:additional_experiments)
  @disable_early_stopping = args[:disable_early_stopping] if args.key?(:disable_early_stopping)
  @export_evaluated_data_items_config = args[:export_evaluated_data_items_config] if args.key?(:export_evaluated_data_items_config)
  @optimization_objective = args[:optimization_objective] if args.key?(:optimization_objective)
  @optimization_objective_precision_value = args[:optimization_objective_precision_value] if args.key?(:optimization_objective_precision_value)
  @optimization_objective_recall_value = args[:optimization_objective_recall_value] if args.key?(:optimization_objective_recall_value)
  @prediction_type = args[:prediction_type] if args.key?(:prediction_type)
  @target_column = args[:target_column] if args.key?(:target_column)
  @train_budget_milli_node_hours = args[:train_budget_milli_node_hours] if args.key?(:train_budget_milli_node_hours)
  @transformations = args[:transformations] if args.key?(:transformations)
  @weight_column_name = args[:weight_column_name] if args.key?(:weight_column_name)
end