Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputs
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputs
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Instance Attribute Summary collapse
-
#additional_experiments ⇒ Array<String>
Additional experiment flags for the Tables training pipeline.
-
#disable_early_stopping ⇒ Boolean
(also: #disable_early_stopping?)
Use the entire training budget.
-
#export_evaluated_data_items_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionExportEvaluatedDataItemsConfig
Configuration for exporting test set predictions to a BigQuery table.
-
#optimization_objective ⇒ String
Objective function the model is optimizing towards.
-
#optimization_objective_precision_value ⇒ Float
Required when optimization_objective is "maximize-recall-at-precision".
-
#optimization_objective_recall_value ⇒ Float
Required when optimization_objective is "maximize-precision-at-recall".
-
#prediction_type ⇒ String
The type of prediction the Model is to produce.
-
#target_column ⇒ String
The column name of the target column that the model is to predict.
-
#train_budget_milli_node_hours ⇒ Fixnum
Required.
-
#transformations ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformation>
Each transformation will apply transform function to given input column.
-
#weight_column_name ⇒ String
Column name that should be used as the weight column.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputs
constructor
A new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputs.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputs
Returns a new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputs.
41548 41549 41550 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41548 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_experiments ⇒ Array<String>
Additional experiment flags for the Tables training pipeline.
Corresponds to the JSON property additionalExperiments
41460 41461 41462 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41460 def additional_experiments @additional_experiments end |
#disable_early_stopping ⇒ Boolean Also known as: disable_early_stopping?
Use the entire training budget. This disables the early stopping feature. By
default, the early stopping feature is enabled, which means that AutoML Tables
might stop training before the entire training budget has been used.
Corresponds to the JSON property disableEarlyStopping
41467 41468 41469 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41467 def disable_early_stopping @disable_early_stopping end |
#export_evaluated_data_items_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionExportEvaluatedDataItemsConfig
Configuration for exporting test set predictions to a BigQuery table.
Corresponds to the JSON property exportEvaluatedDataItemsConfig
41473 41474 41475 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41473 def export_evaluated_data_items_config @export_evaluated_data_items_config end |
#optimization_objective ⇒ String
Objective function the model is optimizing towards. The training process
creates a model that maximizes/minimizes the value of the objective function
over the validation set. The supported optimization objectives depend on the
prediction type. If the field is not set, a default objective function is used.
classification (binary): "maximize-au-roc" (default) - Maximize the area
under the receiver operating characteristic (ROC) curve. "minimize-log-loss" -
Minimize log loss. "maximize-au-prc" - Maximize the area under the precision-
recall curve. "maximize-precision-at-recall" - Maximize precision for a
specified recall value. "maximize-recall-at-precision" - Maximize recall for a
specified precision value. classification (multi-class): "minimize-log-loss" (
default) - Minimize log loss. regression: "minimize-rmse" (default) - Minimize
root-mean-squared error (RMSE). "minimize-mae" - Minimize mean-absolute error (
MAE). "minimize-rmsle" - Minimize root-mean-squared log error (RMSLE).
Corresponds to the JSON property optimizationObjective
41490 41491 41492 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41490 def optimization_objective @optimization_objective end |
#optimization_objective_precision_value ⇒ Float
Required when optimization_objective is "maximize-recall-at-precision". Must
be between 0 and 1, inclusive.
Corresponds to the JSON property optimizationObjectivePrecisionValue
41496 41497 41498 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41496 def optimization_objective_precision_value @optimization_objective_precision_value end |
#optimization_objective_recall_value ⇒ Float
Required when optimization_objective is "maximize-precision-at-recall". Must
be between 0 and 1, inclusive.
Corresponds to the JSON property optimizationObjectiveRecallValue
41502 41503 41504 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41502 def optimization_objective_recall_value @optimization_objective_recall_value end |
#prediction_type ⇒ String
The type of prediction the Model is to produce. "classification" - Predict one
out of multiple target values is picked for each row. "regression" - Predict a
value based on its relation to other values. This type is available only to
columns that contain semantically numeric values, i.e. integers or floating
point number, even if stored as e.g. strings.
Corresponds to the JSON property predictionType
41511 41512 41513 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41511 def prediction_type @prediction_type end |
#target_column ⇒ String
The column name of the target column that the model is to predict.
Corresponds to the JSON property targetColumn
41516 41517 41518 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41516 def target_column @target_column end |
#train_budget_milli_node_hours ⇒ Fixnum
Required. The train budget of creating this model, expressed in milli node
hours i.e. 1,000 value in this field means 1 node hour. The training cost of
the model will not exceed this budget. The final cost will be attempted to be
close to the budget, though may end up being (even) noticeably smaller - at
the backend's discretion. This especially may happen when further model
training ceases to provide any improvements. If the budget is set to a value
known to be insufficient to train a model for the given dataset, the training
won't be attempted and will error. The train budget must be between 1,000 and
72,000 milli node hours, inclusive.
Corresponds to the JSON property trainBudgetMilliNodeHours
41529 41530 41531 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41529 def train_budget_milli_node_hours @train_budget_milli_node_hours end |
#transformations ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformation>
Each transformation will apply transform function to given input column. And
the result will be used for training. When creating transformation for
BigQuery Struct column, the column should be flattened using "." as the
delimiter.
Corresponds to the JSON property transformations
41537 41538 41539 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41537 def transformations @transformations end |
#weight_column_name ⇒ String
Column name that should be used as the weight column. Higher values in this
column give more importance to the row during model training. The column must
have numeric values between 0 and 10000 inclusively; 0 means the row is
ignored for training. If weight column field is not set, then all rows are
assumed to have equal weight of 1.
Corresponds to the JSON property weightColumnName
41546 41547 41548 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41546 def weight_column_name @weight_column_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41553 41554 41555 41556 41557 41558 41559 41560 41561 41562 41563 41564 41565 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41553 def update!(**args) @additional_experiments = args[:additional_experiments] if args.key?(:additional_experiments) @disable_early_stopping = args[:disable_early_stopping] if args.key?(:disable_early_stopping) @export_evaluated_data_items_config = args[:export_evaluated_data_items_config] if args.key?(:export_evaluated_data_items_config) @optimization_objective = args[:optimization_objective] if args.key?(:optimization_objective) @optimization_objective_precision_value = args[:optimization_objective_precision_value] if args.key?(:optimization_objective_precision_value) @optimization_objective_recall_value = args[:optimization_objective_recall_value] if args.key?(:optimization_objective_recall_value) @prediction_type = args[:prediction_type] if args.key?(:prediction_type) @target_column = args[:target_column] if args.key?(:target_column) @train_budget_milli_node_hours = args[:train_budget_milli_node_hours] if args.key?(:train_budget_milli_node_hours) @transformations = args[:transformations] if args.key?(:transformations) @weight_column_name = args[:weight_column_name] if args.key?(:weight_column_name) end |