Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformation

Returns a new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformation.



42076
42077
42078
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42076

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#autoGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationAutoTransformation

Training pipeline will infer the proper transformation based on the statistic of dataset. Corresponds to the JSON property auto



42007
42008
42009
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42007

def auto
  @auto
end

#categoricalGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationCategoricalTransformation

Training pipeline will perform following transformation functions. * The categorical string as is--no change to case, punctuation, spelling, tense, and so on. * Convert the category name to a dictionary lookup index and generate an embedding for each index. * Categories that appear less than 5 times in the training dataset are treated as the "unknown" category. The "unknown" category gets its own special lookup index and resulting embedding. Corresponds to the JSON property categorical



42017
42018
42019
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42017

def categorical
  @categorical
end

#numericGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationNumericTransformation

Training pipeline will perform following transformation functions. * The value converted to float32. * The z_score of the value. * log(value+1) when the value is greater than or equal to 0. Otherwise, this transformation is not applied and the value is considered a missing value. * z_score of log(value+1) when the value is greater than or equal to 0. Otherwise, this transformation is not applied and the value is considered a missing value. * A boolean value that indicates whether the value is valid. Corresponds to the JSON property numeric



42028
42029
42030
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42028

def numeric
  @numeric
end

#repeated_categoricalGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationCategoricalArrayTransformation

Treats the column as categorical array and performs following transformation functions. * For each element in the array, convert the category name to a dictionary lookup index and generate an embedding for each index. Combine the embedding of all elements into a single embedding using the mean. * Empty arrays treated as an embedding of zeroes. Corresponds to the JSON property repeatedCategorical



42037
42038
42039
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42037

def repeated_categorical
  @repeated_categorical
end

#repeated_numericGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationNumericArrayTransformation

Treats the column as numerical array and performs following transformation functions. * All transformations for Numerical types applied to the average of the all elements. * The average of empty arrays is treated as zero. Corresponds to the JSON property repeatedNumeric



42044
42045
42046
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42044

def repeated_numeric
  @repeated_numeric
end

#repeated_textGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationTextArrayTransformation

Treats the column as text array and performs following transformation functions. * Concatenate all text values in the array into a single text value using a space (" ") as a delimiter, and then treat the result as a single text value. Apply the transformations for Text columns. * Empty arrays treated as an empty text. Corresponds to the JSON property repeatedText



42053
42054
42055
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42053

def repeated_text
  @repeated_text
end

#textGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationTextTransformation

Training pipeline will perform following transformation functions. * The text as is--no change to case, punctuation, spelling, tense, and so on. * Tokenize text to words. Convert each words to a dictionary lookup index and generate an embedding for each index. Combine the embedding of all elements into a single embedding using the mean. * Tokenization is based on unicode script boundaries.

  • Missing values get their own lookup index and resulting embedding. * Stop- words receive no special treatment and are not removed. Corresponds to the JSON property text


42064
42065
42066
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42064

def text
  @text
end

#timestampGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationTimestampTransformation

Training pipeline will perform following transformation functions. * Apply the transformation functions for Numerical columns. * Determine the year, month, day,and weekday. Treat each value from the * timestamp as a Categorical column.

  • Invalid numerical values (for example, values that fall outside of a typical timestamp range, or are extreme values) receive no special treatment and are not removed. Corresponds to the JSON property timestamp


42074
42075
42076
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42074

def timestamp
  @timestamp
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42081
42082
42083
42084
42085
42086
42087
42088
42089
42090
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42081

def update!(**args)
  @auto = args[:auto] if args.key?(:auto)
  @categorical = args[:categorical] if args.key?(:categorical)
  @numeric = args[:numeric] if args.key?(:numeric)
  @repeated_categorical = args[:repeated_categorical] if args.key?(:repeated_categorical)
  @repeated_numeric = args[:repeated_numeric] if args.key?(:repeated_numeric)
  @repeated_text = args[:repeated_text] if args.key?(:repeated_text)
  @text = args[:text] if args.key?(:text)
  @timestamp = args[:timestamp] if args.key?(:timestamp)
end