Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformation

Returns a new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformation.



32098
32099
32100
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32098

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#autoGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationAutoTransformation

Training pipeline will infer the proper transformation based on the statistic of dataset. Corresponds to the JSON property auto



32029
32030
32031
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32029

def auto
  @auto
end

#categoricalGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationCategoricalTransformation

Training pipeline will perform following transformation functions. * The categorical string as is--no change to case, punctuation, spelling, tense, and so on. * Convert the category name to a dictionary lookup index and generate an embedding for each index. * Categories that appear less than 5 times in the training dataset are treated as the "unknown" category. The "unknown" category gets its own special lookup index and resulting embedding. Corresponds to the JSON property categorical



32039
32040
32041
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32039

def categorical
  @categorical
end

#numericGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationNumericTransformation

Training pipeline will perform following transformation functions. * The value converted to float32. * The z_score of the value. * log(value+1) when the value is greater than or equal to 0. Otherwise, this transformation is not applied and the value is considered a missing value. * z_score of log(value+1) when the value is greater than or equal to 0. Otherwise, this transformation is not applied and the value is considered a missing value. * A boolean value that indicates whether the value is valid. Corresponds to the JSON property numeric



32050
32051
32052
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32050

def numeric
  @numeric
end

#repeated_categoricalGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationCategoricalArrayTransformation

Treats the column as categorical array and performs following transformation functions. * For each element in the array, convert the category name to a dictionary lookup index and generate an embedding for each index. Combine the embedding of all elements into a single embedding using the mean. * Empty arrays treated as an embedding of zeroes. Corresponds to the JSON property repeatedCategorical



32059
32060
32061
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32059

def repeated_categorical
  @repeated_categorical
end

#repeated_numericGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationNumericArrayTransformation

Treats the column as numerical array and performs following transformation functions. * All transformations for Numerical types applied to the average of the all elements. * The average of empty arrays is treated as zero. Corresponds to the JSON property repeatedNumeric



32066
32067
32068
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32066

def repeated_numeric
  @repeated_numeric
end

#repeated_textGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationTextArrayTransformation

Treats the column as text array and performs following transformation functions. * Concatenate all text values in the array into a single text value using a space (" ") as a delimiter, and then treat the result as a single text value. Apply the transformations for Text columns. * Empty arrays treated as an empty text. Corresponds to the JSON property repeatedText



32075
32076
32077
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32075

def repeated_text
  @repeated_text
end

#textGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationTextTransformation

Training pipeline will perform following transformation functions. * The text as is--no change to case, punctuation, spelling, tense, and so on. * Tokenize text to words. Convert each words to a dictionary lookup index and generate an embedding for each index. Combine the embedding of all elements into a single embedding using the mean. * Tokenization is based on unicode script boundaries.

  • Missing values get their own lookup index and resulting embedding. * Stop- words receive no special treatment and are not removed. Corresponds to the JSON property text


32086
32087
32088
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32086

def text
  @text
end

#timestampGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationTimestampTransformation

Training pipeline will perform following transformation functions. * Apply the transformation functions for Numerical columns. * Determine the year, month, day,and weekday. Treat each value from the * timestamp as a Categorical column.

  • Invalid numerical values (for example, values that fall outside of a typical timestamp range, or are extreme values) receive no special treatment and are not removed. Corresponds to the JSON property timestamp


32096
32097
32098
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32096

def timestamp
  @timestamp
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32103
32104
32105
32106
32107
32108
32109
32110
32111
32112
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32103

def update!(**args)
  @auto = args[:auto] if args.key?(:auto)
  @categorical = args[:categorical] if args.key?(:categorical)
  @numeric = args[:numeric] if args.key?(:numeric)
  @repeated_categorical = args[:repeated_categorical] if args.key?(:repeated_categorical)
  @repeated_numeric = args[:repeated_numeric] if args.key?(:repeated_numeric)
  @repeated_text = args[:repeated_text] if args.key?(:repeated_text)
  @text = args[:text] if args.key?(:text)
  @timestamp = args[:timestamp] if args.key?(:timestamp)
end