Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformation
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Instance Attribute Summary collapse
-
#auto ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationAutoTransformation
Training pipeline will infer the proper transformation based on the statistic of dataset.
-
#categorical ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationCategoricalTransformation
Training pipeline will perform following transformation functions.
-
#numeric ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationNumericTransformation
Training pipeline will perform following transformation functions.
-
#repeated_categorical ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationCategoricalArrayTransformation
Treats the column as categorical array and performs following transformation functions.
-
#repeated_numeric ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationNumericArrayTransformation
Treats the column as numerical array and performs following transformation functions.
-
#repeated_text ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationTextArrayTransformation
Treats the column as text array and performs following transformation functions.
-
#text ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationTextTransformation
Training pipeline will perform following transformation functions.
-
#timestamp ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationTimestampTransformation
Training pipeline will perform following transformation functions.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformation
constructor
A new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformation
Returns a new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformation.
23779 23780 23781 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23779 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationAutoTransformation
Training pipeline will infer the proper transformation based on the statistic
of dataset.
Corresponds to the JSON property auto
23710 23711 23712 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23710 def auto @auto end |
#categorical ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationCategoricalTransformation
Training pipeline will perform following transformation functions. * The
categorical string as is--no change to case, punctuation, spelling, tense, and
so on. * Convert the category name to a dictionary lookup index and generate
an embedding for each index. * Categories that appear less than 5 times in the
training dataset are treated as the "unknown" category. The "unknown" category
gets its own special lookup index and resulting embedding.
Corresponds to the JSON property categorical
23720 23721 23722 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23720 def categorical @categorical end |
#numeric ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationNumericTransformation
Training pipeline will perform following transformation functions. * The value
converted to float32. * The z_score of the value. * log(value+1) when the
value is greater than or equal to 0. Otherwise, this transformation is not
applied and the value is considered a missing value. * z_score of log(value+1)
when the value is greater than or equal to 0. Otherwise, this transformation
is not applied and the value is considered a missing value. * A boolean value
that indicates whether the value is valid.
Corresponds to the JSON property numeric
23731 23732 23733 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23731 def numeric @numeric end |
#repeated_categorical ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationCategoricalArrayTransformation
Treats the column as categorical array and performs following transformation
functions. * For each element in the array, convert the category name to a
dictionary lookup index and generate an embedding for each index. Combine the
embedding of all elements into a single embedding using the mean. * Empty
arrays treated as an embedding of zeroes.
Corresponds to the JSON property repeatedCategorical
23740 23741 23742 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23740 def repeated_categorical @repeated_categorical end |
#repeated_numeric ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationNumericArrayTransformation
Treats the column as numerical array and performs following transformation
functions. * All transformations for Numerical types applied to the average of
the all elements. * The average of empty arrays is treated as zero.
Corresponds to the JSON property repeatedNumeric
23747 23748 23749 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23747 def repeated_numeric @repeated_numeric end |
#repeated_text ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationTextArrayTransformation
Treats the column as text array and performs following transformation
functions. * Concatenate all text values in the array into a single text value
using a space (" ") as a delimiter, and then treat the result as a single text
value. Apply the transformations for Text columns. * Empty arrays treated as
an empty text.
Corresponds to the JSON property repeatedText
23756 23757 23758 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23756 def repeated_text @repeated_text end |
#text ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationTextTransformation
Training pipeline will perform following transformation functions. * The text as is--no change to case, punctuation, spelling, tense, and so on. * Tokenize text to words. Convert each words to a dictionary lookup index and generate an embedding for each index. Combine the embedding of all elements into a single embedding using the mean. * Tokenization is based on unicode script boundaries.
- Missing values get their own lookup index and resulting embedding. * Stop-
words receive no special treatment and are not removed.
Corresponds to the JSON property
text
23767 23768 23769 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23767 def text @text end |
#timestamp ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationTimestampTransformation
Training pipeline will perform following transformation functions. * Apply the transformation functions for Numerical columns. * Determine the year, month, day,and weekday. Treat each value from the * timestamp as a Categorical column.
- Invalid numerical values (for example, values that fall outside of a
typical timestamp range, or are extreme values) receive no special treatment
and are not removed.
Corresponds to the JSON property
timestamp
23777 23778 23779 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23777 def @timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23784 23785 23786 23787 23788 23789 23790 23791 23792 23793 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 23784 def update!(**args) @auto = args[:auto] if args.key?(:auto) @categorical = args[:categorical] if args.key?(:categorical) @numeric = args[:numeric] if args.key?(:numeric) @repeated_categorical = args[:repeated_categorical] if args.key?(:repeated_categorical) @repeated_numeric = args[:repeated_numeric] if args.key?(:repeated_numeric) @repeated_text = args[:repeated_text] if args.key?(:repeated_text) @text = args[:text] if args.key?(:text) @timestamp = args[:timestamp] if args.key?(:timestamp) end |