Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationCategoricalTransformation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Training pipeline will perform following transformation functions. * The categorical string as is--no change to case, punctuation, spelling, tense, and so on. * Convert the category name to a dictionary lookup index and generate an embedding for each index. * Categories that appear less than 5 times in the training dataset are treated as the "unknown" category. The "unknown" category gets its own special lookup index and resulting embedding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationCategoricalTransformation

Returns a new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationCategoricalTransformation.



30754
30755
30756
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30754

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#column_nameString

Corresponds to the JSON property columnName

Returns:

  • (String)


30752
30753
30754
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30752

def column_name
  @column_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30759
30760
30761
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30759

def update!(**args)
  @column_name = args[:column_name] if args.key?(:column_name)
end