Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationTextArrayTransformation
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationTextArrayTransformation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Treats the column as text array and performs following transformation functions. * Concatenate all text values in the array into a single text value using a space (" ") as a delimiter, and then treat the result as a single text value. Apply the transformations for Text columns. * Empty arrays treated as an empty text.
Instance Attribute Summary collapse
-
#column_name ⇒ String
Corresponds to the JSON property
columnName.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationTextArrayTransformation
constructor
A new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationTextArrayTransformation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationTextArrayTransformation
Returns a new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutoMlTablesInputsTransformationTextArrayTransformation.
32395 32396 32397 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32395 def initialize(**args) update!(**args) end |
Instance Attribute Details
#column_name ⇒ String
Corresponds to the JSON property columnName
32393 32394 32395 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32393 def column_name @column_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32400 32401 32402 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32400 def update!(**args) @column_name = args[:column_name] if args.key?(:column_name) end |