Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutomlImageTrainingTunableParameter

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A wrapper class which contains the tunable parameters in an AutoML Image training job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutomlImageTrainingTunableParameter

Returns a new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutomlImageTrainingTunableParameter.



40591
40592
40593
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40591

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#checkpoint_nameString

Optional. An unique name of pretrained model checkpoint provided in model garden, it will be mapped to a GCS location internally. Corresponds to the JSON property checkpointName

Returns:

  • (String)


40569
40570
40571
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40569

def checkpoint_name
  @checkpoint_name
end

#dataset_configHash<String,String>

Customizable dataset settings, used in the model_garden_trainer. Corresponds to the JSON property datasetConfig

Returns:

  • (Hash<String,String>)


40574
40575
40576
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40574

def dataset_config
  @dataset_config
end

#study_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpec

Represents specification of a Study. Corresponds to the JSON property studySpec



40579
40580
40581
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40579

def study_spec
  @study_spec
end

#trainer_configHash<String,String>

Customizable trainer settings, used in the model_garden_trainer. Corresponds to the JSON property trainerConfig

Returns:

  • (Hash<String,String>)


40584
40585
40586
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40584

def trainer_config
  @trainer_config
end

#trainer_typeString

Corresponds to the JSON property trainerType

Returns:

  • (String)


40589
40590
40591
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40589

def trainer_type
  @trainer_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40596
40597
40598
40599
40600
40601
40602
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40596

def update!(**args)
  @checkpoint_name = args[:checkpoint_name] if args.key?(:checkpoint_name)
  @dataset_config = args[:dataset_config] if args.key?(:dataset_config)
  @study_spec = args[:study_spec] if args.key?(:study_spec)
  @trainer_config = args[:trainer_config] if args.key?(:trainer_config)
  @trainer_type = args[:trainer_type] if args.key?(:trainer_type)
end