Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutomlImageTrainingTunableParameter
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutomlImageTrainingTunableParameter
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A wrapper class which contains the tunable parameters in an AutoML Image training job.
Instance Attribute Summary collapse
-
#checkpoint_name ⇒ String
Optional.
-
#dataset_config ⇒ Hash<String,String>
Customizable dataset settings, used in the
model_garden_trainer. -
#study_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpec
Represents specification of a Study.
-
#trainer_config ⇒ Hash<String,String>
Customizable trainer settings, used in the
model_garden_trainer. -
#trainer_type ⇒ String
Corresponds to the JSON property
trainerType.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutomlImageTrainingTunableParameter
constructor
A new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutomlImageTrainingTunableParameter.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutomlImageTrainingTunableParameter
Returns a new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutomlImageTrainingTunableParameter.
38849 38850 38851 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38849 def initialize(**args) update!(**args) end |
Instance Attribute Details
#checkpoint_name ⇒ String
Optional. An unique name of pretrained model checkpoint provided in model
garden, it will be mapped to a GCS location internally.
Corresponds to the JSON property checkpointName
38827 38828 38829 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38827 def checkpoint_name @checkpoint_name end |
#dataset_config ⇒ Hash<String,String>
Customizable dataset settings, used in the model_garden_trainer.
Corresponds to the JSON property datasetConfig
38832 38833 38834 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38832 def dataset_config @dataset_config end |
#study_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpec
Represents specification of a Study.
Corresponds to the JSON property studySpec
38837 38838 38839 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38837 def study_spec @study_spec end |
#trainer_config ⇒ Hash<String,String>
Customizable trainer settings, used in the model_garden_trainer.
Corresponds to the JSON property trainerConfig
38842 38843 38844 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38842 def trainer_config @trainer_config end |
#trainer_type ⇒ String
Corresponds to the JSON property trainerType
38847 38848 38849 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38847 def trainer_type @trainer_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38854 38855 38856 38857 38858 38859 38860 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38854 def update!(**args) @checkpoint_name = args[:checkpoint_name] if args.key?(:checkpoint_name) @dataset_config = args[:dataset_config] if args.key?(:dataset_config) @study_spec = args[:study_spec] if args.key?(:study_spec) @trainer_config = args[:trainer_config] if args.key?(:trainer_config) @trainer_type = args[:trainer_type] if args.key?(:trainer_type) end |