Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutomlImageTrainingTunableParameter

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A wrapper class which contains the tunable parameters in an AutoML Image training job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutomlImageTrainingTunableParameter

Returns a new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutomlImageTrainingTunableParameter.



32832
32833
32834
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32832

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#checkpoint_nameString

Optional. An unique name of pretrained model checkpoint provided in model garden, it will be mapped to a GCS location internally. Corresponds to the JSON property checkpointName

Returns:

  • (String)


32810
32811
32812
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32810

def checkpoint_name
  @checkpoint_name
end

#dataset_configHash<String,String>

Customizable dataset settings, used in the model_garden_trainer. Corresponds to the JSON property datasetConfig

Returns:

  • (Hash<String,String>)


32815
32816
32817
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32815

def dataset_config
  @dataset_config
end

#study_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpec

Represents specification of a Study. Corresponds to the JSON property studySpec



32820
32821
32822
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32820

def study_spec
  @study_spec
end

#trainer_configHash<String,String>

Customizable trainer settings, used in the model_garden_trainer. Corresponds to the JSON property trainerConfig

Returns:

  • (Hash<String,String>)


32825
32826
32827
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32825

def trainer_config
  @trainer_config
end

#trainer_typeString

Corresponds to the JSON property trainerType

Returns:

  • (String)


32830
32831
32832
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32830

def trainer_type
  @trainer_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32837
32838
32839
32840
32841
32842
32843
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32837

def update!(**args)
  @checkpoint_name = args[:checkpoint_name] if args.key?(:checkpoint_name)
  @dataset_config = args[:dataset_config] if args.key?(:dataset_config)
  @study_spec = args[:study_spec] if args.key?(:study_spec)
  @trainer_config = args[:trainer_config] if args.key?(:trainer_config)
  @trainer_type = args[:trainer_type] if args.key?(:trainer_type)
end