Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutomlImageTrainingTunableParameter
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutomlImageTrainingTunableParameter
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A wrapper class which contains the tunable parameters in an AutoML Image training job.
Instance Attribute Summary collapse
-
#checkpoint_name ⇒ String
Optional.
-
#dataset_config ⇒ Hash<String,String>
Customizable dataset settings, used in the
model_garden_trainer. -
#study_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpec
Represents specification of a Study.
-
#trainer_config ⇒ Hash<String,String>
Customizable trainer settings, used in the
model_garden_trainer. -
#trainer_type ⇒ String
Corresponds to the JSON property
trainerType.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutomlImageTrainingTunableParameter
constructor
A new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutomlImageTrainingTunableParameter.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutomlImageTrainingTunableParameter
Returns a new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionAutomlImageTrainingTunableParameter.
24379 24380 24381 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24379 def initialize(**args) update!(**args) end |
Instance Attribute Details
#checkpoint_name ⇒ String
Optional. An unique name of pretrained model checkpoint provided in model
garden, it will be mapped to a GCS location internally.
Corresponds to the JSON property checkpointName
24357 24358 24359 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24357 def checkpoint_name @checkpoint_name end |
#dataset_config ⇒ Hash<String,String>
Customizable dataset settings, used in the model_garden_trainer.
Corresponds to the JSON property datasetConfig
24362 24363 24364 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24362 def dataset_config @dataset_config end |
#study_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpec
Represents specification of a Study.
Corresponds to the JSON property studySpec
24367 24368 24369 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24367 def study_spec @study_spec end |
#trainer_config ⇒ Hash<String,String>
Customizable trainer settings, used in the model_garden_trainer.
Corresponds to the JSON property trainerConfig
24372 24373 24374 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24372 def trainer_config @trainer_config end |
#trainer_type ⇒ String
Corresponds to the JSON property trainerType
24377 24378 24379 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24377 def trainer_type @trainer_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24384 24385 24386 24387 24388 24389 24390 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24384 def update!(**args) @checkpoint_name = args[:checkpoint_name] if args.key?(:checkpoint_name) @dataset_config = args[:dataset_config] if args.key?(:dataset_config) @study_spec = args[:study_spec] if args.key?(:study_spec) @trainer_config = args[:trainer_config] if args.key?(:trainer_config) @trainer_type = args[:trainer_type] if args.key?(:trainer_type) end |