Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionExportEvaluatedDataItemsConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Configuration for exporting test set predictions to a BigQuery table.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionExportEvaluatedDataItemsConfig

Returns a new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionExportEvaluatedDataItemsConfig.



27649
27650
27651
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27649

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destination_bigquery_uriString

URI of desired destination BigQuery table. Expected format: bq://project_id: dataset_id:tableIf not specified, then results are exported to the following auto-created BigQuery table:project_id: export_evaluated_examples_model_name_yyyy_MM_dd'T'HH_mm_ss_SSS'Z'. evaluated_examples Corresponds to the JSON property destinationBigqueryUri

Returns:

  • (String)


27639
27640
27641
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27639

def destination_bigquery_uri
  @destination_bigquery_uri
end

#override_existing_tableBoolean Also known as: override_existing_table?

If true and an export destination is specified, then the contents of the destination are overwritten. Otherwise, if the export destination already exists, then the export operation fails. Corresponds to the JSON property overrideExistingTable

Returns:

  • (Boolean)


27646
27647
27648
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27646

def override_existing_table
  @override_existing_table
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27654
27655
27656
27657
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27654

def update!(**args)
  @destination_bigquery_uri = args[:destination_bigquery_uri] if args.key?(:destination_bigquery_uri)
  @override_existing_table = args[:override_existing_table] if args.key?(:override_existing_table)
end