Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionHyperparameterTuningJobSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionHyperparameterTuningJobSpec

Returns a new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionHyperparameterTuningJobSpec.



40787
40788
40789
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40787

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_failed_trial_countFixnum

The number of failed Trials that need to be seen before failing the HyperparameterTuningJob. If set to 0, Vertex AI decides how many Trials must fail before the whole job fails. Corresponds to the JSON property maxFailedTrialCount

Returns:

  • (Fixnum)


40765
40766
40767
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40765

def max_failed_trial_count
  @max_failed_trial_count
end

#max_trial_countFixnum

The desired total number of Trials. Corresponds to the JSON property maxTrialCount

Returns:

  • (Fixnum)


40770
40771
40772
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40770

def max_trial_count
  @max_trial_count
end

#parallel_trial_countFixnum

The desired number of Trials to run in parallel. Corresponds to the JSON property parallelTrialCount

Returns:

  • (Fixnum)


40775
40776
40777
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40775

def parallel_trial_count
  @parallel_trial_count
end

#study_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpec

Represents specification of a Study. Corresponds to the JSON property studySpec



40780
40781
40782
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40780

def study_spec
  @study_spec
end

#trial_job_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1CustomJobSpec

Represents the spec of a CustomJob. Corresponds to the JSON property trialJobSpec



40785
40786
40787
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40785

def trial_job_spec
  @trial_job_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40792
40793
40794
40795
40796
40797
40798
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40792

def update!(**args)
  @max_failed_trial_count = args[:max_failed_trial_count] if args.key?(:max_failed_trial_count)
  @max_trial_count = args[:max_trial_count] if args.key?(:max_trial_count)
  @parallel_trial_count = args[:parallel_trial_count] if args.key?(:parallel_trial_count)
  @study_spec = args[:study_spec] if args.key?(:study_spec)
  @trial_job_spec = args[:trial_job_spec] if args.key?(:trial_job_spec)
end