Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionHyperparameterTuningJobSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionHyperparameterTuningJobSpec

Returns a new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionHyperparameterTuningJobSpec.



33028
33029
33030
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33028

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_failed_trial_countFixnum

The number of failed Trials that need to be seen before failing the HyperparameterTuningJob. If set to 0, Vertex AI decides how many Trials must fail before the whole job fails. Corresponds to the JSON property maxFailedTrialCount

Returns:

  • (Fixnum)


33006
33007
33008
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33006

def max_failed_trial_count
  @max_failed_trial_count
end

#max_trial_countFixnum

The desired total number of Trials. Corresponds to the JSON property maxTrialCount

Returns:

  • (Fixnum)


33011
33012
33013
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33011

def max_trial_count
  @max_trial_count
end

#parallel_trial_countFixnum

The desired number of Trials to run in parallel. Corresponds to the JSON property parallelTrialCount

Returns:

  • (Fixnum)


33016
33017
33018
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33016

def parallel_trial_count
  @parallel_trial_count
end

#study_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpec

Represents specification of a Study. Corresponds to the JSON property studySpec



33021
33022
33023
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33021

def study_spec
  @study_spec
end

#trial_job_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1CustomJobSpec

Represents the spec of a CustomJob. Corresponds to the JSON property trialJobSpec



33026
33027
33028
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33026

def trial_job_spec
  @trial_job_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33033
33034
33035
33036
33037
33038
33039
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33033

def update!(**args)
  @max_failed_trial_count = args[:max_failed_trial_count] if args.key?(:max_failed_trial_count)
  @max_trial_count = args[:max_trial_count] if args.key?(:max_trial_count)
  @parallel_trial_count = args[:parallel_trial_count] if args.key?(:parallel_trial_count)
  @study_spec = args[:study_spec] if args.key?(:study_spec)
  @trial_job_spec = args[:trial_job_spec] if args.key?(:trial_job_spec)
end