Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionHyperparameterTuningJobSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionHyperparameterTuningJobSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Instance Attribute Summary collapse
-
#max_failed_trial_count ⇒ Fixnum
The number of failed Trials that need to be seen before failing the HyperparameterTuningJob.
-
#max_trial_count ⇒ Fixnum
The desired total number of Trials.
-
#parallel_trial_count ⇒ Fixnum
The desired number of Trials to run in parallel.
-
#study_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpec
Represents specification of a Study.
-
#trial_job_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CustomJobSpec
Represents the spec of a CustomJob.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionHyperparameterTuningJobSpec
constructor
A new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionHyperparameterTuningJobSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionHyperparameterTuningJobSpec
Returns a new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionHyperparameterTuningJobSpec.
31952 31953 31954 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31952 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_failed_trial_count ⇒ Fixnum
The number of failed Trials that need to be seen before failing the
HyperparameterTuningJob. If set to 0, Vertex AI decides how many Trials must
fail before the whole job fails.
Corresponds to the JSON property maxFailedTrialCount
31930 31931 31932 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31930 def max_failed_trial_count @max_failed_trial_count end |
#max_trial_count ⇒ Fixnum
The desired total number of Trials.
Corresponds to the JSON property maxTrialCount
31935 31936 31937 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31935 def max_trial_count @max_trial_count end |
#parallel_trial_count ⇒ Fixnum
The desired number of Trials to run in parallel.
Corresponds to the JSON property parallelTrialCount
31940 31941 31942 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31940 def parallel_trial_count @parallel_trial_count end |
#study_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpec
Represents specification of a Study.
Corresponds to the JSON property studySpec
31945 31946 31947 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31945 def study_spec @study_spec end |
#trial_job_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CustomJobSpec
Represents the spec of a CustomJob.
Corresponds to the JSON property trialJobSpec
31950 31951 31952 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31950 def trial_job_spec @trial_job_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31957 31958 31959 31960 31961 31962 31963 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31957 def update!(**args) @max_failed_trial_count = args[:max_failed_trial_count] if args.key?(:max_failed_trial_count) @max_trial_count = args[:max_trial_count] if args.key?(:max_trial_count) @parallel_trial_count = args[:parallel_trial_count] if args.key?(:parallel_trial_count) @study_spec = args[:study_spec] if args.key?(:study_spec) @trial_job_spec = args[:trial_job_spec] if args.key?(:trial_job_spec) end |