Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionHyperparameterTuningJobSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionHyperparameterTuningJobSpec

Returns a new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionHyperparameterTuningJobSpec.



31671
31672
31673
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31671

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_failed_trial_countFixnum

The number of failed Trials that need to be seen before failing the HyperparameterTuningJob. If set to 0, Vertex AI decides how many Trials must fail before the whole job fails. Corresponds to the JSON property maxFailedTrialCount

Returns:

  • (Fixnum)


31649
31650
31651
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31649

def max_failed_trial_count
  @max_failed_trial_count
end

#max_trial_countFixnum

The desired total number of Trials. Corresponds to the JSON property maxTrialCount

Returns:

  • (Fixnum)


31654
31655
31656
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31654

def max_trial_count
  @max_trial_count
end

#parallel_trial_countFixnum

The desired number of Trials to run in parallel. Corresponds to the JSON property parallelTrialCount

Returns:

  • (Fixnum)


31659
31660
31661
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31659

def parallel_trial_count
  @parallel_trial_count
end

#study_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpec

Represents specification of a Study. Corresponds to the JSON property studySpec



31664
31665
31666
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31664

def study_spec
  @study_spec
end

#trial_job_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1CustomJobSpec

Represents the spec of a CustomJob. Corresponds to the JSON property trialJobSpec



31669
31670
31671
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31669

def trial_job_spec
  @trial_job_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31676
31677
31678
31679
31680
31681
31682
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31676

def update!(**args)
  @max_failed_trial_count = args[:max_failed_trial_count] if args.key?(:max_failed_trial_count)
  @max_trial_count = args[:max_trial_count] if args.key?(:max_trial_count)
  @parallel_trial_count = args[:parallel_trial_count] if args.key?(:parallel_trial_count)
  @study_spec = args[:study_spec] if args.key?(:study_spec)
  @trial_job_spec = args[:trial_job_spec] if args.key?(:trial_job_spec)
end