Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionHyperparameterTuningJobSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionHyperparameterTuningJobSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Instance Attribute Summary collapse
-
#max_failed_trial_count ⇒ Fixnum
The number of failed Trials that need to be seen before failing the HyperparameterTuningJob.
-
#max_trial_count ⇒ Fixnum
The desired total number of Trials.
-
#parallel_trial_count ⇒ Fixnum
The desired number of Trials to run in parallel.
-
#study_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpec
Represents specification of a Study.
-
#trial_job_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CustomJobSpec
Represents the spec of a CustomJob.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionHyperparameterTuningJobSpec
constructor
A new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionHyperparameterTuningJobSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionHyperparameterTuningJobSpec
Returns a new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionHyperparameterTuningJobSpec.
31303 31304 31305 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31303 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_failed_trial_count ⇒ Fixnum
The number of failed Trials that need to be seen before failing the
HyperparameterTuningJob. If set to 0, Vertex AI decides how many Trials must
fail before the whole job fails.
Corresponds to the JSON property maxFailedTrialCount
31281 31282 31283 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31281 def max_failed_trial_count @max_failed_trial_count end |
#max_trial_count ⇒ Fixnum
The desired total number of Trials.
Corresponds to the JSON property maxTrialCount
31286 31287 31288 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31286 def max_trial_count @max_trial_count end |
#parallel_trial_count ⇒ Fixnum
The desired number of Trials to run in parallel.
Corresponds to the JSON property parallelTrialCount
31291 31292 31293 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31291 def parallel_trial_count @parallel_trial_count end |
#study_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpec
Represents specification of a Study.
Corresponds to the JSON property studySpec
31296 31297 31298 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31296 def study_spec @study_spec end |
#trial_job_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CustomJobSpec
Represents the spec of a CustomJob.
Corresponds to the JSON property trialJobSpec
31301 31302 31303 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31301 def trial_job_spec @trial_job_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31308 31309 31310 31311 31312 31313 31314 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31308 def update!(**args) @max_failed_trial_count = args[:max_failed_trial_count] if args.key?(:max_failed_trial_count) @max_trial_count = args[:max_trial_count] if args.key?(:max_trial_count) @parallel_trial_count = args[:parallel_trial_count] if args.key?(:parallel_trial_count) @study_spec = args[:study_spec] if args.key?(:study_spec) @trial_job_spec = args[:trial_job_spec] if args.key?(:trial_job_spec) end |