Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionHyperparameterTuningJobSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionHyperparameterTuningJobSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Instance Attribute Summary collapse
-
#max_failed_trial_count ⇒ Fixnum
The number of failed Trials that need to be seen before failing the HyperparameterTuningJob.
-
#max_trial_count ⇒ Fixnum
The desired total number of Trials.
-
#parallel_trial_count ⇒ Fixnum
The desired number of Trials to run in parallel.
-
#study_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpec
Represents specification of a Study.
-
#trial_job_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CustomJobSpec
Represents the spec of a CustomJob.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionHyperparameterTuningJobSpec
constructor
A new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionHyperparameterTuningJobSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionHyperparameterTuningJobSpec
Returns a new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionHyperparameterTuningJobSpec.
24528 24529 24530 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24528 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_failed_trial_count ⇒ Fixnum
The number of failed Trials that need to be seen before failing the
HyperparameterTuningJob. If set to 0, Vertex AI decides how many Trials must
fail before the whole job fails.
Corresponds to the JSON property maxFailedTrialCount
24506 24507 24508 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24506 def max_failed_trial_count @max_failed_trial_count end |
#max_trial_count ⇒ Fixnum
The desired total number of Trials.
Corresponds to the JSON property maxTrialCount
24511 24512 24513 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24511 def max_trial_count @max_trial_count end |
#parallel_trial_count ⇒ Fixnum
The desired number of Trials to run in parallel.
Corresponds to the JSON property parallelTrialCount
24516 24517 24518 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24516 def parallel_trial_count @parallel_trial_count end |
#study_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpec
Represents specification of a Study.
Corresponds to the JSON property studySpec
24521 24522 24523 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24521 def study_spec @study_spec end |
#trial_job_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1CustomJobSpec
Represents the spec of a CustomJob.
Corresponds to the JSON property trialJobSpec
24526 24527 24528 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24526 def trial_job_spec @trial_job_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24533 24534 24535 24536 24537 24538 24539 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24533 def update!(**args) @max_failed_trial_count = args[:max_failed_trial_count] if args.key?(:max_failed_trial_count) @max_trial_count = args[:max_trial_count] if args.key?(:max_trial_count) @parallel_trial_count = args[:parallel_trial_count] if args.key?(:parallel_trial_count) @study_spec = args[:study_spec] if args.key?(:study_spec) @trial_job_spec = args[:trial_job_spec] if args.key?(:trial_job_spec) end |