Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsTransformation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsTransformation

Returns a new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsTransformation.



33726
33727
33728
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33726

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#autoGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsTransformationAutoTransformation

Training pipeline will infer the proper transformation based on the statistic of dataset. Corresponds to the JSON property auto



33686
33687
33688
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33686

def auto
  @auto
end

#categoricalGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsTransformationCategoricalTransformation

Training pipeline will perform following transformation functions. * The categorical string as is--no change to case, punctuation, spelling, tense, and so on. * Convert the category name to a dictionary lookup index and generate an embedding for each index. * Categories that appear less than 5 times in the training dataset are treated as the "unknown" category. The "unknown" category gets its own special lookup index and resulting embedding. Corresponds to the JSON property categorical



33696
33697
33698
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33696

def categorical
  @categorical
end

#numericGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsTransformationNumericTransformation

Training pipeline will perform following transformation functions. * The value converted to float32. * The z_score of the value. * log(value+1) when the value is greater than or equal to 0. Otherwise, this transformation is not applied and the value is considered a missing value. * z_score of log(value+1) when the value is greater than or equal to 0. Otherwise, this transformation is not applied and the value is considered a missing value. Corresponds to the JSON property numeric



33706
33707
33708
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33706

def numeric
  @numeric
end

#textGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsTransformationTextTransformation

Training pipeline will perform following transformation functions. * The text as is--no change to case, punctuation, spelling, tense, and so on. * Convert the category name to a dictionary lookup index and generate an embedding for each index. Corresponds to the JSON property text



33714
33715
33716
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33714

def text
  @text
end

#timestampGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsTransformationTimestampTransformation

Training pipeline will perform following transformation functions. * Apply the transformation functions for Numerical columns. * Determine the year, month, day,and weekday. Treat each value from the timestamp as a Categorical column. * Invalid numerical values (for example, values that fall outside of a typical timestamp range, or are extreme values) receive no special treatment and are not removed. Corresponds to the JSON property timestamp



33724
33725
33726
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33724

def timestamp
  @timestamp
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33731
33732
33733
33734
33735
33736
33737
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33731

def update!(**args)
  @auto = args[:auto] if args.key?(:auto)
  @categorical = args[:categorical] if args.key?(:categorical)
  @numeric = args[:numeric] if args.key?(:numeric)
  @text = args[:text] if args.key?(:text)
  @timestamp = args[:timestamp] if args.key?(:timestamp)
end