Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsTransformation
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsTransformation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Instance Attribute Summary collapse
-
#auto ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsTransformationAutoTransformation
Training pipeline will infer the proper transformation based on the statistic of dataset.
-
#categorical ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsTransformationCategoricalTransformation
Training pipeline will perform following transformation functions.
-
#numeric ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsTransformationNumericTransformation
Training pipeline will perform following transformation functions.
-
#text ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsTransformationTextTransformation
Training pipeline will perform following transformation functions.
-
#timestamp ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsTransformationTimestampTransformation
Training pipeline will perform following transformation functions.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsTransformation
constructor
A new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsTransformation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsTransformation
Returns a new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsTransformation.
32674 32675 32676 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32674 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsTransformationAutoTransformation
Training pipeline will infer the proper transformation based on the statistic
of dataset.
Corresponds to the JSON property auto
32634 32635 32636 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32634 def auto @auto end |
#categorical ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsTransformationCategoricalTransformation
Training pipeline will perform following transformation functions. * The
categorical string as is--no change to case, punctuation, spelling, tense, and
so on. * Convert the category name to a dictionary lookup index and generate
an embedding for each index. * Categories that appear less than 5 times in the
training dataset are treated as the "unknown" category. The "unknown" category
gets its own special lookup index and resulting embedding.
Corresponds to the JSON property categorical
32644 32645 32646 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32644 def categorical @categorical end |
#numeric ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsTransformationNumericTransformation
Training pipeline will perform following transformation functions. * The value
converted to float32. * The z_score of the value. * log(value+1) when the
value is greater than or equal to 0. Otherwise, this transformation is not
applied and the value is considered a missing value. * z_score of log(value+1)
when the value is greater than or equal to 0. Otherwise, this transformation
is not applied and the value is considered a missing value.
Corresponds to the JSON property numeric
32654 32655 32656 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32654 def numeric @numeric end |
#text ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsTransformationTextTransformation
Training pipeline will perform following transformation functions. * The text
as is--no change to case, punctuation, spelling, tense, and so on. * Convert
the category name to a dictionary lookup index and generate an embedding for
each index.
Corresponds to the JSON property text
32662 32663 32664 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32662 def text @text end |
#timestamp ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionSeq2SeqPlusForecastingInputsTransformationTimestampTransformation
Training pipeline will perform following transformation functions. * Apply the
transformation functions for Numerical columns. * Determine the year, month,
day,and weekday. Treat each value from the timestamp as a Categorical column. *
Invalid numerical values (for example, values that fall outside of a typical
timestamp range, or are extreme values) receive no special treatment and are
not removed.
Corresponds to the JSON property timestamp
32672 32673 32674 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32672 def @timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32679 32680 32681 32682 32683 32684 32685 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32679 def update!(**args) @auto = args[:auto] if args.key?(:auto) @categorical = args[:categorical] if args.key?(:categorical) @numeric = args[:numeric] if args.key?(:numeric) @text = args[:text] if args.key?(:text) @timestamp = args[:timestamp] if args.key?(:timestamp) end |