Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionTftForecastingInputsTransformation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionTftForecastingInputsTransformation

Returns a new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionTftForecastingInputsTransformation.



26565
26566
26567
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26565

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#autoGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionTftForecastingInputsTransformationAutoTransformation

Training pipeline will infer the proper transformation based on the statistic of dataset. Corresponds to the JSON property auto



26525
26526
26527
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26525

def auto
  @auto
end

#categoricalGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionTftForecastingInputsTransformationCategoricalTransformation

Training pipeline will perform following transformation functions. * The categorical string as is--no change to case, punctuation, spelling, tense, and so on. * Convert the category name to a dictionary lookup index and generate an embedding for each index. * Categories that appear less than 5 times in the training dataset are treated as the "unknown" category. The "unknown" category gets its own special lookup index and resulting embedding. Corresponds to the JSON property categorical



26535
26536
26537
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26535

def categorical
  @categorical
end

#numericGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionTftForecastingInputsTransformationNumericTransformation

Training pipeline will perform following transformation functions. * The value converted to float32. * The z_score of the value. * log(value+1) when the value is greater than or equal to 0. Otherwise, this transformation is not applied and the value is considered a missing value. * z_score of log(value+1) when the value is greater than or equal to 0. Otherwise, this transformation is not applied and the value is considered a missing value. Corresponds to the JSON property numeric



26545
26546
26547
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26545

def numeric
  @numeric
end

#textGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionTftForecastingInputsTransformationTextTransformation

Training pipeline will perform following transformation functions. * The text as is--no change to case, punctuation, spelling, tense, and so on. * Convert the category name to a dictionary lookup index and generate an embedding for each index. Corresponds to the JSON property text



26553
26554
26555
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26553

def text
  @text
end

#timestampGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionTftForecastingInputsTransformationTimestampTransformation

Training pipeline will perform following transformation functions. * Apply the transformation functions for Numerical columns. * Determine the year, month, day,and weekday. Treat each value from the timestamp as a Categorical column. * Invalid numerical values (for example, values that fall outside of a typical timestamp range, or are extreme values) receive no special treatment and are not removed. Corresponds to the JSON property timestamp



26563
26564
26565
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26563

def timestamp
  @timestamp
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26570
26571
26572
26573
26574
26575
26576
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26570

def update!(**args)
  @auto = args[:auto] if args.key?(:auto)
  @categorical = args[:categorical] if args.key?(:categorical)
  @numeric = args[:numeric] if args.key?(:numeric)
  @text = args[:text] if args.key?(:text)
  @timestamp = args[:timestamp] if args.key?(:timestamp)
end