Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionWindowConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionWindowConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Config that contains the strategy used to generate sliding windows in time series training. A window is a series of rows that comprise the context up to the time of prediction, and the horizon following. The corresponding row for each window marks the start of the forecast horizon. Each window is used as an input example for training/evaluation.
Instance Attribute Summary collapse
-
#column ⇒ String
Name of the column that should be used to generate sliding windows.
-
#max_count ⇒ Fixnum
Maximum number of windows that should be generated across all time series.
-
#stride_length ⇒ Fixnum
Stride length used to generate input examples.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionWindowConfig
constructor
A new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionWindowConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionWindowConfig
Returns a new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionWindowConfig.
32279 32280 32281 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32279 def initialize(**args) update!(**args) end |
Instance Attribute Details
#column ⇒ String
Name of the column that should be used to generate sliding windows. The column
should contain either booleans or string booleans; if the value of the row is
True, generate a sliding window with the horizon starting at that row. The
column will not be used as a feature in training.
Corresponds to the JSON property column
32266 32267 32268 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32266 def column @column end |
#max_count ⇒ Fixnum
Maximum number of windows that should be generated across all time series.
Corresponds to the JSON property maxCount
32271 32272 32273 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32271 def max_count @max_count end |
#stride_length ⇒ Fixnum
Stride length used to generate input examples. Within one time series, every $
STRIDE_LENGTH rows will be used to generate a sliding window.
Corresponds to the JSON property strideLength
32277 32278 32279 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32277 def stride_length @stride_length end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32284 32285 32286 32287 32288 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32284 def update!(**args) @column = args[:column] if args.key?(:column) @max_count = args[:max_count] if args.key?(:max_count) @stride_length = args[:stride_length] if args.key?(:stride_length) end |