Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaTrainingjobDefinitionWindowConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Config that contains the strategy used to generate sliding windows in time series training. A window is a series of rows that comprise the context up to the time of prediction, and the horizon following. The corresponding row for each window marks the start of the forecast horizon. Each window is used as an input example for training/evaluation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaTrainingjobDefinitionWindowConfig

Returns a new instance of GoogleCloudAiplatformV1SchemaTrainingjobDefinitionWindowConfig.



24297
24298
24299
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24297

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#columnString

Name of the column that should be used to generate sliding windows. The column should contain either booleans or string booleans; if the value of the row is True, generate a sliding window with the horizon starting at that row. The column will not be used as a feature in training. Corresponds to the JSON property column

Returns:

  • (String)


24284
24285
24286
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24284

def column
  @column
end

#max_countFixnum

Maximum number of windows that should be generated across all time series. Corresponds to the JSON property maxCount

Returns:

  • (Fixnum)


24289
24290
24291
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24289

def max_count
  @max_count
end

#stride_lengthFixnum

Stride length used to generate input examples. Within one time series, every $ STRIDE_LENGTH rows will be used to generate a sliding window. Corresponds to the JSON property strideLength

Returns:

  • (Fixnum)


24295
24296
24297
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24295

def stride_length
  @stride_length
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24302
24303
24304
24305
24306
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 24302

def update!(**args)
  @column = args[:column] if args.key?(:column)
  @max_count = args[:max_count] if args.key?(:max_count)
  @stride_length = args[:stride_length] if args.key?(:stride_length)
end