Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaVertex

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents a 2D point in the image. Vertex coordinates are normalized to be relative to the original image dimensions and range from 0 to 1. The origin of the coordinate system (0,0) is the top-left corner of the image. x increases to the right, and y increases to the bottom.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaVertex

Returns a new instance of GoogleCloudAiplatformV1SchemaVertex.



43373
43374
43375
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 43373

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#xFloat

X coordinate of the vertex, normalized to [0.0, 1.0]. Corresponds to the JSON property x

Returns:

  • (Float)


43366
43367
43368
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 43366

def x
  @x
end

#yFloat

Y coordinate of the vertex, normalized to [0.0, 1.0]. Corresponds to the JSON property y

Returns:

  • (Float)


43371
43372
43373
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 43371

def y
  @y
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43378
43379
43380
43381
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 43378

def update!(**args)
  @x = args[:x] if args.key?(:x)
  @y = args[:y] if args.key?(:y)
end