Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaVertex
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaVertex
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Represents a 2D point in the image. Vertex coordinates are normalized to be relative to the original image dimensions and range from 0 to 1. The origin of the coordinate system (0,0) is the top-left corner of the image. x increases to the right, and y increases to the bottom.
Instance Attribute Summary collapse
-
#x ⇒ Float
X coordinate of the vertex, normalized to [0.0, 1.0].
-
#y ⇒ Float
Y coordinate of the vertex, normalized to [0.0, 1.0].
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaVertex
constructor
A new instance of GoogleCloudAiplatformV1SchemaVertex.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaVertex
Returns a new instance of GoogleCloudAiplatformV1SchemaVertex.
40050 40051 40052 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40050 def initialize(**args) update!(**args) end |
Instance Attribute Details
#x ⇒ Float
X coordinate of the vertex, normalized to [0.0, 1.0].
Corresponds to the JSON property x
40043 40044 40045 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40043 def x @x end |
#y ⇒ Float
Y coordinate of the vertex, normalized to [0.0, 1.0].
Corresponds to the JSON property y
40048 40049 40050 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40048 def y @y end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40055 40056 40057 40058 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40055 def update!(**args) @x = args[:x] if args.key?(:x) @y = args[:y] if args.key?(:y) end |