Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaVideoObjectTrackingAnnotation
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaVideoObjectTrackingAnnotation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Annotation details specific to video object tracking.
Instance Attribute Summary collapse
-
#annotation_spec_id ⇒ String
The resource Id of the AnnotationSpec that this Annotation pertains to.
-
#display_name ⇒ String
The display name of the AnnotationSpec that this Annotation pertains to.
-
#instance_id ⇒ Fixnum
The instance of the object, expressed as a positive integer.
-
#time_offset ⇒ String
A time (frame) of a video to which this annotation pertains.
-
#x_max ⇒ Float
The rightmost coordinate of the bounding box.
-
#x_min ⇒ Float
The leftmost coordinate of the bounding box.
-
#y_max ⇒ Float
The bottommost coordinate of the bounding box.
-
#y_min ⇒ Float
The topmost coordinate of the bounding box.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaVideoObjectTrackingAnnotation
constructor
A new instance of GoogleCloudAiplatformV1SchemaVideoObjectTrackingAnnotation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaVideoObjectTrackingAnnotation
Returns a new instance of GoogleCloudAiplatformV1SchemaVideoObjectTrackingAnnotation.
45018 45019 45020 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45018 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotation_spec_id ⇒ String
The resource Id of the AnnotationSpec that this Annotation pertains to.
Corresponds to the JSON property annotationSpecId
44979 44980 44981 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44979 def annotation_spec_id @annotation_spec_id end |
#display_name ⇒ String
The display name of the AnnotationSpec that this Annotation pertains to.
Corresponds to the JSON property displayName
44984 44985 44986 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44984 def display_name @display_name end |
#instance_id ⇒ Fixnum
The instance of the object, expressed as a positive integer. Used to track the
same object across different frames.
Corresponds to the JSON property instanceId
44990 44991 44992 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44990 def instance_id @instance_id end |
#time_offset ⇒ String
A time (frame) of a video to which this annotation pertains. Represented as
the duration since the video's start.
Corresponds to the JSON property timeOffset
44996 44997 44998 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44996 def time_offset @time_offset end |
#x_max ⇒ Float
The rightmost coordinate of the bounding box.
Corresponds to the JSON property xMax
45001 45002 45003 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45001 def x_max @x_max end |
#x_min ⇒ Float
The leftmost coordinate of the bounding box.
Corresponds to the JSON property xMin
45006 45007 45008 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45006 def x_min @x_min end |
#y_max ⇒ Float
The bottommost coordinate of the bounding box.
Corresponds to the JSON property yMax
45011 45012 45013 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45011 def y_max @y_max end |
#y_min ⇒ Float
The topmost coordinate of the bounding box.
Corresponds to the JSON property yMin
45016 45017 45018 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45016 def y_min @y_min end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45023 45024 45025 45026 45027 45028 45029 45030 45031 45032 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45023 def update!(**args) @annotation_spec_id = args[:annotation_spec_id] if args.key?(:annotation_spec_id) @display_name = args[:display_name] if args.key?(:display_name) @instance_id = args[:instance_id] if args.key?(:instance_id) @time_offset = args[:time_offset] if args.key?(:time_offset) @x_max = args[:x_max] if args.key?(:x_max) @x_min = args[:x_min] if args.key?(:x_min) @y_max = args[:y_max] if args.key?(:y_max) @y_min = args[:y_min] if args.key?(:y_min) end |