Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaVideoObjectTrackingAnnotation
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaVideoObjectTrackingAnnotation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Annotation details specific to video object tracking.
Instance Attribute Summary collapse
-
#annotation_spec_id ⇒ String
The resource Id of the AnnotationSpec that this Annotation pertains to.
-
#display_name ⇒ String
The display name of the AnnotationSpec that this Annotation pertains to.
-
#instance_id ⇒ Fixnum
The instance of the object, expressed as a positive integer.
-
#time_offset ⇒ String
A time (frame) of a video to which this annotation pertains.
-
#x_max ⇒ Float
The rightmost coordinate of the bounding box.
-
#x_min ⇒ Float
The leftmost coordinate of the bounding box.
-
#y_max ⇒ Float
The bottommost coordinate of the bounding box.
-
#y_min ⇒ Float
The topmost coordinate of the bounding box.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaVideoObjectTrackingAnnotation
constructor
A new instance of GoogleCloudAiplatformV1SchemaVideoObjectTrackingAnnotation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaVideoObjectTrackingAnnotation
Returns a new instance of GoogleCloudAiplatformV1SchemaVideoObjectTrackingAnnotation.
34133 34134 34135 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34133 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotation_spec_id ⇒ String
The resource Id of the AnnotationSpec that this Annotation pertains to.
Corresponds to the JSON property annotationSpecId
34094 34095 34096 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34094 def annotation_spec_id @annotation_spec_id end |
#display_name ⇒ String
The display name of the AnnotationSpec that this Annotation pertains to.
Corresponds to the JSON property displayName
34099 34100 34101 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34099 def display_name @display_name end |
#instance_id ⇒ Fixnum
The instance of the object, expressed as a positive integer. Used to track the
same object across different frames.
Corresponds to the JSON property instanceId
34105 34106 34107 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34105 def instance_id @instance_id end |
#time_offset ⇒ String
A time (frame) of a video to which this annotation pertains. Represented as
the duration since the video's start.
Corresponds to the JSON property timeOffset
34111 34112 34113 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34111 def time_offset @time_offset end |
#x_max ⇒ Float
The rightmost coordinate of the bounding box.
Corresponds to the JSON property xMax
34116 34117 34118 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34116 def x_max @x_max end |
#x_min ⇒ Float
The leftmost coordinate of the bounding box.
Corresponds to the JSON property xMin
34121 34122 34123 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34121 def x_min @x_min end |
#y_max ⇒ Float
The bottommost coordinate of the bounding box.
Corresponds to the JSON property yMax
34126 34127 34128 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34126 def y_max @y_max end |
#y_min ⇒ Float
The topmost coordinate of the bounding box.
Corresponds to the JSON property yMin
34131 34132 34133 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34131 def y_min @y_min end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34138 34139 34140 34141 34142 34143 34144 34145 34146 34147 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34138 def update!(**args) @annotation_spec_id = args[:annotation_spec_id] if args.key?(:annotation_spec_id) @display_name = args[:display_name] if args.key?(:display_name) @instance_id = args[:instance_id] if args.key?(:instance_id) @time_offset = args[:time_offset] if args.key?(:time_offset) @x_max = args[:x_max] if args.key?(:x_max) @x_min = args[:x_min] if args.key?(:x_min) @y_max = args[:y_max] if args.key?(:y_max) @y_min = args[:y_min] if args.key?(:y_min) end |