Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaVideoObjectTrackingAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Annotation details specific to video object tracking.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaVideoObjectTrackingAnnotation

Returns a new instance of GoogleCloudAiplatformV1SchemaVideoObjectTrackingAnnotation.



33997
33998
33999
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33997

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotation_spec_idString

The resource Id of the AnnotationSpec that this Annotation pertains to. Corresponds to the JSON property annotationSpecId

Returns:

  • (String)


33958
33959
33960
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33958

def annotation_spec_id
  @annotation_spec_id
end

#display_nameString

The display name of the AnnotationSpec that this Annotation pertains to. Corresponds to the JSON property displayName

Returns:

  • (String)


33963
33964
33965
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33963

def display_name
  @display_name
end

#instance_idFixnum

The instance of the object, expressed as a positive integer. Used to track the same object across different frames. Corresponds to the JSON property instanceId

Returns:

  • (Fixnum)


33969
33970
33971
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33969

def instance_id
  @instance_id
end

#time_offsetString

A time (frame) of a video to which this annotation pertains. Represented as the duration since the video's start. Corresponds to the JSON property timeOffset

Returns:

  • (String)


33975
33976
33977
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33975

def time_offset
  @time_offset
end

#x_maxFloat

The rightmost coordinate of the bounding box. Corresponds to the JSON property xMax

Returns:

  • (Float)


33980
33981
33982
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33980

def x_max
  @x_max
end

#x_minFloat

The leftmost coordinate of the bounding box. Corresponds to the JSON property xMin

Returns:

  • (Float)


33985
33986
33987
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33985

def x_min
  @x_min
end

#y_maxFloat

The bottommost coordinate of the bounding box. Corresponds to the JSON property yMax

Returns:

  • (Float)


33990
33991
33992
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33990

def y_max
  @y_max
end

#y_minFloat

The topmost coordinate of the bounding box. Corresponds to the JSON property yMin

Returns:

  • (Float)


33995
33996
33997
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33995

def y_min
  @y_min
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34002
34003
34004
34005
34006
34007
34008
34009
34010
34011
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34002

def update!(**args)
  @annotation_spec_id = args[:annotation_spec_id] if args.key?(:annotation_spec_id)
  @display_name = args[:display_name] if args.key?(:display_name)
  @instance_id = args[:instance_id] if args.key?(:instance_id)
  @time_offset = args[:time_offset] if args.key?(:time_offset)
  @x_max = args[:x_max] if args.key?(:x_max)
  @x_min = args[:x_min] if args.key?(:x_min)
  @y_max = args[:y_max] if args.key?(:y_max)
  @y_min = args[:y_min] if args.key?(:y_min)
end