Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SchemaVideoObjectTrackingAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Annotation details specific to video object tracking.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SchemaVideoObjectTrackingAnnotation

Returns a new instance of GoogleCloudAiplatformV1SchemaVideoObjectTrackingAnnotation.



32997
32998
32999
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32997

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotation_spec_idString

The resource Id of the AnnotationSpec that this Annotation pertains to. Corresponds to the JSON property annotationSpecId

Returns:

  • (String)


32958
32959
32960
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32958

def annotation_spec_id
  @annotation_spec_id
end

#display_nameString

The display name of the AnnotationSpec that this Annotation pertains to. Corresponds to the JSON property displayName

Returns:

  • (String)


32963
32964
32965
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32963

def display_name
  @display_name
end

#instance_idFixnum

The instance of the object, expressed as a positive integer. Used to track the same object across different frames. Corresponds to the JSON property instanceId

Returns:

  • (Fixnum)


32969
32970
32971
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32969

def instance_id
  @instance_id
end

#time_offsetString

A time (frame) of a video to which this annotation pertains. Represented as the duration since the video's start. Corresponds to the JSON property timeOffset

Returns:

  • (String)


32975
32976
32977
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32975

def time_offset
  @time_offset
end

#x_maxFloat

The rightmost coordinate of the bounding box. Corresponds to the JSON property xMax

Returns:

  • (Float)


32980
32981
32982
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32980

def x_max
  @x_max
end

#x_minFloat

The leftmost coordinate of the bounding box. Corresponds to the JSON property xMin

Returns:

  • (Float)


32985
32986
32987
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32985

def x_min
  @x_min
end

#y_maxFloat

The bottommost coordinate of the bounding box. Corresponds to the JSON property yMax

Returns:

  • (Float)


32990
32991
32992
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32990

def y_max
  @y_max
end

#y_minFloat

The topmost coordinate of the bounding box. Corresponds to the JSON property yMin

Returns:

  • (Float)


32995
32996
32997
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32995

def y_min
  @y_min
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33002
33003
33004
33005
33006
33007
33008
33009
33010
33011
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33002

def update!(**args)
  @annotation_spec_id = args[:annotation_spec_id] if args.key?(:annotation_spec_id)
  @display_name = args[:display_name] if args.key?(:display_name)
  @instance_id = args[:instance_id] if args.key?(:instance_id)
  @time_offset = args[:time_offset] if args.key?(:time_offset)
  @x_max = args[:x_max] if args.key?(:x_max)
  @x_min = args[:x_min] if args.key?(:x_min)
  @y_max = args[:y_max] if args.key?(:y_max)
  @y_min = args[:y_min] if args.key?(:y_min)
end