Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SearchEntryPoint
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SearchEntryPoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
An entry point for displaying Google Search results. A SearchEntryPoint is
populated when the grounding source for a model's response is Google Search.
It provides information that you can use to display the search results in your
application.
Instance Attribute Summary collapse
-
#rendered_content ⇒ String
Optional.
-
#sdk_blob ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SearchEntryPoint
constructor
A new instance of GoogleCloudAiplatformV1SearchEntryPoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SearchEntryPoint
Returns a new instance of GoogleCloudAiplatformV1SearchEntryPoint.
40037 40038 40039 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40037 def initialize(**args) update!(**args) end |
Instance Attribute Details
#rendered_content ⇒ String
Optional. An HTML snippet that can be embedded in a web page or an application'
s webview. This snippet displays a search result, including the title, URL,
and a brief description of the search result.
Corresponds to the JSON property renderedContent
40027 40028 40029 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40027 def rendered_content @rendered_content end |
#sdk_blob ⇒ String
Optional. A base64-encoded JSON object that contains a list of search queries
and their corresponding search URLs. This information can be used to build a
custom search UI.
Corresponds to the JSON property sdkBlob
NOTE: Values are automatically base64 encoded/decoded in the client library.
40035 40036 40037 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40035 def sdk_blob @sdk_blob end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40042 40043 40044 40045 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40042 def update!(**args) @rendered_content = args[:rendered_content] if args.key?(:rendered_content) @sdk_blob = args[:sdk_blob] if args.key?(:sdk_blob) end |