Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SearchModelDeploymentMonitoringStatsAnomaliesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for JobService.SearchModelDeploymentMonitoringStatsAnomalies.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SearchModelDeploymentMonitoringStatsAnomaliesRequest

Returns a new instance of GoogleCloudAiplatformV1SearchModelDeploymentMonitoringStatsAnomaliesRequest.



32819
32820
32821
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32819

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deployed_model_idString

Required. The DeployedModel ID of the [ ModelDeploymentMonitoringObjectiveConfig.deployed_model_id]. Corresponds to the JSON property deployedModelId

Returns:

  • (String)


32781
32782
32783
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32781

def deployed_model_id
  @deployed_model_id
end

#end_timeString

The latest timestamp of stats being generated. If not set, indicates feching stats till the latest possible one. Corresponds to the JSON property endTime

Returns:

  • (String)


32787
32788
32789
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32787

def end_time
  @end_time
end

#feature_display_nameString

The feature display name. If specified, only return the stats belonging to this feature. Format: ModelMonitoringStatsAnomalies. FeatureHistoricStatsAnomalies.feature_display_name, example: "user_destination" . Corresponds to the JSON property featureDisplayName

Returns:

  • (String)


32795
32796
32797
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32795

def feature_display_name
  @feature_display_name
end

#objectivesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SearchModelDeploymentMonitoringStatsAnomaliesRequestStatsAnomaliesObjective>

Required. Objectives of the stats to retrieve. Corresponds to the JSON property objectives



32800
32801
32802
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32800

def objectives
  @objectives
end

#page_sizeFixnum

The standard list page size. Corresponds to the JSON property pageSize

Returns:

  • (Fixnum)


32805
32806
32807
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32805

def page_size
  @page_size
end

#page_tokenString

A page token received from a previous JobService. SearchModelDeploymentMonitoringStatsAnomalies call. Corresponds to the JSON property pageToken

Returns:

  • (String)


32811
32812
32813
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32811

def page_token
  @page_token
end

#start_timeString

The earliest timestamp of stats being generated. If not set, indicates fetching stats till the earliest possible one. Corresponds to the JSON property startTime

Returns:

  • (String)


32817
32818
32819
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32817

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32824
32825
32826
32827
32828
32829
32830
32831
32832
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32824

def update!(**args)
  @deployed_model_id = args[:deployed_model_id] if args.key?(:deployed_model_id)
  @end_time = args[:end_time] if args.key?(:end_time)
  @feature_display_name = args[:feature_display_name] if args.key?(:feature_display_name)
  @objectives = args[:objectives] if args.key?(:objectives)
  @page_size = args[:page_size] if args.key?(:page_size)
  @page_token = args[:page_token] if args.key?(:page_token)
  @start_time = args[:start_time] if args.key?(:start_time)
end