Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SearchModelDeploymentMonitoringStatsAnomaliesRequestStatsAnomaliesObjective

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Stats requested for specific objective.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SearchModelDeploymentMonitoringStatsAnomaliesRequestStatsAnomaliesObjective

Returns a new instance of GoogleCloudAiplatformV1SearchModelDeploymentMonitoringStatsAnomaliesRequestStatsAnomaliesObjective.



33945
33946
33947
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33945

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#top_feature_countFixnum

If set, all attribution scores between SearchModelDeploymentMonitoringStatsAnomaliesRequest.start_time and SearchModelDeploymentMonitoringStatsAnomaliesRequest.end_time are fetched, and page token doesn't take effect in this case. Only used to retrieve attribution score for the top Features which has the highest attribution score in the latest monitoring run. Corresponds to the JSON property topFeatureCount

Returns:

  • (Fixnum)


33938
33939
33940
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33938

def top_feature_count
  @top_feature_count
end

#typeString

Corresponds to the JSON property type

Returns:

  • (String)


33943
33944
33945
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33943

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33950
33951
33952
33953
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33950

def update!(**args)
  @top_feature_count = args[:top_feature_count] if args.key?(:top_feature_count)
  @type = args[:type] if args.key?(:type)
end