Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SearchNearestEntitiesRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SearchNearestEntitiesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The request message for FeatureOnlineStoreService.SearchNearestEntities.
Instance Attribute Summary collapse
-
#query ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborQuery
A query to find a number of similar entities.
-
#return_full_entity ⇒ Boolean
(also: #return_full_entity?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SearchNearestEntitiesRequest
constructor
A new instance of GoogleCloudAiplatformV1SearchNearestEntitiesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SearchNearestEntitiesRequest
Returns a new instance of GoogleCloudAiplatformV1SearchNearestEntitiesRequest.
44315 44316 44317 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44315 def initialize(**args) update!(**args) end |
Instance Attribute Details
#query ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborQuery
A query to find a number of similar entities.
Corresponds to the JSON property query
44304 44305 44306 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44304 def query @query end |
#return_full_entity ⇒ Boolean Also known as: return_full_entity?
Optional. If set to true, the full entities (including all vector values and
metadata) of the nearest neighbors are returned; otherwise only entity id of
the nearest neighbors will be returned. Note that returning full entities will
significantly increase the latency and cost of the query.
Corresponds to the JSON property returnFullEntity
44312 44313 44314 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44312 def return_full_entity @return_full_entity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
44320 44321 44322 44323 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44320 def update!(**args) @query = args[:query] if args.key?(:query) @return_full_entity = args[:return_full_entity] if args.key?(:return_full_entity) end |