Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SearchNearestEntitiesRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SearchNearestEntitiesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The request message for FeatureOnlineStoreService.SearchNearestEntities.
Instance Attribute Summary collapse
-
#query ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborQuery
A query to find a number of similar entities.
-
#return_full_entity ⇒ Boolean
(also: #return_full_entity?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SearchNearestEntitiesRequest
constructor
A new instance of GoogleCloudAiplatformV1SearchNearestEntitiesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SearchNearestEntitiesRequest
Returns a new instance of GoogleCloudAiplatformV1SearchNearestEntitiesRequest.
33994 33995 33996 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33994 def initialize(**args) update!(**args) end |
Instance Attribute Details
#query ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborQuery
A query to find a number of similar entities.
Corresponds to the JSON property query
33983 33984 33985 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33983 def query @query end |
#return_full_entity ⇒ Boolean Also known as: return_full_entity?
Optional. If set to true, the full entities (including all vector values and
metadata) of the nearest neighbors are returned; otherwise only entity id of
the nearest neighbors will be returned. Note that returning full entities will
significantly increase the latency and cost of the query.
Corresponds to the JSON property returnFullEntity
33991 33992 33993 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33991 def return_full_entity @return_full_entity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33999 34000 34001 34002 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33999 def update!(**args) @query = args[:query] if args.key?(:query) @return_full_entity = args[:return_full_entity] if args.key?(:return_full_entity) end |