Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SearchNearestEntitiesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The request message for FeatureOnlineStoreService.SearchNearestEntities.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SearchNearestEntitiesRequest

Returns a new instance of GoogleCloudAiplatformV1SearchNearestEntitiesRequest.



32560
32561
32562
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32560

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#queryGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1NearestNeighborQuery

A query to find a number of similar entities. Corresponds to the JSON property query



32549
32550
32551
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32549

def query
  @query
end

#return_full_entityBoolean Also known as: return_full_entity?

Optional. If set to true, the full entities (including all vector values and metadata) of the nearest neighbors are returned; otherwise only entity id of the nearest neighbors will be returned. Note that returning full entities will significantly increase the latency and cost of the query. Corresponds to the JSON property returnFullEntity

Returns:

  • (Boolean)


32557
32558
32559
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32557

def return_full_entity
  @return_full_entity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32565
32566
32567
32568
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32565

def update!(**args)
  @query = args[:query] if args.key?(:query)
  @return_full_entity = args[:return_full_entity] if args.key?(:return_full_entity)
end