Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SecretEnvVar

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents an environment variable where the value is a secret in Cloud Secret Manager.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SecretEnvVar

Returns a new instance of GoogleCloudAiplatformV1SecretEnvVar.



33961
33962
33963
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33961

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Required. Name of the secret environment variable. Corresponds to the JSON property name

Returns:

  • (String)


33953
33954
33955
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33953

def name
  @name
end

#secret_refGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SecretRef

Reference to a secret stored in the Cloud Secret Manager that will provide the value for this environment variable. Corresponds to the JSON property secretRef



33959
33960
33961
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33959

def secret_ref
  @secret_ref
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33966
33967
33968
33969
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33966

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @secret_ref = args[:secret_ref] if args.key?(:secret_ref)
end