Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SecretEnvVar
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SecretEnvVar
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Represents an environment variable where the value is a secret in Cloud Secret Manager.
Instance Attribute Summary collapse
-
#name ⇒ String
Required.
-
#secret_ref ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SecretRef
Reference to a secret stored in the Cloud Secret Manager that will provide the value for this environment variable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SecretEnvVar
constructor
A new instance of GoogleCloudAiplatformV1SecretEnvVar.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SecretEnvVar
Returns a new instance of GoogleCloudAiplatformV1SecretEnvVar.
33225 33226 33227 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33225 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Required. Name of the secret environment variable.
Corresponds to the JSON property name
33217 33218 33219 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33217 def name @name end |
#secret_ref ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SecretRef
Reference to a secret stored in the Cloud Secret Manager that will provide the
value for this environment variable.
Corresponds to the JSON property secretRef
33223 33224 33225 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33223 def secret_ref @secret_ref end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33230 33231 33232 33233 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33230 def update!(**args) @name = args[:name] if args.key?(:name) @secret_ref = args[:secret_ref] if args.key?(:secret_ref) end |