Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SecretRef

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Reference to a secret stored in the Cloud Secret Manager that will provide the value for this environment variable.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SecretRef

Returns a new instance of GoogleCloudAiplatformV1SecretRef.



40351
40352
40353
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40351

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#secretString

Required. The name of the secret in Cloud Secret Manager. Format: secret_name . Corresponds to the JSON property secret

Returns:

  • (String)


40343
40344
40345
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40343

def secret
  @secret
end

#versionString

The Cloud Secret Manager secret version. Can be 'latest' for the latest version, an integer for a specific version, or a version alias. Corresponds to the JSON property version

Returns:

  • (String)


40349
40350
40351
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40349

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40356
40357
40358
40359
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40356

def update!(**args)
  @secret = args[:secret] if args.key?(:secret)
  @version = args[:version] if args.key?(:version)
end