Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SecretRef

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Reference to a secret stored in the Cloud Secret Manager that will provide the value for this environment variable.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SecretRef

Returns a new instance of GoogleCloudAiplatformV1SecretRef.



34610
34611
34612
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34610

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#secretString

Required. The name of the secret in Cloud Secret Manager. Format: secret_name . Corresponds to the JSON property secret

Returns:

  • (String)


34602
34603
34604
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34602

def secret
  @secret
end

#versionString

The Cloud Secret Manager secret version. Can be 'latest' for the latest version, an integer for a specific version, or a version alias. Corresponds to the JSON property version

Returns:

  • (String)


34608
34609
34610
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34608

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34615
34616
34617
34618
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34615

def update!(**args)
  @secret = args[:secret] if args.key?(:secret)
  @version = args[:version] if args.key?(:version)
end