Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Segment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Segment of the content.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Segment

Returns a new instance of GoogleCloudAiplatformV1Segment.



35018
35019
35020
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35018

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_indexFixnum

Output only. End index in the given Part, measured in bytes. Offset from the start of the Part, exclusive, starting at zero. Corresponds to the JSON property endIndex

Returns:

  • (Fixnum)


35000
35001
35002
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35000

def end_index
  @end_index
end

#part_indexFixnum

Output only. The index of a Part object within its parent Content object. Corresponds to the JSON property partIndex

Returns:

  • (Fixnum)


35005
35006
35007
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35005

def part_index
  @part_index
end

#start_indexFixnum

Output only. Start index in the given Part, measured in bytes. Offset from the start of the Part, inclusive, starting at zero. Corresponds to the JSON property startIndex

Returns:

  • (Fixnum)


35011
35012
35013
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35011

def start_index
  @start_index
end

#textString

Output only. The text corresponding to the segment from the response. Corresponds to the JSON property text

Returns:

  • (String)


35016
35017
35018
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35016

def text
  @text
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35023
35024
35025
35026
35027
35028
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35023

def update!(**args)
  @end_index = args[:end_index] if args.key?(:end_index)
  @part_index = args[:part_index] if args.key?(:part_index)
  @start_index = args[:start_index] if args.key?(:start_index)
  @text = args[:text] if args.key?(:text)
end