Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Segment
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Segment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Segment of the content.
Instance Attribute Summary collapse
-
#end_index ⇒ Fixnum
Output only.
-
#part_index ⇒ Fixnum
Output only.
-
#start_index ⇒ Fixnum
Output only.
-
#text ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Segment
constructor
A new instance of GoogleCloudAiplatformV1Segment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Segment
Returns a new instance of GoogleCloudAiplatformV1Segment.
34026 34027 34028 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34026 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_index ⇒ Fixnum
Output only. End index in the given Part, measured in bytes. Offset from the
start of the Part, exclusive, starting at zero.
Corresponds to the JSON property endIndex
34008 34009 34010 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34008 def end_index @end_index end |
#part_index ⇒ Fixnum
Output only. The index of a Part object within its parent Content object.
Corresponds to the JSON property partIndex
34013 34014 34015 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34013 def part_index @part_index end |
#start_index ⇒ Fixnum
Output only. Start index in the given Part, measured in bytes. Offset from the
start of the Part, inclusive, starting at zero.
Corresponds to the JSON property startIndex
34019 34020 34021 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34019 def start_index @start_index end |
#text ⇒ String
Output only. The text corresponding to the segment from the response.
Corresponds to the JSON property text
34024 34025 34026 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34024 def text @text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34031 34032 34033 34034 34035 34036 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34031 def update!(**args) @end_index = args[:end_index] if args.key?(:end_index) @part_index = args[:part_index] if args.key?(:part_index) @start_index = args[:start_index] if args.key?(:start_index) @text = args[:text] if args.key?(:text) end |