Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Segment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Segment of the content.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Segment

Returns a new instance of GoogleCloudAiplatformV1Segment.



33022
33023
33024
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33022

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_indexFixnum

Output only. End index in the given Part, measured in bytes. Offset from the start of the Part, exclusive, starting at zero. Corresponds to the JSON property endIndex

Returns:

  • (Fixnum)


33004
33005
33006
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33004

def end_index
  @end_index
end

#part_indexFixnum

Output only. The index of a Part object within its parent Content object. Corresponds to the JSON property partIndex

Returns:

  • (Fixnum)


33009
33010
33011
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33009

def part_index
  @part_index
end

#start_indexFixnum

Output only. Start index in the given Part, measured in bytes. Offset from the start of the Part, inclusive, starting at zero. Corresponds to the JSON property startIndex

Returns:

  • (Fixnum)


33015
33016
33017
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33015

def start_index
  @start_index
end

#textString

Output only. The text corresponding to the segment from the response. Corresponds to the JSON property text

Returns:

  • (String)


33020
33021
33022
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33020

def text
  @text
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33027
33028
33029
33030
33031
33032
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33027

def update!(**args)
  @end_index = args[:end_index] if args.key?(:end_index)
  @part_index = args[:part_index] if args.key?(:part_index)
  @start_index = args[:start_index] if args.key?(:start_index)
  @text = args[:text] if args.key?(:text)
end