Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SemanticGovernancePolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents a governance policy applied to a specific Agent and optionally a specific Tool within that Agent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SemanticGovernancePolicy

Returns a new instance of GoogleCloudAiplatformV1SemanticGovernancePolicy.



45087
45088
45089
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45087

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agentString

Required. The name of the agent in Agent Registry that is affected by this policy. Corresponds to the JSON property agent

Returns:

  • (String)


45033
45034
45035
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45033

def agent
  @agent
end

#agent_identityString

Output only. Represents the principal of the agent, used by the Policy Decision Point (PDP) for governance checks. For more information, see https:// docs.cloud.google.com/agent-builder/agent-engine/agent-identity Format: principal://TRUST_DOMAIN/NAMESPACE/AGENT_NAME Example: principal://agents. global.org-ORGANIZATION_ID.system.id.goog/resources/aiplatform/projects/ PROJECT_NUMBER/locations/LOCATION/reasoningEngines/AGENT_ENGINE_ID Corresponds to the JSON property agentIdentity

Returns:

  • (String)


45043
45044
45045
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45043

def agent_identity
  @agent_identity
end

#create_timeString

Output only. Timestamp when this SemanticGovernancePolicy was created. Corresponds to the JSON property createTime

Returns:

  • (String)


45048
45049
45050
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45048

def create_time
  @create_time
end

#descriptionString

Optional. The description of the SemanticGovernancePolicy. Corresponds to the JSON property description

Returns:

  • (String)


45053
45054
45055
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45053

def description
  @description
end

#display_nameString

Optional. The user-defined name of the SemanticGovernancePolicy. Corresponds to the JSON property displayName

Returns:

  • (String)


45058
45059
45060
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45058

def display_name
  @display_name
end

#etagString

Optional. Used to perform consistent read-modify-write transactions. If provided, the request will only succeed if the etag matches the current value. Otherwise, an ABORTED error will be returned. Corresponds to the JSON property etag

Returns:

  • (String)


45065
45066
45067
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45065

def etag
  @etag
end

#mcp_toolsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SemanticGovernancePolicyMcpTool>

Optional. The McpTools that are affected by this policy. Corresponds to the JSON property mcpTools



45070
45071
45072
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45070

def mcp_tools
  @mcp_tools
end

#nameString

Identifier. Resource name of the SemanticGovernancePolicy. Corresponds to the JSON property name

Returns:

  • (String)


45075
45076
45077
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45075

def name
  @name
end

#natural_language_constraintString

Required. The natural language constraint of the SemanticGovernancePolicy. Corresponds to the JSON property naturalLanguageConstraint

Returns:

  • (String)


45080
45081
45082
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45080

def natural_language_constraint
  @natural_language_constraint
end

#update_timeString

Output only. Timestamp when this SemanticGovernancePolicy was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


45085
45086
45087
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45085

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45092
45093
45094
45095
45096
45097
45098
45099
45100
45101
45102
45103
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45092

def update!(**args)
  @agent = args[:agent] if args.key?(:agent)
  @agent_identity = args[:agent_identity] if args.key?(:agent_identity)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @mcp_tools = args[:mcp_tools] if args.key?(:mcp_tools)
  @name = args[:name] if args.key?(:name)
  @natural_language_constraint = args[:natural_language_constraint] if args.key?(:natural_language_constraint)
  @update_time = args[:update_time] if args.key?(:update_time)
end