Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SemanticGovernancePolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents a governance policy applied to a specific Agent and optionally a specific Tool within that Agent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SemanticGovernancePolicy

Returns a new instance of GoogleCloudAiplatformV1SemanticGovernancePolicy.



44074
44075
44076
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44074

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agentString

Required. The name of the agent in Agent Registry that is affected by this policy. Corresponds to the JSON property agent

Returns:

  • (String)


44020
44021
44022
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44020

def agent
  @agent
end

#agent_identityString

Output only. Represents the principal of the agent, used by the Policy Decision Point (PDP) for governance checks. For more information, see https:// docs.cloud.google.com/agent-builder/agent-engine/agent-identity Format: principal://TRUST_DOMAIN/NAMESPACE/AGENT_NAME Example: principal://agents. global.org-ORGANIZATION_ID.system.id.goog/resources/aiplatform/projects/ PROJECT_NUMBER/locations/LOCATION/reasoningEngines/AGENT_ENGINE_ID Corresponds to the JSON property agentIdentity

Returns:

  • (String)


44030
44031
44032
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44030

def agent_identity
  @agent_identity
end

#create_timeString

Output only. Timestamp when this SemanticGovernancePolicy was created. Corresponds to the JSON property createTime

Returns:

  • (String)


44035
44036
44037
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44035

def create_time
  @create_time
end

#descriptionString

Optional. The description of the SemanticGovernancePolicy. Corresponds to the JSON property description

Returns:

  • (String)


44040
44041
44042
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44040

def description
  @description
end

#display_nameString

Optional. The user-defined name of the SemanticGovernancePolicy. Corresponds to the JSON property displayName

Returns:

  • (String)


44045
44046
44047
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44045

def display_name
  @display_name
end

#etagString

Optional. Used to perform consistent read-modify-write transactions. If provided, the request will only succeed if the etag matches the current value. Otherwise, an ABORTED error will be returned. Corresponds to the JSON property etag

Returns:

  • (String)


44052
44053
44054
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44052

def etag
  @etag
end

#mcp_toolsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SemanticGovernancePolicyMcpTool>

Optional. The McpTools that are affected by this policy. Corresponds to the JSON property mcpTools



44057
44058
44059
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44057

def mcp_tools
  @mcp_tools
end

#nameString

Identifier. Resource name of the SemanticGovernancePolicy. Corresponds to the JSON property name

Returns:

  • (String)


44062
44063
44064
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44062

def name
  @name
end

#natural_language_constraintString

Required. The natural language constraint of the SemanticGovernancePolicy. Corresponds to the JSON property naturalLanguageConstraint

Returns:

  • (String)


44067
44068
44069
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44067

def natural_language_constraint
  @natural_language_constraint
end

#update_timeString

Output only. Timestamp when this SemanticGovernancePolicy was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


44072
44073
44074
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44072

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44079
44080
44081
44082
44083
44084
44085
44086
44087
44088
44089
44090
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44079

def update!(**args)
  @agent = args[:agent] if args.key?(:agent)
  @agent_identity = args[:agent_identity] if args.key?(:agent_identity)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @mcp_tools = args[:mcp_tools] if args.key?(:mcp_tools)
  @name = args[:name] if args.key?(:name)
  @natural_language_constraint = args[:natural_language_constraint] if args.key?(:natural_language_constraint)
  @update_time = args[:update_time] if args.key?(:update_time)
end