Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SemanticGovernancePolicyMcpTool

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents a governance policy applied to MCP tools used by an Agent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SemanticGovernancePolicyMcpTool

Returns a new instance of GoogleCloudAiplatformV1SemanticGovernancePolicyMcpTool.



44622
44623
44624
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44622

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#mcp_serverString

Required. The resource name of the McpServer in Agent Registry that is affected by this policy. Format: projects/project/locations/location/ mcpServers/mcp_server` Corresponds to the JSON propertymcpServer`

Returns:

  • (String)


44613
44614
44615
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44613

def mcp_server
  @mcp_server
end

#toolsArray<String>

Optional. The resource names of the McpTools used by the Agent that is affected by this policy. If not specified, the policy applies to all McpTools in the McpServer. Corresponds to the JSON property tools

Returns:

  • (Array<String>)


44620
44621
44622
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44620

def tools
  @tools
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44627
44628
44629
44630
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44627

def update!(**args)
  @mcp_server = args[:mcp_server] if args.key?(:mcp_server)
  @tools = args[:tools] if args.key?(:tools)
end