Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SemanticGovernancePolicyMcpTool

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents a governance policy applied to MCP tools used by an Agent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SemanticGovernancePolicyMcpTool

Returns a new instance of GoogleCloudAiplatformV1SemanticGovernancePolicyMcpTool.



44609
44610
44611
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44609

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#mcp_serverString

Required. The resource name of the McpServer in Agent Registry that is affected by this policy. Format: projects/project/locations/location/ mcpServers/mcp_server` Corresponds to the JSON propertymcpServer`

Returns:

  • (String)


44600
44601
44602
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44600

def mcp_server
  @mcp_server
end

#toolsArray<String>

Optional. The resource names of the McpTools used by the Agent that is affected by this policy. If not specified, the policy applies to all McpTools in the McpServer. Corresponds to the JSON property tools

Returns:

  • (Array<String>)


44607
44608
44609
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44607

def tools
  @tools
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44614
44615
44616
44617
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44614

def update!(**args)
  @mcp_server = args[:mcp_server] if args.key?(:mcp_server)
  @tools = args[:tools] if args.key?(:tools)
end