Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SemanticGovernancePolicyMcpTool

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents a governance policy applied to MCP tools used by an Agent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SemanticGovernancePolicyMcpTool

Returns a new instance of GoogleCloudAiplatformV1SemanticGovernancePolicyMcpTool.



44178
44179
44180
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44178

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#mcp_serverString

Required. The resource name of the McpServer in Agent Registry that is affected by this policy. Format: projects/project/locations/location/ mcpServers/mcp_server` Corresponds to the JSON propertymcpServer`

Returns:

  • (String)


44169
44170
44171
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44169

def mcp_server
  @mcp_server
end

#toolsArray<String>

Optional. The resource names of the McpTools used by the Agent that is affected by this policy. If not specified, the policy applies to all McpTools in the McpServer. Corresponds to the JSON property tools

Returns:

  • (Array<String>)


44176
44177
44178
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44176

def tools
  @tools
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44183
44184
44185
44186
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44183

def update!(**args)
  @mcp_server = args[:mcp_server] if args.key?(:mcp_server)
  @tools = args[:tools] if args.key?(:tools)
end