Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ServiceAccountSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ServiceAccountSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Configuration for the use of custom service account to run the workloads.
Instance Attribute Summary collapse
-
#enable_custom_service_account ⇒ Boolean
(also: #enable_custom_service_account?)
Required.
-
#service_account ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ServiceAccountSpec
constructor
A new instance of GoogleCloudAiplatformV1ServiceAccountSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ServiceAccountSpec
Returns a new instance of GoogleCloudAiplatformV1ServiceAccountSpec.
34477 34478 34479 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34477 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable_custom_service_account ⇒ Boolean Also known as: enable_custom_service_account?
Required. If true, custom user-managed service account is enforced to run any
workloads (for example, Vertex Jobs) on the resource. Otherwise, uses the
Vertex AI Custom Code Service Agent.
Corresponds to the JSON property enableCustomServiceAccount
34463 34464 34465 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34463 def enable_custom_service_account @enable_custom_service_account end |
#service_account ⇒ String
Optional. Required when all below conditions are met *
enable_custom_service_account is true; * any runtime is specified via
ResourceRuntimeSpec on creation time, for example, Ray The users must have
iam.serviceAccounts.actAs permission on this service account and then the
specified runtime containers will run as it. Do not set this field if you want
to submit jobs using custom service account to this PersistentResource after
creation, but only specify the service_account inside the job.
Corresponds to the JSON property serviceAccount
34475 34476 34477 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34475 def service_account @service_account end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34482 34483 34484 34485 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34482 def update!(**args) @enable_custom_service_account = args[:enable_custom_service_account] if args.key?(:enable_custom_service_account) @service_account = args[:service_account] if args.key?(:service_account) end |