Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ServiceAccountSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ServiceAccountSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Configuration for the use of custom service account to run the workloads.
Instance Attribute Summary collapse
-
#enable_custom_service_account ⇒ Boolean
(also: #enable_custom_service_account?)
Required.
-
#service_account ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ServiceAccountSpec
constructor
A new instance of GoogleCloudAiplatformV1ServiceAccountSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ServiceAccountSpec
Returns a new instance of GoogleCloudAiplatformV1ServiceAccountSpec.
32960 32961 32962 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32960 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable_custom_service_account ⇒ Boolean Also known as: enable_custom_service_account?
Required. If true, custom user-managed service account is enforced to run any
workloads (for example, Vertex Jobs) on the resource. Otherwise, uses the
Vertex AI Custom Code Service Agent.
Corresponds to the JSON property enableCustomServiceAccount
32946 32947 32948 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32946 def enable_custom_service_account @enable_custom_service_account end |
#service_account ⇒ String
Optional. Required when all below conditions are met *
enable_custom_service_account is true; * any runtime is specified via
ResourceRuntimeSpec on creation time, for example, Ray The users must have
iam.serviceAccounts.actAs permission on this service account and then the
specified runtime containers will run as it. Do not set this field if you want
to submit jobs using custom service account to this PersistentResource after
creation, but only specify the service_account inside the job.
Corresponds to the JSON property serviceAccount
32958 32959 32960 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32958 def service_account @service_account end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32965 32966 32967 32968 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32965 def update!(**args) @enable_custom_service_account = args[:enable_custom_service_account] if args.key?(:enable_custom_service_account) @service_account = args[:service_account] if args.key?(:service_account) end |