Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Session
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Session
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A session contains a set of actions between users and Vertex agents.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Optional.
-
#expire_time ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your Sessions.
-
#name ⇒ String
Identifier.
-
#session_state ⇒ Hash<String,Object>
Optional.
-
#ttl ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
-
#user_id ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Session
constructor
A new instance of GoogleCloudAiplatformV1Session.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Session
Returns a new instance of GoogleCloudAiplatformV1Session.
45293 45294 45295 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45293 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when the session was created.
Corresponds to the JSON property createTime
45244 45245 45246 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45244 def create_time @create_time end |
#display_name ⇒ String
Optional. The display name of the session.
Corresponds to the JSON property displayName
45249 45250 45251 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45249 def display_name @display_name end |
#expire_time ⇒ String
Optional. Timestamp of when this session is considered expired. This is *
always* provided on output, regardless of what was sent on input. The minimum
value is 24 hours from the time of creation.
Corresponds to the JSON property expireTime
45256 45257 45258 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45256 def expire_time @expire_time end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your Sessions. Label keys
and values can be no longer than 64 characters (Unicode codepoints), can only
contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. See https://goo.gl/xmQnxf for more
information and examples of labels.
Corresponds to the JSON property labels
45265 45266 45267 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45265 def labels @labels end |
#name ⇒ String
Identifier. The resource name of the session. Format: 'projects/project/
locations/location/reasoningEngines/reasoning_engine/sessions/session'.
Corresponds to the JSON property name
45271 45272 45273 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45271 def name @name end |
#session_state ⇒ Hash<String,Object>
Optional. Session specific memory which stores key conversation points.
Corresponds to the JSON property sessionState
45276 45277 45278 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45276 def session_state @session_state end |
#ttl ⇒ String
Optional. Input only. The TTL for this session. The minimum value is 24 hours.
Corresponds to the JSON property ttl
45281 45282 45283 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45281 def ttl @ttl end |
#update_time ⇒ String
Output only. Timestamp when the session was updated.
Corresponds to the JSON property updateTime
45286 45287 45288 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45286 def update_time @update_time end |
#user_id ⇒ String
Required. Immutable. String id provided by the user
Corresponds to the JSON property userId
45291 45292 45293 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45291 def user_id @user_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45298 45299 45300 45301 45302 45303 45304 45305 45306 45307 45308 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45298 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @expire_time = args[:expire_time] if args.key?(:expire_time) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @session_state = args[:session_state] if args.key?(:session_state) @ttl = args[:ttl] if args.key?(:ttl) @update_time = args[:update_time] if args.key?(:update_time) @user_id = args[:user_id] if args.key?(:user_id) end |