Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Session
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Session
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A session contains a set of actions between users and Vertex agents.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Optional.
-
#expire_time ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your Sessions.
-
#name ⇒ String
Identifier.
-
#session_state ⇒ Hash<String,Object>
Optional.
-
#ttl ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
-
#user_id ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Session
constructor
A new instance of GoogleCloudAiplatformV1Session.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Session
Returns a new instance of GoogleCloudAiplatformV1Session.
44724 44725 44726 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44724 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when the session was created.
Corresponds to the JSON property createTime
44675 44676 44677 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44675 def create_time @create_time end |
#display_name ⇒ String
Optional. The display name of the session.
Corresponds to the JSON property displayName
44680 44681 44682 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44680 def display_name @display_name end |
#expire_time ⇒ String
Optional. Timestamp of when this session is considered expired. This is *
always* provided on output, regardless of what was sent on input. The minimum
value is 24 hours from the time of creation.
Corresponds to the JSON property expireTime
44687 44688 44689 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44687 def expire_time @expire_time end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your Sessions. Label keys
and values can be no longer than 64 characters (Unicode codepoints), can only
contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. See https://goo.gl/xmQnxf for more
information and examples of labels.
Corresponds to the JSON property labels
44696 44697 44698 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44696 def labels @labels end |
#name ⇒ String
Identifier. The resource name of the session. Format: 'projects/project/
locations/location/reasoningEngines/reasoning_engine/sessions/session'.
Corresponds to the JSON property name
44702 44703 44704 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44702 def name @name end |
#session_state ⇒ Hash<String,Object>
Optional. Session specific memory which stores key conversation points.
Corresponds to the JSON property sessionState
44707 44708 44709 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44707 def session_state @session_state end |
#ttl ⇒ String
Optional. Input only. The TTL for this session. The minimum value is 24 hours.
Corresponds to the JSON property ttl
44712 44713 44714 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44712 def ttl @ttl end |
#update_time ⇒ String
Output only. Timestamp when the session was updated.
Corresponds to the JSON property updateTime
44717 44718 44719 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44717 def update_time @update_time end |
#user_id ⇒ String
Required. Immutable. String id provided by the user
Corresponds to the JSON property userId
44722 44723 44724 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44722 def user_id @user_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
44729 44730 44731 44732 44733 44734 44735 44736 44737 44738 44739 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44729 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @expire_time = args[:expire_time] if args.key?(:expire_time) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @session_state = args[:session_state] if args.key?(:session_state) @ttl = args[:ttl] if args.key?(:ttl) @update_time = args[:update_time] if args.key?(:update_time) @user_id = args[:user_id] if args.key?(:user_id) end |