Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Session
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Session
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A session contains a set of actions between users and Vertex agents.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Optional.
-
#expire_time ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your Sessions.
-
#name ⇒ String
Identifier.
-
#session_state ⇒ Hash<String,Object>
Optional.
-
#ttl ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
-
#user_id ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Session
constructor
A new instance of GoogleCloudAiplatformV1Session.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Session
Returns a new instance of GoogleCloudAiplatformV1Session.
44280 44281 44282 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44280 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when the session was created.
Corresponds to the JSON property createTime
44231 44232 44233 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44231 def create_time @create_time end |
#display_name ⇒ String
Optional. The display name of the session.
Corresponds to the JSON property displayName
44236 44237 44238 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44236 def display_name @display_name end |
#expire_time ⇒ String
Optional. Timestamp of when this session is considered expired. This is *
always* provided on output, regardless of what was sent on input. The minimum
value is 24 hours from the time of creation.
Corresponds to the JSON property expireTime
44243 44244 44245 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44243 def expire_time @expire_time end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your Sessions. Label keys
and values can be no longer than 64 characters (Unicode codepoints), can only
contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. See https://goo.gl/xmQnxf for more
information and examples of labels.
Corresponds to the JSON property labels
44252 44253 44254 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44252 def labels @labels end |
#name ⇒ String
Identifier. The resource name of the session. Format: 'projects/project/
locations/location/reasoningEngines/reasoning_engine/sessions/session'.
Corresponds to the JSON property name
44258 44259 44260 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44258 def name @name end |
#session_state ⇒ Hash<String,Object>
Optional. Session specific memory which stores key conversation points.
Corresponds to the JSON property sessionState
44263 44264 44265 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44263 def session_state @session_state end |
#ttl ⇒ String
Optional. Input only. The TTL for this session. The minimum value is 24 hours.
Corresponds to the JSON property ttl
44268 44269 44270 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44268 def ttl @ttl end |
#update_time ⇒ String
Output only. Timestamp when the session was updated.
Corresponds to the JSON property updateTime
44273 44274 44275 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44273 def update_time @update_time end |
#user_id ⇒ String
Required. Immutable. String id provided by the user
Corresponds to the JSON property userId
44278 44279 44280 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44278 def user_id @user_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
44285 44286 44287 44288 44289 44290 44291 44292 44293 44294 44295 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44285 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @expire_time = args[:expire_time] if args.key?(:expire_time) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @session_state = args[:session_state] if args.key?(:session_state) @ttl = args[:ttl] if args.key?(:ttl) @update_time = args[:update_time] if args.key?(:update_time) @user_id = args[:user_id] if args.key?(:user_id) end |