Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Session

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A session contains a set of actions between users and Vertex agents.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Session

Returns a new instance of GoogleCloudAiplatformV1Session.



42716
42717
42718
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42716

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when the session was created. Corresponds to the JSON property createTime

Returns:

  • (String)


42667
42668
42669
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42667

def create_time
  @create_time
end

#display_nameString

Optional. The display name of the session. Corresponds to the JSON property displayName

Returns:

  • (String)


42672
42673
42674
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42672

def display_name
  @display_name
end

#expire_timeString

Optional. Timestamp of when this session is considered expired. This is * always* provided on output, regardless of what was sent on input. The minimum value is 24 hours from the time of creation. Corresponds to the JSON property expireTime

Returns:

  • (String)


42679
42680
42681
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42679

def expire_time
  @expire_time
end

#labelsHash<String,String>

The labels with user-defined metadata to organize your Sessions. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


42688
42689
42690
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42688

def labels
  @labels
end

#nameString

Identifier. The resource name of the session. Format: 'projects/project/ locations/location/reasoningEngines/reasoning_engine/sessions/session'. Corresponds to the JSON property name

Returns:

  • (String)


42694
42695
42696
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42694

def name
  @name
end

#session_stateHash<String,Object>

Optional. Session specific memory which stores key conversation points. Corresponds to the JSON property sessionState

Returns:

  • (Hash<String,Object>)


42699
42700
42701
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42699

def session_state
  @session_state
end

#ttlString

Optional. Input only. The TTL for this session. The minimum value is 24 hours. Corresponds to the JSON property ttl

Returns:

  • (String)


42704
42705
42706
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42704

def ttl
  @ttl
end

#update_timeString

Output only. Timestamp when the session was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


42709
42710
42711
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42709

def update_time
  @update_time
end

#user_idString

Required. Immutable. String id provided by the user Corresponds to the JSON property userId

Returns:

  • (String)


42714
42715
42716
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42714

def user_id
  @user_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42721
42722
42723
42724
42725
42726
42727
42728
42729
42730
42731
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42721

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @session_state = args[:session_state] if args.key?(:session_state)
  @ttl = args[:ttl] if args.key?(:ttl)
  @update_time = args[:update_time] if args.key?(:update_time)
  @user_id = args[:user_id] if args.key?(:user_id)
end