Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SessionEvent
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SessionEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
An event represents a message from either the user or agent.
Instance Attribute Summary collapse
-
#actions ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EventActions
Actions are parts of events that are executed by the agent.
-
#author ⇒ String
Required.
-
#content ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content
The structured data content of a message.
-
#error_code ⇒ String
Optional.
-
#error_message ⇒ String
Optional.
-
#event_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EventMetadata
Metadata relating to a LLM response event.
-
#invocation_id ⇒ String
Required.
-
#name ⇒ String
Identifier.
-
#raw_event ⇒ Hash<String,Object>
Optional.
-
#timestamp ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SessionEvent
constructor
A new instance of GoogleCloudAiplatformV1SessionEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SessionEvent
Returns a new instance of GoogleCloudAiplatformV1SessionEvent.
42670 42671 42672 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42670 def initialize(**args) update!(**args) end |
Instance Attribute Details
#actions ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EventActions
Actions are parts of events that are executed by the agent.
Corresponds to the JSON property actions
42618 42619 42620 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42618 def actions @actions end |
#author ⇒ String
Required. The name of the agent that sent the event, or user.
Corresponds to the JSON property author
42623 42624 42625 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42623 def @author end |
#content ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content
The structured data content of a message. A Content message contains a role
field, which indicates the producer of the content, and a parts field, which
contains the multi-part data of the message.
Corresponds to the JSON property content
42630 42631 42632 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42630 def content @content end |
#error_code ⇒ String
Optional. Error code if the response is an error. Code varies by model.
Corresponds to the JSON property errorCode
42635 42636 42637 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42635 def error_code @error_code end |
#error_message ⇒ String
Optional. Error message if the response is an error.
Corresponds to the JSON property errorMessage
42640 42641 42642 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42640 def @error_message end |
#event_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EventMetadata
Metadata relating to a LLM response event.
Corresponds to the JSON property eventMetadata
42645 42646 42647 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42645 def @event_metadata end |
#invocation_id ⇒ String
Required. The invocation id of the event, multiple events can have the same
invocation id.
Corresponds to the JSON property invocationId
42651 42652 42653 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42651 def invocation_id @invocation_id end |
#name ⇒ String
Identifier. The resource name of the event. Format:projects/project/
locations/location/reasoningEngines/reasoning_engine/sessions/session/
events/event`.
Corresponds to the JSON propertyname`
42658 42659 42660 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42658 def name @name end |
#raw_event ⇒ Hash<String,Object>
Optional. Weakly typed raw event data in proto struct format.
Corresponds to the JSON property rawEvent
42663 42664 42665 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42663 def raw_event @raw_event end |
#timestamp ⇒ String
Required. Timestamp when the event was created on client side.
Corresponds to the JSON property timestamp
42668 42669 42670 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42668 def @timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42675 42676 42677 42678 42679 42680 42681 42682 42683 42684 42685 42686 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42675 def update!(**args) @actions = args[:actions] if args.key?(:actions) @author = args[:author] if args.key?(:author) @content = args[:content] if args.key?(:content) @error_code = args[:error_code] if args.key?(:error_code) @error_message = args[:error_message] if args.key?(:error_message) @event_metadata = args[:event_metadata] if args.key?(:event_metadata) @invocation_id = args[:invocation_id] if args.key?(:invocation_id) @name = args[:name] if args.key?(:name) @raw_event = args[:raw_event] if args.key?(:raw_event) @timestamp = args[:timestamp] if args.key?(:timestamp) end |