Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SessionEvent
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SessionEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
An event represents a message from either the user or agent.
Instance Attribute Summary collapse
-
#actions ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EventActions
Actions are parts of events that are executed by the agent.
-
#author ⇒ String
Required.
-
#content ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content
The structured data content of a message.
-
#error_code ⇒ String
Optional.
-
#error_message ⇒ String
Optional.
-
#event_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EventMetadata
Metadata relating to a LLM response event.
-
#invocation_id ⇒ String
Required.
-
#name ⇒ String
Identifier.
-
#timestamp ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SessionEvent
constructor
A new instance of GoogleCloudAiplatformV1SessionEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SessionEvent
Returns a new instance of GoogleCloudAiplatformV1SessionEvent.
40851 40852 40853 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40851 def initialize(**args) update!(**args) end |
Instance Attribute Details
#actions ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EventActions
Actions are parts of events that are executed by the agent.
Corresponds to the JSON property actions
40804 40805 40806 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40804 def actions @actions end |
#author ⇒ String
Required. The name of the agent that sent the event, or user.
Corresponds to the JSON property author
40809 40810 40811 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40809 def @author end |
#content ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content
The structured data content of a message. A Content message contains a role
field, which indicates the producer of the content, and a parts field, which
contains the multi-part data of the message.
Corresponds to the JSON property content
40816 40817 40818 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40816 def content @content end |
#error_code ⇒ String
Optional. Error code if the response is an error. Code varies by model.
Corresponds to the JSON property errorCode
40821 40822 40823 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40821 def error_code @error_code end |
#error_message ⇒ String
Optional. Error message if the response is an error.
Corresponds to the JSON property errorMessage
40826 40827 40828 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40826 def @error_message end |
#event_metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EventMetadata
Metadata relating to a LLM response event.
Corresponds to the JSON property eventMetadata
40831 40832 40833 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40831 def @event_metadata end |
#invocation_id ⇒ String
Required. The invocation id of the event, multiple events can have the same
invocation id.
Corresponds to the JSON property invocationId
40837 40838 40839 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40837 def invocation_id @invocation_id end |
#name ⇒ String
Identifier. The resource name of the event. Format:projects/project/
locations/location/reasoningEngines/reasoning_engine/sessions/session/
events/event`.
Corresponds to the JSON propertyname`
40844 40845 40846 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40844 def name @name end |
#timestamp ⇒ String
Required. Timestamp when the event was created on client side.
Corresponds to the JSON property timestamp
40849 40850 40851 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40849 def @timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40856 40857 40858 40859 40860 40861 40862 40863 40864 40865 40866 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40856 def update!(**args) @actions = args[:actions] if args.key?(:actions) @author = args[:author] if args.key?(:author) @content = args[:content] if args.key?(:content) @error_code = args[:error_code] if args.key?(:error_code) @error_message = args[:error_message] if args.key?(:error_message) @event_metadata = args[:event_metadata] if args.key?(:event_metadata) @invocation_id = args[:invocation_id] if args.key?(:invocation_id) @name = args[:name] if args.key?(:name) @timestamp = args[:timestamp] if args.key?(:timestamp) end |