Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SessionEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

An event represents a message from either the user or agent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SessionEvent

Returns a new instance of GoogleCloudAiplatformV1SessionEvent.



40567
40568
40569
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40567

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EventActions

Actions are parts of events that are executed by the agent. Corresponds to the JSON property actions



40520
40521
40522
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40520

def actions
  @actions
end

#authorString

Required. The name of the agent that sent the event, or user. Corresponds to the JSON property author

Returns:

  • (String)


40525
40526
40527
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40525

def author
  @author
end

#contentGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Content

The structured data content of a message. A Content message contains a role field, which indicates the producer of the content, and a parts field, which contains the multi-part data of the message. Corresponds to the JSON property content



40532
40533
40534
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40532

def content
  @content
end

#error_codeString

Optional. Error code if the response is an error. Code varies by model. Corresponds to the JSON property errorCode

Returns:

  • (String)


40537
40538
40539
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40537

def error_code
  @error_code
end

#error_messageString

Optional. Error message if the response is an error. Corresponds to the JSON property errorMessage

Returns:

  • (String)


40542
40543
40544
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40542

def error_message
  @error_message
end

#event_metadataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EventMetadata

Metadata relating to a LLM response event. Corresponds to the JSON property eventMetadata



40547
40548
40549
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40547

def 
  @event_metadata
end

#invocation_idString

Required. The invocation id of the event, multiple events can have the same invocation id. Corresponds to the JSON property invocationId

Returns:

  • (String)


40553
40554
40555
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40553

def invocation_id
  @invocation_id
end

#nameString

Identifier. The resource name of the event. Format:projects/project/ locations/location/reasoningEngines/reasoning_engine/sessions/session/ events/event`. Corresponds to the JSON propertyname`

Returns:

  • (String)


40560
40561
40562
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40560

def name
  @name
end

#timestampString

Required. Timestamp when the event was created on client side. Corresponds to the JSON property timestamp

Returns:

  • (String)


40565
40566
40567
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40565

def timestamp
  @timestamp
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40572
40573
40574
40575
40576
40577
40578
40579
40580
40581
40582
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40572

def update!(**args)
  @actions = args[:actions] if args.key?(:actions)
  @author = args[:author] if args.key?(:author)
  @content = args[:content] if args.key?(:content)
  @error_code = args[:error_code] if args.key?(:error_code)
  @error_message = args[:error_message] if args.key?(:error_message)
  @event_metadata = args[:event_metadata] if args.key?(:event_metadata)
  @invocation_id = args[:invocation_id] if args.key?(:invocation_id)
  @name = args[:name] if args.key?(:name)
  @timestamp = args[:timestamp] if args.key?(:timestamp)
end