Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SharePointSourcesSharePointSource
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SharePointSourcesSharePointSource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
An individual SharePointSource.
Instance Attribute Summary collapse
-
#client_id ⇒ String
The Application ID for the app registered in Microsoft Azure Portal.
-
#client_secret ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ApiAuthApiKeyConfig
The API secret.
-
#drive_id ⇒ String
The ID of the drive to download from.
-
#drive_name ⇒ String
The name of the drive to download from.
-
#file_id ⇒ String
Output only.
-
#sharepoint_folder_id ⇒ String
The ID of the SharePoint folder to download from.
-
#sharepoint_folder_path ⇒ String
The path of the SharePoint folder to download from.
-
#sharepoint_site_name ⇒ String
The name of the SharePoint site to download from.
-
#tenant_id ⇒ String
Unique identifier of the Azure Active Directory Instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SharePointSourcesSharePointSource
constructor
A new instance of GoogleCloudAiplatformV1SharePointSourcesSharePointSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SharePointSourcesSharePointSource
Returns a new instance of GoogleCloudAiplatformV1SharePointSourcesSharePointSource.
44891 44892 44893 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44891 def initialize(**args) update!(**args) end |
Instance Attribute Details
#client_id ⇒ String
The Application ID for the app registered in Microsoft Azure Portal. The
application must also be configured with MS Graph permissions "Files.ReadAll",
"Sites.ReadAll" and BrowserSiteLists.Read.All.
Corresponds to the JSON property clientId
44848 44849 44850 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44848 def client_id @client_id end |
#client_secret ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ApiAuthApiKeyConfig
The API secret.
Corresponds to the JSON property clientSecret
44853 44854 44855 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44853 def client_secret @client_secret end |
#drive_id ⇒ String
The ID of the drive to download from.
Corresponds to the JSON property driveId
44858 44859 44860 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44858 def drive_id @drive_id end |
#drive_name ⇒ String
The name of the drive to download from.
Corresponds to the JSON property driveName
44863 44864 44865 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44863 def drive_name @drive_name end |
#file_id ⇒ String
Output only. The SharePoint file id. Output only.
Corresponds to the JSON property fileId
44868 44869 44870 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44868 def file_id @file_id end |
#sharepoint_folder_id ⇒ String
The ID of the SharePoint folder to download from.
Corresponds to the JSON property sharepointFolderId
44873 44874 44875 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44873 def sharepoint_folder_id @sharepoint_folder_id end |
#sharepoint_folder_path ⇒ String
The path of the SharePoint folder to download from.
Corresponds to the JSON property sharepointFolderPath
44878 44879 44880 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44878 def sharepoint_folder_path @sharepoint_folder_path end |
#sharepoint_site_name ⇒ String
The name of the SharePoint site to download from. This can be the site name or
the site id.
Corresponds to the JSON property sharepointSiteName
44884 44885 44886 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44884 def sharepoint_site_name @sharepoint_site_name end |
#tenant_id ⇒ String
Unique identifier of the Azure Active Directory Instance.
Corresponds to the JSON property tenantId
44889 44890 44891 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44889 def tenant_id @tenant_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
44896 44897 44898 44899 44900 44901 44902 44903 44904 44905 44906 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44896 def update!(**args) @client_id = args[:client_id] if args.key?(:client_id) @client_secret = args[:client_secret] if args.key?(:client_secret) @drive_id = args[:drive_id] if args.key?(:drive_id) @drive_name = args[:drive_name] if args.key?(:drive_name) @file_id = args[:file_id] if args.key?(:file_id) @sharepoint_folder_id = args[:sharepoint_folder_id] if args.key?(:sharepoint_folder_id) @sharepoint_folder_path = args[:sharepoint_folder_path] if args.key?(:sharepoint_folder_path) @sharepoint_site_name = args[:sharepoint_site_name] if args.key?(:sharepoint_site_name) @tenant_id = args[:tenant_id] if args.key?(:tenant_id) end |