Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SharePointSourcesSharePointSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

An individual SharePointSource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SharePointSourcesSharePointSource

Returns a new instance of GoogleCloudAiplatformV1SharePointSourcesSharePointSource.



42688
42689
42690
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42688

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_idString

The Application ID for the app registered in Microsoft Azure Portal. The application must also be configured with MS Graph permissions "Files.ReadAll", "Sites.ReadAll" and BrowserSiteLists.Read.All. Corresponds to the JSON property clientId

Returns:

  • (String)


42645
42646
42647
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42645

def client_id
  @client_id
end

#client_secretGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ApiAuthApiKeyConfig

The API secret. Corresponds to the JSON property clientSecret



42650
42651
42652
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42650

def client_secret
  @client_secret
end

#drive_idString

The ID of the drive to download from. Corresponds to the JSON property driveId

Returns:

  • (String)


42655
42656
42657
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42655

def drive_id
  @drive_id
end

#drive_nameString

The name of the drive to download from. Corresponds to the JSON property driveName

Returns:

  • (String)


42660
42661
42662
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42660

def drive_name
  @drive_name
end

#file_idString

Output only. The SharePoint file id. Output only. Corresponds to the JSON property fileId

Returns:

  • (String)


42665
42666
42667
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42665

def file_id
  @file_id
end

#sharepoint_folder_idString

The ID of the SharePoint folder to download from. Corresponds to the JSON property sharepointFolderId

Returns:

  • (String)


42670
42671
42672
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42670

def sharepoint_folder_id
  @sharepoint_folder_id
end

#sharepoint_folder_pathString

The path of the SharePoint folder to download from. Corresponds to the JSON property sharepointFolderPath

Returns:

  • (String)


42675
42676
42677
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42675

def sharepoint_folder_path
  @sharepoint_folder_path
end

#sharepoint_site_nameString

The name of the SharePoint site to download from. This can be the site name or the site id. Corresponds to the JSON property sharepointSiteName

Returns:

  • (String)


42681
42682
42683
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42681

def sharepoint_site_name
  @sharepoint_site_name
end

#tenant_idString

Unique identifier of the Azure Active Directory Instance. Corresponds to the JSON property tenantId

Returns:

  • (String)


42686
42687
42688
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42686

def tenant_id
  @tenant_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42693
42694
42695
42696
42697
42698
42699
42700
42701
42702
42703
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42693

def update!(**args)
  @client_id = args[:client_id] if args.key?(:client_id)
  @client_secret = args[:client_secret] if args.key?(:client_secret)
  @drive_id = args[:drive_id] if args.key?(:drive_id)
  @drive_name = args[:drive_name] if args.key?(:drive_name)
  @file_id = args[:file_id] if args.key?(:file_id)
  @sharepoint_folder_id = args[:sharepoint_folder_id] if args.key?(:sharepoint_folder_id)
  @sharepoint_folder_path = args[:sharepoint_folder_path] if args.key?(:sharepoint_folder_path)
  @sharepoint_site_name = args[:sharepoint_site_name] if args.key?(:sharepoint_site_name)
  @tenant_id = args[:tenant_id] if args.key?(:tenant_id)
end