Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SharePointSourcesSharePointSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

An individual SharePointSource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SharePointSourcesSharePointSource

Returns a new instance of GoogleCloudAiplatformV1SharePointSourcesSharePointSource.



34232
34233
34234
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34232

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_idString

The Application ID for the app registered in Microsoft Azure Portal. The application must also be configured with MS Graph permissions "Files.ReadAll", "Sites.ReadAll" and BrowserSiteLists.Read.All. Corresponds to the JSON property clientId

Returns:

  • (String)


34189
34190
34191
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34189

def client_id
  @client_id
end

#client_secretGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ApiAuthApiKeyConfig

The API secret. Corresponds to the JSON property clientSecret



34194
34195
34196
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34194

def client_secret
  @client_secret
end

#drive_idString

The ID of the drive to download from. Corresponds to the JSON property driveId

Returns:

  • (String)


34199
34200
34201
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34199

def drive_id
  @drive_id
end

#drive_nameString

The name of the drive to download from. Corresponds to the JSON property driveName

Returns:

  • (String)


34204
34205
34206
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34204

def drive_name
  @drive_name
end

#file_idString

Output only. The SharePoint file id. Output only. Corresponds to the JSON property fileId

Returns:

  • (String)


34209
34210
34211
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34209

def file_id
  @file_id
end

#sharepoint_folder_idString

The ID of the SharePoint folder to download from. Corresponds to the JSON property sharepointFolderId

Returns:

  • (String)


34214
34215
34216
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34214

def sharepoint_folder_id
  @sharepoint_folder_id
end

#sharepoint_folder_pathString

The path of the SharePoint folder to download from. Corresponds to the JSON property sharepointFolderPath

Returns:

  • (String)


34219
34220
34221
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34219

def sharepoint_folder_path
  @sharepoint_folder_path
end

#sharepoint_site_nameString

The name of the SharePoint site to download from. This can be the site name or the site id. Corresponds to the JSON property sharepointSiteName

Returns:

  • (String)


34225
34226
34227
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34225

def sharepoint_site_name
  @sharepoint_site_name
end

#tenant_idString

Unique identifier of the Azure Active Directory Instance. Corresponds to the JSON property tenantId

Returns:

  • (String)


34230
34231
34232
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34230

def tenant_id
  @tenant_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34237
34238
34239
34240
34241
34242
34243
34244
34245
34246
34247
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34237

def update!(**args)
  @client_id = args[:client_id] if args.key?(:client_id)
  @client_secret = args[:client_secret] if args.key?(:client_secret)
  @drive_id = args[:drive_id] if args.key?(:drive_id)
  @drive_name = args[:drive_name] if args.key?(:drive_name)
  @file_id = args[:file_id] if args.key?(:file_id)
  @sharepoint_folder_id = args[:sharepoint_folder_id] if args.key?(:sharepoint_folder_id)
  @sharepoint_folder_path = args[:sharepoint_folder_path] if args.key?(:sharepoint_folder_path)
  @sharepoint_site_name = args[:sharepoint_site_name] if args.key?(:sharepoint_site_name)
  @tenant_id = args[:tenant_id] if args.key?(:tenant_id)
end