Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SharePointSourcesSharePointSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

An individual SharePointSource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SharePointSourcesSharePointSource

Returns a new instance of GoogleCloudAiplatformV1SharePointSourcesSharePointSource.



32959
32960
32961
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32959

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_idString

The Application ID for the app registered in Microsoft Azure Portal. The application must also be configured with MS Graph permissions "Files.ReadAll", "Sites.ReadAll" and BrowserSiteLists.Read.All. Corresponds to the JSON property clientId

Returns:

  • (String)


32916
32917
32918
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32916

def client_id
  @client_id
end

#client_secretGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ApiAuthApiKeyConfig

The API secret. Corresponds to the JSON property clientSecret



32921
32922
32923
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32921

def client_secret
  @client_secret
end

#drive_idString

The ID of the drive to download from. Corresponds to the JSON property driveId

Returns:

  • (String)


32926
32927
32928
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32926

def drive_id
  @drive_id
end

#drive_nameString

The name of the drive to download from. Corresponds to the JSON property driveName

Returns:

  • (String)


32931
32932
32933
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32931

def drive_name
  @drive_name
end

#file_idString

Output only. The SharePoint file id. Output only. Corresponds to the JSON property fileId

Returns:

  • (String)


32936
32937
32938
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32936

def file_id
  @file_id
end

#sharepoint_folder_idString

The ID of the SharePoint folder to download from. Corresponds to the JSON property sharepointFolderId

Returns:

  • (String)


32941
32942
32943
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32941

def sharepoint_folder_id
  @sharepoint_folder_id
end

#sharepoint_folder_pathString

The path of the SharePoint folder to download from. Corresponds to the JSON property sharepointFolderPath

Returns:

  • (String)


32946
32947
32948
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32946

def sharepoint_folder_path
  @sharepoint_folder_path
end

#sharepoint_site_nameString

The name of the SharePoint site to download from. This can be the site name or the site id. Corresponds to the JSON property sharepointSiteName

Returns:

  • (String)


32952
32953
32954
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32952

def sharepoint_site_name
  @sharepoint_site_name
end

#tenant_idString

Unique identifier of the Azure Active Directory Instance. Corresponds to the JSON property tenantId

Returns:

  • (String)


32957
32958
32959
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32957

def tenant_id
  @tenant_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32964
32965
32966
32967
32968
32969
32970
32971
32972
32973
32974
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32964

def update!(**args)
  @client_id = args[:client_id] if args.key?(:client_id)
  @client_secret = args[:client_secret] if args.key?(:client_secret)
  @drive_id = args[:drive_id] if args.key?(:drive_id)
  @drive_name = args[:drive_name] if args.key?(:drive_name)
  @file_id = args[:file_id] if args.key?(:file_id)
  @sharepoint_folder_id = args[:sharepoint_folder_id] if args.key?(:sharepoint_folder_id)
  @sharepoint_folder_path = args[:sharepoint_folder_path] if args.key?(:sharepoint_folder_path)
  @sharepoint_site_name = args[:sharepoint_site_name] if args.key?(:sharepoint_site_name)
  @tenant_id = args[:tenant_id] if args.key?(:tenant_id)
end