Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ShieldedVmConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A set of Shielded Instance options. See Images using supported Shielded VM features.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ShieldedVmConfig

Returns a new instance of GoogleCloudAiplatformV1ShieldedVmConfig.



44481
44482
44483
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44481

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_secure_bootBoolean Also known as: enable_secure_boot?

Defines whether the instance has Secure Boot enabled. Secure Boot helps ensure that the system only runs authentic software by verifying the digital signature of all boot components, and halting the boot process if signature verification fails. Corresponds to the JSON property enableSecureBoot

Returns:

  • (Boolean)


44478
44479
44480
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44478

def enable_secure_boot
  @enable_secure_boot
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44486
44487
44488
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44486

def update!(**args)
  @enable_secure_boot = args[:enable_secure_boot] if args.key?(:enable_secure_boot)
end