Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ShieldedVmConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A set of Shielded Instance options. See Images using supported Shielded VM features.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ShieldedVmConfig

Returns a new instance of GoogleCloudAiplatformV1ShieldedVmConfig.



25280
25281
25282
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25280

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_secure_bootBoolean Also known as: enable_secure_boot?

Defines whether the instance has Secure Boot enabled. Secure Boot helps ensure that the system only runs authentic software by verifying the digital signature of all boot components, and halting the boot process if signature verification fails. Corresponds to the JSON property enableSecureBoot

Returns:

  • (Boolean)


25277
25278
25279
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25277

def enable_secure_boot
  @enable_secure_boot
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25285
25286
25287
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25285

def update!(**args)
  @enable_secure_boot = args[:enable_secure_boot] if args.key?(:enable_secure_boot)
end