Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SmoothGradConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Config for SmoothGrad approximation of gradients. When enabled, the gradients are approximated by averaging the gradients from noisy samples in the vicinity of the inputs. Adding noise can help improve the computed gradients. Refer to this paper for more details: https://arxiv.org/pdf/1706.03825.pdf

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SmoothGradConfig

Returns a new instance of GoogleCloudAiplatformV1SmoothGradConfig.



33113
33114
33115
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33113

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#feature_noise_sigmaGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1FeatureNoiseSigma

Noise sigma by features. Noise sigma represents the standard deviation of the gaussian kernel that will be used to add noise to interpolated inputs prior to computing gradients. Corresponds to the JSON property featureNoiseSigma



33090
33091
33092
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33090

def feature_noise_sigma
  @feature_noise_sigma
end

#noise_sigmaFloat

This is a single float value and will be used to add noise to all the features. Use this field when all features are normalized to have the same distribution: scale to range [0, 1], [-1, 1] or z-scoring, where features are normalized to have 0-mean and 1-variance. Learn more about normalization. For best results the recommended value is about 10% - 20% of the standard deviation of the input feature. Refer to section 3.2 of the SmoothGrad paper: https://arxiv.org/pdf/1706.03825.pdf. Defaults to 0.1. If the distribution is different per feature, set feature_noise_sigma instead for each feature. Corresponds to the JSON property noiseSigma

Returns:

  • (Float)


33103
33104
33105
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33103

def noise_sigma
  @noise_sigma
end

#noisy_sample_countFixnum

The number of gradient samples to use for approximation. The higher this number, the more accurate the gradient is, but the runtime complexity increases by this factor as well. Valid range of its value is [1, 50]. Defaults to 3. Corresponds to the JSON property noisySampleCount

Returns:

  • (Fixnum)


33111
33112
33113
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33111

def noisy_sample_count
  @noisy_sample_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33118
33119
33120
33121
33122
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33118

def update!(**args)
  @feature_noise_sigma = args[:feature_noise_sigma] if args.key?(:feature_noise_sigma)
  @noise_sigma = args[:noise_sigma] if args.key?(:noise_sigma)
  @noisy_sample_count = args[:noisy_sample_count] if args.key?(:noisy_sample_count)
end