Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SpecialistPool

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

SpecialistPool represents customers' own workforce to work on their data labeling jobs. It includes a group of specialist managers and workers. Managers are responsible for managing the workers in this pool as well as customers' data labeling jobs associated with this pool. Customers create specialist pool as well as start data labeling jobs on Cloud, managers and workers handle the jobs using CrowdCompute console.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SpecialistPool

Returns a new instance of GoogleCloudAiplatformV1SpecialistPool.



40889
40890
40891
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40889

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Required. The user-defined name of the SpecialistPool. The name can be up to 128 characters long and can consist of any UTF-8 characters. This field should be unique on project-level. Corresponds to the JSON property displayName

Returns:

  • (String)


40862
40863
40864
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40862

def display_name
  @display_name
end

#nameString

Required. The resource name of the SpecialistPool. Corresponds to the JSON property name

Returns:

  • (String)


40867
40868
40869
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40867

def name
  @name
end

#pending_data_labeling_jobsArray<String>

Output only. The resource name of the pending data labeling jobs. Corresponds to the JSON property pendingDataLabelingJobs

Returns:

  • (Array<String>)


40872
40873
40874
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40872

def pending_data_labeling_jobs
  @pending_data_labeling_jobs
end

#specialist_manager_emailsArray<String>

The email addresses of the managers in the SpecialistPool. Corresponds to the JSON property specialistManagerEmails

Returns:

  • (Array<String>)


40877
40878
40879
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40877

def specialist_manager_emails
  @specialist_manager_emails
end

#specialist_managers_countFixnum

Output only. The number of managers in this SpecialistPool. Corresponds to the JSON property specialistManagersCount

Returns:

  • (Fixnum)


40882
40883
40884
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40882

def specialist_managers_count
  @specialist_managers_count
end

#specialist_worker_emailsArray<String>

The email addresses of workers in the SpecialistPool. Corresponds to the JSON property specialistWorkerEmails

Returns:

  • (Array<String>)


40887
40888
40889
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40887

def specialist_worker_emails
  @specialist_worker_emails
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40894
40895
40896
40897
40898
40899
40900
40901
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40894

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @pending_data_labeling_jobs = args[:pending_data_labeling_jobs] if args.key?(:pending_data_labeling_jobs)
  @specialist_manager_emails = args[:specialist_manager_emails] if args.key?(:specialist_manager_emails)
  @specialist_managers_count = args[:specialist_managers_count] if args.key?(:specialist_managers_count)
  @specialist_worker_emails = args[:specialist_worker_emails] if args.key?(:specialist_worker_emails)
end