Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SpecialistPool

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

SpecialistPool represents customers' own workforce to work on their data labeling jobs. It includes a group of specialist managers and workers. Managers are responsible for managing the workers in this pool as well as customers' data labeling jobs associated with this pool. Customers create specialist pool as well as start data labeling jobs on Cloud, managers and workers handle the jobs using CrowdCompute console.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SpecialistPool

Returns a new instance of GoogleCloudAiplatformV1SpecialistPool.



33897
33898
33899
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33897

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Required. The user-defined name of the SpecialistPool. The name can be up to 128 characters long and can consist of any UTF-8 characters. This field should be unique on project-level. Corresponds to the JSON property displayName

Returns:

  • (String)


33870
33871
33872
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33870

def display_name
  @display_name
end

#nameString

Required. The resource name of the SpecialistPool. Corresponds to the JSON property name

Returns:

  • (String)


33875
33876
33877
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33875

def name
  @name
end

#pending_data_labeling_jobsArray<String>

Output only. The resource name of the pending data labeling jobs. Corresponds to the JSON property pendingDataLabelingJobs

Returns:

  • (Array<String>)


33880
33881
33882
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33880

def pending_data_labeling_jobs
  @pending_data_labeling_jobs
end

#specialist_manager_emailsArray<String>

The email addresses of the managers in the SpecialistPool. Corresponds to the JSON property specialistManagerEmails

Returns:

  • (Array<String>)


33885
33886
33887
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33885

def specialist_manager_emails
  @specialist_manager_emails
end

#specialist_managers_countFixnum

Output only. The number of managers in this SpecialistPool. Corresponds to the JSON property specialistManagersCount

Returns:

  • (Fixnum)


33890
33891
33892
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33890

def specialist_managers_count
  @specialist_managers_count
end

#specialist_worker_emailsArray<String>

The email addresses of workers in the SpecialistPool. Corresponds to the JSON property specialistWorkerEmails

Returns:

  • (Array<String>)


33895
33896
33897
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33895

def specialist_worker_emails
  @specialist_worker_emails
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33902
33903
33904
33905
33906
33907
33908
33909
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33902

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @pending_data_labeling_jobs = args[:pending_data_labeling_jobs] if args.key?(:pending_data_labeling_jobs)
  @specialist_manager_emails = args[:specialist_manager_emails] if args.key?(:specialist_manager_emails)
  @specialist_managers_count = args[:specialist_managers_count] if args.key?(:specialist_managers_count)
  @specialist_worker_emails = args[:specialist_worker_emails] if args.key?(:specialist_worker_emails)
end