Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SpeculativeDecodingSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Configuration for Speculative Decoding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SpeculativeDecodingSpec

Returns a new instance of GoogleCloudAiplatformV1SpeculativeDecodingSpec.



41209
41210
41211
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41209

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#draft_model_speculationGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SpeculativeDecodingSpecDraftModelSpeculation

Draft model speculation works by using the smaller model to generate candidate tokens for speculative decoding. Corresponds to the JSON property draftModelSpeculation



41196
41197
41198
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41196

def draft_model_speculation
  @draft_model_speculation
end

#ngram_speculationGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SpeculativeDecodingSpecNgramSpeculation

N-Gram speculation works by trying to find matching tokens in the previous prompt sequence and use those as speculation for generating new tokens. Corresponds to the JSON property ngramSpeculation



41202
41203
41204
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41202

def ngram_speculation
  @ngram_speculation
end

#speculative_token_countFixnum

The number of speculative tokens to generate at each step. Corresponds to the JSON property speculativeTokenCount

Returns:

  • (Fixnum)


41207
41208
41209
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41207

def speculative_token_count
  @speculative_token_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41214
41215
41216
41217
41218
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41214

def update!(**args)
  @draft_model_speculation = args[:draft_model_speculation] if args.key?(:draft_model_speculation)
  @ngram_speculation = args[:ngram_speculation] if args.key?(:ngram_speculation)
  @speculative_token_count = args[:speculative_token_count] if args.key?(:speculative_token_count)
end