Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SpeculativeDecodingSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SpeculativeDecodingSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Configuration for Speculative Decoding.
Instance Attribute Summary collapse
-
#draft_model_speculation ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SpeculativeDecodingSpecDraftModelSpeculation
Draft model speculation works by using the smaller model to generate candidate tokens for speculative decoding.
-
#ngram_speculation ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SpeculativeDecodingSpecNgramSpeculation
N-Gram speculation works by trying to find matching tokens in the previous prompt sequence and use those as speculation for generating new tokens.
-
#speculative_token_count ⇒ Fixnum
The number of speculative tokens to generate at each step.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SpeculativeDecodingSpec
constructor
A new instance of GoogleCloudAiplatformV1SpeculativeDecodingSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SpeculativeDecodingSpec
Returns a new instance of GoogleCloudAiplatformV1SpeculativeDecodingSpec.
34802 34803 34804 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34802 def initialize(**args) update!(**args) end |
Instance Attribute Details
#draft_model_speculation ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SpeculativeDecodingSpecDraftModelSpeculation
Draft model speculation works by using the smaller model to generate candidate
tokens for speculative decoding.
Corresponds to the JSON property draftModelSpeculation
34789 34790 34791 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34789 def draft_model_speculation @draft_model_speculation end |
#ngram_speculation ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SpeculativeDecodingSpecNgramSpeculation
N-Gram speculation works by trying to find matching tokens in the previous
prompt sequence and use those as speculation for generating new tokens.
Corresponds to the JSON property ngramSpeculation
34795 34796 34797 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34795 def ngram_speculation @ngram_speculation end |
#speculative_token_count ⇒ Fixnum
The number of speculative tokens to generate at each step.
Corresponds to the JSON property speculativeTokenCount
34800 34801 34802 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34800 def speculative_token_count @speculative_token_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34807 34808 34809 34810 34811 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34807 def update!(**args) @draft_model_speculation = args[:draft_model_speculation] if args.key?(:draft_model_speculation) @ngram_speculation = args[:ngram_speculation] if args.key?(:ngram_speculation) @speculative_token_count = args[:speculative_token_count] if args.key?(:speculative_token_count) end |