Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StreamQueryReasoningEngineRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StreamQueryReasoningEngineRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Request message for ReasoningEngineExecutionService.StreamQuery.
Instance Attribute Summary collapse
-
#class_method ⇒ String
Optional.
-
#input ⇒ Hash<String,Object>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1StreamQueryReasoningEngineRequest
constructor
A new instance of GoogleCloudAiplatformV1StreamQueryReasoningEngineRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1StreamQueryReasoningEngineRequest
Returns a new instance of GoogleCloudAiplatformV1StreamQueryReasoningEngineRequest.
33855 33856 33857 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33855 def initialize(**args) update!(**args) end |
Instance Attribute Details
#class_method ⇒ String
Optional. Class method to be used for the stream query. It is optional and
defaults to "stream_query" if unspecified.
Corresponds to the JSON property classMethod
33847 33848 33849 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33847 def class_method @class_method end |
#input ⇒ Hash<String,Object>
Optional. Input content provided by users in JSON object format. Examples
include text query, function calling parameters, media bytes, etc.
Corresponds to the JSON property input
33853 33854 33855 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33853 def input @input end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33860 33861 33862 33863 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33860 def update!(**args) @class_method = args[:class_method] if args.key?(:class_method) @input = args[:input] if args.key?(:input) end |