Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Study

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A message representing a Study.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Study

Returns a new instance of GoogleCloudAiplatformV1Study.



35442
35443
35444
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35442

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Time at which the study was created. Corresponds to the JSON property createTime

Returns:

  • (String)


35413
35414
35415
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35413

def create_time
  @create_time
end

#display_nameString

Required. Describes the Study, default value is empty string. Corresponds to the JSON property displayName

Returns:

  • (String)


35418
35419
35420
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35418

def display_name
  @display_name
end

#inactive_reasonString

Output only. A human readable reason why the Study is inactive. This should be empty if a study is ACTIVE or COMPLETED. Corresponds to the JSON property inactiveReason

Returns:

  • (String)


35424
35425
35426
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35424

def inactive_reason
  @inactive_reason
end

#nameString

Output only. The name of a study. The study's globally unique identifier. Format: projects/project/locations/location/studies/study` Corresponds to the JSON propertyname`

Returns:

  • (String)


35430
35431
35432
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35430

def name
  @name
end

#stateString

Output only. The detailed state of a Study. Corresponds to the JSON property state

Returns:

  • (String)


35435
35436
35437
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35435

def state
  @state
end

#study_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpec

Represents specification of a Study. Corresponds to the JSON property studySpec



35440
35441
35442
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35440

def study_spec
  @study_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35447
35448
35449
35450
35451
35452
35453
35454
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35447

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @inactive_reason = args[:inactive_reason] if args.key?(:inactive_reason)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @study_spec = args[:study_spec] if args.key?(:study_spec)
end