Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Study

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A message representing a Study.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Study

Returns a new instance of GoogleCloudAiplatformV1Study.



34366
34367
34368
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34366

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Time at which the study was created. Corresponds to the JSON property createTime

Returns:

  • (String)


34337
34338
34339
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34337

def create_time
  @create_time
end

#display_nameString

Required. Describes the Study, default value is empty string. Corresponds to the JSON property displayName

Returns:

  • (String)


34342
34343
34344
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34342

def display_name
  @display_name
end

#inactive_reasonString

Output only. A human readable reason why the Study is inactive. This should be empty if a study is ACTIVE or COMPLETED. Corresponds to the JSON property inactiveReason

Returns:

  • (String)


34348
34349
34350
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34348

def inactive_reason
  @inactive_reason
end

#nameString

Output only. The name of a study. The study's globally unique identifier. Format: projects/project/locations/location/studies/study` Corresponds to the JSON propertyname`

Returns:

  • (String)


34354
34355
34356
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34354

def name
  @name
end

#stateString

Output only. The detailed state of a Study. Corresponds to the JSON property state

Returns:

  • (String)


34359
34360
34361
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34359

def state
  @state
end

#study_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpec

Represents specification of a Study. Corresponds to the JSON property studySpec



34364
34365
34366
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34364

def study_spec
  @study_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34371
34372
34373
34374
34375
34376
34377
34378
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34371

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @inactive_reason = args[:inactive_reason] if args.key?(:inactive_reason)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @study_spec = args[:study_spec] if args.key?(:study_spec)
end