Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Represents specification of a Study.
Instance Attribute Summary collapse
-
#algorithm ⇒ String
The search algorithm specified for the Study.
-
#convex_automated_stopping_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecConvexAutomatedStoppingSpec
Configuration for ConvexAutomatedStoppingSpec.
-
#decay_curve_stopping_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecDecayCurveAutomatedStoppingSpec
The decay curve automated stopping rule builds a Gaussian Process Regressor to predict the final objective value of a Trial based on the already completed Trials and the intermediate measurements of the current Trial.
-
#measurement_selection_type ⇒ String
Describe which measurement selection type will be used Corresponds to the JSON property
measurementSelectionType. -
#median_automated_stopping_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecMedianAutomatedStoppingSpec
The median automated stopping rule stops a pending Trial if the Trial's best objective_value is strictly below the median 'performance' of all completed Trials reported up to the Trial's last measurement.
-
#metrics ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecMetricSpec>
Required.
-
#observation_noise ⇒ String
The observation noise level of the study.
-
#parameters ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpec>
Required.
-
#study_stopping_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecStudyStoppingConfig
The configuration (stopping conditions) for automated stopping of a Study.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1StudySpec
constructor
A new instance of GoogleCloudAiplatformV1StudySpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1StudySpec
Returns a new instance of GoogleCloudAiplatformV1StudySpec.
35881 35882 35883 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35881 def initialize(**args) update!(**args) end |
Instance Attribute Details
#algorithm ⇒ String
The search algorithm specified for the Study.
Corresponds to the JSON property algorithm
35820 35821 35822 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35820 def algorithm @algorithm end |
#convex_automated_stopping_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecConvexAutomatedStoppingSpec
Configuration for ConvexAutomatedStoppingSpec. When there are enough completed
trials (configured by min_measurement_count), for pending trials with enough
measurements and steps, the policy first computes an overestimate of the
objective value at max_num_steps according to the slope of the incomplete
objective value curve. No prediction can be made if the curve is completely
flat. If the overestimation is worse than the best objective value of the
completed trials, this pending trial will be early-stopped, but a last
measurement will be added to the pending trial with max_num_steps and
predicted objective value from the autoregression model.
Corresponds to the JSON property convexAutomatedStoppingSpec
35833 35834 35835 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35833 def convex_automated_stopping_spec @convex_automated_stopping_spec end |
#decay_curve_stopping_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecDecayCurveAutomatedStoppingSpec
The decay curve automated stopping rule builds a Gaussian Process Regressor to
predict the final objective value of a Trial based on the already completed
Trials and the intermediate measurements of the current Trial. Early stopping
is requested for the current Trial if there is very low probability to exceed
the optimal value found so far.
Corresponds to the JSON property decayCurveStoppingSpec
35842 35843 35844 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35842 def decay_curve_stopping_spec @decay_curve_stopping_spec end |
#measurement_selection_type ⇒ String
Describe which measurement selection type will be used
Corresponds to the JSON property measurementSelectionType
35847 35848 35849 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35847 def measurement_selection_type @measurement_selection_type end |
#median_automated_stopping_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecMedianAutomatedStoppingSpec
The median automated stopping rule stops a pending Trial if the Trial's best
objective_value is strictly below the median 'performance' of all completed
Trials reported up to the Trial's last measurement. Currently, 'performance'
refers to the running average of the objective values reported by the Trial in
each measurement.
Corresponds to the JSON property medianAutomatedStoppingSpec
35856 35857 35858 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35856 def median_automated_stopping_spec @median_automated_stopping_spec end |
#metrics ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecMetricSpec>
Required. Metric specs for the Study.
Corresponds to the JSON property metrics
35861 35862 35863 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35861 def metrics @metrics end |
#observation_noise ⇒ String
The observation noise level of the study. Currently only supported by the
Vertex AI Vizier service. Not supported by HyperparameterTuningJob or
TrainingPipeline.
Corresponds to the JSON property observationNoise
35868 35869 35870 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35868 def observation_noise @observation_noise end |
#parameters ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpec>
Required. The set of parameters to tune.
Corresponds to the JSON property parameters
35873 35874 35875 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35873 def parameters @parameters end |
#study_stopping_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecStudyStoppingConfig
The configuration (stopping conditions) for automated stopping of a Study.
Conditions include trial budgets, time budgets, and convergence detection.
Corresponds to the JSON property studyStoppingConfig
35879 35880 35881 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35879 def study_stopping_config @study_stopping_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35886 35887 35888 35889 35890 35891 35892 35893 35894 35895 35896 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35886 def update!(**args) @algorithm = args[:algorithm] if args.key?(:algorithm) @convex_automated_stopping_spec = args[:convex_automated_stopping_spec] if args.key?(:convex_automated_stopping_spec) @decay_curve_stopping_spec = args[:decay_curve_stopping_spec] if args.key?(:decay_curve_stopping_spec) @measurement_selection_type = args[:measurement_selection_type] if args.key?(:measurement_selection_type) @median_automated_stopping_spec = args[:median_automated_stopping_spec] if args.key?(:median_automated_stopping_spec) @metrics = args[:metrics] if args.key?(:metrics) @observation_noise = args[:observation_noise] if args.key?(:observation_noise) @parameters = args[:parameters] if args.key?(:parameters) @study_stopping_config = args[:study_stopping_config] if args.key?(:study_stopping_config) end |