Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents specification of a Study.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1StudySpec

Returns a new instance of GoogleCloudAiplatformV1StudySpec.



27882
27883
27884
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27882

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#algorithmString

The search algorithm specified for the Study. Corresponds to the JSON property algorithm

Returns:

  • (String)


27821
27822
27823
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27821

def algorithm
  @algorithm
end

#convex_automated_stopping_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecConvexAutomatedStoppingSpec

Configuration for ConvexAutomatedStoppingSpec. When there are enough completed trials (configured by min_measurement_count), for pending trials with enough measurements and steps, the policy first computes an overestimate of the objective value at max_num_steps according to the slope of the incomplete objective value curve. No prediction can be made if the curve is completely flat. If the overestimation is worse than the best objective value of the completed trials, this pending trial will be early-stopped, but a last measurement will be added to the pending trial with max_num_steps and predicted objective value from the autoregression model. Corresponds to the JSON property convexAutomatedStoppingSpec



27834
27835
27836
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27834

def convex_automated_stopping_spec
  @convex_automated_stopping_spec
end

#decay_curve_stopping_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecDecayCurveAutomatedStoppingSpec

The decay curve automated stopping rule builds a Gaussian Process Regressor to predict the final objective value of a Trial based on the already completed Trials and the intermediate measurements of the current Trial. Early stopping is requested for the current Trial if there is very low probability to exceed the optimal value found so far. Corresponds to the JSON property decayCurveStoppingSpec



27843
27844
27845
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27843

def decay_curve_stopping_spec
  @decay_curve_stopping_spec
end

#measurement_selection_typeString

Describe which measurement selection type will be used Corresponds to the JSON property measurementSelectionType

Returns:

  • (String)


27848
27849
27850
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27848

def measurement_selection_type
  @measurement_selection_type
end

#median_automated_stopping_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecMedianAutomatedStoppingSpec

The median automated stopping rule stops a pending Trial if the Trial's best objective_value is strictly below the median 'performance' of all completed Trials reported up to the Trial's last measurement. Currently, 'performance' refers to the running average of the objective values reported by the Trial in each measurement. Corresponds to the JSON property medianAutomatedStoppingSpec



27857
27858
27859
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27857

def median_automated_stopping_spec
  @median_automated_stopping_spec
end

#metricsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecMetricSpec>

Required. Metric specs for the Study. Corresponds to the JSON property metrics



27862
27863
27864
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27862

def metrics
  @metrics
end

#observation_noiseString

The observation noise level of the study. Currently only supported by the Vertex AI Vizier service. Not supported by HyperparameterTuningJob or TrainingPipeline. Corresponds to the JSON property observationNoise

Returns:

  • (String)


27869
27870
27871
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27869

def observation_noise
  @observation_noise
end

#parametersArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpec>

Required. The set of parameters to tune. Corresponds to the JSON property parameters



27874
27875
27876
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27874

def parameters
  @parameters
end

#study_stopping_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecStudyStoppingConfig

The configuration (stopping conditions) for automated stopping of a Study. Conditions include trial budgets, time budgets, and convergence detection. Corresponds to the JSON property studyStoppingConfig



27880
27881
27882
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27880

def study_stopping_config
  @study_stopping_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27887
27888
27889
27890
27891
27892
27893
27894
27895
27896
27897
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27887

def update!(**args)
  @algorithm = args[:algorithm] if args.key?(:algorithm)
  @convex_automated_stopping_spec = args[:convex_automated_stopping_spec] if args.key?(:convex_automated_stopping_spec)
  @decay_curve_stopping_spec = args[:decay_curve_stopping_spec] if args.key?(:decay_curve_stopping_spec)
  @measurement_selection_type = args[:measurement_selection_type] if args.key?(:measurement_selection_type)
  @median_automated_stopping_spec = args[:median_automated_stopping_spec] if args.key?(:median_automated_stopping_spec)
  @metrics = args[:metrics] if args.key?(:metrics)
  @observation_noise = args[:observation_noise] if args.key?(:observation_noise)
  @parameters = args[:parameters] if args.key?(:parameters)
  @study_stopping_config = args[:study_stopping_config] if args.key?(:study_stopping_config)
end