Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecDecayCurveAutomatedStoppingSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecDecayCurveAutomatedStoppingSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The decay curve automated stopping rule builds a Gaussian Process Regressor to predict the final objective value of a Trial based on the already completed Trials and the intermediate measurements of the current Trial. Early stopping is requested for the current Trial if there is very low probability to exceed the optimal value found so far.
Instance Attribute Summary collapse
-
#use_elapsed_duration ⇒ Boolean
(also: #use_elapsed_duration?)
True if Measurement.elapsed_duration is used as the x-axis of each Trials Decay Curve.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1StudySpecDecayCurveAutomatedStoppingSpec
constructor
A new instance of GoogleCloudAiplatformV1StudySpecDecayCurveAutomatedStoppingSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1StudySpecDecayCurveAutomatedStoppingSpec
Returns a new instance of GoogleCloudAiplatformV1StudySpecDecayCurveAutomatedStoppingSpec.
34277 34278 34279 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34277 def initialize(**args) update!(**args) end |
Instance Attribute Details
#use_elapsed_duration ⇒ Boolean Also known as: use_elapsed_duration?
True if Measurement.elapsed_duration is used as the x-axis of each Trials
Decay Curve. Otherwise, Measurement.step_count will be used as the x-axis.
Corresponds to the JSON property useElapsedDuration
34274 34275 34276 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34274 def use_elapsed_duration @use_elapsed_duration end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34282 34283 34284 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34282 def update!(**args) @use_elapsed_duration = args[:use_elapsed_duration] if args.key?(:use_elapsed_duration) end |