Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecDecayCurveAutomatedStoppingSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The decay curve automated stopping rule builds a Gaussian Process Regressor to predict the final objective value of a Trial based on the already completed Trials and the intermediate measurements of the current Trial. Early stopping is requested for the current Trial if there is very low probability to exceed the optimal value found so far.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1StudySpecDecayCurveAutomatedStoppingSpec

Returns a new instance of GoogleCloudAiplatformV1StudySpecDecayCurveAutomatedStoppingSpec.



25862
25863
25864
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25862

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#use_elapsed_durationBoolean Also known as: use_elapsed_duration?

True if Measurement.elapsed_duration is used as the x-axis of each Trials Decay Curve. Otherwise, Measurement.step_count will be used as the x-axis. Corresponds to the JSON property useElapsedDuration

Returns:

  • (Boolean)


25859
25860
25861
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25859

def use_elapsed_duration
  @use_elapsed_duration
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25867
25868
25869
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25867

def update!(**args)
  @use_elapsed_duration = args[:use_elapsed_duration] if args.key?(:use_elapsed_duration)
end