Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecMedianAutomatedStoppingSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecMedianAutomatedStoppingSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The median automated stopping rule stops a pending Trial if the Trial's best objective_value is strictly below the median 'performance' of all completed Trials reported up to the Trial's last measurement. Currently, 'performance' refers to the running average of the objective values reported by the Trial in each measurement.
Instance Attribute Summary collapse
-
#use_elapsed_duration ⇒ Boolean
(also: #use_elapsed_duration?)
True if median automated stopping rule applies on Measurement.elapsed_duration.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1StudySpecMedianAutomatedStoppingSpec
constructor
A new instance of GoogleCloudAiplatformV1StudySpecMedianAutomatedStoppingSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1StudySpecMedianAutomatedStoppingSpec
Returns a new instance of GoogleCloudAiplatformV1StudySpecMedianAutomatedStoppingSpec.
41872 41873 41874 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41872 def initialize(**args) update!(**args) end |
Instance Attribute Details
#use_elapsed_duration ⇒ Boolean Also known as: use_elapsed_duration?
True if median automated stopping rule applies on Measurement.elapsed_duration.
It means that elapsed_duration field of latest measurement of current Trial
is used to compute median objective value for each completed Trials.
Corresponds to the JSON property useElapsedDuration
41869 41870 41871 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41869 def use_elapsed_duration @use_elapsed_duration end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41877 41878 41879 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 41877 def update!(**args) @use_elapsed_duration = args[:use_elapsed_duration] if args.key?(:use_elapsed_duration) end |