Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecMedianAutomatedStoppingSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The median automated stopping rule stops a pending Trial if the Trial's best objective_value is strictly below the median 'performance' of all completed Trials reported up to the Trial's last measurement. Currently, 'performance' refers to the running average of the objective values reported by the Trial in each measurement.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1StudySpecMedianAutomatedStoppingSpec

Returns a new instance of GoogleCloudAiplatformV1StudySpecMedianAutomatedStoppingSpec.



33918
33919
33920
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33918

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#use_elapsed_durationBoolean Also known as: use_elapsed_duration?

True if median automated stopping rule applies on Measurement.elapsed_duration. It means that elapsed_duration field of latest measurement of current Trial is used to compute median objective value for each completed Trials. Corresponds to the JSON property useElapsedDuration

Returns:

  • (Boolean)


33915
33916
33917
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33915

def use_elapsed_duration
  @use_elapsed_duration
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33923
33924
33925
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33923

def update!(**args)
  @use_elapsed_duration = args[:use_elapsed_duration] if args.key?(:use_elapsed_duration)
end