Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecMetricSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecMetricSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Represents a metric to optimize.
Instance Attribute Summary collapse
-
#goal ⇒ String
Required.
-
#metric_id ⇒ String
Required.
-
#safety_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecMetricSpecSafetyMetricConfig
Used in safe optimization to specify threshold levels and risk tolerance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1StudySpecMetricSpec
constructor
A new instance of GoogleCloudAiplatformV1StudySpecMetricSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1StudySpecMetricSpec
Returns a new instance of GoogleCloudAiplatformV1StudySpecMetricSpec.
33966 33967 33968 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33966 def initialize(**args) update!(**args) end |
Instance Attribute Details
#goal ⇒ String
Required. The optimization goal of the metric.
Corresponds to the JSON property goal
33953 33954 33955 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33953 def goal @goal end |
#metric_id ⇒ String
Required. The ID of the metric. Must not contain whitespaces and must be
unique amongst all MetricSpecs.
Corresponds to the JSON property metricId
33959 33960 33961 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33959 def metric_id @metric_id end |
#safety_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecMetricSpecSafetyMetricConfig
Used in safe optimization to specify threshold levels and risk tolerance.
Corresponds to the JSON property safetyConfig
33964 33965 33966 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33964 def safety_config @safety_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33971 33972 33973 33974 33975 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33971 def update!(**args) @goal = args[:goal] if args.key?(:goal) @metric_id = args[:metric_id] if args.key?(:metric_id) @safety_config = args[:safety_config] if args.key?(:safety_config) end |