Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecMetricSpecSafetyMetricConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Used in safe optimization to specify threshold levels and risk tolerance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1StudySpecMetricSpecSafetyMetricConfig

Returns a new instance of GoogleCloudAiplatformV1StudySpecMetricSpecSafetyMetricConfig.



45884
45885
45886
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45884

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#desired_min_safe_trials_fractionFloat

Desired minimum fraction of safe trials (over total number of trials) that should be targeted by the algorithm at any time during the study (best effort). This should be between 0.0 and 1.0 and a value of 0.0 means that there is no minimum and an algorithm proceeds without targeting any specific fraction. A value of 1.0 means that the algorithm attempts to only Suggest safe Trials. Corresponds to the JSON property desiredMinSafeTrialsFraction

Returns:

  • (Float)


45876
45877
45878
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45876

def desired_min_safe_trials_fraction
  @desired_min_safe_trials_fraction
end

#safety_thresholdFloat

Safety threshold (boundary value between safe and unsafe). NOTE that if you leave SafetyMetricConfig unset, a default value of 0 will be used. Corresponds to the JSON property safetyThreshold

Returns:

  • (Float)


45882
45883
45884
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45882

def safety_threshold
  @safety_threshold
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45889
45890
45891
45892
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45889

def update!(**args)
  @desired_min_safe_trials_fraction = args[:desired_min_safe_trials_fraction] if args.key?(:desired_min_safe_trials_fraction)
  @safety_threshold = args[:safety_threshold] if args.key?(:safety_threshold)
end