Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecMetricSpecSafetyMetricConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecMetricSpecSafetyMetricConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Used in safe optimization to specify threshold levels and risk tolerance.
Instance Attribute Summary collapse
-
#desired_min_safe_trials_fraction ⇒ Float
Desired minimum fraction of safe trials (over total number of trials) that should be targeted by the algorithm at any time during the study (best effort).
-
#safety_threshold ⇒ Float
Safety threshold (boundary value between safe and unsafe).
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1StudySpecMetricSpecSafetyMetricConfig
constructor
A new instance of GoogleCloudAiplatformV1StudySpecMetricSpecSafetyMetricConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1StudySpecMetricSpecSafetyMetricConfig
Returns a new instance of GoogleCloudAiplatformV1StudySpecMetricSpecSafetyMetricConfig.
26785 26786 26787 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26785 def initialize(**args) update!(**args) end |
Instance Attribute Details
#desired_min_safe_trials_fraction ⇒ Float
Desired minimum fraction of safe trials (over total number of trials) that
should be targeted by the algorithm at any time during the study (best effort).
This should be between 0.0 and 1.0 and a value of 0.0 means that there is no
minimum and an algorithm proceeds without targeting any specific fraction. A
value of 1.0 means that the algorithm attempts to only Suggest safe Trials.
Corresponds to the JSON property desiredMinSafeTrialsFraction
26777 26778 26779 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26777 def desired_min_safe_trials_fraction @desired_min_safe_trials_fraction end |
#safety_threshold ⇒ Float
Safety threshold (boundary value between safe and unsafe). NOTE that if you
leave SafetyMetricConfig unset, a default value of 0 will be used.
Corresponds to the JSON property safetyThreshold
26783 26784 26785 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26783 def safety_threshold @safety_threshold end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26790 26791 26792 26793 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26790 def update!(**args) @desired_min_safe_trials_fraction = args[:desired_min_safe_trials_fraction] if args.key?(:desired_min_safe_trials_fraction) @safety_threshold = args[:safety_threshold] if args.key?(:safety_threshold) end |