Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Represents a single parameter to optimize.
Instance Attribute Summary collapse
-
#categorical_value_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecCategoricalValueSpec
Value specification for a parameter in
CATEGORICALtype. -
#conditional_parameter_specs ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecConditionalParameterSpec>
A conditional parameter node is active if the parameter's value matches the conditional node's parent_value_condition.
-
#discrete_value_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecDiscreteValueSpec
Value specification for a parameter in
DISCRETEtype. -
#double_value_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecDoubleValueSpec
Value specification for a parameter in
DOUBLEtype. -
#integer_value_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecIntegerValueSpec
Value specification for a parameter in
INTEGERtype. -
#parameter_id ⇒ String
Required.
-
#scale_type ⇒ String
How the parameter should be scaled.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1StudySpecParameterSpec
constructor
A new instance of GoogleCloudAiplatformV1StudySpecParameterSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1StudySpecParameterSpec
Returns a new instance of GoogleCloudAiplatformV1StudySpecParameterSpec.
46507 46508 46509 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46507 def initialize(**args) update!(**args) end |
Instance Attribute Details
#categorical_value_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecCategoricalValueSpec
Value specification for a parameter in CATEGORICAL type.
Corresponds to the JSON property categoricalValueSpec
46471 46472 46473 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46471 def categorical_value_spec @categorical_value_spec end |
#conditional_parameter_specs ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecConditionalParameterSpec>
A conditional parameter node is active if the parameter's value matches the
conditional node's parent_value_condition. If two items in
conditional_parameter_specs have the same name, they must have disjoint
parent_value_condition.
Corresponds to the JSON property conditionalParameterSpecs
46479 46480 46481 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46479 def conditional_parameter_specs @conditional_parameter_specs end |
#discrete_value_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecDiscreteValueSpec
Value specification for a parameter in DISCRETE type.
Corresponds to the JSON property discreteValueSpec
46484 46485 46486 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46484 def discrete_value_spec @discrete_value_spec end |
#double_value_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecDoubleValueSpec
Value specification for a parameter in DOUBLE type.
Corresponds to the JSON property doubleValueSpec
46489 46490 46491 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46489 def double_value_spec @double_value_spec end |
#integer_value_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecIntegerValueSpec
Value specification for a parameter in INTEGER type.
Corresponds to the JSON property integerValueSpec
46494 46495 46496 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46494 def integer_value_spec @integer_value_spec end |
#parameter_id ⇒ String
Required. The ID of the parameter. Must not contain whitespaces and must be
unique amongst all ParameterSpecs.
Corresponds to the JSON property parameterId
46500 46501 46502 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46500 def parameter_id @parameter_id end |
#scale_type ⇒ String
How the parameter should be scaled. Leave unset for CATEGORICAL parameters.
Corresponds to the JSON property scaleType
46505 46506 46507 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46505 def scale_type @scale_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46512 46513 46514 46515 46516 46517 46518 46519 46520 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46512 def update!(**args) @categorical_value_spec = args[:categorical_value_spec] if args.key?(:categorical_value_spec) @conditional_parameter_specs = args[:conditional_parameter_specs] if args.key?(:conditional_parameter_specs) @discrete_value_spec = args[:discrete_value_spec] if args.key?(:discrete_value_spec) @double_value_spec = args[:double_value_spec] if args.key?(:double_value_spec) @integer_value_spec = args[:integer_value_spec] if args.key?(:integer_value_spec) @parameter_id = args[:parameter_id] if args.key?(:parameter_id) @scale_type = args[:scale_type] if args.key?(:scale_type) end |