Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Represents a single parameter to optimize.
Instance Attribute Summary collapse
-
#categorical_value_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecCategoricalValueSpec
Value specification for a parameter in
CATEGORICALtype. -
#conditional_parameter_specs ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecConditionalParameterSpec>
A conditional parameter node is active if the parameter's value matches the conditional node's parent_value_condition.
-
#discrete_value_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecDiscreteValueSpec
Value specification for a parameter in
DISCRETEtype. -
#double_value_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecDoubleValueSpec
Value specification for a parameter in
DOUBLEtype. -
#integer_value_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecIntegerValueSpec
Value specification for a parameter in
INTEGERtype. -
#parameter_id ⇒ String
Required.
-
#scale_type ⇒ String
How the parameter should be scaled.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1StudySpecParameterSpec
constructor
A new instance of GoogleCloudAiplatformV1StudySpecParameterSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1StudySpecParameterSpec
Returns a new instance of GoogleCloudAiplatformV1StudySpecParameterSpec.
45925 45926 45927 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45925 def initialize(**args) update!(**args) end |
Instance Attribute Details
#categorical_value_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecCategoricalValueSpec
Value specification for a parameter in CATEGORICAL type.
Corresponds to the JSON property categoricalValueSpec
45889 45890 45891 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45889 def categorical_value_spec @categorical_value_spec end |
#conditional_parameter_specs ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecConditionalParameterSpec>
A conditional parameter node is active if the parameter's value matches the
conditional node's parent_value_condition. If two items in
conditional_parameter_specs have the same name, they must have disjoint
parent_value_condition.
Corresponds to the JSON property conditionalParameterSpecs
45897 45898 45899 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45897 def conditional_parameter_specs @conditional_parameter_specs end |
#discrete_value_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecDiscreteValueSpec
Value specification for a parameter in DISCRETE type.
Corresponds to the JSON property discreteValueSpec
45902 45903 45904 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45902 def discrete_value_spec @discrete_value_spec end |
#double_value_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecDoubleValueSpec
Value specification for a parameter in DOUBLE type.
Corresponds to the JSON property doubleValueSpec
45907 45908 45909 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45907 def double_value_spec @double_value_spec end |
#integer_value_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecIntegerValueSpec
Value specification for a parameter in INTEGER type.
Corresponds to the JSON property integerValueSpec
45912 45913 45914 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45912 def integer_value_spec @integer_value_spec end |
#parameter_id ⇒ String
Required. The ID of the parameter. Must not contain whitespaces and must be
unique amongst all ParameterSpecs.
Corresponds to the JSON property parameterId
45918 45919 45920 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45918 def parameter_id @parameter_id end |
#scale_type ⇒ String
How the parameter should be scaled. Leave unset for CATEGORICAL parameters.
Corresponds to the JSON property scaleType
45923 45924 45925 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45923 def scale_type @scale_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45930 45931 45932 45933 45934 45935 45936 45937 45938 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45930 def update!(**args) @categorical_value_spec = args[:categorical_value_spec] if args.key?(:categorical_value_spec) @conditional_parameter_specs = args[:conditional_parameter_specs] if args.key?(:conditional_parameter_specs) @discrete_value_spec = args[:discrete_value_spec] if args.key?(:discrete_value_spec) @double_value_spec = args[:double_value_spec] if args.key?(:double_value_spec) @integer_value_spec = args[:integer_value_spec] if args.key?(:integer_value_spec) @parameter_id = args[:parameter_id] if args.key?(:parameter_id) @scale_type = args[:scale_type] if args.key?(:scale_type) end |