Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents a single parameter to optimize.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1StudySpecParameterSpec

Returns a new instance of GoogleCloudAiplatformV1StudySpecParameterSpec.



34705
34706
34707
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34705

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#categorical_value_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecCategoricalValueSpec

Value specification for a parameter in CATEGORICAL type. Corresponds to the JSON property categoricalValueSpec



34669
34670
34671
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34669

def categorical_value_spec
  @categorical_value_spec
end

#conditional_parameter_specsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecConditionalParameterSpec>

A conditional parameter node is active if the parameter's value matches the conditional node's parent_value_condition. If two items in conditional_parameter_specs have the same name, they must have disjoint parent_value_condition. Corresponds to the JSON property conditionalParameterSpecs



34677
34678
34679
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34677

def conditional_parameter_specs
  @conditional_parameter_specs
end

#discrete_value_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecDiscreteValueSpec

Value specification for a parameter in DISCRETE type. Corresponds to the JSON property discreteValueSpec



34682
34683
34684
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34682

def discrete_value_spec
  @discrete_value_spec
end

#double_value_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecDoubleValueSpec

Value specification for a parameter in DOUBLE type. Corresponds to the JSON property doubleValueSpec



34687
34688
34689
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34687

def double_value_spec
  @double_value_spec
end

#integer_value_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecIntegerValueSpec

Value specification for a parameter in INTEGER type. Corresponds to the JSON property integerValueSpec



34692
34693
34694
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34692

def integer_value_spec
  @integer_value_spec
end

#parameter_idString

Required. The ID of the parameter. Must not contain whitespaces and must be unique amongst all ParameterSpecs. Corresponds to the JSON property parameterId

Returns:

  • (String)


34698
34699
34700
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34698

def parameter_id
  @parameter_id
end

#scale_typeString

How the parameter should be scaled. Leave unset for CATEGORICAL parameters. Corresponds to the JSON property scaleType

Returns:

  • (String)


34703
34704
34705
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34703

def scale_type
  @scale_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34710
34711
34712
34713
34714
34715
34716
34717
34718
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34710

def update!(**args)
  @categorical_value_spec = args[:categorical_value_spec] if args.key?(:categorical_value_spec)
  @conditional_parameter_specs = args[:conditional_parameter_specs] if args.key?(:conditional_parameter_specs)
  @discrete_value_spec = args[:discrete_value_spec] if args.key?(:discrete_value_spec)
  @double_value_spec = args[:double_value_spec] if args.key?(:double_value_spec)
  @integer_value_spec = args[:integer_value_spec] if args.key?(:integer_value_spec)
  @parameter_id = args[:parameter_id] if args.key?(:parameter_id)
  @scale_type = args[:scale_type] if args.key?(:scale_type)
end