Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents a single parameter to optimize.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1StudySpecParameterSpec

Returns a new instance of GoogleCloudAiplatformV1StudySpecParameterSpec.



30159
30160
30161
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30159

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#categorical_value_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecCategoricalValueSpec

Value specification for a parameter in CATEGORICAL type. Corresponds to the JSON property categoricalValueSpec



30123
30124
30125
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30123

def categorical_value_spec
  @categorical_value_spec
end

#conditional_parameter_specsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecConditionalParameterSpec>

A conditional parameter node is active if the parameter's value matches the conditional node's parent_value_condition. If two items in conditional_parameter_specs have the same name, they must have disjoint parent_value_condition. Corresponds to the JSON property conditionalParameterSpecs



30131
30132
30133
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30131

def conditional_parameter_specs
  @conditional_parameter_specs
end

#discrete_value_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecDiscreteValueSpec

Value specification for a parameter in DISCRETE type. Corresponds to the JSON property discreteValueSpec



30136
30137
30138
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30136

def discrete_value_spec
  @discrete_value_spec
end

#double_value_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecDoubleValueSpec

Value specification for a parameter in DOUBLE type. Corresponds to the JSON property doubleValueSpec



30141
30142
30143
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30141

def double_value_spec
  @double_value_spec
end

#integer_value_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecIntegerValueSpec

Value specification for a parameter in INTEGER type. Corresponds to the JSON property integerValueSpec



30146
30147
30148
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30146

def integer_value_spec
  @integer_value_spec
end

#parameter_idString

Required. The ID of the parameter. Must not contain whitespaces and must be unique amongst all ParameterSpecs. Corresponds to the JSON property parameterId

Returns:

  • (String)


30152
30153
30154
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30152

def parameter_id
  @parameter_id
end

#scale_typeString

How the parameter should be scaled. Leave unset for CATEGORICAL parameters. Corresponds to the JSON property scaleType

Returns:

  • (String)


30157
30158
30159
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30157

def scale_type
  @scale_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30164
30165
30166
30167
30168
30169
30170
30171
30172
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30164

def update!(**args)
  @categorical_value_spec = args[:categorical_value_spec] if args.key?(:categorical_value_spec)
  @conditional_parameter_specs = args[:conditional_parameter_specs] if args.key?(:conditional_parameter_specs)
  @discrete_value_spec = args[:discrete_value_spec] if args.key?(:discrete_value_spec)
  @double_value_spec = args[:double_value_spec] if args.key?(:double_value_spec)
  @integer_value_spec = args[:integer_value_spec] if args.key?(:integer_value_spec)
  @parameter_id = args[:parameter_id] if args.key?(:parameter_id)
  @scale_type = args[:scale_type] if args.key?(:scale_type)
end