Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents a single parameter to optimize.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1StudySpecParameterSpec

Returns a new instance of GoogleCloudAiplatformV1StudySpecParameterSpec.



28784
28785
28786
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28784

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#categorical_value_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecCategoricalValueSpec

Value specification for a parameter in CATEGORICAL type. Corresponds to the JSON property categoricalValueSpec



28748
28749
28750
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28748

def categorical_value_spec
  @categorical_value_spec
end

#conditional_parameter_specsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecConditionalParameterSpec>

A conditional parameter node is active if the parameter's value matches the conditional node's parent_value_condition. If two items in conditional_parameter_specs have the same name, they must have disjoint parent_value_condition. Corresponds to the JSON property conditionalParameterSpecs



28756
28757
28758
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28756

def conditional_parameter_specs
  @conditional_parameter_specs
end

#discrete_value_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecDiscreteValueSpec

Value specification for a parameter in DISCRETE type. Corresponds to the JSON property discreteValueSpec



28761
28762
28763
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28761

def discrete_value_spec
  @discrete_value_spec
end

#double_value_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecDoubleValueSpec

Value specification for a parameter in DOUBLE type. Corresponds to the JSON property doubleValueSpec



28766
28767
28768
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28766

def double_value_spec
  @double_value_spec
end

#integer_value_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecIntegerValueSpec

Value specification for a parameter in INTEGER type. Corresponds to the JSON property integerValueSpec



28771
28772
28773
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28771

def integer_value_spec
  @integer_value_spec
end

#parameter_idString

Required. The ID of the parameter. Must not contain whitespaces and must be unique amongst all ParameterSpecs. Corresponds to the JSON property parameterId

Returns:

  • (String)


28777
28778
28779
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28777

def parameter_id
  @parameter_id
end

#scale_typeString

How the parameter should be scaled. Leave unset for CATEGORICAL parameters. Corresponds to the JSON property scaleType

Returns:

  • (String)


28782
28783
28784
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28782

def scale_type
  @scale_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28789
28790
28791
28792
28793
28794
28795
28796
28797
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28789

def update!(**args)
  @categorical_value_spec = args[:categorical_value_spec] if args.key?(:categorical_value_spec)
  @conditional_parameter_specs = args[:conditional_parameter_specs] if args.key?(:conditional_parameter_specs)
  @discrete_value_spec = args[:discrete_value_spec] if args.key?(:discrete_value_spec)
  @double_value_spec = args[:double_value_spec] if args.key?(:double_value_spec)
  @integer_value_spec = args[:integer_value_spec] if args.key?(:integer_value_spec)
  @parameter_id = args[:parameter_id] if args.key?(:parameter_id)
  @scale_type = args[:scale_type] if args.key?(:scale_type)
end