Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Represents a single parameter to optimize.
Instance Attribute Summary collapse
-
#categorical_value_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecCategoricalValueSpec
Value specification for a parameter in
CATEGORICALtype. -
#conditional_parameter_specs ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecConditionalParameterSpec>
A conditional parameter node is active if the parameter's value matches the conditional node's parent_value_condition.
-
#discrete_value_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecDiscreteValueSpec
Value specification for a parameter in
DISCRETEtype. -
#double_value_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecDoubleValueSpec
Value specification for a parameter in
DOUBLEtype. -
#integer_value_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecIntegerValueSpec
Value specification for a parameter in
INTEGERtype. -
#parameter_id ⇒ String
Required.
-
#scale_type ⇒ String
How the parameter should be scaled.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1StudySpecParameterSpec
constructor
A new instance of GoogleCloudAiplatformV1StudySpecParameterSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1StudySpecParameterSpec
Returns a new instance of GoogleCloudAiplatformV1StudySpecParameterSpec.
26002 26003 26004 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26002 def initialize(**args) update!(**args) end |
Instance Attribute Details
#categorical_value_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecCategoricalValueSpec
Value specification for a parameter in CATEGORICAL type.
Corresponds to the JSON property categoricalValueSpec
25966 25967 25968 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25966 def categorical_value_spec @categorical_value_spec end |
#conditional_parameter_specs ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecConditionalParameterSpec>
A conditional parameter node is active if the parameter's value matches the
conditional node's parent_value_condition. If two items in
conditional_parameter_specs have the same name, they must have disjoint
parent_value_condition.
Corresponds to the JSON property conditionalParameterSpecs
25974 25975 25976 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25974 def conditional_parameter_specs @conditional_parameter_specs end |
#discrete_value_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecDiscreteValueSpec
Value specification for a parameter in DISCRETE type.
Corresponds to the JSON property discreteValueSpec
25979 25980 25981 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25979 def discrete_value_spec @discrete_value_spec end |
#double_value_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecDoubleValueSpec
Value specification for a parameter in DOUBLE type.
Corresponds to the JSON property doubleValueSpec
25984 25985 25986 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25984 def double_value_spec @double_value_spec end |
#integer_value_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecIntegerValueSpec
Value specification for a parameter in INTEGER type.
Corresponds to the JSON property integerValueSpec
25989 25990 25991 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25989 def integer_value_spec @integer_value_spec end |
#parameter_id ⇒ String
Required. The ID of the parameter. Must not contain whitespaces and must be
unique amongst all ParameterSpecs.
Corresponds to the JSON property parameterId
25995 25996 25997 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 25995 def parameter_id @parameter_id end |
#scale_type ⇒ String
How the parameter should be scaled. Leave unset for CATEGORICAL parameters.
Corresponds to the JSON property scaleType
26000 26001 26002 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26000 def scale_type @scale_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26007 26008 26009 26010 26011 26012 26013 26014 26015 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26007 def update!(**args) @categorical_value_spec = args[:categorical_value_spec] if args.key?(:categorical_value_spec) @conditional_parameter_specs = args[:conditional_parameter_specs] if args.key?(:conditional_parameter_specs) @discrete_value_spec = args[:discrete_value_spec] if args.key?(:discrete_value_spec) @double_value_spec = args[:double_value_spec] if args.key?(:double_value_spec) @integer_value_spec = args[:integer_value_spec] if args.key?(:integer_value_spec) @parameter_id = args[:parameter_id] if args.key?(:parameter_id) @scale_type = args[:scale_type] if args.key?(:scale_type) end |