Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecCategoricalValueSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Value specification for a parameter in CATEGORICAL type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1StudySpecParameterSpecCategoricalValueSpec

Returns a new instance of GoogleCloudAiplatformV1StudySpecParameterSpecCategoricalValueSpec.



28171
28172
28173
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28171

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#default_valueString

A default value for a CATEGORICAL parameter that is assumed to be a relatively good starting point. Unset value signals that there is no offered starting point. Currently only supported by the Vertex AI Vizier service. Not supported by HyperparameterTuningJob or TrainingPipeline. Corresponds to the JSON property defaultValue

Returns:

  • (String)


28164
28165
28166
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28164

def default_value
  @default_value
end

#valuesArray<String>

Required. The list of possible categories. Corresponds to the JSON property values

Returns:

  • (Array<String>)


28169
28170
28171
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28169

def values
  @values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28176
28177
28178
28179
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28176

def update!(**args)
  @default_value = args[:default_value] if args.key?(:default_value)
  @values = args[:values] if args.key?(:values)
end