Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecConditionalParameterSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecConditionalParameterSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Represents a parameter spec with condition from its parent parameter.
Instance Attribute Summary collapse
-
#parameter_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpec
Represents a single parameter to optimize.
-
#parent_categorical_values ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecConditionalParameterSpecCategoricalValueCondition
Represents the spec to match categorical values from parent parameter.
-
#parent_discrete_values ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecConditionalParameterSpecDiscreteValueCondition
Represents the spec to match discrete values from parent parameter.
-
#parent_int_values ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecConditionalParameterSpecIntValueCondition
Represents the spec to match integer values from parent parameter.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1StudySpecParameterSpecConditionalParameterSpec
constructor
A new instance of GoogleCloudAiplatformV1StudySpecParameterSpecConditionalParameterSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1StudySpecParameterSpecConditionalParameterSpec
Returns a new instance of GoogleCloudAiplatformV1StudySpecParameterSpecConditionalParameterSpec.
34773 34774 34775 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34773 def initialize(**args) update!(**args) end |
Instance Attribute Details
#parameter_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpec
Represents a single parameter to optimize.
Corresponds to the JSON property parameterSpec
34756 34757 34758 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34756 def parameter_spec @parameter_spec end |
#parent_categorical_values ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecConditionalParameterSpecCategoricalValueCondition
Represents the spec to match categorical values from parent parameter.
Corresponds to the JSON property parentCategoricalValues
34761 34762 34763 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34761 def parent_categorical_values @parent_categorical_values end |
#parent_discrete_values ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecConditionalParameterSpecDiscreteValueCondition
Represents the spec to match discrete values from parent parameter.
Corresponds to the JSON property parentDiscreteValues
34766 34767 34768 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34766 def parent_discrete_values @parent_discrete_values end |
#parent_int_values ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecConditionalParameterSpecIntValueCondition
Represents the spec to match integer values from parent parameter.
Corresponds to the JSON property parentIntValues
34771 34772 34773 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34771 def parent_int_values @parent_int_values end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34778 34779 34780 34781 34782 34783 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34778 def update!(**args) @parameter_spec = args[:parameter_spec] if args.key?(:parameter_spec) @parent_categorical_values = args[:parent_categorical_values] if args.key?(:parent_categorical_values) @parent_discrete_values = args[:parent_discrete_values] if args.key?(:parent_discrete_values) @parent_int_values = args[:parent_int_values] if args.key?(:parent_int_values) end |