Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecConditionalParameterSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents a parameter spec with condition from its parent parameter.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1StudySpecParameterSpecConditionalParameterSpec

Returns a new instance of GoogleCloudAiplatformV1StudySpecParameterSpecConditionalParameterSpec.



28206
28207
28208
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28206

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#parameter_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpec

Represents a single parameter to optimize. Corresponds to the JSON property parameterSpec



28189
28190
28191
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28189

def parameter_spec
  @parameter_spec
end

#parent_categorical_valuesGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecConditionalParameterSpecCategoricalValueCondition

Represents the spec to match categorical values from parent parameter. Corresponds to the JSON property parentCategoricalValues



28194
28195
28196
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28194

def parent_categorical_values
  @parent_categorical_values
end

#parent_discrete_valuesGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecConditionalParameterSpecDiscreteValueCondition

Represents the spec to match discrete values from parent parameter. Corresponds to the JSON property parentDiscreteValues



28199
28200
28201
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28199

def parent_discrete_values
  @parent_discrete_values
end

#parent_int_valuesGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecConditionalParameterSpecIntValueCondition

Represents the spec to match integer values from parent parameter. Corresponds to the JSON property parentIntValues



28204
28205
28206
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28204

def parent_int_values
  @parent_int_values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28211
28212
28213
28214
28215
28216
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28211

def update!(**args)
  @parameter_spec = args[:parameter_spec] if args.key?(:parameter_spec)
  @parent_categorical_values = args[:parent_categorical_values] if args.key?(:parent_categorical_values)
  @parent_discrete_values = args[:parent_discrete_values] if args.key?(:parent_discrete_values)
  @parent_int_values = args[:parent_int_values] if args.key?(:parent_int_values)
end