Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecDiscreteValueSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Value specification for a parameter in DISCRETE type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1StudySpecParameterSpecDiscreteValueSpec

Returns a new instance of GoogleCloudAiplatformV1StudySpecParameterSpecDiscreteValueSpec.



33907
33908
33909
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33907

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#default_valueFloat

A default value for a DISCRETE parameter that is assumed to be a relatively good starting point. Unset value signals that there is no offered starting point. It automatically rounds to the nearest feasible discrete point. Currently only supported by the Vertex AI Vizier service. Not supported by HyperparameterTuningJob or TrainingPipeline. Corresponds to the JSON property defaultValue

Returns:

  • (Float)


33897
33898
33899
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33897

def default_value
  @default_value
end

#valuesArray<Float>

Required. A list of possible values. The list should be in increasing order and at least 1e-10 apart. For instance, this parameter might have possible settings of 1.5, 2.5, and 4.0. This list should not contain more than 1,000 values. Corresponds to the JSON property values

Returns:

  • (Array<Float>)


33905
33906
33907
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33905

def values
  @values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33912
33913
33914
33915
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33912

def update!(**args)
  @default_value = args[:default_value] if args.key?(:default_value)
  @values = args[:values] if args.key?(:values)
end