Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecDiscreteValueSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecDiscreteValueSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Value specification for a parameter in DISCRETE type.
Instance Attribute Summary collapse
-
#default_value ⇒ Float
A default value for a
DISCRETEparameter that is assumed to be a relatively good starting point. -
#values ⇒ Array<Float>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1StudySpecParameterSpecDiscreteValueSpec
constructor
A new instance of GoogleCloudAiplatformV1StudySpecParameterSpecDiscreteValueSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1StudySpecParameterSpecDiscreteValueSpec
Returns a new instance of GoogleCloudAiplatformV1StudySpecParameterSpecDiscreteValueSpec.
29716 29717 29718 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29716 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_value ⇒ Float
A default value for a DISCRETE parameter that is assumed to be a relatively
good starting point. Unset value signals that there is no offered starting
point. It automatically rounds to the nearest feasible discrete point.
Currently only supported by the Vertex AI Vizier service. Not supported by
HyperparameterTuningJob or TrainingPipeline.
Corresponds to the JSON property defaultValue
29706 29707 29708 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29706 def default_value @default_value end |
#values ⇒ Array<Float>
Required. A list of possible values. The list should be in increasing order
and at least 1e-10 apart. For instance, this parameter might have possible
settings of 1.5, 2.5, and 4.0. This list should not contain more than 1,000
values.
Corresponds to the JSON property values
29714 29715 29716 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29714 def values @values end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29721 29722 29723 29724 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29721 def update!(**args) @default_value = args[:default_value] if args.key?(:default_value) @values = args[:values] if args.key?(:values) end |