Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecDoubleValueSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecDoubleValueSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Value specification for a parameter in DOUBLE type.
Instance Attribute Summary collapse
-
#default_value ⇒ Float
A default value for a
DOUBLEparameter that is assumed to be a relatively good starting point. -
#max_value ⇒ Float
Required.
-
#min_value ⇒ Float
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1StudySpecParameterSpecDoubleValueSpec
constructor
A new instance of GoogleCloudAiplatformV1StudySpecParameterSpecDoubleValueSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1StudySpecParameterSpecDoubleValueSpec
Returns a new instance of GoogleCloudAiplatformV1StudySpecParameterSpecDoubleValueSpec.
35977 35978 35979 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35977 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_value ⇒ Float
A default value for a DOUBLE parameter that is assumed to be a relatively
good starting point. Unset value signals that there is no offered starting
point. Currently only supported by the Vertex AI Vizier service. Not supported
by HyperparameterTuningJob or TrainingPipeline.
Corresponds to the JSON property defaultValue
35965 35966 35967 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35965 def default_value @default_value end |
#max_value ⇒ Float
Required. Inclusive maximum value of the parameter.
Corresponds to the JSON property maxValue
35970 35971 35972 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35970 def max_value @max_value end |
#min_value ⇒ Float
Required. Inclusive minimum value of the parameter.
Corresponds to the JSON property minValue
35975 35976 35977 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35975 def min_value @min_value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35982 35983 35984 35985 35986 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35982 def update!(**args) @default_value = args[:default_value] if args.key?(:default_value) @max_value = args[:max_value] if args.key?(:max_value) @min_value = args[:min_value] if args.key?(:min_value) end |