Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecDoubleValueSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Value specification for a parameter in DOUBLE type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1StudySpecParameterSpecDoubleValueSpec

Returns a new instance of GoogleCloudAiplatformV1StudySpecParameterSpecDoubleValueSpec.



34229
34230
34231
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34229

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#default_valueFloat

A default value for a DOUBLE parameter that is assumed to be a relatively good starting point. Unset value signals that there is no offered starting point. Currently only supported by the Vertex AI Vizier service. Not supported by HyperparameterTuningJob or TrainingPipeline. Corresponds to the JSON property defaultValue

Returns:

  • (Float)


34217
34218
34219
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34217

def default_value
  @default_value
end

#max_valueFloat

Required. Inclusive maximum value of the parameter. Corresponds to the JSON property maxValue

Returns:

  • (Float)


34222
34223
34224
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34222

def max_value
  @max_value
end

#min_valueFloat

Required. Inclusive minimum value of the parameter. Corresponds to the JSON property minValue

Returns:

  • (Float)


34227
34228
34229
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34227

def min_value
  @min_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34234
34235
34236
34237
34238
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34234

def update!(**args)
  @default_value = args[:default_value] if args.key?(:default_value)
  @max_value = args[:max_value] if args.key?(:max_value)
  @min_value = args[:min_value] if args.key?(:min_value)
end