Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecDoubleValueSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecDoubleValueSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Value specification for a parameter in DOUBLE type.
Instance Attribute Summary collapse
-
#default_value ⇒ Float
A default value for a
DOUBLEparameter that is assumed to be a relatively good starting point. -
#max_value ⇒ Float
Required.
-
#min_value ⇒ Float
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1StudySpecParameterSpecDoubleValueSpec
constructor
A new instance of GoogleCloudAiplatformV1StudySpecParameterSpecDoubleValueSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1StudySpecParameterSpecDoubleValueSpec
Returns a new instance of GoogleCloudAiplatformV1StudySpecParameterSpecDoubleValueSpec.
29989 29990 29991 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29989 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_value ⇒ Float
A default value for a DOUBLE parameter that is assumed to be a relatively
good starting point. Unset value signals that there is no offered starting
point. Currently only supported by the Vertex AI Vizier service. Not supported
by HyperparameterTuningJob or TrainingPipeline.
Corresponds to the JSON property defaultValue
29977 29978 29979 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29977 def default_value @default_value end |
#max_value ⇒ Float
Required. Inclusive maximum value of the parameter.
Corresponds to the JSON property maxValue
29982 29983 29984 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29982 def max_value @max_value end |
#min_value ⇒ Float
Required. Inclusive minimum value of the parameter.
Corresponds to the JSON property minValue
29987 29988 29989 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29987 def min_value @min_value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29994 29995 29996 29997 29998 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29994 def update!(**args) @default_value = args[:default_value] if args.key?(:default_value) @max_value = args[:max_value] if args.key?(:max_value) @min_value = args[:min_value] if args.key?(:min_value) end |