Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecIntegerValueSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecIntegerValueSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Value specification for a parameter in INTEGER type.
Instance Attribute Summary collapse
-
#default_value ⇒ Fixnum
A default value for an
INTEGERparameter that is assumed to be a relatively good starting point. -
#max_value ⇒ Fixnum
Required.
-
#min_value ⇒ Fixnum
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1StudySpecParameterSpecIntegerValueSpec
constructor
A new instance of GoogleCloudAiplatformV1StudySpecParameterSpecIntegerValueSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1StudySpecParameterSpecIntegerValueSpec
Returns a new instance of GoogleCloudAiplatformV1StudySpecParameterSpecIntegerValueSpec.
46737 46738 46739 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46737 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_value ⇒ Fixnum
A default value for an INTEGER parameter that is assumed to be a relatively
good starting point. Unset value signals that there is no offered starting
point. Currently only supported by the Vertex AI Vizier service. Not supported
by HyperparameterTuningJob or TrainingPipeline.
Corresponds to the JSON property defaultValue
46725 46726 46727 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46725 def default_value @default_value end |
#max_value ⇒ Fixnum
Required. Inclusive maximum value of the parameter.
Corresponds to the JSON property maxValue
46730 46731 46732 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46730 def max_value @max_value end |
#min_value ⇒ Fixnum
Required. Inclusive minimum value of the parameter.
Corresponds to the JSON property minValue
46735 46736 46737 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46735 def min_value @min_value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46742 46743 46744 46745 46746 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46742 def update!(**args) @default_value = args[:default_value] if args.key?(:default_value) @max_value = args[:max_value] if args.key?(:max_value) @min_value = args[:min_value] if args.key?(:min_value) end |