Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecIntegerValueSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Value specification for a parameter in INTEGER type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1StudySpecParameterSpecIntegerValueSpec

Returns a new instance of GoogleCloudAiplatformV1StudySpecParameterSpecIntegerValueSpec.



36367
36368
36369
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36367

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#default_valueFixnum

A default value for an INTEGER parameter that is assumed to be a relatively good starting point. Unset value signals that there is no offered starting point. Currently only supported by the Vertex AI Vizier service. Not supported by HyperparameterTuningJob or TrainingPipeline. Corresponds to the JSON property defaultValue

Returns:

  • (Fixnum)


36355
36356
36357
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36355

def default_value
  @default_value
end

#max_valueFixnum

Required. Inclusive maximum value of the parameter. Corresponds to the JSON property maxValue

Returns:

  • (Fixnum)


36360
36361
36362
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36360

def max_value
  @max_value
end

#min_valueFixnum

Required. Inclusive minimum value of the parameter. Corresponds to the JSON property minValue

Returns:

  • (Fixnum)


36365
36366
36367
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36365

def min_value
  @min_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36372
36373
36374
36375
36376
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36372

def update!(**args)
  @default_value = args[:default_value] if args.key?(:default_value)
  @max_value = args[:max_value] if args.key?(:max_value)
  @min_value = args[:min_value] if args.key?(:min_value)
end