Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecIntegerValueSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecIntegerValueSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Value specification for a parameter in INTEGER type.
Instance Attribute Summary collapse
-
#default_value ⇒ Fixnum
A default value for an
INTEGERparameter that is assumed to be a relatively good starting point. -
#max_value ⇒ Fixnum
Required.
-
#min_value ⇒ Fixnum
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1StudySpecParameterSpecIntegerValueSpec
constructor
A new instance of GoogleCloudAiplatformV1StudySpecParameterSpecIntegerValueSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1StudySpecParameterSpecIntegerValueSpec
Returns a new instance of GoogleCloudAiplatformV1StudySpecParameterSpecIntegerValueSpec.
35940 35941 35942 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35940 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_value ⇒ Fixnum
A default value for an INTEGER parameter that is assumed to be a relatively
good starting point. Unset value signals that there is no offered starting
point. Currently only supported by the Vertex AI Vizier service. Not supported
by HyperparameterTuningJob or TrainingPipeline.
Corresponds to the JSON property defaultValue
35928 35929 35930 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35928 def default_value @default_value end |
#max_value ⇒ Fixnum
Required. Inclusive maximum value of the parameter.
Corresponds to the JSON property maxValue
35933 35934 35935 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35933 def max_value @max_value end |
#min_value ⇒ Fixnum
Required. Inclusive minimum value of the parameter.
Corresponds to the JSON property minValue
35938 35939 35940 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35938 def min_value @min_value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35945 35946 35947 35948 35949 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35945 def update!(**args) @default_value = args[:default_value] if args.key?(:default_value) @max_value = args[:max_value] if args.key?(:max_value) @min_value = args[:min_value] if args.key?(:min_value) end |