Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecParameterSpecIntegerValueSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Value specification for a parameter in INTEGER type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1StudySpecParameterSpecIntegerValueSpec

Returns a new instance of GoogleCloudAiplatformV1StudySpecParameterSpecIntegerValueSpec.



33974
33975
33976
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33974

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#default_valueFixnum

A default value for an INTEGER parameter that is assumed to be a relatively good starting point. Unset value signals that there is no offered starting point. Currently only supported by the Vertex AI Vizier service. Not supported by HyperparameterTuningJob or TrainingPipeline. Corresponds to the JSON property defaultValue

Returns:

  • (Fixnum)


33962
33963
33964
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33962

def default_value
  @default_value
end

#max_valueFixnum

Required. Inclusive maximum value of the parameter. Corresponds to the JSON property maxValue

Returns:

  • (Fixnum)


33967
33968
33969
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33967

def max_value
  @max_value
end

#min_valueFixnum

Required. Inclusive minimum value of the parameter. Corresponds to the JSON property minValue

Returns:

  • (Fixnum)


33972
33973
33974
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33972

def min_value
  @min_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33979
33980
33981
33982
33983
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33979

def update!(**args)
  @default_value = args[:default_value] if args.key?(:default_value)
  @max_value = args[:max_value] if args.key?(:max_value)
  @min_value = args[:min_value] if args.key?(:min_value)
end