Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecStudyStoppingConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecStudyStoppingConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The configuration (stopping conditions) for automated stopping of a Study. Conditions include trial budgets, time budgets, and convergence detection.
Instance Attribute Summary collapse
-
#max_duration_no_progress ⇒ String
If the objective value has not improved for this much time, stop the study.
-
#max_num_trials ⇒ Fixnum
If there are more than this many trials, stop the study.
-
#max_num_trials_no_progress ⇒ Fixnum
If the objective value has not improved for this many consecutive trials, stop the study.
-
#maximum_runtime_constraint ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudyTimeConstraint
Time-based Constraint for Study Corresponds to the JSON property
maximumRuntimeConstraint. -
#min_num_trials ⇒ Fixnum
If there are fewer than this many COMPLETED trials, do not stop the study.
-
#minimum_runtime_constraint ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudyTimeConstraint
Time-based Constraint for Study Corresponds to the JSON property
minimumRuntimeConstraint. -
#should_stop_asap ⇒ Boolean
(also: #should_stop_asap?)
If true, a Study enters STOPPING_ASAP whenever it would normally enters STOPPING state.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1StudySpecStudyStoppingConfig
constructor
A new instance of GoogleCloudAiplatformV1StudySpecStudyStoppingConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1StudySpecStudyStoppingConfig
Returns a new instance of GoogleCloudAiplatformV1StudySpecStudyStoppingConfig.
46795 46796 46797 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46795 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_duration_no_progress ⇒ String
If the objective value has not improved for this much time, stop the study.
WARNING: Effective only for single-objective studies.
Corresponds to the JSON property maxDurationNoProgress
46758 46759 46760 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46758 def max_duration_no_progress @max_duration_no_progress end |
#max_num_trials ⇒ Fixnum
If there are more than this many trials, stop the study.
Corresponds to the JSON property maxNumTrials
46763 46764 46765 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46763 def max_num_trials @max_num_trials end |
#max_num_trials_no_progress ⇒ Fixnum
If the objective value has not improved for this many consecutive trials, stop
the study. WARNING: Effective only for single-objective studies.
Corresponds to the JSON property maxNumTrialsNoProgress
46769 46770 46771 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46769 def max_num_trials_no_progress @max_num_trials_no_progress end |
#maximum_runtime_constraint ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudyTimeConstraint
Time-based Constraint for Study
Corresponds to the JSON property maximumRuntimeConstraint
46774 46775 46776 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46774 def maximum_runtime_constraint @maximum_runtime_constraint end |
#min_num_trials ⇒ Fixnum
If there are fewer than this many COMPLETED trials, do not stop the study.
Corresponds to the JSON property minNumTrials
46779 46780 46781 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46779 def min_num_trials @min_num_trials end |
#minimum_runtime_constraint ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudyTimeConstraint
Time-based Constraint for Study
Corresponds to the JSON property minimumRuntimeConstraint
46784 46785 46786 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46784 def minimum_runtime_constraint @minimum_runtime_constraint end |
#should_stop_asap ⇒ Boolean Also known as: should_stop_asap?
If true, a Study enters STOPPING_ASAP whenever it would normally enters
STOPPING state. The bottom line is: set to true if you want to interrupt on-
going evaluations of Trials as soon as the study stopping condition is met. (
Please see Study.State documentation for the source of truth).
Corresponds to the JSON property shouldStopAsap
46792 46793 46794 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46792 def should_stop_asap @should_stop_asap end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46800 46801 46802 46803 46804 46805 46806 46807 46808 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46800 def update!(**args) @max_duration_no_progress = args[:max_duration_no_progress] if args.key?(:max_duration_no_progress) @max_num_trials = args[:max_num_trials] if args.key?(:max_num_trials) @max_num_trials_no_progress = args[:max_num_trials_no_progress] if args.key?(:max_num_trials_no_progress) @maximum_runtime_constraint = args[:maximum_runtime_constraint] if args.key?(:maximum_runtime_constraint) @min_num_trials = args[:min_num_trials] if args.key?(:min_num_trials) @minimum_runtime_constraint = args[:minimum_runtime_constraint] if args.key?(:minimum_runtime_constraint) @should_stop_asap = args[:should_stop_asap] if args.key?(:should_stop_asap) end |