Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecStudyStoppingConfig
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecStudyStoppingConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The configuration (stopping conditions) for automated stopping of a Study. Conditions include trial budgets, time budgets, and convergence detection.
Instance Attribute Summary collapse
-
#max_duration_no_progress ⇒ String
If the objective value has not improved for this much time, stop the study.
-
#max_num_trials ⇒ Fixnum
If there are more than this many trials, stop the study.
-
#max_num_trials_no_progress ⇒ Fixnum
If the objective value has not improved for this many consecutive trials, stop the study.
-
#maximum_runtime_constraint ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudyTimeConstraint
Time-based Constraint for Study Corresponds to the JSON property
maximumRuntimeConstraint. -
#min_num_trials ⇒ Fixnum
If there are fewer than this many COMPLETED trials, do not stop the study.
-
#minimum_runtime_constraint ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudyTimeConstraint
Time-based Constraint for Study Corresponds to the JSON property
minimumRuntimeConstraint. -
#should_stop_asap ⇒ Boolean
(also: #should_stop_asap?)
If true, a Study enters STOPPING_ASAP whenever it would normally enters STOPPING state.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1StudySpecStudyStoppingConfig
constructor
A new instance of GoogleCloudAiplatformV1StudySpecStudyStoppingConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1StudySpecStudyStoppingConfig
Returns a new instance of GoogleCloudAiplatformV1StudySpecStudyStoppingConfig.
44218 44219 44220 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44218 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_duration_no_progress ⇒ String
If the objective value has not improved for this much time, stop the study.
WARNING: Effective only for single-objective studies.
Corresponds to the JSON property maxDurationNoProgress
44181 44182 44183 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44181 def max_duration_no_progress @max_duration_no_progress end |
#max_num_trials ⇒ Fixnum
If there are more than this many trials, stop the study.
Corresponds to the JSON property maxNumTrials
44186 44187 44188 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44186 def max_num_trials @max_num_trials end |
#max_num_trials_no_progress ⇒ Fixnum
If the objective value has not improved for this many consecutive trials, stop
the study. WARNING: Effective only for single-objective studies.
Corresponds to the JSON property maxNumTrialsNoProgress
44192 44193 44194 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44192 def max_num_trials_no_progress @max_num_trials_no_progress end |
#maximum_runtime_constraint ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudyTimeConstraint
Time-based Constraint for Study
Corresponds to the JSON property maximumRuntimeConstraint
44197 44198 44199 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44197 def maximum_runtime_constraint @maximum_runtime_constraint end |
#min_num_trials ⇒ Fixnum
If there are fewer than this many COMPLETED trials, do not stop the study.
Corresponds to the JSON property minNumTrials
44202 44203 44204 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44202 def min_num_trials @min_num_trials end |
#minimum_runtime_constraint ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudyTimeConstraint
Time-based Constraint for Study
Corresponds to the JSON property minimumRuntimeConstraint
44207 44208 44209 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44207 def minimum_runtime_constraint @minimum_runtime_constraint end |
#should_stop_asap ⇒ Boolean Also known as: should_stop_asap?
If true, a Study enters STOPPING_ASAP whenever it would normally enters
STOPPING state. The bottom line is: set to true if you want to interrupt on-
going evaluations of Trials as soon as the study stopping condition is met. (
Please see Study.State documentation for the source of truth).
Corresponds to the JSON property shouldStopAsap
44215 44216 44217 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44215 def should_stop_asap @should_stop_asap end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
44223 44224 44225 44226 44227 44228 44229 44230 44231 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44223 def update!(**args) @max_duration_no_progress = args[:max_duration_no_progress] if args.key?(:max_duration_no_progress) @max_num_trials = args[:max_num_trials] if args.key?(:max_num_trials) @max_num_trials_no_progress = args[:max_num_trials_no_progress] if args.key?(:max_num_trials_no_progress) @maximum_runtime_constraint = args[:maximum_runtime_constraint] if args.key?(:maximum_runtime_constraint) @min_num_trials = args[:min_num_trials] if args.key?(:min_num_trials) @minimum_runtime_constraint = args[:minimum_runtime_constraint] if args.key?(:minimum_runtime_constraint) @should_stop_asap = args[:should_stop_asap] if args.key?(:should_stop_asap) end |