Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1StudySpecStudyStoppingConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The configuration (stopping conditions) for automated stopping of a Study. Conditions include trial budgets, time budgets, and convergence detection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1StudySpecStudyStoppingConfig

Returns a new instance of GoogleCloudAiplatformV1StudySpecStudyStoppingConfig.



34706
34707
34708
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34706

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_duration_no_progressString

If the objective value has not improved for this much time, stop the study. WARNING: Effective only for single-objective studies. Corresponds to the JSON property maxDurationNoProgress

Returns:

  • (String)


34669
34670
34671
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34669

def max_duration_no_progress
  @max_duration_no_progress
end

#max_num_trialsFixnum

If there are more than this many trials, stop the study. Corresponds to the JSON property maxNumTrials

Returns:

  • (Fixnum)


34674
34675
34676
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34674

def max_num_trials
  @max_num_trials
end

#max_num_trials_no_progressFixnum

If the objective value has not improved for this many consecutive trials, stop the study. WARNING: Effective only for single-objective studies. Corresponds to the JSON property maxNumTrialsNoProgress

Returns:

  • (Fixnum)


34680
34681
34682
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34680

def max_num_trials_no_progress
  @max_num_trials_no_progress
end

#maximum_runtime_constraintGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1StudyTimeConstraint

Time-based Constraint for Study Corresponds to the JSON property maximumRuntimeConstraint



34685
34686
34687
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34685

def maximum_runtime_constraint
  @maximum_runtime_constraint
end

#min_num_trialsFixnum

If there are fewer than this many COMPLETED trials, do not stop the study. Corresponds to the JSON property minNumTrials

Returns:

  • (Fixnum)


34690
34691
34692
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34690

def min_num_trials
  @min_num_trials
end

#minimum_runtime_constraintGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1StudyTimeConstraint

Time-based Constraint for Study Corresponds to the JSON property minimumRuntimeConstraint



34695
34696
34697
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34695

def minimum_runtime_constraint
  @minimum_runtime_constraint
end

#should_stop_asapBoolean Also known as: should_stop_asap?

If true, a Study enters STOPPING_ASAP whenever it would normally enters STOPPING state. The bottom line is: set to true if you want to interrupt on- going evaluations of Trials as soon as the study stopping condition is met. ( Please see Study.State documentation for the source of truth). Corresponds to the JSON property shouldStopAsap

Returns:

  • (Boolean)


34703
34704
34705
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34703

def should_stop_asap
  @should_stop_asap
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34711
34712
34713
34714
34715
34716
34717
34718
34719
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34711

def update!(**args)
  @max_duration_no_progress = args[:max_duration_no_progress] if args.key?(:max_duration_no_progress)
  @max_num_trials = args[:max_num_trials] if args.key?(:max_num_trials)
  @max_num_trials_no_progress = args[:max_num_trials_no_progress] if args.key?(:max_num_trials_no_progress)
  @maximum_runtime_constraint = args[:maximum_runtime_constraint] if args.key?(:maximum_runtime_constraint)
  @min_num_trials = args[:min_num_trials] if args.key?(:min_num_trials)
  @minimum_runtime_constraint = args[:minimum_runtime_constraint] if args.key?(:minimum_runtime_constraint)
  @should_stop_asap = args[:should_stop_asap] if args.key?(:should_stop_asap)
end