Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDataStats

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Tuning data statistics for Supervised Tuning.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SupervisedTuningDataStats

Returns a new instance of GoogleCloudAiplatformV1SupervisedTuningDataStats.



36150
36151
36152
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36150

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dropped_example_reasonsArray<String>

Output only. For each index in truncated_example_indices, the user-facing reason why the example was dropped. Corresponds to the JSON property droppedExampleReasons

Returns:

  • (Array<String>)


36090
36091
36092
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36090

def dropped_example_reasons
  @dropped_example_reasons
end

#total_billable_character_countFixnum

Output only. Number of billable characters in the tuning dataset. Corresponds to the JSON property totalBillableCharacterCount

Returns:

  • (Fixnum)


36095
36096
36097
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36095

def total_billable_character_count
  @total_billable_character_count
end

#total_billable_token_countFixnum

Output only. Number of billable tokens in the tuning dataset. Corresponds to the JSON property totalBillableTokenCount

Returns:

  • (Fixnum)


36100
36101
36102
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36100

def total_billable_token_count
  @total_billable_token_count
end

#total_truncated_example_countFixnum

Output only. The number of examples in the dataset that have been dropped. An example can be dropped for reasons including: too many tokens, contains an invalid image, contains too many images, etc. Corresponds to the JSON property totalTruncatedExampleCount

Returns:

  • (Fixnum)


36107
36108
36109
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36107

def total_truncated_example_count
  @total_truncated_example_count
end

#total_tuning_character_countFixnum

Output only. Number of tuning characters in the tuning dataset. Corresponds to the JSON property totalTuningCharacterCount

Returns:

  • (Fixnum)


36112
36113
36114
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36112

def total_tuning_character_count
  @total_tuning_character_count
end

#truncated_example_indicesArray<Fixnum>

Output only. A partial sample of the indices (starting from 1) of the dropped examples. Corresponds to the JSON property truncatedExampleIndices

Returns:

  • (Array<Fixnum>)


36118
36119
36120
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36118

def truncated_example_indices
  @truncated_example_indices
end

#tuning_dataset_example_countFixnum

Output only. Number of examples in the tuning dataset. Corresponds to the JSON property tuningDatasetExampleCount

Returns:

  • (Fixnum)


36123
36124
36125
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36123

def tuning_dataset_example_count
  @tuning_dataset_example_count
end

#tuning_step_countFixnum

Output only. Number of tuning steps for this Tuning Job. Corresponds to the JSON property tuningStepCount

Returns:

  • (Fixnum)


36128
36129
36130
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36128

def tuning_step_count
  @tuning_step_count
end

#user_dataset_examplesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content>

Output only. Sample user messages in the training dataset uri. Corresponds to the JSON property userDatasetExamples



36133
36134
36135
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36133

def user_dataset_examples
  @user_dataset_examples
end

#user_input_token_distributionGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution

Dataset distribution for Supervised Tuning. Corresponds to the JSON property userInputTokenDistribution



36138
36139
36140
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36138

def user_input_token_distribution
  @user_input_token_distribution
end

#user_message_per_example_distributionGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution

Dataset distribution for Supervised Tuning. Corresponds to the JSON property userMessagePerExampleDistribution



36143
36144
36145
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36143

def user_message_per_example_distribution
  @user_message_per_example_distribution
end

#user_output_token_distributionGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution

Dataset distribution for Supervised Tuning. Corresponds to the JSON property userOutputTokenDistribution



36148
36149
36150
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36148

def user_output_token_distribution
  @user_output_token_distribution
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36155
36156
36157
36158
36159
36160
36161
36162
36163
36164
36165
36166
36167
36168
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36155

def update!(**args)
  @dropped_example_reasons = args[:dropped_example_reasons] if args.key?(:dropped_example_reasons)
  @total_billable_character_count = args[:total_billable_character_count] if args.key?(:total_billable_character_count)
  @total_billable_token_count = args[:total_billable_token_count] if args.key?(:total_billable_token_count)
  @total_truncated_example_count = args[:total_truncated_example_count] if args.key?(:total_truncated_example_count)
  @total_tuning_character_count = args[:total_tuning_character_count] if args.key?(:total_tuning_character_count)
  @truncated_example_indices = args[:truncated_example_indices] if args.key?(:truncated_example_indices)
  @tuning_dataset_example_count = args[:tuning_dataset_example_count] if args.key?(:tuning_dataset_example_count)
  @tuning_step_count = args[:tuning_step_count] if args.key?(:tuning_step_count)
  @user_dataset_examples = args[:user_dataset_examples] if args.key?(:user_dataset_examples)
  @user_input_token_distribution = args[:user_input_token_distribution] if args.key?(:user_input_token_distribution)
  @user_message_per_example_distribution = args[:user_message_per_example_distribution] if args.key?(:user_message_per_example_distribution)
  @user_output_token_distribution = args[:user_output_token_distribution] if args.key?(:user_output_token_distribution)
end