Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDataStats

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Tuning data statistics for Supervised Tuning.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SupervisedTuningDataStats

Returns a new instance of GoogleCloudAiplatformV1SupervisedTuningDataStats.



34655
34656
34657
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34655

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dropped_example_reasonsArray<String>

Output only. For each index in truncated_example_indices, the user-facing reason why the example was dropped. Must not include example itself. Corresponds to the JSON property droppedExampleReasons

Returns:

  • (Array<String>)


34595
34596
34597
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34595

def dropped_example_reasons
  @dropped_example_reasons
end

#total_billable_character_countFixnum

Output only. Number of billable characters in the tuning dataset. Corresponds to the JSON property totalBillableCharacterCount

Returns:

  • (Fixnum)


34600
34601
34602
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34600

def total_billable_character_count
  @total_billable_character_count
end

#total_billable_token_countFixnum

Output only. Number of billable tokens in the tuning dataset. Corresponds to the JSON property totalBillableTokenCount

Returns:

  • (Fixnum)


34605
34606
34607
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34605

def total_billable_token_count
  @total_billable_token_count
end

#total_truncated_example_countFixnum

Output only. The number of examples in the dataset that have been dropped. An example can be dropped for reasons including: too many tokens, contains an invalid image, contains too many images, etc. Corresponds to the JSON property totalTruncatedExampleCount

Returns:

  • (Fixnum)


34612
34613
34614
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34612

def total_truncated_example_count
  @total_truncated_example_count
end

#total_tuning_character_countFixnum

Output only. Number of tuning characters in the tuning dataset. Corresponds to the JSON property totalTuningCharacterCount

Returns:

  • (Fixnum)


34617
34618
34619
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34617

def total_tuning_character_count
  @total_tuning_character_count
end

#truncated_example_indicesArray<Fixnum>

Output only. A partial sample of the indices (starting from 1) of the dropped examples. Corresponds to the JSON property truncatedExampleIndices

Returns:

  • (Array<Fixnum>)


34623
34624
34625
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34623

def truncated_example_indices
  @truncated_example_indices
end

#tuning_dataset_example_countFixnum

Output only. Number of examples in the tuning dataset. Corresponds to the JSON property tuningDatasetExampleCount

Returns:

  • (Fixnum)


34628
34629
34630
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34628

def tuning_dataset_example_count
  @tuning_dataset_example_count
end

#tuning_step_countFixnum

Output only. Number of tuning steps for this Tuning Job. Corresponds to the JSON property tuningStepCount

Returns:

  • (Fixnum)


34633
34634
34635
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34633

def tuning_step_count
  @tuning_step_count
end

#user_dataset_examplesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content>

Output only. Sample user messages in the training dataset uri. Corresponds to the JSON property userDatasetExamples



34638
34639
34640
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34638

def user_dataset_examples
  @user_dataset_examples
end

#user_input_token_distributionGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution

Dataset distribution for Supervised Tuning. Corresponds to the JSON property userInputTokenDistribution



34643
34644
34645
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34643

def user_input_token_distribution
  @user_input_token_distribution
end

#user_message_per_example_distributionGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution

Dataset distribution for Supervised Tuning. Corresponds to the JSON property userMessagePerExampleDistribution



34648
34649
34650
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34648

def user_message_per_example_distribution
  @user_message_per_example_distribution
end

#user_output_token_distributionGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution

Dataset distribution for Supervised Tuning. Corresponds to the JSON property userOutputTokenDistribution



34653
34654
34655
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34653

def user_output_token_distribution
  @user_output_token_distribution
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34660
34661
34662
34663
34664
34665
34666
34667
34668
34669
34670
34671
34672
34673
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34660

def update!(**args)
  @dropped_example_reasons = args[:dropped_example_reasons] if args.key?(:dropped_example_reasons)
  @total_billable_character_count = args[:total_billable_character_count] if args.key?(:total_billable_character_count)
  @total_billable_token_count = args[:total_billable_token_count] if args.key?(:total_billable_token_count)
  @total_truncated_example_count = args[:total_truncated_example_count] if args.key?(:total_truncated_example_count)
  @total_tuning_character_count = args[:total_tuning_character_count] if args.key?(:total_tuning_character_count)
  @truncated_example_indices = args[:truncated_example_indices] if args.key?(:truncated_example_indices)
  @tuning_dataset_example_count = args[:tuning_dataset_example_count] if args.key?(:tuning_dataset_example_count)
  @tuning_step_count = args[:tuning_step_count] if args.key?(:tuning_step_count)
  @user_dataset_examples = args[:user_dataset_examples] if args.key?(:user_dataset_examples)
  @user_input_token_distribution = args[:user_input_token_distribution] if args.key?(:user_input_token_distribution)
  @user_message_per_example_distribution = args[:user_message_per_example_distribution] if args.key?(:user_message_per_example_distribution)
  @user_output_token_distribution = args[:user_output_token_distribution] if args.key?(:user_output_token_distribution)
end