Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDataStats
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDataStats
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Tuning data statistics for Supervised Tuning.
Instance Attribute Summary collapse
-
#total_billable_character_count ⇒ Fixnum
Output only.
-
#total_billable_token_count ⇒ Fixnum
Output only.
-
#total_truncated_example_count ⇒ Fixnum
The number of examples in the dataset that have been truncated by any amount.
-
#total_tuning_character_count ⇒ Fixnum
Output only.
-
#truncated_example_indices ⇒ Array<Fixnum>
A partial sample of the indices (starting from 1) of the truncated examples.
-
#tuning_dataset_example_count ⇒ Fixnum
Output only.
-
#tuning_step_count ⇒ Fixnum
Output only.
-
#user_dataset_examples ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content>
Output only.
-
#user_input_token_distribution ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution
Dataset distribution for Supervised Tuning.
-
#user_message_per_example_distribution ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution
Dataset distribution for Supervised Tuning.
-
#user_output_token_distribution ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution
Dataset distribution for Supervised Tuning.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SupervisedTuningDataStats
constructor
A new instance of GoogleCloudAiplatformV1SupervisedTuningDataStats.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SupervisedTuningDataStats
Returns a new instance of GoogleCloudAiplatformV1SupervisedTuningDataStats.
30695 30696 30697 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30695 def initialize(**args) update!(**args) end |
Instance Attribute Details
#total_billable_character_count ⇒ Fixnum
Output only. Number of billable characters in the tuning dataset.
Corresponds to the JSON property totalBillableCharacterCount
30643 30644 30645 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30643 def total_billable_character_count @total_billable_character_count end |
#total_billable_token_count ⇒ Fixnum
Output only. Number of billable tokens in the tuning dataset.
Corresponds to the JSON property totalBillableTokenCount
30648 30649 30650 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30648 def total_billable_token_count @total_billable_token_count end |
#total_truncated_example_count ⇒ Fixnum
The number of examples in the dataset that have been truncated by any amount.
Corresponds to the JSON property totalTruncatedExampleCount
30653 30654 30655 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30653 def total_truncated_example_count @total_truncated_example_count end |
#total_tuning_character_count ⇒ Fixnum
Output only. Number of tuning characters in the tuning dataset.
Corresponds to the JSON property totalTuningCharacterCount
30658 30659 30660 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30658 def total_tuning_character_count @total_tuning_character_count end |
#truncated_example_indices ⇒ Array<Fixnum>
A partial sample of the indices (starting from 1) of the truncated examples.
Corresponds to the JSON property truncatedExampleIndices
30663 30664 30665 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30663 def truncated_example_indices @truncated_example_indices end |
#tuning_dataset_example_count ⇒ Fixnum
Output only. Number of examples in the tuning dataset.
Corresponds to the JSON property tuningDatasetExampleCount
30668 30669 30670 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30668 def tuning_dataset_example_count @tuning_dataset_example_count end |
#tuning_step_count ⇒ Fixnum
Output only. Number of tuning steps for this Tuning Job.
Corresponds to the JSON property tuningStepCount
30673 30674 30675 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30673 def tuning_step_count @tuning_step_count end |
#user_dataset_examples ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Content>
Output only. Sample user messages in the training dataset uri.
Corresponds to the JSON property userDatasetExamples
30678 30679 30680 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30678 def user_dataset_examples @user_dataset_examples end |
#user_input_token_distribution ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution
Dataset distribution for Supervised Tuning.
Corresponds to the JSON property userInputTokenDistribution
30683 30684 30685 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30683 def user_input_token_distribution @user_input_token_distribution end |
#user_message_per_example_distribution ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution
Dataset distribution for Supervised Tuning.
Corresponds to the JSON property userMessagePerExampleDistribution
30688 30689 30690 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30688 def @user_message_per_example_distribution end |
#user_output_token_distribution ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution
Dataset distribution for Supervised Tuning.
Corresponds to the JSON property userOutputTokenDistribution
30693 30694 30695 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30693 def user_output_token_distribution @user_output_token_distribution end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30700 30701 30702 30703 30704 30705 30706 30707 30708 30709 30710 30711 30712 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30700 def update!(**args) @total_billable_character_count = args[:total_billable_character_count] if args.key?(:total_billable_character_count) @total_billable_token_count = args[:total_billable_token_count] if args.key?(:total_billable_token_count) @total_truncated_example_count = args[:total_truncated_example_count] if args.key?(:total_truncated_example_count) @total_tuning_character_count = args[:total_tuning_character_count] if args.key?(:total_tuning_character_count) @truncated_example_indices = args[:truncated_example_indices] if args.key?(:truncated_example_indices) @tuning_dataset_example_count = args[:tuning_dataset_example_count] if args.key?(:tuning_dataset_example_count) @tuning_step_count = args[:tuning_step_count] if args.key?(:tuning_step_count) @user_dataset_examples = args[:user_dataset_examples] if args.key?(:user_dataset_examples) @user_input_token_distribution = args[:user_input_token_distribution] if args.key?(:user_input_token_distribution) @user_message_per_example_distribution = args[:user_message_per_example_distribution] if args.key?(:user_message_per_example_distribution) @user_output_token_distribution = args[:user_output_token_distribution] if args.key?(:user_output_token_distribution) end |