Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Dataset distribution for Supervised Tuning.
Instance Attribute Summary collapse
-
#billable_sum ⇒ Fixnum
Output only.
-
#buckets ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistributionDatasetBucket>
Output only.
-
#max ⇒ Float
Output only.
-
#mean ⇒ Float
Output only.
-
#median ⇒ Float
Output only.
-
#min ⇒ Float
Output only.
-
#p5 ⇒ Float
Output only.
-
#p95 ⇒ Float
Output only.
-
#sum ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution
constructor
A new instance of GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution
Returns a new instance of GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution.
47520 47521 47522 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47520 def initialize(**args) update!(**args) end |
Instance Attribute Details
#billable_sum ⇒ Fixnum
Output only. Sum of a given population of values that are billable.
Corresponds to the JSON property billableSum
47478 47479 47480 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47478 def billable_sum @billable_sum end |
#buckets ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistributionDatasetBucket>
Output only. Defines the histogram bucket.
Corresponds to the JSON property buckets
47483 47484 47485 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47483 def buckets @buckets end |
#max ⇒ Float
Output only. The maximum of the population values.
Corresponds to the JSON property max
47488 47489 47490 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47488 def max @max end |
#mean ⇒ Float
Output only. The arithmetic mean of the values in the population.
Corresponds to the JSON property mean
47493 47494 47495 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47493 def mean @mean end |
#median ⇒ Float
Output only. The median of the values in the population.
Corresponds to the JSON property median
47498 47499 47500 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47498 def median @median end |
#min ⇒ Float
Output only. The minimum of the population values.
Corresponds to the JSON property min
47503 47504 47505 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47503 def min @min end |
#p5 ⇒ Float
Output only. The 5th percentile of the values in the population.
Corresponds to the JSON property p5
47508 47509 47510 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47508 def p5 @p5 end |
#p95 ⇒ Float
Output only. The 95th percentile of the values in the population.
Corresponds to the JSON property p95
47513 47514 47515 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47513 def p95 @p95 end |
#sum ⇒ Fixnum
Output only. Sum of a given population of values.
Corresponds to the JSON property sum
47518 47519 47520 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47518 def sum @sum end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47525 47526 47527 47528 47529 47530 47531 47532 47533 47534 47535 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47525 def update!(**args) @billable_sum = args[:billable_sum] if args.key?(:billable_sum) @buckets = args[:buckets] if args.key?(:buckets) @max = args[:max] if args.key?(:max) @mean = args[:mean] if args.key?(:mean) @median = args[:median] if args.key?(:median) @min = args[:min] if args.key?(:min) @p5 = args[:p5] if args.key?(:p5) @p95 = args[:p95] if args.key?(:p95) @sum = args[:sum] if args.key?(:sum) end |