Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Dataset distribution for Supervised Tuning.
Instance Attribute Summary collapse
-
#billable_sum ⇒ Fixnum
Output only.
-
#buckets ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistributionDatasetBucket>
Output only.
-
#max ⇒ Float
Output only.
-
#mean ⇒ Float
Output only.
-
#median ⇒ Float
Output only.
-
#min ⇒ Float
Output only.
-
#p5 ⇒ Float
Output only.
-
#p95 ⇒ Float
Output only.
-
#sum ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution
constructor
A new instance of GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution
Returns a new instance of GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution.
44943 44944 44945 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44943 def initialize(**args) update!(**args) end |
Instance Attribute Details
#billable_sum ⇒ Fixnum
Output only. Sum of a given population of values that are billable.
Corresponds to the JSON property billableSum
44901 44902 44903 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44901 def billable_sum @billable_sum end |
#buckets ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistributionDatasetBucket>
Output only. Defines the histogram bucket.
Corresponds to the JSON property buckets
44906 44907 44908 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44906 def buckets @buckets end |
#max ⇒ Float
Output only. The maximum of the population values.
Corresponds to the JSON property max
44911 44912 44913 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44911 def max @max end |
#mean ⇒ Float
Output only. The arithmetic mean of the values in the population.
Corresponds to the JSON property mean
44916 44917 44918 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44916 def mean @mean end |
#median ⇒ Float
Output only. The median of the values in the population.
Corresponds to the JSON property median
44921 44922 44923 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44921 def median @median end |
#min ⇒ Float
Output only. The minimum of the population values.
Corresponds to the JSON property min
44926 44927 44928 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44926 def min @min end |
#p5 ⇒ Float
Output only. The 5th percentile of the values in the population.
Corresponds to the JSON property p5
44931 44932 44933 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44931 def p5 @p5 end |
#p95 ⇒ Float
Output only. The 95th percentile of the values in the population.
Corresponds to the JSON property p95
44936 44937 44938 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44936 def p95 @p95 end |
#sum ⇒ Fixnum
Output only. Sum of a given population of values.
Corresponds to the JSON property sum
44941 44942 44943 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44941 def sum @sum end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
44948 44949 44950 44951 44952 44953 44954 44955 44956 44957 44958 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44948 def update!(**args) @billable_sum = args[:billable_sum] if args.key?(:billable_sum) @buckets = args[:buckets] if args.key?(:buckets) @max = args[:max] if args.key?(:max) @mean = args[:mean] if args.key?(:mean) @median = args[:median] if args.key?(:median) @min = args[:min] if args.key?(:min) @p5 = args[:p5] if args.key?(:p5) @p95 = args[:p95] if args.key?(:p95) @sum = args[:sum] if args.key?(:sum) end |