Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Dataset distribution for Supervised Tuning.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution

Returns a new instance of GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution.



44770
44771
44772
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44770

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#billable_sumFixnum

Output only. Sum of a given population of values that are billable. Corresponds to the JSON property billableSum

Returns:

  • (Fixnum)


44728
44729
44730
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44728

def billable_sum
  @billable_sum
end

#bucketsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistributionDatasetBucket>

Output only. Defines the histogram bucket. Corresponds to the JSON property buckets



44733
44734
44735
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44733

def buckets
  @buckets
end

#maxFloat

Output only. The maximum of the population values. Corresponds to the JSON property max

Returns:

  • (Float)


44738
44739
44740
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44738

def max
  @max
end

#meanFloat

Output only. The arithmetic mean of the values in the population. Corresponds to the JSON property mean

Returns:

  • (Float)


44743
44744
44745
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44743

def mean
  @mean
end

#medianFloat

Output only. The median of the values in the population. Corresponds to the JSON property median

Returns:

  • (Float)


44748
44749
44750
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44748

def median
  @median
end

#minFloat

Output only. The minimum of the population values. Corresponds to the JSON property min

Returns:

  • (Float)


44753
44754
44755
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44753

def min
  @min
end

#p5Float

Output only. The 5th percentile of the values in the population. Corresponds to the JSON property p5

Returns:

  • (Float)


44758
44759
44760
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44758

def p5
  @p5
end

#p95Float

Output only. The 95th percentile of the values in the population. Corresponds to the JSON property p95

Returns:

  • (Float)


44763
44764
44765
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44763

def p95
  @p95
end

#sumFixnum

Output only. Sum of a given population of values. Corresponds to the JSON property sum

Returns:

  • (Fixnum)


44768
44769
44770
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44768

def sum
  @sum
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44775
44776
44777
44778
44779
44780
44781
44782
44783
44784
44785
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44775

def update!(**args)
  @billable_sum = args[:billable_sum] if args.key?(:billable_sum)
  @buckets = args[:buckets] if args.key?(:buckets)
  @max = args[:max] if args.key?(:max)
  @mean = args[:mean] if args.key?(:mean)
  @median = args[:median] if args.key?(:median)
  @min = args[:min] if args.key?(:min)
  @p5 = args[:p5] if args.key?(:p5)
  @p95 = args[:p95] if args.key?(:p95)
  @sum = args[:sum] if args.key?(:sum)
end