Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Dataset distribution for Supervised Tuning.
Instance Attribute Summary collapse
-
#billable_sum ⇒ Fixnum
Output only.
-
#buckets ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistributionDatasetBucket>
Output only.
-
#max ⇒ Float
Output only.
-
#mean ⇒ Float
Output only.
-
#median ⇒ Float
Output only.
-
#min ⇒ Float
Output only.
-
#p5 ⇒ Float
Output only.
-
#p95 ⇒ Float
Output only.
-
#sum ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution
constructor
A new instance of GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution
Returns a new instance of GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution.
44748 44749 44750 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44748 def initialize(**args) update!(**args) end |
Instance Attribute Details
#billable_sum ⇒ Fixnum
Output only. Sum of a given population of values that are billable.
Corresponds to the JSON property billableSum
44706 44707 44708 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44706 def billable_sum @billable_sum end |
#buckets ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistributionDatasetBucket>
Output only. Defines the histogram bucket.
Corresponds to the JSON property buckets
44711 44712 44713 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44711 def buckets @buckets end |
#max ⇒ Float
Output only. The maximum of the population values.
Corresponds to the JSON property max
44716 44717 44718 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44716 def max @max end |
#mean ⇒ Float
Output only. The arithmetic mean of the values in the population.
Corresponds to the JSON property mean
44721 44722 44723 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44721 def mean @mean end |
#median ⇒ Float
Output only. The median of the values in the population.
Corresponds to the JSON property median
44726 44727 44728 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44726 def median @median end |
#min ⇒ Float
Output only. The minimum of the population values.
Corresponds to the JSON property min
44731 44732 44733 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44731 def min @min end |
#p5 ⇒ Float
Output only. The 5th percentile of the values in the population.
Corresponds to the JSON property p5
44736 44737 44738 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44736 def p5 @p5 end |
#p95 ⇒ Float
Output only. The 95th percentile of the values in the population.
Corresponds to the JSON property p95
44741 44742 44743 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44741 def p95 @p95 end |
#sum ⇒ Fixnum
Output only. Sum of a given population of values.
Corresponds to the JSON property sum
44746 44747 44748 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44746 def sum @sum end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
44753 44754 44755 44756 44757 44758 44759 44760 44761 44762 44763 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44753 def update!(**args) @billable_sum = args[:billable_sum] if args.key?(:billable_sum) @buckets = args[:buckets] if args.key?(:buckets) @max = args[:max] if args.key?(:max) @mean = args[:mean] if args.key?(:mean) @median = args[:median] if args.key?(:median) @min = args[:min] if args.key?(:min) @p5 = args[:p5] if args.key?(:p5) @p95 = args[:p95] if args.key?(:p95) @sum = args[:sum] if args.key?(:sum) end |