Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Dataset distribution for Supervised Tuning.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution

Returns a new instance of GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution.



37134
37135
37136
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37134

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#billable_sumFixnum

Output only. Sum of a given population of values that are billable. Corresponds to the JSON property billableSum

Returns:

  • (Fixnum)


37092
37093
37094
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37092

def billable_sum
  @billable_sum
end

#bucketsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistributionDatasetBucket>

Output only. Defines the histogram bucket. Corresponds to the JSON property buckets



37097
37098
37099
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37097

def buckets
  @buckets
end

#maxFloat

Output only. The maximum of the population values. Corresponds to the JSON property max

Returns:

  • (Float)


37102
37103
37104
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37102

def max
  @max
end

#meanFloat

Output only. The arithmetic mean of the values in the population. Corresponds to the JSON property mean

Returns:

  • (Float)


37107
37108
37109
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37107

def mean
  @mean
end

#medianFloat

Output only. The median of the values in the population. Corresponds to the JSON property median

Returns:

  • (Float)


37112
37113
37114
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37112

def median
  @median
end

#minFloat

Output only. The minimum of the population values. Corresponds to the JSON property min

Returns:

  • (Float)


37117
37118
37119
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37117

def min
  @min
end

#p5Float

Output only. The 5th percentile of the values in the population. Corresponds to the JSON property p5

Returns:

  • (Float)


37122
37123
37124
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37122

def p5
  @p5
end

#p95Float

Output only. The 95th percentile of the values in the population. Corresponds to the JSON property p95

Returns:

  • (Float)


37127
37128
37129
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37127

def p95
  @p95
end

#sumFixnum

Output only. Sum of a given population of values. Corresponds to the JSON property sum

Returns:

  • (Fixnum)


37132
37133
37134
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37132

def sum
  @sum
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37139
37140
37141
37142
37143
37144
37145
37146
37147
37148
37149
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37139

def update!(**args)
  @billable_sum = args[:billable_sum] if args.key?(:billable_sum)
  @buckets = args[:buckets] if args.key?(:buckets)
  @max = args[:max] if args.key?(:max)
  @mean = args[:mean] if args.key?(:mean)
  @median = args[:median] if args.key?(:median)
  @min = args[:min] if args.key?(:min)
  @p5 = args[:p5] if args.key?(:p5)
  @p95 = args[:p95] if args.key?(:p95)
  @sum = args[:sum] if args.key?(:sum)
end