Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Dataset distribution for Supervised Tuning.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution

Returns a new instance of GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution.



36709
36710
36711
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36709

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#billable_sumFixnum

Output only. Sum of a given population of values that are billable. Corresponds to the JSON property billableSum

Returns:

  • (Fixnum)


36667
36668
36669
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36667

def billable_sum
  @billable_sum
end

#bucketsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistributionDatasetBucket>

Output only. Defines the histogram bucket. Corresponds to the JSON property buckets



36672
36673
36674
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36672

def buckets
  @buckets
end

#maxFloat

Output only. The maximum of the population values. Corresponds to the JSON property max

Returns:

  • (Float)


36677
36678
36679
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36677

def max
  @max
end

#meanFloat

Output only. The arithmetic mean of the values in the population. Corresponds to the JSON property mean

Returns:

  • (Float)


36682
36683
36684
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36682

def mean
  @mean
end

#medianFloat

Output only. The median of the values in the population. Corresponds to the JSON property median

Returns:

  • (Float)


36687
36688
36689
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36687

def median
  @median
end

#minFloat

Output only. The minimum of the population values. Corresponds to the JSON property min

Returns:

  • (Float)


36692
36693
36694
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36692

def min
  @min
end

#p5Float

Output only. The 5th percentile of the values in the population. Corresponds to the JSON property p5

Returns:

  • (Float)


36697
36698
36699
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36697

def p5
  @p5
end

#p95Float

Output only. The 95th percentile of the values in the population. Corresponds to the JSON property p95

Returns:

  • (Float)


36702
36703
36704
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36702

def p95
  @p95
end

#sumFixnum

Output only. Sum of a given population of values. Corresponds to the JSON property sum

Returns:

  • (Fixnum)


36707
36708
36709
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36707

def sum
  @sum
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36714
36715
36716
36717
36718
36719
36720
36721
36722
36723
36724
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36714

def update!(**args)
  @billable_sum = args[:billable_sum] if args.key?(:billable_sum)
  @buckets = args[:buckets] if args.key?(:buckets)
  @max = args[:max] if args.key?(:max)
  @mean = args[:mean] if args.key?(:mean)
  @median = args[:median] if args.key?(:median)
  @min = args[:min] if args.key?(:min)
  @p5 = args[:p5] if args.key?(:p5)
  @p95 = args[:p95] if args.key?(:p95)
  @sum = args[:sum] if args.key?(:sum)
end