Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Dataset distribution for Supervised Tuning.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution

Returns a new instance of GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution.



36555
36556
36557
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36555

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#billable_sumFixnum

Output only. Sum of a given population of values that are billable. Corresponds to the JSON property billableSum

Returns:

  • (Fixnum)


36513
36514
36515
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36513

def billable_sum
  @billable_sum
end

#bucketsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistributionDatasetBucket>

Output only. Defines the histogram bucket. Corresponds to the JSON property buckets



36518
36519
36520
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36518

def buckets
  @buckets
end

#maxFloat

Output only. The maximum of the population values. Corresponds to the JSON property max

Returns:

  • (Float)


36523
36524
36525
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36523

def max
  @max
end

#meanFloat

Output only. The arithmetic mean of the values in the population. Corresponds to the JSON property mean

Returns:

  • (Float)


36528
36529
36530
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36528

def mean
  @mean
end

#medianFloat

Output only. The median of the values in the population. Corresponds to the JSON property median

Returns:

  • (Float)


36533
36534
36535
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36533

def median
  @median
end

#minFloat

Output only. The minimum of the population values. Corresponds to the JSON property min

Returns:

  • (Float)


36538
36539
36540
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36538

def min
  @min
end

#p5Float

Output only. The 5th percentile of the values in the population. Corresponds to the JSON property p5

Returns:

  • (Float)


36543
36544
36545
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36543

def p5
  @p5
end

#p95Float

Output only. The 95th percentile of the values in the population. Corresponds to the JSON property p95

Returns:

  • (Float)


36548
36549
36550
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36548

def p95
  @p95
end

#sumFixnum

Output only. Sum of a given population of values. Corresponds to the JSON property sum

Returns:

  • (Fixnum)


36553
36554
36555
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36553

def sum
  @sum
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36560
36561
36562
36563
36564
36565
36566
36567
36568
36569
36570
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36560

def update!(**args)
  @billable_sum = args[:billable_sum] if args.key?(:billable_sum)
  @buckets = args[:buckets] if args.key?(:buckets)
  @max = args[:max] if args.key?(:max)
  @mean = args[:mean] if args.key?(:mean)
  @median = args[:median] if args.key?(:median)
  @min = args[:min] if args.key?(:min)
  @p5 = args[:p5] if args.key?(:p5)
  @p95 = args[:p95] if args.key?(:p95)
  @sum = args[:sum] if args.key?(:sum)
end