Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Dataset distribution for Supervised Tuning.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution

Returns a new instance of GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution.



35686
35687
35688
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35686

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#billable_sumFixnum

Output only. Sum of a given population of values that are billable. Corresponds to the JSON property billableSum

Returns:

  • (Fixnum)


35644
35645
35646
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35644

def billable_sum
  @billable_sum
end

#bucketsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistributionDatasetBucket>

Output only. Defines the histogram bucket. Corresponds to the JSON property buckets



35649
35650
35651
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35649

def buckets
  @buckets
end

#maxFloat

Output only. The maximum of the population values. Corresponds to the JSON property max

Returns:

  • (Float)


35654
35655
35656
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35654

def max
  @max
end

#meanFloat

Output only. The arithmetic mean of the values in the population. Corresponds to the JSON property mean

Returns:

  • (Float)


35659
35660
35661
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35659

def mean
  @mean
end

#medianFloat

Output only. The median of the values in the population. Corresponds to the JSON property median

Returns:

  • (Float)


35664
35665
35666
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35664

def median
  @median
end

#minFloat

Output only. The minimum of the population values. Corresponds to the JSON property min

Returns:

  • (Float)


35669
35670
35671
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35669

def min
  @min
end

#p5Float

Output only. The 5th percentile of the values in the population. Corresponds to the JSON property p5

Returns:

  • (Float)


35674
35675
35676
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35674

def p5
  @p5
end

#p95Float

Output only. The 95th percentile of the values in the population. Corresponds to the JSON property p95

Returns:

  • (Float)


35679
35680
35681
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35679

def p95
  @p95
end

#sumFixnum

Output only. Sum of a given population of values. Corresponds to the JSON property sum

Returns:

  • (Fixnum)


35684
35685
35686
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35684

def sum
  @sum
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35691
35692
35693
35694
35695
35696
35697
35698
35699
35700
35701
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35691

def update!(**args)
  @billable_sum = args[:billable_sum] if args.key?(:billable_sum)
  @buckets = args[:buckets] if args.key?(:buckets)
  @max = args[:max] if args.key?(:max)
  @mean = args[:mean] if args.key?(:mean)
  @median = args[:median] if args.key?(:median)
  @min = args[:min] if args.key?(:min)
  @p5 = args[:p5] if args.key?(:p5)
  @p95 = args[:p95] if args.key?(:p95)
  @sum = args[:sum] if args.key?(:sum)
end