Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Dataset distribution for Supervised Tuning.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution

Returns a new instance of GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution.



35555
35556
35557
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35555

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#billable_sumFixnum

Output only. Sum of a given population of values that are billable. Corresponds to the JSON property billableSum

Returns:

  • (Fixnum)


35513
35514
35515
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35513

def billable_sum
  @billable_sum
end

#bucketsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistributionDatasetBucket>

Output only. Defines the histogram bucket. Corresponds to the JSON property buckets



35518
35519
35520
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35518

def buckets
  @buckets
end

#maxFloat

Output only. The maximum of the population values. Corresponds to the JSON property max

Returns:

  • (Float)


35523
35524
35525
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35523

def max
  @max
end

#meanFloat

Output only. The arithmetic mean of the values in the population. Corresponds to the JSON property mean

Returns:

  • (Float)


35528
35529
35530
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35528

def mean
  @mean
end

#medianFloat

Output only. The median of the values in the population. Corresponds to the JSON property median

Returns:

  • (Float)


35533
35534
35535
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35533

def median
  @median
end

#minFloat

Output only. The minimum of the population values. Corresponds to the JSON property min

Returns:

  • (Float)


35538
35539
35540
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35538

def min
  @min
end

#p5Float

Output only. The 5th percentile of the values in the population. Corresponds to the JSON property p5

Returns:

  • (Float)


35543
35544
35545
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35543

def p5
  @p5
end

#p95Float

Output only. The 95th percentile of the values in the population. Corresponds to the JSON property p95

Returns:

  • (Float)


35548
35549
35550
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35548

def p95
  @p95
end

#sumFixnum

Output only. Sum of a given population of values. Corresponds to the JSON property sum

Returns:

  • (Fixnum)


35553
35554
35555
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35553

def sum
  @sum
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35560
35561
35562
35563
35564
35565
35566
35567
35568
35569
35570
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35560

def update!(**args)
  @billable_sum = args[:billable_sum] if args.key?(:billable_sum)
  @buckets = args[:buckets] if args.key?(:buckets)
  @max = args[:max] if args.key?(:max)
  @mean = args[:mean] if args.key?(:mean)
  @median = args[:median] if args.key?(:median)
  @min = args[:min] if args.key?(:min)
  @p5 = args[:p5] if args.key?(:p5)
  @p95 = args[:p95] if args.key?(:p95)
  @sum = args[:sum] if args.key?(:sum)
end