Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Dataset distribution for Supervised Tuning.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution

Returns a new instance of GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution.



35131
35132
35133
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35131

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#billable_sumFixnum

Output only. Sum of a given population of values that are billable. Corresponds to the JSON property billableSum

Returns:

  • (Fixnum)


35089
35090
35091
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35089

def billable_sum
  @billable_sum
end

#bucketsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistributionDatasetBucket>

Output only. Defines the histogram bucket. Corresponds to the JSON property buckets



35094
35095
35096
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35094

def buckets
  @buckets
end

#maxFloat

Output only. The maximum of the population values. Corresponds to the JSON property max

Returns:

  • (Float)


35099
35100
35101
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35099

def max
  @max
end

#meanFloat

Output only. The arithmetic mean of the values in the population. Corresponds to the JSON property mean

Returns:

  • (Float)


35104
35105
35106
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35104

def mean
  @mean
end

#medianFloat

Output only. The median of the values in the population. Corresponds to the JSON property median

Returns:

  • (Float)


35109
35110
35111
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35109

def median
  @median
end

#minFloat

Output only. The minimum of the population values. Corresponds to the JSON property min

Returns:

  • (Float)


35114
35115
35116
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35114

def min
  @min
end

#p5Float

Output only. The 5th percentile of the values in the population. Corresponds to the JSON property p5

Returns:

  • (Float)


35119
35120
35121
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35119

def p5
  @p5
end

#p95Float

Output only. The 95th percentile of the values in the population. Corresponds to the JSON property p95

Returns:

  • (Float)


35124
35125
35126
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35124

def p95
  @p95
end

#sumFixnum

Output only. Sum of a given population of values. Corresponds to the JSON property sum

Returns:

  • (Fixnum)


35129
35130
35131
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35129

def sum
  @sum
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35136
35137
35138
35139
35140
35141
35142
35143
35144
35145
35146
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35136

def update!(**args)
  @billable_sum = args[:billable_sum] if args.key?(:billable_sum)
  @buckets = args[:buckets] if args.key?(:buckets)
  @max = args[:max] if args.key?(:max)
  @mean = args[:mean] if args.key?(:mean)
  @median = args[:median] if args.key?(:median)
  @min = args[:min] if args.key?(:min)
  @p5 = args[:p5] if args.key?(:p5)
  @p95 = args[:p95] if args.key?(:p95)
  @sum = args[:sum] if args.key?(:sum)
end