Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Dataset distribution for Supervised Tuning.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution

Returns a new instance of GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution.



35032
35033
35034
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35032

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#billable_sumFixnum

Output only. Sum of a given population of values that are billable. Corresponds to the JSON property billableSum

Returns:

  • (Fixnum)


34990
34991
34992
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34990

def billable_sum
  @billable_sum
end

#bucketsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistributionDatasetBucket>

Output only. Defines the histogram bucket. Corresponds to the JSON property buckets



34995
34996
34997
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34995

def buckets
  @buckets
end

#maxFloat

Output only. The maximum of the population values. Corresponds to the JSON property max

Returns:

  • (Float)


35000
35001
35002
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35000

def max
  @max
end

#meanFloat

Output only. The arithmetic mean of the values in the population. Corresponds to the JSON property mean

Returns:

  • (Float)


35005
35006
35007
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35005

def mean
  @mean
end

#medianFloat

Output only. The median of the values in the population. Corresponds to the JSON property median

Returns:

  • (Float)


35010
35011
35012
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35010

def median
  @median
end

#minFloat

Output only. The minimum of the population values. Corresponds to the JSON property min

Returns:

  • (Float)


35015
35016
35017
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35015

def min
  @min
end

#p5Float

Output only. The 5th percentile of the values in the population. Corresponds to the JSON property p5

Returns:

  • (Float)


35020
35021
35022
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35020

def p5
  @p5
end

#p95Float

Output only. The 95th percentile of the values in the population. Corresponds to the JSON property p95

Returns:

  • (Float)


35025
35026
35027
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35025

def p95
  @p95
end

#sumFixnum

Output only. Sum of a given population of values. Corresponds to the JSON property sum

Returns:

  • (Fixnum)


35030
35031
35032
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35030

def sum
  @sum
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35037
35038
35039
35040
35041
35042
35043
35044
35045
35046
35047
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35037

def update!(**args)
  @billable_sum = args[:billable_sum] if args.key?(:billable_sum)
  @buckets = args[:buckets] if args.key?(:buckets)
  @max = args[:max] if args.key?(:max)
  @mean = args[:mean] if args.key?(:mean)
  @median = args[:median] if args.key?(:median)
  @min = args[:min] if args.key?(:min)
  @p5 = args[:p5] if args.key?(:p5)
  @p95 = args[:p95] if args.key?(:p95)
  @sum = args[:sum] if args.key?(:sum)
end