Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Dataset distribution for Supervised Tuning.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution

Returns a new instance of GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution.



35014
35015
35016
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35014

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#billable_sumFixnum

Output only. Sum of a given population of values that are billable. Corresponds to the JSON property billableSum

Returns:

  • (Fixnum)


34972
34973
34974
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34972

def billable_sum
  @billable_sum
end

#bucketsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistributionDatasetBucket>

Output only. Defines the histogram bucket. Corresponds to the JSON property buckets



34977
34978
34979
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34977

def buckets
  @buckets
end

#maxFloat

Output only. The maximum of the population values. Corresponds to the JSON property max

Returns:

  • (Float)


34982
34983
34984
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34982

def max
  @max
end

#meanFloat

Output only. The arithmetic mean of the values in the population. Corresponds to the JSON property mean

Returns:

  • (Float)


34987
34988
34989
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34987

def mean
  @mean
end

#medianFloat

Output only. The median of the values in the population. Corresponds to the JSON property median

Returns:

  • (Float)


34992
34993
34994
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34992

def median
  @median
end

#minFloat

Output only. The minimum of the population values. Corresponds to the JSON property min

Returns:

  • (Float)


34997
34998
34999
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34997

def min
  @min
end

#p5Float

Output only. The 5th percentile of the values in the population. Corresponds to the JSON property p5

Returns:

  • (Float)


35002
35003
35004
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35002

def p5
  @p5
end

#p95Float

Output only. The 95th percentile of the values in the population. Corresponds to the JSON property p95

Returns:

  • (Float)


35007
35008
35009
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35007

def p95
  @p95
end

#sumFixnum

Output only. Sum of a given population of values. Corresponds to the JSON property sum

Returns:

  • (Fixnum)


35012
35013
35014
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35012

def sum
  @sum
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35019
35020
35021
35022
35023
35024
35025
35026
35027
35028
35029
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35019

def update!(**args)
  @billable_sum = args[:billable_sum] if args.key?(:billable_sum)
  @buckets = args[:buckets] if args.key?(:buckets)
  @max = args[:max] if args.key?(:max)
  @mean = args[:mean] if args.key?(:mean)
  @median = args[:median] if args.key?(:median)
  @min = args[:min] if args.key?(:min)
  @p5 = args[:p5] if args.key?(:p5)
  @p95 = args[:p95] if args.key?(:p95)
  @sum = args[:sum] if args.key?(:sum)
end