Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Dataset distribution for Supervised Tuning.
Instance Attribute Summary collapse
-
#billable_sum ⇒ Fixnum
Output only.
-
#buckets ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistributionDatasetBucket>
Output only.
-
#max ⇒ Float
Output only.
-
#mean ⇒ Float
Output only.
-
#median ⇒ Float
Output only.
-
#min ⇒ Float
Output only.
-
#p5 ⇒ Float
Output only.
-
#p95 ⇒ Float
Output only.
-
#sum ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution
constructor
A new instance of GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution
Returns a new instance of GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution.
34949 34950 34951 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34949 def initialize(**args) update!(**args) end |
Instance Attribute Details
#billable_sum ⇒ Fixnum
Output only. Sum of a given population of values that are billable.
Corresponds to the JSON property billableSum
34907 34908 34909 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34907 def billable_sum @billable_sum end |
#buckets ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistributionDatasetBucket>
Output only. Defines the histogram bucket.
Corresponds to the JSON property buckets
34912 34913 34914 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34912 def buckets @buckets end |
#max ⇒ Float
Output only. The maximum of the population values.
Corresponds to the JSON property max
34917 34918 34919 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34917 def max @max end |
#mean ⇒ Float
Output only. The arithmetic mean of the values in the population.
Corresponds to the JSON property mean
34922 34923 34924 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34922 def mean @mean end |
#median ⇒ Float
Output only. The median of the values in the population.
Corresponds to the JSON property median
34927 34928 34929 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34927 def median @median end |
#min ⇒ Float
Output only. The minimum of the population values.
Corresponds to the JSON property min
34932 34933 34934 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34932 def min @min end |
#p5 ⇒ Float
Output only. The 5th percentile of the values in the population.
Corresponds to the JSON property p5
34937 34938 34939 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34937 def p5 @p5 end |
#p95 ⇒ Float
Output only. The 95th percentile of the values in the population.
Corresponds to the JSON property p95
34942 34943 34944 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34942 def p95 @p95 end |
#sum ⇒ Fixnum
Output only. Sum of a given population of values.
Corresponds to the JSON property sum
34947 34948 34949 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34947 def sum @sum end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34954 34955 34956 34957 34958 34959 34960 34961 34962 34963 34964 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34954 def update!(**args) @billable_sum = args[:billable_sum] if args.key?(:billable_sum) @buckets = args[:buckets] if args.key?(:buckets) @max = args[:max] if args.key?(:max) @mean = args[:mean] if args.key?(:mean) @median = args[:median] if args.key?(:median) @min = args[:min] if args.key?(:min) @p5 = args[:p5] if args.key?(:p5) @p95 = args[:p95] if args.key?(:p95) @sum = args[:sum] if args.key?(:sum) end |