Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Dataset distribution for Supervised Tuning.
Instance Attribute Summary collapse
-
#billable_sum ⇒ Fixnum
Output only.
-
#buckets ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistributionDatasetBucket>
Output only.
-
#max ⇒ Float
Output only.
-
#mean ⇒ Float
Output only.
-
#median ⇒ Float
Output only.
-
#min ⇒ Float
Output only.
-
#p5 ⇒ Float
Output only.
-
#p95 ⇒ Float
Output only.
-
#sum ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution
constructor
A new instance of GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution
Returns a new instance of GoogleCloudAiplatformV1SupervisedTuningDatasetDistribution.
34725 34726 34727 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34725 def initialize(**args) update!(**args) end |
Instance Attribute Details
#billable_sum ⇒ Fixnum
Output only. Sum of a given population of values that are billable.
Corresponds to the JSON property billableSum
34683 34684 34685 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34683 def billable_sum @billable_sum end |
#buckets ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningDatasetDistributionDatasetBucket>
Output only. Defines the histogram bucket.
Corresponds to the JSON property buckets
34688 34689 34690 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34688 def buckets @buckets end |
#max ⇒ Float
Output only. The maximum of the population values.
Corresponds to the JSON property max
34693 34694 34695 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34693 def max @max end |
#mean ⇒ Float
Output only. The arithmetic mean of the values in the population.
Corresponds to the JSON property mean
34698 34699 34700 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34698 def mean @mean end |
#median ⇒ Float
Output only. The median of the values in the population.
Corresponds to the JSON property median
34703 34704 34705 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34703 def median @median end |
#min ⇒ Float
Output only. The minimum of the population values.
Corresponds to the JSON property min
34708 34709 34710 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34708 def min @min end |
#p5 ⇒ Float
Output only. The 5th percentile of the values in the population.
Corresponds to the JSON property p5
34713 34714 34715 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34713 def p5 @p5 end |
#p95 ⇒ Float
Output only. The 95th percentile of the values in the population.
Corresponds to the JSON property p95
34718 34719 34720 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34718 def p95 @p95 end |
#sum ⇒ Fixnum
Output only. Sum of a given population of values.
Corresponds to the JSON property sum
34723 34724 34725 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34723 def sum @sum end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34730 34731 34732 34733 34734 34735 34736 34737 34738 34739 34740 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34730 def update!(**args) @billable_sum = args[:billable_sum] if args.key?(:billable_sum) @buckets = args[:buckets] if args.key?(:buckets) @max = args[:max] if args.key?(:max) @mean = args[:mean] if args.key?(:mean) @median = args[:median] if args.key?(:median) @min = args[:min] if args.key?(:min) @p5 = args[:p5] if args.key?(:p5) @p95 = args[:p95] if args.key?(:p95) @sum = args[:sum] if args.key?(:sum) end |