Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Tuning Spec for Supervised Tuning for first party models.
Instance Attribute Summary collapse
-
#export_last_checkpoint_only ⇒ Boolean
(also: #export_last_checkpoint_only?)
Optional.
-
#hyper_parameters ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedHyperParameters
Hyperparameters for SFT.
-
#training_dataset_uri ⇒ String
Required.
-
#validation_dataset_uri ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SupervisedTuningSpec
constructor
A new instance of GoogleCloudAiplatformV1SupervisedTuningSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SupervisedTuningSpec
Returns a new instance of GoogleCloudAiplatformV1SupervisedTuningSpec.
43081 43082 43083 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 43081 def initialize(**args) update!(**args) end |
Instance Attribute Details
#export_last_checkpoint_only ⇒ Boolean Also known as: export_last_checkpoint_only?
Optional. If set to true, disable intermediate checkpoints for SFT and only
the last checkpoint will be exported. Otherwise, enable intermediate
checkpoints for SFT. Default is false.
Corresponds to the JSON property exportLastCheckpointOnly
43059 43060 43061 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 43059 def export_last_checkpoint_only @export_last_checkpoint_only end |
#hyper_parameters ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedHyperParameters
Hyperparameters for SFT.
Corresponds to the JSON property hyperParameters
43065 43066 43067 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 43065 def hyper_parameters @hyper_parameters end |
#training_dataset_uri ⇒ String
Required. Training dataset used for tuning. The dataset can be specified as
either a Cloud Storage path to a JSONL file or as the resource name of a
Vertex Multimodal Dataset.
Corresponds to the JSON property trainingDatasetUri
43072 43073 43074 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 43072 def training_dataset_uri @training_dataset_uri end |
#validation_dataset_uri ⇒ String
Optional. Validation dataset used for tuning. The dataset can be specified as
either a Cloud Storage path to a JSONL file or as the resource name of a
Vertex Multimodal Dataset.
Corresponds to the JSON property validationDatasetUri
43079 43080 43081 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 43079 def validation_dataset_uri @validation_dataset_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
43086 43087 43088 43089 43090 43091 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 43086 def update!(**args) @export_last_checkpoint_only = args[:export_last_checkpoint_only] if args.key?(:export_last_checkpoint_only) @hyper_parameters = args[:hyper_parameters] if args.key?(:hyper_parameters) @training_dataset_uri = args[:training_dataset_uri] if args.key?(:training_dataset_uri) @validation_dataset_uri = args[:validation_dataset_uri] if args.key?(:validation_dataset_uri) end |