Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Tuning Spec for Supervised Tuning for first party models.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SupervisedTuningSpec

Returns a new instance of GoogleCloudAiplatformV1SupervisedTuningSpec.



36844
36845
36846
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36844

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#export_last_checkpoint_onlyBoolean Also known as: export_last_checkpoint_only?

Optional. If set to true, disable intermediate checkpoints for SFT and only the last checkpoint will be exported. Otherwise, enable intermediate checkpoints for SFT. Default is false. Corresponds to the JSON property exportLastCheckpointOnly

Returns:

  • (Boolean)


36822
36823
36824
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36822

def export_last_checkpoint_only
  @export_last_checkpoint_only
end

#hyper_parametersGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedHyperParameters

Hyperparameters for SFT. Corresponds to the JSON property hyperParameters



36828
36829
36830
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36828

def hyper_parameters
  @hyper_parameters
end

#training_dataset_uriString

Required. Training dataset used for tuning. The dataset can be specified as either a Cloud Storage path to a JSONL file or as the resource name of a Vertex Multimodal Dataset. Corresponds to the JSON property trainingDatasetUri

Returns:

  • (String)


36835
36836
36837
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36835

def training_dataset_uri
  @training_dataset_uri
end

#validation_dataset_uriString

Optional. Validation dataset used for tuning. The dataset can be specified as either a Cloud Storage path to a JSONL file or as the resource name of a Vertex Multimodal Dataset. Corresponds to the JSON property validationDatasetUri

Returns:

  • (String)


36842
36843
36844
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36842

def validation_dataset_uri
  @validation_dataset_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36849
36850
36851
36852
36853
36854
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36849

def update!(**args)
  @export_last_checkpoint_only = args[:export_last_checkpoint_only] if args.key?(:export_last_checkpoint_only)
  @hyper_parameters = args[:hyper_parameters] if args.key?(:hyper_parameters)
  @training_dataset_uri = args[:training_dataset_uri] if args.key?(:training_dataset_uri)
  @validation_dataset_uri = args[:validation_dataset_uri] if args.key?(:validation_dataset_uri)
end