Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Tuning Spec for Supervised Tuning for first party models.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SupervisedTuningSpec

Returns a new instance of GoogleCloudAiplatformV1SupervisedTuningSpec.



36773
36774
36775
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36773

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#export_last_checkpoint_onlyBoolean Also known as: export_last_checkpoint_only?

Optional. If set to true, disable intermediate checkpoints for SFT and only the last checkpoint will be exported. Otherwise, enable intermediate checkpoints for SFT. Default is false. Corresponds to the JSON property exportLastCheckpointOnly

Returns:

  • (Boolean)


36751
36752
36753
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36751

def export_last_checkpoint_only
  @export_last_checkpoint_only
end

#hyper_parametersGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedHyperParameters

Hyperparameters for SFT. Corresponds to the JSON property hyperParameters



36757
36758
36759
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36757

def hyper_parameters
  @hyper_parameters
end

#training_dataset_uriString

Required. Training dataset used for tuning. The dataset can be specified as either a Cloud Storage path to a JSONL file or as the resource name of a Vertex Multimodal Dataset. Corresponds to the JSON property trainingDatasetUri

Returns:

  • (String)


36764
36765
36766
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36764

def training_dataset_uri
  @training_dataset_uri
end

#validation_dataset_uriString

Optional. Validation dataset used for tuning. The dataset can be specified as either a Cloud Storage path to a JSONL file or as the resource name of a Vertex Multimodal Dataset. Corresponds to the JSON property validationDatasetUri

Returns:

  • (String)


36771
36772
36773
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36771

def validation_dataset_uri
  @validation_dataset_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36778
36779
36780
36781
36782
36783
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36778

def update!(**args)
  @export_last_checkpoint_only = args[:export_last_checkpoint_only] if args.key?(:export_last_checkpoint_only)
  @hyper_parameters = args[:hyper_parameters] if args.key?(:hyper_parameters)
  @training_dataset_uri = args[:training_dataset_uri] if args.key?(:training_dataset_uri)
  @validation_dataset_uri = args[:validation_dataset_uri] if args.key?(:validation_dataset_uri)
end