Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Tuning Spec for Supervised Tuning for first party models.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SupervisedTuningSpec

Returns a new instance of GoogleCloudAiplatformV1SupervisedTuningSpec.



35702
35703
35704
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35702

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#export_last_checkpoint_onlyBoolean Also known as: export_last_checkpoint_only?

Optional. If set to true, disable intermediate checkpoints for SFT and only the last checkpoint will be exported. Otherwise, enable intermediate checkpoints for SFT. Default is false. Corresponds to the JSON property exportLastCheckpointOnly

Returns:

  • (Boolean)


35682
35683
35684
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35682

def export_last_checkpoint_only
  @export_last_checkpoint_only
end

#hyper_parametersGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedHyperParameters

Hyperparameters for SFT. Corresponds to the JSON property hyperParameters



35688
35689
35690
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35688

def hyper_parameters
  @hyper_parameters
end

#training_dataset_uriString

Required. Cloud Storage path to file containing training dataset for tuning. The dataset must be formatted as a JSONL file. Corresponds to the JSON property trainingDatasetUri

Returns:

  • (String)


35694
35695
35696
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35694

def training_dataset_uri
  @training_dataset_uri
end

#validation_dataset_uriString

Optional. Cloud Storage path to file containing validation dataset for tuning. The dataset must be formatted as a JSONL file. Corresponds to the JSON property validationDatasetUri

Returns:

  • (String)


35700
35701
35702
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35700

def validation_dataset_uri
  @validation_dataset_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35707
35708
35709
35710
35711
35712
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35707

def update!(**args)
  @export_last_checkpoint_only = args[:export_last_checkpoint_only] if args.key?(:export_last_checkpoint_only)
  @hyper_parameters = args[:hyper_parameters] if args.key?(:hyper_parameters)
  @training_dataset_uri = args[:training_dataset_uri] if args.key?(:training_dataset_uri)
  @validation_dataset_uri = args[:validation_dataset_uri] if args.key?(:validation_dataset_uri)
end