Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SyntheticExample

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A single instance of generated synthetic data. Each example is made up of one or more named fields, as defined in OutputFieldSpec. These examples are used as few-shot examples to show the model what you want (in GenerateSyntheticDataRequest.examples) and to return generated examples in the response (in GenerateSyntheticDataResponse.synthetic_examples).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SyntheticExample

Returns a new instance of GoogleCloudAiplatformV1SyntheticExample.



44895
44896
44897
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44895

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fieldsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SyntheticField>

Required. A list of fields that constitute an example. Corresponds to the JSON property fields



44893
44894
44895
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44893

def fields
  @fields
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44900
44901
44902
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44900

def update!(**args)
  @fields = args[:fields] if args.key?(:fields)
end