Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SyntheticExample

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents a single synthetic example, composed of multiple fields. Used for providing few-shot examples in the request and for returning generated examples in the response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SyntheticExample

Returns a new instance of GoogleCloudAiplatformV1SyntheticExample.



43139
43140
43141
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 43139

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fieldsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SyntheticField>

Required. A list of fields that constitute an example. Corresponds to the JSON property fields



43137
43138
43139
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 43137

def fields
  @fields
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43144
43145
43146
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 43144

def update!(**args)
  @fields = args[:fields] if args.key?(:fields)
end