Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SyntheticExample
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SyntheticExample
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Represents a single synthetic example, composed of multiple fields. Used for providing few-shot examples in the request and for returning generated examples in the response.
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1SyntheticExample
constructor
A new instance of GoogleCloudAiplatformV1SyntheticExample.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1SyntheticExample
Returns a new instance of GoogleCloudAiplatformV1SyntheticExample.
42855 42856 42857 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42855 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fields ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SyntheticField>
Required. A list of fields that constitute an example.
Corresponds to the JSON property fields
42853 42854 42855 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42853 def fields @fields end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42860 42861 42862 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42860 def update!(**args) @fields = args[:fields] if args.key?(:fields) end |