Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SyntheticField

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents a single named field within a synthetic example, consisting of a name and the actual content.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SyntheticField

Returns a new instance of GoogleCloudAiplatformV1SyntheticField.



44995
44996
44997
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44995

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Content

The structured data content of a message. A Content message contains a role field, which indicates the producer of the content, and a parts field, which contains the multi-part data of the message. Corresponds to the JSON property content



44987
44988
44989
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44987

def content
  @content
end

#field_nameString

Optional. The name of the specific field, such as "product_name" or " review_text". Corresponds to the JSON property fieldName

Returns:

  • (String)


44993
44994
44995
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44993

def field_name
  @field_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45000
45001
45002
45003
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45000

def update!(**args)
  @content = args[:content] if args.key?(:content)
  @field_name = args[:field_name] if args.key?(:field_name)
end