Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SyntheticField

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents a single named field within a SyntheticExample.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SyntheticField

Returns a new instance of GoogleCloudAiplatformV1SyntheticField.



43165
43166
43167
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 43165

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Content

The structured data content of a message. A Content message contains a role field, which indicates the producer of the content, and a parts field, which contains the multi-part data of the message. Corresponds to the JSON property content



43158
43159
43160
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 43158

def content
  @content
end

#field_nameString

Optional. The name of the field. Corresponds to the JSON property fieldName

Returns:

  • (String)


43163
43164
43165
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 43163

def field_name
  @field_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43170
43171
43172
43173
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 43170

def update!(**args)
  @content = args[:content] if args.key?(:content)
  @field_name = args[:field_name] if args.key?(:field_name)
end