Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SyntheticField

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents a single named field within a SyntheticExample.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1SyntheticField

Returns a new instance of GoogleCloudAiplatformV1SyntheticField.



42881
42882
42883
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42881

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Content

The structured data content of a message. A Content message contains a role field, which indicates the producer of the content, and a parts field, which contains the multi-part data of the message. Corresponds to the JSON property content



42874
42875
42876
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42874

def content
  @content
end

#field_nameString

Optional. The name of the field. Corresponds to the JSON property fieldName

Returns:

  • (String)


42879
42880
42881
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42879

def field_name
  @field_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42886
42887
42888
42889
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 42886

def update!(**args)
  @content = args[:content] if args.key?(:content)
  @field_name = args[:field_name] if args.key?(:field_name)
end