Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TaskDescriptionStrategy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Defines a generation strategy based on a general task description.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1TaskDescriptionStrategy

Returns a new instance of GoogleCloudAiplatformV1TaskDescriptionStrategy.



44963
44964
44965
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44963

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#task_descriptionString

Required. A general description of the type of synthetic data you want to generate. For example, "Generate customer reviews for a new smartphone." Corresponds to the JSON property taskDescription

Returns:

  • (String)


44961
44962
44963
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44961

def task_description
  @task_description
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44968
44969
44970
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44968

def update!(**args)
  @task_description = args[:task_description] if args.key?(:task_description)
end