Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tensor
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tensor
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A tensor value type.
Instance Attribute Summary collapse
-
#bool_val ⇒ Array<Boolean>
Type specific representations that make it easy to create tensor protos in all languages.
-
#bytes_val ⇒ Array<String>
STRING Corresponds to the JSON property
bytesVal. -
#double_val ⇒ Array<Float>
DOUBLE Corresponds to the JSON property
doubleVal. -
#dtype ⇒ String
The data type of tensor.
-
#float_val ⇒ Array<Float>
FLOAT Corresponds to the JSON property
floatVal. -
#int64_val ⇒ Array<Fixnum>
INT64 Corresponds to the JSON property
int64Val. -
#int_val ⇒ Array<Fixnum>
INT_8 INT_16 INT_32 Corresponds to the JSON property
intVal. -
#list_val ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tensor>
A list of tensor values.
-
#shape ⇒ Array<Fixnum>
Shape of the tensor.
-
#string_val ⇒ Array<String>
STRING Corresponds to the JSON property
stringVal. -
#struct_val ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tensor>
A map of string to tensor.
-
#tensor_val ⇒ String
Serialized raw tensor content.
-
#uint64_val ⇒ Array<Fixnum>
UINT64 Corresponds to the JSON property
uint64Val. -
#uint_val ⇒ Array<Fixnum>
UINT8 UINT16 UINT32 Corresponds to the JSON property
uintVal.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Tensor
constructor
A new instance of GoogleCloudAiplatformV1Tensor.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Tensor
Returns a new instance of GoogleCloudAiplatformV1Tensor.
47855 47856 47857 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47855 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bool_val ⇒ Array<Boolean>
Type specific representations that make it easy to create tensor protos in all
languages. Only the representation corresponding to "dtype" can be set. The
values hold the flattened representation of the tensor in row major order.
BOOL
Corresponds to the JSON property boolVal
47787 47788 47789 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47787 def bool_val @bool_val end |
#bytes_val ⇒ Array<String>
STRING
Corresponds to the JSON property bytesVal
47792 47793 47794 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47792 def bytes_val @bytes_val end |
#double_val ⇒ Array<Float>
DOUBLE
Corresponds to the JSON property doubleVal
47797 47798 47799 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47797 def double_val @double_val end |
#dtype ⇒ String
The data type of tensor.
Corresponds to the JSON property dtype
47802 47803 47804 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47802 def dtype @dtype end |
#float_val ⇒ Array<Float>
FLOAT
Corresponds to the JSON property floatVal
47807 47808 47809 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47807 def float_val @float_val end |
#int64_val ⇒ Array<Fixnum>
INT64
Corresponds to the JSON property int64Val
47812 47813 47814 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47812 def int64_val @int64_val end |
#int_val ⇒ Array<Fixnum>
INT_8 INT_16 INT_32
Corresponds to the JSON property intVal
47817 47818 47819 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47817 def int_val @int_val end |
#list_val ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tensor>
A list of tensor values.
Corresponds to the JSON property listVal
47822 47823 47824 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47822 def list_val @list_val end |
#shape ⇒ Array<Fixnum>
Shape of the tensor.
Corresponds to the JSON property shape
47827 47828 47829 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47827 def shape @shape end |
#string_val ⇒ Array<String>
STRING
Corresponds to the JSON property stringVal
47832 47833 47834 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47832 def string_val @string_val end |
#struct_val ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tensor>
A map of string to tensor.
Corresponds to the JSON property structVal
47837 47838 47839 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47837 def struct_val @struct_val end |
#tensor_val ⇒ String
Serialized raw tensor content.
Corresponds to the JSON property tensorVal
NOTE: Values are automatically base64 encoded/decoded in the client library.
47843 47844 47845 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47843 def tensor_val @tensor_val end |
#uint64_val ⇒ Array<Fixnum>
UINT64
Corresponds to the JSON property uint64Val
47848 47849 47850 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47848 def uint64_val @uint64_val end |
#uint_val ⇒ Array<Fixnum>
UINT8 UINT16 UINT32
Corresponds to the JSON property uintVal
47853 47854 47855 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47853 def uint_val @uint_val end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47860 47861 47862 47863 47864 47865 47866 47867 47868 47869 47870 47871 47872 47873 47874 47875 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47860 def update!(**args) @bool_val = args[:bool_val] if args.key?(:bool_val) @bytes_val = args[:bytes_val] if args.key?(:bytes_val) @double_val = args[:double_val] if args.key?(:double_val) @dtype = args[:dtype] if args.key?(:dtype) @float_val = args[:float_val] if args.key?(:float_val) @int64_val = args[:int64_val] if args.key?(:int64_val) @int_val = args[:int_val] if args.key?(:int_val) @list_val = args[:list_val] if args.key?(:list_val) @shape = args[:shape] if args.key?(:shape) @string_val = args[:string_val] if args.key?(:string_val) @struct_val = args[:struct_val] if args.key?(:struct_val) @tensor_val = args[:tensor_val] if args.key?(:tensor_val) @uint64_val = args[:uint64_val] if args.key?(:uint64_val) @uint_val = args[:uint_val] if args.key?(:uint_val) end |