Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tensor

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A tensor value type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Tensor

Returns a new instance of GoogleCloudAiplatformV1Tensor.



47273
47274
47275
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47273

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bool_valArray<Boolean>

Type specific representations that make it easy to create tensor protos in all languages. Only the representation corresponding to "dtype" can be set. The values hold the flattened representation of the tensor in row major order. BOOL Corresponds to the JSON property boolVal

Returns:

  • (Array<Boolean>)


47205
47206
47207
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47205

def bool_val
  @bool_val
end

#bytes_valArray<String>

STRING Corresponds to the JSON property bytesVal

Returns:

  • (Array<String>)


47210
47211
47212
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47210

def bytes_val
  @bytes_val
end

#double_valArray<Float>

DOUBLE Corresponds to the JSON property doubleVal

Returns:

  • (Array<Float>)


47215
47216
47217
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47215

def double_val
  @double_val
end

#dtypeString

The data type of tensor. Corresponds to the JSON property dtype

Returns:

  • (String)


47220
47221
47222
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47220

def dtype
  @dtype
end

#float_valArray<Float>

FLOAT Corresponds to the JSON property floatVal

Returns:

  • (Array<Float>)


47225
47226
47227
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47225

def float_val
  @float_val
end

#int64_valArray<Fixnum>

INT64 Corresponds to the JSON property int64Val

Returns:

  • (Array<Fixnum>)


47230
47231
47232
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47230

def int64_val
  @int64_val
end

#int_valArray<Fixnum>

INT_8 INT_16 INT_32 Corresponds to the JSON property intVal

Returns:

  • (Array<Fixnum>)


47235
47236
47237
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47235

def int_val
  @int_val
end

#list_valArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tensor>

A list of tensor values. Corresponds to the JSON property listVal



47240
47241
47242
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47240

def list_val
  @list_val
end

#shapeArray<Fixnum>

Shape of the tensor. Corresponds to the JSON property shape

Returns:

  • (Array<Fixnum>)


47245
47246
47247
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47245

def shape
  @shape
end

#string_valArray<String>

STRING Corresponds to the JSON property stringVal

Returns:

  • (Array<String>)


47250
47251
47252
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47250

def string_val
  @string_val
end

#struct_valHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tensor>

A map of string to tensor. Corresponds to the JSON property structVal



47255
47256
47257
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47255

def struct_val
  @struct_val
end

#tensor_valString

Serialized raw tensor content. Corresponds to the JSON property tensorVal NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


47261
47262
47263
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47261

def tensor_val
  @tensor_val
end

#uint64_valArray<Fixnum>

UINT64 Corresponds to the JSON property uint64Val

Returns:

  • (Array<Fixnum>)


47266
47267
47268
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47266

def uint64_val
  @uint64_val
end

#uint_valArray<Fixnum>

UINT8 UINT16 UINT32 Corresponds to the JSON property uintVal

Returns:

  • (Array<Fixnum>)


47271
47272
47273
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47271

def uint_val
  @uint_val
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47278
47279
47280
47281
47282
47283
47284
47285
47286
47287
47288
47289
47290
47291
47292
47293
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47278

def update!(**args)
  @bool_val = args[:bool_val] if args.key?(:bool_val)
  @bytes_val = args[:bytes_val] if args.key?(:bytes_val)
  @double_val = args[:double_val] if args.key?(:double_val)
  @dtype = args[:dtype] if args.key?(:dtype)
  @float_val = args[:float_val] if args.key?(:float_val)
  @int64_val = args[:int64_val] if args.key?(:int64_val)
  @int_val = args[:int_val] if args.key?(:int_val)
  @list_val = args[:list_val] if args.key?(:list_val)
  @shape = args[:shape] if args.key?(:shape)
  @string_val = args[:string_val] if args.key?(:string_val)
  @struct_val = args[:struct_val] if args.key?(:struct_val)
  @tensor_val = args[:tensor_val] if args.key?(:tensor_val)
  @uint64_val = args[:uint64_val] if args.key?(:uint64_val)
  @uint_val = args[:uint_val] if args.key?(:uint_val)
end