Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tensor

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A tensor value type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Tensor

Returns a new instance of GoogleCloudAiplatformV1Tensor.



43292
43293
43294
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 43292

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bool_valArray<Boolean>

Type specific representations that make it easy to create tensor protos in all languages. Only the representation corresponding to "dtype" can be set. The values hold the flattened representation of the tensor in row major order. BOOL Corresponds to the JSON property boolVal

Returns:

  • (Array<Boolean>)


43224
43225
43226
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 43224

def bool_val
  @bool_val
end

#bytes_valArray<String>

STRING Corresponds to the JSON property bytesVal

Returns:

  • (Array<String>)


43229
43230
43231
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 43229

def bytes_val
  @bytes_val
end

#double_valArray<Float>

DOUBLE Corresponds to the JSON property doubleVal

Returns:

  • (Array<Float>)


43234
43235
43236
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 43234

def double_val
  @double_val
end

#dtypeString

The data type of tensor. Corresponds to the JSON property dtype

Returns:

  • (String)


43239
43240
43241
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 43239

def dtype
  @dtype
end

#float_valArray<Float>

FLOAT Corresponds to the JSON property floatVal

Returns:

  • (Array<Float>)


43244
43245
43246
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 43244

def float_val
  @float_val
end

#int64_valArray<Fixnum>

INT64 Corresponds to the JSON property int64Val

Returns:

  • (Array<Fixnum>)


43249
43250
43251
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 43249

def int64_val
  @int64_val
end

#int_valArray<Fixnum>

INT_8 INT_16 INT_32 Corresponds to the JSON property intVal

Returns:

  • (Array<Fixnum>)


43254
43255
43256
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 43254

def int_val
  @int_val
end

#list_valArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tensor>

A list of tensor values. Corresponds to the JSON property listVal



43259
43260
43261
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 43259

def list_val
  @list_val
end

#shapeArray<Fixnum>

Shape of the tensor. Corresponds to the JSON property shape

Returns:

  • (Array<Fixnum>)


43264
43265
43266
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 43264

def shape
  @shape
end

#string_valArray<String>

STRING Corresponds to the JSON property stringVal

Returns:

  • (Array<String>)


43269
43270
43271
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 43269

def string_val
  @string_val
end

#struct_valHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tensor>

A map of string to tensor. Corresponds to the JSON property structVal



43274
43275
43276
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 43274

def struct_val
  @struct_val
end

#tensor_valString

Serialized raw tensor content. Corresponds to the JSON property tensorVal NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


43280
43281
43282
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 43280

def tensor_val
  @tensor_val
end

#uint64_valArray<Fixnum>

UINT64 Corresponds to the JSON property uint64Val

Returns:

  • (Array<Fixnum>)


43285
43286
43287
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 43285

def uint64_val
  @uint64_val
end

#uint_valArray<Fixnum>

UINT8 UINT16 UINT32 Corresponds to the JSON property uintVal

Returns:

  • (Array<Fixnum>)


43290
43291
43292
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 43290

def uint_val
  @uint_val
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43297
43298
43299
43300
43301
43302
43303
43304
43305
43306
43307
43308
43309
43310
43311
43312
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 43297

def update!(**args)
  @bool_val = args[:bool_val] if args.key?(:bool_val)
  @bytes_val = args[:bytes_val] if args.key?(:bytes_val)
  @double_val = args[:double_val] if args.key?(:double_val)
  @dtype = args[:dtype] if args.key?(:dtype)
  @float_val = args[:float_val] if args.key?(:float_val)
  @int64_val = args[:int64_val] if args.key?(:int64_val)
  @int_val = args[:int_val] if args.key?(:int_val)
  @list_val = args[:list_val] if args.key?(:list_val)
  @shape = args[:shape] if args.key?(:shape)
  @string_val = args[:string_val] if args.key?(:string_val)
  @struct_val = args[:struct_val] if args.key?(:struct_val)
  @tensor_val = args[:tensor_val] if args.key?(:tensor_val)
  @uint64_val = args[:uint64_val] if args.key?(:uint64_val)
  @uint_val = args[:uint_val] if args.key?(:uint_val)
end