Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tensor
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tensor
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A tensor value type.
Instance Attribute Summary collapse
-
#bool_val ⇒ Array<Boolean>
Type specific representations that make it easy to create tensor protos in all languages.
-
#bytes_val ⇒ Array<String>
STRING Corresponds to the JSON property
bytesVal. -
#double_val ⇒ Array<Float>
DOUBLE Corresponds to the JSON property
doubleVal. -
#dtype ⇒ String
The data type of tensor.
-
#float_val ⇒ Array<Float>
FLOAT Corresponds to the JSON property
floatVal. -
#int64_val ⇒ Array<Fixnum>
INT64 Corresponds to the JSON property
int64Val. -
#int_val ⇒ Array<Fixnum>
INT_8 INT_16 INT_32 Corresponds to the JSON property
intVal. -
#list_val ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tensor>
A list of tensor values.
-
#shape ⇒ Array<Fixnum>
Shape of the tensor.
-
#string_val ⇒ Array<String>
STRING Corresponds to the JSON property
stringVal. -
#struct_val ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tensor>
A map of string to tensor.
-
#tensor_val ⇒ String
Serialized raw tensor content.
-
#uint64_val ⇒ Array<Fixnum>
UINT64 Corresponds to the JSON property
uint64Val. -
#uint_val ⇒ Array<Fixnum>
UINT8 UINT16 UINT32 Corresponds to the JSON property
uintVal.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Tensor
constructor
A new instance of GoogleCloudAiplatformV1Tensor.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Tensor
Returns a new instance of GoogleCloudAiplatformV1Tensor.
37359 37360 37361 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37359 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bool_val ⇒ Array<Boolean>
Type specific representations that make it easy to create tensor protos in all
languages. Only the representation corresponding to "dtype" can be set. The
values hold the flattened representation of the tensor in row major order.
BOOL
Corresponds to the JSON property boolVal
37291 37292 37293 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37291 def bool_val @bool_val end |
#bytes_val ⇒ Array<String>
STRING
Corresponds to the JSON property bytesVal
37296 37297 37298 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37296 def bytes_val @bytes_val end |
#double_val ⇒ Array<Float>
DOUBLE
Corresponds to the JSON property doubleVal
37301 37302 37303 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37301 def double_val @double_val end |
#dtype ⇒ String
The data type of tensor.
Corresponds to the JSON property dtype
37306 37307 37308 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37306 def dtype @dtype end |
#float_val ⇒ Array<Float>
FLOAT
Corresponds to the JSON property floatVal
37311 37312 37313 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37311 def float_val @float_val end |
#int64_val ⇒ Array<Fixnum>
INT64
Corresponds to the JSON property int64Val
37316 37317 37318 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37316 def int64_val @int64_val end |
#int_val ⇒ Array<Fixnum>
INT_8 INT_16 INT_32
Corresponds to the JSON property intVal
37321 37322 37323 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37321 def int_val @int_val end |
#list_val ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tensor>
A list of tensor values.
Corresponds to the JSON property listVal
37326 37327 37328 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37326 def list_val @list_val end |
#shape ⇒ Array<Fixnum>
Shape of the tensor.
Corresponds to the JSON property shape
37331 37332 37333 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37331 def shape @shape end |
#string_val ⇒ Array<String>
STRING
Corresponds to the JSON property stringVal
37336 37337 37338 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37336 def string_val @string_val end |
#struct_val ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tensor>
A map of string to tensor.
Corresponds to the JSON property structVal
37341 37342 37343 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37341 def struct_val @struct_val end |
#tensor_val ⇒ String
Serialized raw tensor content.
Corresponds to the JSON property tensorVal
NOTE: Values are automatically base64 encoded/decoded in the client library.
37347 37348 37349 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37347 def tensor_val @tensor_val end |
#uint64_val ⇒ Array<Fixnum>
UINT64
Corresponds to the JSON property uint64Val
37352 37353 37354 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37352 def uint64_val @uint64_val end |
#uint_val ⇒ Array<Fixnum>
UINT8 UINT16 UINT32
Corresponds to the JSON property uintVal
37357 37358 37359 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37357 def uint_val @uint_val end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37364 37365 37366 37367 37368 37369 37370 37371 37372 37373 37374 37375 37376 37377 37378 37379 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37364 def update!(**args) @bool_val = args[:bool_val] if args.key?(:bool_val) @bytes_val = args[:bytes_val] if args.key?(:bytes_val) @double_val = args[:double_val] if args.key?(:double_val) @dtype = args[:dtype] if args.key?(:dtype) @float_val = args[:float_val] if args.key?(:float_val) @int64_val = args[:int64_val] if args.key?(:int64_val) @int_val = args[:int_val] if args.key?(:int_val) @list_val = args[:list_val] if args.key?(:list_val) @shape = args[:shape] if args.key?(:shape) @string_val = args[:string_val] if args.key?(:string_val) @struct_val = args[:struct_val] if args.key?(:struct_val) @tensor_val = args[:tensor_val] if args.key?(:tensor_val) @uint64_val = args[:uint64_val] if args.key?(:uint64_val) @uint_val = args[:uint_val] if args.key?(:uint_val) end |