Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tensor

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A tensor value type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Tensor

Returns a new instance of GoogleCloudAiplatformV1Tensor.



35345
35346
35347
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35345

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bool_valArray<Boolean>

Type specific representations that make it easy to create tensor protos in all languages. Only the representation corresponding to "dtype" can be set. The values hold the flattened representation of the tensor in row major order. BOOL Corresponds to the JSON property boolVal

Returns:

  • (Array<Boolean>)


35277
35278
35279
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35277

def bool_val
  @bool_val
end

#bytes_valArray<String>

STRING Corresponds to the JSON property bytesVal

Returns:

  • (Array<String>)


35282
35283
35284
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35282

def bytes_val
  @bytes_val
end

#double_valArray<Float>

DOUBLE Corresponds to the JSON property doubleVal

Returns:

  • (Array<Float>)


35287
35288
35289
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35287

def double_val
  @double_val
end

#dtypeString

The data type of tensor. Corresponds to the JSON property dtype

Returns:

  • (String)


35292
35293
35294
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35292

def dtype
  @dtype
end

#float_valArray<Float>

FLOAT Corresponds to the JSON property floatVal

Returns:

  • (Array<Float>)


35297
35298
35299
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35297

def float_val
  @float_val
end

#int64_valArray<Fixnum>

INT64 Corresponds to the JSON property int64Val

Returns:

  • (Array<Fixnum>)


35302
35303
35304
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35302

def int64_val
  @int64_val
end

#int_valArray<Fixnum>

INT_8 INT_16 INT_32 Corresponds to the JSON property intVal

Returns:

  • (Array<Fixnum>)


35307
35308
35309
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35307

def int_val
  @int_val
end

#list_valArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tensor>

A list of tensor values. Corresponds to the JSON property listVal



35312
35313
35314
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35312

def list_val
  @list_val
end

#shapeArray<Fixnum>

Shape of the tensor. Corresponds to the JSON property shape

Returns:

  • (Array<Fixnum>)


35317
35318
35319
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35317

def shape
  @shape
end

#string_valArray<String>

STRING Corresponds to the JSON property stringVal

Returns:

  • (Array<String>)


35322
35323
35324
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35322

def string_val
  @string_val
end

#struct_valHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tensor>

A map of string to tensor. Corresponds to the JSON property structVal



35327
35328
35329
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35327

def struct_val
  @struct_val
end

#tensor_valString

Serialized raw tensor content. Corresponds to the JSON property tensorVal NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


35333
35334
35335
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35333

def tensor_val
  @tensor_val
end

#uint64_valArray<Fixnum>

UINT64 Corresponds to the JSON property uint64Val

Returns:

  • (Array<Fixnum>)


35338
35339
35340
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35338

def uint64_val
  @uint64_val
end

#uint_valArray<Fixnum>

UINT8 UINT16 UINT32 Corresponds to the JSON property uintVal

Returns:

  • (Array<Fixnum>)


35343
35344
35345
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35343

def uint_val
  @uint_val
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35350
35351
35352
35353
35354
35355
35356
35357
35358
35359
35360
35361
35362
35363
35364
35365
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35350

def update!(**args)
  @bool_val = args[:bool_val] if args.key?(:bool_val)
  @bytes_val = args[:bytes_val] if args.key?(:bytes_val)
  @double_val = args[:double_val] if args.key?(:double_val)
  @dtype = args[:dtype] if args.key?(:dtype)
  @float_val = args[:float_val] if args.key?(:float_val)
  @int64_val = args[:int64_val] if args.key?(:int64_val)
  @int_val = args[:int_val] if args.key?(:int_val)
  @list_val = args[:list_val] if args.key?(:list_val)
  @shape = args[:shape] if args.key?(:shape)
  @string_val = args[:string_val] if args.key?(:string_val)
  @struct_val = args[:struct_val] if args.key?(:struct_val)
  @tensor_val = args[:tensor_val] if args.key?(:tensor_val)
  @uint64_val = args[:uint64_val] if args.key?(:uint64_val)
  @uint_val = args[:uint_val] if args.key?(:uint_val)
end