Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tensor

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A tensor value type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Tensor

Returns a new instance of GoogleCloudAiplatformV1Tensor.



35228
35229
35230
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35228

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bool_valArray<Boolean>

Type specific representations that make it easy to create tensor protos in all languages. Only the representation corresponding to "dtype" can be set. The values hold the flattened representation of the tensor in row major order. BOOL Corresponds to the JSON property boolVal

Returns:

  • (Array<Boolean>)


35160
35161
35162
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35160

def bool_val
  @bool_val
end

#bytes_valArray<String>

STRING Corresponds to the JSON property bytesVal

Returns:

  • (Array<String>)


35165
35166
35167
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35165

def bytes_val
  @bytes_val
end

#double_valArray<Float>

DOUBLE Corresponds to the JSON property doubleVal

Returns:

  • (Array<Float>)


35170
35171
35172
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35170

def double_val
  @double_val
end

#dtypeString

The data type of tensor. Corresponds to the JSON property dtype

Returns:

  • (String)


35175
35176
35177
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35175

def dtype
  @dtype
end

#float_valArray<Float>

FLOAT Corresponds to the JSON property floatVal

Returns:

  • (Array<Float>)


35180
35181
35182
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35180

def float_val
  @float_val
end

#int64_valArray<Fixnum>

INT64 Corresponds to the JSON property int64Val

Returns:

  • (Array<Fixnum>)


35185
35186
35187
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35185

def int64_val
  @int64_val
end

#int_valArray<Fixnum>

INT_8 INT_16 INT_32 Corresponds to the JSON property intVal

Returns:

  • (Array<Fixnum>)


35190
35191
35192
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35190

def int_val
  @int_val
end

#list_valArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tensor>

A list of tensor values. Corresponds to the JSON property listVal



35195
35196
35197
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35195

def list_val
  @list_val
end

#shapeArray<Fixnum>

Shape of the tensor. Corresponds to the JSON property shape

Returns:

  • (Array<Fixnum>)


35200
35201
35202
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35200

def shape
  @shape
end

#string_valArray<String>

STRING Corresponds to the JSON property stringVal

Returns:

  • (Array<String>)


35205
35206
35207
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35205

def string_val
  @string_val
end

#struct_valHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tensor>

A map of string to tensor. Corresponds to the JSON property structVal



35210
35211
35212
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35210

def struct_val
  @struct_val
end

#tensor_valString

Serialized raw tensor content. Corresponds to the JSON property tensorVal NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


35216
35217
35218
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35216

def tensor_val
  @tensor_val
end

#uint64_valArray<Fixnum>

UINT64 Corresponds to the JSON property uint64Val

Returns:

  • (Array<Fixnum>)


35221
35222
35223
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35221

def uint64_val
  @uint64_val
end

#uint_valArray<Fixnum>

UINT8 UINT16 UINT32 Corresponds to the JSON property uintVal

Returns:

  • (Array<Fixnum>)


35226
35227
35228
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35226

def uint_val
  @uint_val
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35233
35234
35235
35236
35237
35238
35239
35240
35241
35242
35243
35244
35245
35246
35247
35248
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35233

def update!(**args)
  @bool_val = args[:bool_val] if args.key?(:bool_val)
  @bytes_val = args[:bytes_val] if args.key?(:bytes_val)
  @double_val = args[:double_val] if args.key?(:double_val)
  @dtype = args[:dtype] if args.key?(:dtype)
  @float_val = args[:float_val] if args.key?(:float_val)
  @int64_val = args[:int64_val] if args.key?(:int64_val)
  @int_val = args[:int_val] if args.key?(:int_val)
  @list_val = args[:list_val] if args.key?(:list_val)
  @shape = args[:shape] if args.key?(:shape)
  @string_val = args[:string_val] if args.key?(:string_val)
  @struct_val = args[:struct_val] if args.key?(:struct_val)
  @tensor_val = args[:tensor_val] if args.key?(:tensor_val)
  @uint64_val = args[:uint64_val] if args.key?(:uint64_val)
  @uint_val = args[:uint_val] if args.key?(:uint_val)
end