Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tensor

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A tensor value type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Tensor

Returns a new instance of GoogleCloudAiplatformV1Tensor.



35163
35164
35165
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35163

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bool_valArray<Boolean>

Type specific representations that make it easy to create tensor protos in all languages. Only the representation corresponding to "dtype" can be set. The values hold the flattened representation of the tensor in row major order. BOOL Corresponds to the JSON property boolVal

Returns:

  • (Array<Boolean>)


35095
35096
35097
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35095

def bool_val
  @bool_val
end

#bytes_valArray<String>

STRING Corresponds to the JSON property bytesVal

Returns:

  • (Array<String>)


35100
35101
35102
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35100

def bytes_val
  @bytes_val
end

#double_valArray<Float>

DOUBLE Corresponds to the JSON property doubleVal

Returns:

  • (Array<Float>)


35105
35106
35107
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35105

def double_val
  @double_val
end

#dtypeString

The data type of tensor. Corresponds to the JSON property dtype

Returns:

  • (String)


35110
35111
35112
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35110

def dtype
  @dtype
end

#float_valArray<Float>

FLOAT Corresponds to the JSON property floatVal

Returns:

  • (Array<Float>)


35115
35116
35117
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35115

def float_val
  @float_val
end

#int64_valArray<Fixnum>

INT64 Corresponds to the JSON property int64Val

Returns:

  • (Array<Fixnum>)


35120
35121
35122
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35120

def int64_val
  @int64_val
end

#int_valArray<Fixnum>

INT_8 INT_16 INT_32 Corresponds to the JSON property intVal

Returns:

  • (Array<Fixnum>)


35125
35126
35127
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35125

def int_val
  @int_val
end

#list_valArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tensor>

A list of tensor values. Corresponds to the JSON property listVal



35130
35131
35132
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35130

def list_val
  @list_val
end

#shapeArray<Fixnum>

Shape of the tensor. Corresponds to the JSON property shape

Returns:

  • (Array<Fixnum>)


35135
35136
35137
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35135

def shape
  @shape
end

#string_valArray<String>

STRING Corresponds to the JSON property stringVal

Returns:

  • (Array<String>)


35140
35141
35142
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35140

def string_val
  @string_val
end

#struct_valHash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tensor>

A map of string to tensor. Corresponds to the JSON property structVal



35145
35146
35147
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35145

def struct_val
  @struct_val
end

#tensor_valString

Serialized raw tensor content. Corresponds to the JSON property tensorVal NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


35151
35152
35153
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35151

def tensor_val
  @tensor_val
end

#uint64_valArray<Fixnum>

UINT64 Corresponds to the JSON property uint64Val

Returns:

  • (Array<Fixnum>)


35156
35157
35158
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35156

def uint64_val
  @uint64_val
end

#uint_valArray<Fixnum>

UINT8 UINT16 UINT32 Corresponds to the JSON property uintVal

Returns:

  • (Array<Fixnum>)


35161
35162
35163
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35161

def uint_val
  @uint_val
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35168
35169
35170
35171
35172
35173
35174
35175
35176
35177
35178
35179
35180
35181
35182
35183
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35168

def update!(**args)
  @bool_val = args[:bool_val] if args.key?(:bool_val)
  @bytes_val = args[:bytes_val] if args.key?(:bytes_val)
  @double_val = args[:double_val] if args.key?(:double_val)
  @dtype = args[:dtype] if args.key?(:dtype)
  @float_val = args[:float_val] if args.key?(:float_val)
  @int64_val = args[:int64_val] if args.key?(:int64_val)
  @int_val = args[:int_val] if args.key?(:int_val)
  @list_val = args[:list_val] if args.key?(:list_val)
  @shape = args[:shape] if args.key?(:shape)
  @string_val = args[:string_val] if args.key?(:string_val)
  @struct_val = args[:struct_val] if args.key?(:struct_val)
  @tensor_val = args[:tensor_val] if args.key?(:tensor_val)
  @uint64_val = args[:uint64_val] if args.key?(:uint64_val)
  @uint_val = args[:uint_val] if args.key?(:uint_val)
end