Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tensor
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tensor
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A tensor value type.
Instance Attribute Summary collapse
-
#bool_val ⇒ Array<Boolean>
Type specific representations that make it easy to create tensor protos in all languages.
-
#bytes_val ⇒ Array<String>
STRING Corresponds to the JSON property
bytesVal. -
#double_val ⇒ Array<Float>
DOUBLE Corresponds to the JSON property
doubleVal. -
#dtype ⇒ String
The data type of tensor.
-
#float_val ⇒ Array<Float>
FLOAT Corresponds to the JSON property
floatVal. -
#int64_val ⇒ Array<Fixnum>
INT64 Corresponds to the JSON property
int64Val. -
#int_val ⇒ Array<Fixnum>
INT_8 INT_16 INT_32 Corresponds to the JSON property
intVal. -
#list_val ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tensor>
A list of tensor values.
-
#shape ⇒ Array<Fixnum>
Shape of the tensor.
-
#string_val ⇒ Array<String>
STRING Corresponds to the JSON property
stringVal. -
#struct_val ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tensor>
A map of string to tensor.
-
#tensor_val ⇒ String
Serialized raw tensor content.
-
#uint64_val ⇒ Array<Fixnum>
UINT64 Corresponds to the JSON property
uint64Val. -
#uint_val ⇒ Array<Fixnum>
UINT8 UINT16 UINT32 Corresponds to the JSON property
uintVal.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Tensor
constructor
A new instance of GoogleCloudAiplatformV1Tensor.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Tensor
Returns a new instance of GoogleCloudAiplatformV1Tensor.
26154 26155 26156 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26154 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bool_val ⇒ Array<Boolean>
Type specific representations that make it easy to create tensor protos in all
languages. Only the representation corresponding to "dtype" can be set. The
values hold the flattened representation of the tensor in row major order.
BOOL
Corresponds to the JSON property boolVal
26086 26087 26088 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26086 def bool_val @bool_val end |
#bytes_val ⇒ Array<String>
STRING
Corresponds to the JSON property bytesVal
26091 26092 26093 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26091 def bytes_val @bytes_val end |
#double_val ⇒ Array<Float>
DOUBLE
Corresponds to the JSON property doubleVal
26096 26097 26098 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26096 def double_val @double_val end |
#dtype ⇒ String
The data type of tensor.
Corresponds to the JSON property dtype
26101 26102 26103 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26101 def dtype @dtype end |
#float_val ⇒ Array<Float>
FLOAT
Corresponds to the JSON property floatVal
26106 26107 26108 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26106 def float_val @float_val end |
#int64_val ⇒ Array<Fixnum>
INT64
Corresponds to the JSON property int64Val
26111 26112 26113 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26111 def int64_val @int64_val end |
#int_val ⇒ Array<Fixnum>
INT_8 INT_16 INT_32
Corresponds to the JSON property intVal
26116 26117 26118 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26116 def int_val @int_val end |
#list_val ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tensor>
A list of tensor values.
Corresponds to the JSON property listVal
26121 26122 26123 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26121 def list_val @list_val end |
#shape ⇒ Array<Fixnum>
Shape of the tensor.
Corresponds to the JSON property shape
26126 26127 26128 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26126 def shape @shape end |
#string_val ⇒ Array<String>
STRING
Corresponds to the JSON property stringVal
26131 26132 26133 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26131 def string_val @string_val end |
#struct_val ⇒ Hash<String,Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tensor>
A map of string to tensor.
Corresponds to the JSON property structVal
26136 26137 26138 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26136 def struct_val @struct_val end |
#tensor_val ⇒ String
Serialized raw tensor content.
Corresponds to the JSON property tensorVal
NOTE: Values are automatically base64 encoded/decoded in the client library.
26142 26143 26144 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26142 def tensor_val @tensor_val end |
#uint64_val ⇒ Array<Fixnum>
UINT64
Corresponds to the JSON property uint64Val
26147 26148 26149 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26147 def uint64_val @uint64_val end |
#uint_val ⇒ Array<Fixnum>
UINT8 UINT16 UINT32
Corresponds to the JSON property uintVal
26152 26153 26154 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26152 def uint_val @uint_val end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26159 26160 26161 26162 26163 26164 26165 26166 26167 26168 26169 26170 26171 26172 26173 26174 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26159 def update!(**args) @bool_val = args[:bool_val] if args.key?(:bool_val) @bytes_val = args[:bytes_val] if args.key?(:bytes_val) @double_val = args[:double_val] if args.key?(:double_val) @dtype = args[:dtype] if args.key?(:dtype) @float_val = args[:float_val] if args.key?(:float_val) @int64_val = args[:int64_val] if args.key?(:int64_val) @int_val = args[:int_val] if args.key?(:int_val) @list_val = args[:list_val] if args.key?(:list_val) @shape = args[:shape] if args.key?(:shape) @string_val = args[:string_val] if args.key?(:string_val) @struct_val = args[:struct_val] if args.key?(:struct_val) @tensor_val = args[:tensor_val] if args.key?(:tensor_val) @uint64_val = args[:uint64_val] if args.key?(:uint64_val) @uint_val = args[:uint_val] if args.key?(:uint_val) end |