Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tensorboard

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Tensorboard is a physical database that stores users' training metrics. A default Tensorboard is provided in each region of a Google Cloud project. If needed users can also create extra Tensorboards in their projects.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Tensorboard

Returns a new instance of GoogleCloudAiplatformV1Tensorboard.



47396
47397
47398
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47396

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blob_storage_path_prefixString

Output only. Consumer project Cloud Storage path prefix used to store blob data, which can either be a bucket or directory. Does not end with a '/'. Corresponds to the JSON property blobStoragePathPrefix

Returns:

  • (String)


47319
47320
47321
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47319

def blob_storage_path_prefix
  @blob_storage_path_prefix
end

#create_timeString

Output only. Timestamp when this Tensorboard was created. Corresponds to the JSON property createTime

Returns:

  • (String)


47324
47325
47326
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47324

def create_time
  @create_time
end

#descriptionString

Description of this Tensorboard. Corresponds to the JSON property description

Returns:

  • (String)


47329
47330
47331
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47329

def description
  @description
end

#display_nameString

Required. User provided name of this Tensorboard. Corresponds to the JSON property displayName

Returns:

  • (String)


47334
47335
47336
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47334

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource. Corresponds to the JSON property encryptionSpec



47340
47341
47342
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47340

def encryption_spec
  @encryption_spec
end

#etagString

Used to perform a consistent read-modify-write updates. If not set, a blind " overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


47346
47347
47348
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47346

def etag
  @etag
end

#is_defaultBoolean Also known as: is_default?

Used to indicate if the TensorBoard instance is the default one. Each project & region can have at most one default TensorBoard instance. Creation of a default TensorBoard instance and updating an existing TensorBoard instance to be default will mark all other TensorBoard instances (if any) as non default. Corresponds to the JSON property isDefault

Returns:

  • (Boolean)


47354
47355
47356
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47354

def is_default
  @is_default
end

#labelsHash<String,String>

The labels with user-defined metadata to organize your Tensorboards. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. No more than 64 user labels can be associated with one Tensorboard (System labels are excluded). See https://goo. gl/xmQnxf for more information and examples of labels. System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


47366
47367
47368
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47366

def labels
  @labels
end

#nameString

Output only. Name of the Tensorboard. Format: projects/project/locations/ location/tensorboards/tensorboard` Corresponds to the JSON propertyname`

Returns:

  • (String)


47372
47373
47374
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47372

def name
  @name
end

#run_countFixnum

Output only. The number of Runs stored in this Tensorboard. Corresponds to the JSON property runCount

Returns:

  • (Fixnum)


47377
47378
47379
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47377

def run_count
  @run_count
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


47382
47383
47384
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47382

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


47388
47389
47390
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47388

def satisfies_pzs
  @satisfies_pzs
end

#update_timeString

Output only. Timestamp when this Tensorboard was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


47394
47395
47396
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47394

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47401
47402
47403
47404
47405
47406
47407
47408
47409
47410
47411
47412
47413
47414
47415
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47401

def update!(**args)
  @blob_storage_path_prefix = args[:blob_storage_path_prefix] if args.key?(:blob_storage_path_prefix)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @etag = args[:etag] if args.key?(:etag)
  @is_default = args[:is_default] if args.key?(:is_default)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @run_count = args[:run_count] if args.key?(:run_count)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @update_time = args[:update_time] if args.key?(:update_time)
end