Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tensorboard
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tensorboard
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Tensorboard is a physical database that stores users' training metrics. A default Tensorboard is provided in each region of a Google Cloud project. If needed users can also create extra Tensorboards in their projects.
Instance Attribute Summary collapse
-
#blob_storage_path_prefix ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Description of this Tensorboard.
-
#display_name ⇒ String
Required.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top- level resource.
-
#etag ⇒ String
Used to perform a consistent read-modify-write updates.
-
#is_default ⇒ Boolean
(also: #is_default?)
Used to indicate if the TensorBoard instance is the default one.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your Tensorboards.
-
#name ⇒ String
Output only.
-
#run_count ⇒ Fixnum
Output only.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Tensorboard
constructor
A new instance of GoogleCloudAiplatformV1Tensorboard.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Tensorboard
Returns a new instance of GoogleCloudAiplatformV1Tensorboard.
37454 37455 37456 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37454 def initialize(**args) update!(**args) end |
Instance Attribute Details
#blob_storage_path_prefix ⇒ String
Output only. Consumer project Cloud Storage path prefix used to store blob
data, which can either be a bucket or directory. Does not end with a '/'.
Corresponds to the JSON property blobStoragePathPrefix
37377 37378 37379 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37377 def blob_storage_path_prefix @blob_storage_path_prefix end |
#create_time ⇒ String
Output only. Timestamp when this Tensorboard was created.
Corresponds to the JSON property createTime
37382 37383 37384 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37382 def create_time @create_time end |
#description ⇒ String
Description of this Tensorboard.
Corresponds to the JSON property description
37387 37388 37389 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37387 def description @description end |
#display_name ⇒ String
Required. User provided name of this Tensorboard.
Corresponds to the JSON property displayName
37392 37393 37394 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37392 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top-
level resource.
Corresponds to the JSON property encryptionSpec
37398 37399 37400 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37398 def encryption_spec @encryption_spec end |
#etag ⇒ String
Used to perform a consistent read-modify-write updates. If not set, a blind "
overwrite" update happens.
Corresponds to the JSON property etag
37404 37405 37406 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37404 def etag @etag end |
#is_default ⇒ Boolean Also known as: is_default?
Used to indicate if the TensorBoard instance is the default one. Each project &
region can have at most one default TensorBoard instance. Creation of a
default TensorBoard instance and updating an existing TensorBoard instance to
be default will mark all other TensorBoard instances (if any) as non default.
Corresponds to the JSON property isDefault
37412 37413 37414 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37412 def is_default @is_default end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your Tensorboards. Label
keys and values can be no longer than 64 characters (Unicode codepoints), can
only contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. No more than 64 user labels can be
associated with one Tensorboard (System labels are excluded). See https://goo.
gl/xmQnxf for more information and examples of labels. System reserved label
keys are prefixed with "aiplatform.googleapis.com/" and are immutable.
Corresponds to the JSON property labels
37424 37425 37426 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37424 def labels @labels end |
#name ⇒ String
Output only. Name of the Tensorboard. Format: projects/project/locations/
location/tensorboards/tensorboard`
Corresponds to the JSON propertyname`
37430 37431 37432 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37430 def name @name end |
#run_count ⇒ Fixnum
Output only. The number of Runs stored in this Tensorboard.
Corresponds to the JSON property runCount
37435 37436 37437 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37435 def run_count @run_count end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
37440 37441 37442 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37440 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
37446 37447 37448 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37446 def satisfies_pzs @satisfies_pzs end |
#update_time ⇒ String
Output only. Timestamp when this Tensorboard was last updated.
Corresponds to the JSON property updateTime
37452 37453 37454 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37452 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37459 37460 37461 37462 37463 37464 37465 37466 37467 37468 37469 37470 37471 37472 37473 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37459 def update!(**args) @blob_storage_path_prefix = args[:blob_storage_path_prefix] if args.key?(:blob_storage_path_prefix) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @etag = args[:etag] if args.key?(:etag) @is_default = args[:is_default] if args.key?(:is_default) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @run_count = args[:run_count] if args.key?(:run_count) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @update_time = args[:update_time] if args.key?(:update_time) end |