Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tensorboard

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Tensorboard is a physical database that stores users' training metrics. A default Tensorboard is provided in each region of a Google Cloud project. If needed users can also create extra Tensorboards in their projects.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Tensorboard

Returns a new instance of GoogleCloudAiplatformV1Tensorboard.



35273
35274
35275
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35273

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blob_storage_path_prefixString

Output only. Consumer project Cloud Storage path prefix used to store blob data, which can either be a bucket or directory. Does not end with a '/'. Corresponds to the JSON property blobStoragePathPrefix

Returns:

  • (String)


35196
35197
35198
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35196

def blob_storage_path_prefix
  @blob_storage_path_prefix
end

#create_timeString

Output only. Timestamp when this Tensorboard was created. Corresponds to the JSON property createTime

Returns:

  • (String)


35201
35202
35203
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35201

def create_time
  @create_time
end

#descriptionString

Description of this Tensorboard. Corresponds to the JSON property description

Returns:

  • (String)


35206
35207
35208
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35206

def description
  @description
end

#display_nameString

Required. User provided name of this Tensorboard. Corresponds to the JSON property displayName

Returns:

  • (String)


35211
35212
35213
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35211

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key spec that can be applied to a top- level resource. Corresponds to the JSON property encryptionSpec



35217
35218
35219
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35217

def encryption_spec
  @encryption_spec
end

#etagString

Used to perform a consistent read-modify-write updates. If not set, a blind " overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


35223
35224
35225
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35223

def etag
  @etag
end

#is_defaultBoolean Also known as: is_default?

Used to indicate if the TensorBoard instance is the default one. Each project & region can have at most one default TensorBoard instance. Creation of a default TensorBoard instance and updating an existing TensorBoard instance to be default will mark all other TensorBoard instances (if any) as non default. Corresponds to the JSON property isDefault

Returns:

  • (Boolean)


35231
35232
35233
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35231

def is_default
  @is_default
end

#labelsHash<String,String>

The labels with user-defined metadata to organize your Tensorboards. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. No more than 64 user labels can be associated with one Tensorboard (System labels are excluded). See https://goo. gl/xmQnxf for more information and examples of labels. System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


35243
35244
35245
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35243

def labels
  @labels
end

#nameString

Output only. Name of the Tensorboard. Format: projects/project/locations/ location/tensorboards/tensorboard` Corresponds to the JSON propertyname`

Returns:

  • (String)


35249
35250
35251
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35249

def name
  @name
end

#run_countFixnum

Output only. The number of Runs stored in this Tensorboard. Corresponds to the JSON property runCount

Returns:

  • (Fixnum)


35254
35255
35256
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35254

def run_count
  @run_count
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


35259
35260
35261
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35259

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


35265
35266
35267
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35265

def satisfies_pzs
  @satisfies_pzs
end

#update_timeString

Output only. Timestamp when this Tensorboard was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


35271
35272
35273
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35271

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35278
35279
35280
35281
35282
35283
35284
35285
35286
35287
35288
35289
35290
35291
35292
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35278

def update!(**args)
  @blob_storage_path_prefix = args[:blob_storage_path_prefix] if args.key?(:blob_storage_path_prefix)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @etag = args[:etag] if args.key?(:etag)
  @is_default = args[:is_default] if args.key?(:is_default)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @run_count = args[:run_count] if args.key?(:run_count)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @update_time = args[:update_time] if args.key?(:update_time)
end