Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tensorboard

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Tensorboard is a physical database that stores users' training metrics. A default Tensorboard is provided in each region of a Google Cloud project. If needed users can also create extra Tensorboards in their projects.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Tensorboard

Returns a new instance of GoogleCloudAiplatformV1Tensorboard.



34142
34143
34144
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34142

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blob_storage_path_prefixString

Output only. Consumer project Cloud Storage path prefix used to store blob data, which can either be a bucket or directory. Does not end with a '/'. Corresponds to the JSON property blobStoragePathPrefix

Returns:

  • (String)


34065
34066
34067
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34065

def blob_storage_path_prefix
  @blob_storage_path_prefix
end

#create_timeString

Output only. Timestamp when this Tensorboard was created. Corresponds to the JSON property createTime

Returns:

  • (String)


34070
34071
34072
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34070

def create_time
  @create_time
end

#descriptionString

Description of this Tensorboard. Corresponds to the JSON property description

Returns:

  • (String)


34075
34076
34077
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34075

def description
  @description
end

#display_nameString

Required. User provided name of this Tensorboard. Corresponds to the JSON property displayName

Returns:

  • (String)


34080
34081
34082
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34080

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key spec that can be applied to a top- level resource. Corresponds to the JSON property encryptionSpec



34086
34087
34088
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34086

def encryption_spec
  @encryption_spec
end

#etagString

Used to perform a consistent read-modify-write updates. If not set, a blind " overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


34092
34093
34094
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34092

def etag
  @etag
end

#is_defaultBoolean Also known as: is_default?

Used to indicate if the TensorBoard instance is the default one. Each project & region can have at most one default TensorBoard instance. Creation of a default TensorBoard instance and updating an existing TensorBoard instance to be default will mark all other TensorBoard instances (if any) as non default. Corresponds to the JSON property isDefault

Returns:

  • (Boolean)


34100
34101
34102
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34100

def is_default
  @is_default
end

#labelsHash<String,String>

The labels with user-defined metadata to organize your Tensorboards. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. No more than 64 user labels can be associated with one Tensorboard (System labels are excluded). See https://goo. gl/xmQnxf for more information and examples of labels. System reserved label keys are prefixed with "aiplatform.googleapis.com/" and are immutable. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


34112
34113
34114
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34112

def labels
  @labels
end

#nameString

Output only. Name of the Tensorboard. Format: projects/project/locations/ location/tensorboards/tensorboard` Corresponds to the JSON propertyname`

Returns:

  • (String)


34118
34119
34120
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34118

def name
  @name
end

#run_countFixnum

Output only. The number of Runs stored in this Tensorboard. Corresponds to the JSON property runCount

Returns:

  • (Fixnum)


34123
34124
34125
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34123

def run_count
  @run_count
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


34128
34129
34130
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34128

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


34134
34135
34136
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34134

def satisfies_pzs
  @satisfies_pzs
end

#update_timeString

Output only. Timestamp when this Tensorboard was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


34140
34141
34142
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34140

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34147
34148
34149
34150
34151
34152
34153
34154
34155
34156
34157
34158
34159
34160
34161
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34147

def update!(**args)
  @blob_storage_path_prefix = args[:blob_storage_path_prefix] if args.key?(:blob_storage_path_prefix)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @etag = args[:etag] if args.key?(:etag)
  @is_default = args[:is_default] if args.key?(:is_default)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @run_count = args[:run_count] if args.key?(:run_count)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @update_time = args[:update_time] if args.key?(:update_time)
end