Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tensorboard
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tensorboard
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Tensorboard is a physical database that stores users' training metrics. A default Tensorboard is provided in each region of a Google Cloud project. If needed users can also create extra Tensorboards in their projects.
Instance Attribute Summary collapse
-
#blob_storage_path_prefix ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Description of this Tensorboard.
-
#display_name ⇒ String
Required.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top- level resource.
-
#etag ⇒ String
Used to perform a consistent read-modify-write updates.
-
#is_default ⇒ Boolean
(also: #is_default?)
Used to indicate if the TensorBoard instance is the default one.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your Tensorboards.
-
#name ⇒ String
Output only.
-
#run_count ⇒ Fixnum
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Tensorboard
constructor
A new instance of GoogleCloudAiplatformV1Tensorboard.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Tensorboard
Returns a new instance of GoogleCloudAiplatformV1Tensorboard.
27737 27738 27739 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27737 def initialize(**args) update!(**args) end |
Instance Attribute Details
#blob_storage_path_prefix ⇒ String
Output only. Consumer project Cloud Storage path prefix used to store blob
data, which can either be a bucket or directory. Does not end with a '/'.
Corresponds to the JSON property blobStoragePathPrefix
27672 27673 27674 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27672 def blob_storage_path_prefix @blob_storage_path_prefix end |
#create_time ⇒ String
Output only. Timestamp when this Tensorboard was created.
Corresponds to the JSON property createTime
27677 27678 27679 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27677 def create_time @create_time end |
#description ⇒ String
Description of this Tensorboard.
Corresponds to the JSON property description
27682 27683 27684 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27682 def description @description end |
#display_name ⇒ String
Required. User provided name of this Tensorboard.
Corresponds to the JSON property displayName
27687 27688 27689 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27687 def display_name @display_name end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top-
level resource.
Corresponds to the JSON property encryptionSpec
27693 27694 27695 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27693 def encryption_spec @encryption_spec end |
#etag ⇒ String
Used to perform a consistent read-modify-write updates. If not set, a blind "
overwrite" update happens.
Corresponds to the JSON property etag
27699 27700 27701 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27699 def etag @etag end |
#is_default ⇒ Boolean Also known as: is_default?
Used to indicate if the TensorBoard instance is the default one. Each project &
region can have at most one default TensorBoard instance. Creation of a
default TensorBoard instance and updating an existing TensorBoard instance to
be default will mark all other TensorBoard instances (if any) as non default.
Corresponds to the JSON property isDefault
27707 27708 27709 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27707 def is_default @is_default end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your Tensorboards. Label
keys and values can be no longer than 64 characters (Unicode codepoints), can
only contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. No more than 64 user labels can be
associated with one Tensorboard (System labels are excluded). See https://goo.
gl/xmQnxf for more information and examples of labels. System reserved label
keys are prefixed with "aiplatform.googleapis.com/" and are immutable.
Corresponds to the JSON property labels
27719 27720 27721 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27719 def labels @labels end |
#name ⇒ String
Output only. Name of the Tensorboard. Format: projects/project/locations/
location/tensorboards/tensorboard`
Corresponds to the JSON propertyname`
27725 27726 27727 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27725 def name @name end |
#run_count ⇒ Fixnum
Output only. The number of Runs stored in this Tensorboard.
Corresponds to the JSON property runCount
27730 27731 27732 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27730 def run_count @run_count end |
#update_time ⇒ String
Output only. Timestamp when this Tensorboard was last updated.
Corresponds to the JSON property updateTime
27735 27736 27737 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27735 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27742 27743 27744 27745 27746 27747 27748 27749 27750 27751 27752 27753 27754 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27742 def update!(**args) @blob_storage_path_prefix = args[:blob_storage_path_prefix] if args.key?(:blob_storage_path_prefix) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @etag = args[:etag] if args.key?(:etag) @is_default = args[:is_default] if args.key?(:is_default) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @run_count = args[:run_count] if args.key?(:run_count) @update_time = args[:update_time] if args.key?(:update_time) end |