Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardBlobSequence

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

One point viewable on a blob metric plot, but mostly just a wrapper message to work around repeated fields can't be used directly within oneof fields.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1TensorboardBlobSequence

Returns a new instance of GoogleCloudAiplatformV1TensorboardBlobSequence.



43178
43179
43180
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 43178

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#valuesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardBlob>

List of blobs contained within the sequence. Corresponds to the JSON property values



43176
43177
43178
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 43176

def values
  @values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43183
43184
43185
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 43183

def update!(**args)
  @values = args[:values] if args.key?(:values)
end