Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardBlobSequence

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

One point viewable on a blob metric plot, but mostly just a wrapper message to work around repeated fields can't be used directly within oneof fields.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1TensorboardBlobSequence

Returns a new instance of GoogleCloudAiplatformV1TensorboardBlobSequence.



31514
31515
31516
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31514

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#valuesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardBlob>

List of blobs contained within the sequence. Corresponds to the JSON property values



31512
31513
31514
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31512

def values
  @values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31519
31520
31521
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31519

def update!(**args)
  @values = args[:values] if args.key?(:values)
end