Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardExperiment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A TensorboardExperiment is a group of TensorboardRuns, that are typically the results of a training job run, in a Tensorboard.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1TensorboardExperiment

Returns a new instance of GoogleCloudAiplatformV1TensorboardExperiment.



47522
47523
47524
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47522

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this TensorboardExperiment was created. Corresponds to the JSON property createTime

Returns:

  • (String)


47474
47475
47476
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47474

def create_time
  @create_time
end

#descriptionString

Description of this TensorboardExperiment. Corresponds to the JSON property description

Returns:

  • (String)


47479
47480
47481
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47479

def description
  @description
end

#display_nameString

User provided name of this TensorboardExperiment. Corresponds to the JSON property displayName

Returns:

  • (String)


47484
47485
47486
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47484

def display_name
  @display_name
end

#etagString

Used to perform consistent read-modify-write updates. If not set, a blind " overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


47490
47491
47492
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47490

def etag
  @etag
end

#labelsHash<String,String>

The labels with user-defined metadata to organize your TensorboardExperiment. Label keys and values cannot be longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. No more than 64 user labels can be associated with one Dataset (System labels are excluded). See https://goo. gl/xmQnxf for more information and examples of labels. System reserved label keys are prefixed with aiplatform.googleapis.com/ and are immutable. The following system labels exist for each Dataset: * aiplatform.googleapis.com/ dataset_metadata_schema: output only. Its value is the metadata_schema's title. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


47504
47505
47506
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47504

def labels
  @labels
end

#nameString

Output only. Name of the TensorboardExperiment. Format: projects/project/ locations/location/tensorboards/tensorboard/experiments/experiment` Corresponds to the JSON propertyname`

Returns:

  • (String)


47510
47511
47512
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47510

def name
  @name
end

#sourceString

Immutable. Source of the TensorboardExperiment. Example: a custom training job. Corresponds to the JSON property source

Returns:

  • (String)


47515
47516
47517
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47515

def source
  @source
end

#update_timeString

Output only. Timestamp when this TensorboardExperiment was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


47520
47521
47522
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47520

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47527
47528
47529
47530
47531
47532
47533
47534
47535
47536
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47527

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @source = args[:source] if args.key?(:source)
  @update_time = args[:update_time] if args.key?(:update_time)
end