Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardExperiment
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardExperiment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A TensorboardExperiment is a group of TensorboardRuns, that are typically the results of a training job run, in a Tensorboard.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Description of this TensorboardExperiment.
-
#display_name ⇒ String
User provided name of this TensorboardExperiment.
-
#etag ⇒ String
Used to perform consistent read-modify-write updates.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your TensorboardExperiment.
-
#name ⇒ String
Output only.
-
#source ⇒ String
Immutable.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1TensorboardExperiment
constructor
A new instance of GoogleCloudAiplatformV1TensorboardExperiment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1TensorboardExperiment
Returns a new instance of GoogleCloudAiplatformV1TensorboardExperiment.
37595 37596 37597 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37595 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this TensorboardExperiment was created.
Corresponds to the JSON property createTime
37547 37548 37549 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37547 def create_time @create_time end |
#description ⇒ String
Description of this TensorboardExperiment.
Corresponds to the JSON property description
37552 37553 37554 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37552 def description @description end |
#display_name ⇒ String
User provided name of this TensorboardExperiment.
Corresponds to the JSON property displayName
37557 37558 37559 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37557 def display_name @display_name end |
#etag ⇒ String
Used to perform consistent read-modify-write updates. If not set, a blind "
overwrite" update happens.
Corresponds to the JSON property etag
37563 37564 37565 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37563 def etag @etag end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your TensorboardExperiment.
Label keys and values cannot be longer than 64 characters (Unicode codepoints),
can only contain lowercase letters, numeric characters, underscores and
dashes. International characters are allowed. No more than 64 user labels can
be associated with one Dataset (System labels are excluded). See https://goo.
gl/xmQnxf for more information and examples of labels. System reserved label
keys are prefixed with aiplatform.googleapis.com/ and are immutable. The
following system labels exist for each Dataset: * aiplatform.googleapis.com/
dataset_metadata_schema: output only. Its value is the metadata_schema's
title.
Corresponds to the JSON property labels
37577 37578 37579 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37577 def labels @labels end |
#name ⇒ String
Output only. Name of the TensorboardExperiment. Format: projects/project/
locations/location/tensorboards/tensorboard/experiments/experiment`
Corresponds to the JSON propertyname`
37583 37584 37585 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37583 def name @name end |
#source ⇒ String
Immutable. Source of the TensorboardExperiment. Example: a custom training job.
Corresponds to the JSON property source
37588 37589 37590 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37588 def source @source end |
#update_time ⇒ String
Output only. Timestamp when this TensorboardExperiment was last updated.
Corresponds to the JSON property updateTime
37593 37594 37595 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37593 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37600 37601 37602 37603 37604 37605 37606 37607 37608 37609 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37600 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @source = args[:source] if args.key?(:source) @update_time = args[:update_time] if args.key?(:update_time) end |