Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardExperiment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A TensorboardExperiment is a group of TensorboardRuns, that are typically the results of a training job run, in a Tensorboard.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1TensorboardExperiment

Returns a new instance of GoogleCloudAiplatformV1TensorboardExperiment.



36082
36083
36084
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36082

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this TensorboardExperiment was created. Corresponds to the JSON property createTime

Returns:

  • (String)


36034
36035
36036
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36034

def create_time
  @create_time
end

#descriptionString

Description of this TensorboardExperiment. Corresponds to the JSON property description

Returns:

  • (String)


36039
36040
36041
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36039

def description
  @description
end

#display_nameString

User provided name of this TensorboardExperiment. Corresponds to the JSON property displayName

Returns:

  • (String)


36044
36045
36046
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36044

def display_name
  @display_name
end

#etagString

Used to perform consistent read-modify-write updates. If not set, a blind " overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


36050
36051
36052
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36050

def etag
  @etag
end

#labelsHash<String,String>

The labels with user-defined metadata to organize your TensorboardExperiment. Label keys and values cannot be longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. No more than 64 user labels can be associated with one Dataset (System labels are excluded). See https://goo. gl/xmQnxf for more information and examples of labels. System reserved label keys are prefixed with aiplatform.googleapis.com/ and are immutable. The following system labels exist for each Dataset: * aiplatform.googleapis.com/ dataset_metadata_schema: output only. Its value is the metadata_schema's title. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


36064
36065
36066
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36064

def labels
  @labels
end

#nameString

Output only. Name of the TensorboardExperiment. Format: projects/project/ locations/location/tensorboards/tensorboard/experiments/experiment` Corresponds to the JSON propertyname`

Returns:

  • (String)


36070
36071
36072
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36070

def name
  @name
end

#sourceString

Immutable. Source of the TensorboardExperiment. Example: a custom training job. Corresponds to the JSON property source

Returns:

  • (String)


36075
36076
36077
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36075

def source
  @source
end

#update_timeString

Output only. Timestamp when this TensorboardExperiment was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


36080
36081
36082
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36080

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36087
36088
36089
36090
36091
36092
36093
36094
36095
36096
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36087

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @source = args[:source] if args.key?(:source)
  @update_time = args[:update_time] if args.key?(:update_time)
end