Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardExperiment
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardExperiment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A TensorboardExperiment is a group of TensorboardRuns, that are typically the results of a training job run, in a Tensorboard.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Description of this TensorboardExperiment.
-
#display_name ⇒ String
User provided name of this TensorboardExperiment.
-
#etag ⇒ String
Used to perform consistent read-modify-write updates.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your TensorboardExperiment.
-
#name ⇒ String
Output only.
-
#source ⇒ String
Immutable.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1TensorboardExperiment
constructor
A new instance of GoogleCloudAiplatformV1TensorboardExperiment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1TensorboardExperiment
Returns a new instance of GoogleCloudAiplatformV1TensorboardExperiment.
35464 35465 35466 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35464 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this TensorboardExperiment was created.
Corresponds to the JSON property createTime
35416 35417 35418 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35416 def create_time @create_time end |
#description ⇒ String
Description of this TensorboardExperiment.
Corresponds to the JSON property description
35421 35422 35423 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35421 def description @description end |
#display_name ⇒ String
User provided name of this TensorboardExperiment.
Corresponds to the JSON property displayName
35426 35427 35428 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35426 def display_name @display_name end |
#etag ⇒ String
Used to perform consistent read-modify-write updates. If not set, a blind "
overwrite" update happens.
Corresponds to the JSON property etag
35432 35433 35434 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35432 def etag @etag end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your TensorboardExperiment.
Label keys and values cannot be longer than 64 characters (Unicode codepoints),
can only contain lowercase letters, numeric characters, underscores and
dashes. International characters are allowed. No more than 64 user labels can
be associated with one Dataset (System labels are excluded). See https://goo.
gl/xmQnxf for more information and examples of labels. System reserved label
keys are prefixed with aiplatform.googleapis.com/ and are immutable. The
following system labels exist for each Dataset: * aiplatform.googleapis.com/
dataset_metadata_schema: output only. Its value is the metadata_schema's
title.
Corresponds to the JSON property labels
35446 35447 35448 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35446 def labels @labels end |
#name ⇒ String
Output only. Name of the TensorboardExperiment. Format: projects/project/
locations/location/tensorboards/tensorboard/experiments/experiment`
Corresponds to the JSON propertyname`
35452 35453 35454 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35452 def name @name end |
#source ⇒ String
Immutable. Source of the TensorboardExperiment. Example: a custom training job.
Corresponds to the JSON property source
35457 35458 35459 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35457 def source @source end |
#update_time ⇒ String
Output only. Timestamp when this TensorboardExperiment was last updated.
Corresponds to the JSON property updateTime
35462 35463 35464 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35462 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35469 35470 35471 35472 35473 35474 35475 35476 35477 35478 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35469 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @source = args[:source] if args.key?(:source) @update_time = args[:update_time] if args.key?(:update_time) end |