Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardExperiment
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardExperiment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A TensorboardExperiment is a group of TensorboardRuns, that are typically the results of a training job run, in a Tensorboard.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Description of this TensorboardExperiment.
-
#display_name ⇒ String
User provided name of this TensorboardExperiment.
-
#etag ⇒ String
Used to perform consistent read-modify-write updates.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your TensorboardExperiment.
-
#name ⇒ String
Output only.
-
#source ⇒ String
Immutable.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1TensorboardExperiment
constructor
A new instance of GoogleCloudAiplatformV1TensorboardExperiment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1TensorboardExperiment
Returns a new instance of GoogleCloudAiplatformV1TensorboardExperiment.
27914 27915 27916 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27914 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this TensorboardExperiment was created.
Corresponds to the JSON property createTime
27866 27867 27868 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27866 def create_time @create_time end |
#description ⇒ String
Description of this TensorboardExperiment.
Corresponds to the JSON property description
27871 27872 27873 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27871 def description @description end |
#display_name ⇒ String
User provided name of this TensorboardExperiment.
Corresponds to the JSON property displayName
27876 27877 27878 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27876 def display_name @display_name end |
#etag ⇒ String
Used to perform consistent read-modify-write updates. If not set, a blind "
overwrite" update happens.
Corresponds to the JSON property etag
27882 27883 27884 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27882 def etag @etag end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your TensorboardExperiment.
Label keys and values cannot be longer than 64 characters (Unicode codepoints),
can only contain lowercase letters, numeric characters, underscores and
dashes. International characters are allowed. No more than 64 user labels can
be associated with one Dataset (System labels are excluded). See https://goo.
gl/xmQnxf for more information and examples of labels. System reserved label
keys are prefixed with aiplatform.googleapis.com/ and are immutable. The
following system labels exist for each Dataset: * aiplatform.googleapis.com/
dataset_metadata_schema: output only. Its value is the metadata_schema's
title.
Corresponds to the JSON property labels
27896 27897 27898 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27896 def labels @labels end |
#name ⇒ String
Output only. Name of the TensorboardExperiment. Format: projects/project/
locations/location/tensorboards/tensorboard/experiments/experiment`
Corresponds to the JSON propertyname`
27902 27903 27904 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27902 def name @name end |
#source ⇒ String
Immutable. Source of the TensorboardExperiment. Example: a custom training job.
Corresponds to the JSON property source
27907 27908 27909 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27907 def source @source end |
#update_time ⇒ String
Output only. Timestamp when this TensorboardExperiment was last updated.
Corresponds to the JSON property updateTime
27912 27913 27914 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27912 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27919 27920 27921 27922 27923 27924 27925 27926 27927 27928 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27919 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @source = args[:source] if args.key?(:source) @update_time = args[:update_time] if args.key?(:update_time) end |