Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardRun
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardRun
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
TensorboardRun maps to a specific execution of a training job with a given set of hyperparameter values, model definition, dataset, etc
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Description of this TensorboardRun.
-
#display_name ⇒ String
Required.
-
#etag ⇒ String
Used to perform a consistent read-modify-write updates.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your TensorboardRuns.
-
#name ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1TensorboardRun
constructor
A new instance of GoogleCloudAiplatformV1TensorboardRun.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1TensorboardRun
Returns a new instance of GoogleCloudAiplatformV1TensorboardRun.
35554 35555 35556 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35554 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this TensorboardRun was created.
Corresponds to the JSON property createTime
35507 35508 35509 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35507 def create_time @create_time end |
#description ⇒ String
Description of this TensorboardRun.
Corresponds to the JSON property description
35512 35513 35514 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35512 def description @description end |
#display_name ⇒ String
Required. User provided name of this TensorboardRun. This value must be unique
among all TensorboardRuns belonging to the same parent TensorboardExperiment.
Corresponds to the JSON property displayName
35518 35519 35520 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35518 def display_name @display_name end |
#etag ⇒ String
Used to perform a consistent read-modify-write updates. If not set, a blind "
overwrite" update happens.
Corresponds to the JSON property etag
35524 35525 35526 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35524 def etag @etag end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your TensorboardRuns. This
field will be used to filter and visualize Runs in the Tensorboard UI. For
example, a Vertex AI training job can set a label aiplatform.googleapis.com/
training_job_id=xxxxx to all the runs created within that job. An end user can
set a label experiment_id=xxxxx for all the runs produced in a Jupyter
notebook. These runs can be grouped by a label value and visualized together
in the Tensorboard UI. Label keys and values can be no longer than 64
characters (Unicode codepoints), can only contain lowercase letters, numeric
characters, underscores and dashes. International characters are allowed. No
more than 64 user labels can be associated with one TensorboardRun (System
labels are excluded). See https://goo.gl/xmQnxf for more information and
examples of labels. System reserved label keys are prefixed with "aiplatform.
googleapis.com/" and are immutable.
Corresponds to the JSON property labels
35541 35542 35543 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35541 def labels @labels end |
#name ⇒ String
Output only. Name of the TensorboardRun. Format: projects/project/locations/
location/tensorboards/tensorboard/experiments/experiment/runs/run`
Corresponds to the JSON propertyname`
35547 35548 35549 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35547 def name @name end |
#update_time ⇒ String
Output only. Timestamp when this TensorboardRun was last updated.
Corresponds to the JSON property updateTime
35552 35553 35554 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35552 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35559 35560 35561 35562 35563 35564 35565 35566 35567 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35559 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) end |