Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardRun

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

TensorboardRun maps to a specific execution of a training job with a given set of hyperparameter values, model definition, dataset, etc

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1TensorboardRun

Returns a new instance of GoogleCloudAiplatformV1TensorboardRun.



35536
35537
35538
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35536

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this TensorboardRun was created. Corresponds to the JSON property createTime

Returns:

  • (String)


35489
35490
35491
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35489

def create_time
  @create_time
end

#descriptionString

Description of this TensorboardRun. Corresponds to the JSON property description

Returns:

  • (String)


35494
35495
35496
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35494

def description
  @description
end

#display_nameString

Required. User provided name of this TensorboardRun. This value must be unique among all TensorboardRuns belonging to the same parent TensorboardExperiment. Corresponds to the JSON property displayName

Returns:

  • (String)


35500
35501
35502
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35500

def display_name
  @display_name
end

#etagString

Used to perform a consistent read-modify-write updates. If not set, a blind " overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


35506
35507
35508
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35506

def etag
  @etag
end

#labelsHash<String,String>

The labels with user-defined metadata to organize your TensorboardRuns. This field will be used to filter and visualize Runs in the Tensorboard UI. For example, a Vertex AI training job can set a label aiplatform.googleapis.com/ training_job_id=xxxxx to all the runs created within that job. An end user can set a label experiment_id=xxxxx for all the runs produced in a Jupyter notebook. These runs can be grouped by a label value and visualized together in the Tensorboard UI. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. No more than 64 user labels can be associated with one TensorboardRun (System labels are excluded). See https://goo.gl/xmQnxf for more information and examples of labels. System reserved label keys are prefixed with "aiplatform. googleapis.com/" and are immutable. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


35523
35524
35525
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35523

def labels
  @labels
end

#nameString

Output only. Name of the TensorboardRun. Format: projects/project/locations/ location/tensorboards/tensorboard/experiments/experiment/runs/run` Corresponds to the JSON propertyname`

Returns:

  • (String)


35529
35530
35531
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35529

def name
  @name
end

#update_timeString

Output only. Timestamp when this TensorboardRun was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


35534
35535
35536
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35534

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35541
35542
35543
35544
35545
35546
35547
35548
35549
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35541

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end