Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardRun
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardRun
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
TensorboardRun maps to a specific execution of a training job with a given set of hyperparameter values, model definition, dataset, etc
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Description of this TensorboardRun.
-
#display_name ⇒ String
Required.
-
#etag ⇒ String
Used to perform a consistent read-modify-write updates.
-
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your TensorboardRuns.
-
#name ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1TensorboardRun
constructor
A new instance of GoogleCloudAiplatformV1TensorboardRun.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1TensorboardRun
Returns a new instance of GoogleCloudAiplatformV1TensorboardRun.
31652 31653 31654 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31652 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this TensorboardRun was created.
Corresponds to the JSON property createTime
31605 31606 31607 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31605 def create_time @create_time end |
#description ⇒ String
Description of this TensorboardRun.
Corresponds to the JSON property description
31610 31611 31612 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31610 def description @description end |
#display_name ⇒ String
Required. User provided name of this TensorboardRun. This value must be unique
among all TensorboardRuns belonging to the same parent TensorboardExperiment.
Corresponds to the JSON property displayName
31616 31617 31618 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31616 def display_name @display_name end |
#etag ⇒ String
Used to perform a consistent read-modify-write updates. If not set, a blind "
overwrite" update happens.
Corresponds to the JSON property etag
31622 31623 31624 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31622 def etag @etag end |
#labels ⇒ Hash<String,String>
The labels with user-defined metadata to organize your TensorboardRuns. This
field will be used to filter and visualize Runs in the Tensorboard UI. For
example, a Vertex AI training job can set a label aiplatform.googleapis.com/
training_job_id=xxxxx to all the runs created within that job. An end user can
set a label experiment_id=xxxxx for all the runs produced in a Jupyter
notebook. These runs can be grouped by a label value and visualized together
in the Tensorboard UI. Label keys and values can be no longer than 64
characters (Unicode codepoints), can only contain lowercase letters, numeric
characters, underscores and dashes. International characters are allowed. No
more than 64 user labels can be associated with one TensorboardRun (System
labels are excluded). See https://goo.gl/xmQnxf for more information and
examples of labels. System reserved label keys are prefixed with "aiplatform.
googleapis.com/" and are immutable.
Corresponds to the JSON property labels
31639 31640 31641 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31639 def labels @labels end |
#name ⇒ String
Output only. Name of the TensorboardRun. Format: projects/project/locations/
location/tensorboards/tensorboard/experiments/experiment/runs/run`
Corresponds to the JSON propertyname`
31645 31646 31647 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31645 def name @name end |
#update_time ⇒ String
Output only. Timestamp when this TensorboardRun was last updated.
Corresponds to the JSON property updateTime
31650 31651 31652 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31650 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31657 31658 31659 31660 31661 31662 31663 31664 31665 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31657 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) end |