Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardTimeSeries
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardTimeSeries
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
TensorboardTimeSeries maps to times series produced in training runs
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Description of this TensorboardTimeSeries.
-
#display_name ⇒ String
Required.
-
#etag ⇒ String
Used to perform a consistent read-modify-write updates.
-
#metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardTimeSeriesMetadata
Describes metadata for a TensorboardTimeSeries.
-
#name ⇒ String
Output only.
-
#plugin_data ⇒ String
Data of the current plugin, with the size limited to 65KB.
-
#plugin_name ⇒ String
Immutable.
-
#update_time ⇒ String
Output only.
-
#value_type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1TensorboardTimeSeries
constructor
A new instance of GoogleCloudAiplatformV1TensorboardTimeSeries.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1TensorboardTimeSeries
Returns a new instance of GoogleCloudAiplatformV1TensorboardTimeSeries.
37769 37770 37771 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37769 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this TensorboardTimeSeries was created.
Corresponds to the JSON property createTime
37717 37718 37719 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37717 def create_time @create_time end |
#description ⇒ String
Description of this TensorboardTimeSeries.
Corresponds to the JSON property description
37722 37723 37724 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37722 def description @description end |
#display_name ⇒ String
Required. User provided name of this TensorboardTimeSeries. This value should
be unique among all TensorboardTimeSeries resources belonging to the same
TensorboardRun resource (parent resource).
Corresponds to the JSON property displayName
37729 37730 37731 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37729 def display_name @display_name end |
#etag ⇒ String
Used to perform a consistent read-modify-write updates. If not set, a blind "
overwrite" update happens.
Corresponds to the JSON property etag
37735 37736 37737 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37735 def etag @etag end |
#metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardTimeSeriesMetadata
Describes metadata for a TensorboardTimeSeries.
Corresponds to the JSON property metadata
37740 37741 37742 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37740 def @metadata end |
#name ⇒ String
Output only. Name of the TensorboardTimeSeries.
Corresponds to the JSON property name
37745 37746 37747 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37745 def name @name end |
#plugin_data ⇒ String
Data of the current plugin, with the size limited to 65KB.
Corresponds to the JSON property pluginData
NOTE: Values are automatically base64 encoded/decoded in the client library.
37751 37752 37753 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37751 def plugin_data @plugin_data end |
#plugin_name ⇒ String
Immutable. Name of the plugin this time series pertain to. Such as Scalar,
Tensor, Blob
Corresponds to the JSON property pluginName
37757 37758 37759 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37757 def plugin_name @plugin_name end |
#update_time ⇒ String
Output only. Timestamp when this TensorboardTimeSeries was last updated.
Corresponds to the JSON property updateTime
37762 37763 37764 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37762 def update_time @update_time end |
#value_type ⇒ String
Required. Immutable. Type of TensorboardTimeSeries value.
Corresponds to the JSON property valueType
37767 37768 37769 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37767 def value_type @value_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37774 37775 37776 37777 37778 37779 37780 37781 37782 37783 37784 37785 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37774 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @metadata = args[:metadata] if args.key?(:metadata) @name = args[:name] if args.key?(:name) @plugin_data = args[:plugin_data] if args.key?(:plugin_data) @plugin_name = args[:plugin_name] if args.key?(:plugin_name) @update_time = args[:update_time] if args.key?(:update_time) @value_type = args[:value_type] if args.key?(:value_type) end |