Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardTimeSeries

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

TensorboardTimeSeries maps to times series produced in training runs

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1TensorboardTimeSeries

Returns a new instance of GoogleCloudAiplatformV1TensorboardTimeSeries.



37190
37191
37192
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37190

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this TensorboardTimeSeries was created. Corresponds to the JSON property createTime

Returns:

  • (String)


37138
37139
37140
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37138

def create_time
  @create_time
end

#descriptionString

Description of this TensorboardTimeSeries. Corresponds to the JSON property description

Returns:

  • (String)


37143
37144
37145
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37143

def description
  @description
end

#display_nameString

Required. User provided name of this TensorboardTimeSeries. This value should be unique among all TensorboardTimeSeries resources belonging to the same TensorboardRun resource (parent resource). Corresponds to the JSON property displayName

Returns:

  • (String)


37150
37151
37152
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37150

def display_name
  @display_name
end

#etagString

Used to perform a consistent read-modify-write updates. If not set, a blind " overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


37156
37157
37158
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37156

def etag
  @etag
end

#metadataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardTimeSeriesMetadata

Describes metadata for a TensorboardTimeSeries. Corresponds to the JSON property metadata



37161
37162
37163
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37161

def 
  @metadata
end

#nameString

Output only. Name of the TensorboardTimeSeries. Corresponds to the JSON property name

Returns:

  • (String)


37166
37167
37168
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37166

def name
  @name
end

#plugin_dataString

Data of the current plugin, with the size limited to 65KB. Corresponds to the JSON property pluginData NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


37172
37173
37174
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37172

def plugin_data
  @plugin_data
end

#plugin_nameString

Immutable. Name of the plugin this time series pertain to. Such as Scalar, Tensor, Blob Corresponds to the JSON property pluginName

Returns:

  • (String)


37178
37179
37180
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37178

def plugin_name
  @plugin_name
end

#update_timeString

Output only. Timestamp when this TensorboardTimeSeries was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


37183
37184
37185
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37183

def update_time
  @update_time
end

#value_typeString

Required. Immutable. Type of TensorboardTimeSeries value. Corresponds to the JSON property valueType

Returns:

  • (String)


37188
37189
37190
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37188

def value_type
  @value_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37195
37196
37197
37198
37199
37200
37201
37202
37203
37204
37205
37206
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37195

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @plugin_data = args[:plugin_data] if args.key?(:plugin_data)
  @plugin_name = args[:plugin_name] if args.key?(:plugin_name)
  @update_time = args[:update_time] if args.key?(:update_time)
  @value_type = args[:value_type] if args.key?(:value_type)
end