Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardTimeSeries

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

TensorboardTimeSeries maps to times series produced in training runs

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1TensorboardTimeSeries

Returns a new instance of GoogleCloudAiplatformV1TensorboardTimeSeries.



35656
35657
35658
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35656

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this TensorboardTimeSeries was created. Corresponds to the JSON property createTime

Returns:

  • (String)


35604
35605
35606
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35604

def create_time
  @create_time
end

#descriptionString

Description of this TensorboardTimeSeries. Corresponds to the JSON property description

Returns:

  • (String)


35609
35610
35611
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35609

def description
  @description
end

#display_nameString

Required. User provided name of this TensorboardTimeSeries. This value should be unique among all TensorboardTimeSeries resources belonging to the same TensorboardRun resource (parent resource). Corresponds to the JSON property displayName

Returns:

  • (String)


35616
35617
35618
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35616

def display_name
  @display_name
end

#etagString

Used to perform a consistent read-modify-write updates. If not set, a blind " overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


35622
35623
35624
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35622

def etag
  @etag
end

#metadataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardTimeSeriesMetadata

Describes metadata for a TensorboardTimeSeries. Corresponds to the JSON property metadata



35627
35628
35629
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35627

def 
  @metadata
end

#nameString

Output only. Name of the TensorboardTimeSeries. Corresponds to the JSON property name

Returns:

  • (String)


35632
35633
35634
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35632

def name
  @name
end

#plugin_dataString

Data of the current plugin, with the size limited to 65KB. Corresponds to the JSON property pluginData NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


35638
35639
35640
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35638

def plugin_data
  @plugin_data
end

#plugin_nameString

Immutable. Name of the plugin this time series pertain to. Such as Scalar, Tensor, Blob Corresponds to the JSON property pluginName

Returns:

  • (String)


35644
35645
35646
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35644

def plugin_name
  @plugin_name
end

#update_timeString

Output only. Timestamp when this TensorboardTimeSeries was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


35649
35650
35651
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35649

def update_time
  @update_time
end

#value_typeString

Required. Immutable. Type of TensorboardTimeSeries value. Corresponds to the JSON property valueType

Returns:

  • (String)


35654
35655
35656
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35654

def value_type
  @value_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35661
35662
35663
35664
35665
35666
35667
35668
35669
35670
35671
35672
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35661

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @plugin_data = args[:plugin_data] if args.key?(:plugin_data)
  @plugin_name = args[:plugin_name] if args.key?(:plugin_name)
  @update_time = args[:update_time] if args.key?(:update_time)
  @value_type = args[:value_type] if args.key?(:value_type)
end