Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardTimeSeries
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardTimeSeries
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
TensorboardTimeSeries maps to times series produced in training runs
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Description of this TensorboardTimeSeries.
-
#display_name ⇒ String
Required.
-
#etag ⇒ String
Used to perform a consistent read-modify-write updates.
-
#metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardTimeSeriesMetadata
Describes metadata for a TensorboardTimeSeries.
-
#name ⇒ String
Output only.
-
#plugin_data ⇒ String
Data of the current plugin, with the size limited to 65KB.
-
#plugin_name ⇒ String
Immutable.
-
#update_time ⇒ String
Output only.
-
#value_type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1TensorboardTimeSeries
constructor
A new instance of GoogleCloudAiplatformV1TensorboardTimeSeries.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1TensorboardTimeSeries
Returns a new instance of GoogleCloudAiplatformV1TensorboardTimeSeries.
34442 34443 34444 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34442 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when this TensorboardTimeSeries was created.
Corresponds to the JSON property createTime
34390 34391 34392 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34390 def create_time @create_time end |
#description ⇒ String
Description of this TensorboardTimeSeries.
Corresponds to the JSON property description
34395 34396 34397 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34395 def description @description end |
#display_name ⇒ String
Required. User provided name of this TensorboardTimeSeries. This value should
be unique among all TensorboardTimeSeries resources belonging to the same
TensorboardRun resource (parent resource).
Corresponds to the JSON property displayName
34402 34403 34404 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34402 def display_name @display_name end |
#etag ⇒ String
Used to perform a consistent read-modify-write updates. If not set, a blind "
overwrite" update happens.
Corresponds to the JSON property etag
34408 34409 34410 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34408 def etag @etag end |
#metadata ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardTimeSeriesMetadata
Describes metadata for a TensorboardTimeSeries.
Corresponds to the JSON property metadata
34413 34414 34415 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34413 def @metadata end |
#name ⇒ String
Output only. Name of the TensorboardTimeSeries.
Corresponds to the JSON property name
34418 34419 34420 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34418 def name @name end |
#plugin_data ⇒ String
Data of the current plugin, with the size limited to 65KB.
Corresponds to the JSON property pluginData
NOTE: Values are automatically base64 encoded/decoded in the client library.
34424 34425 34426 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34424 def plugin_data @plugin_data end |
#plugin_name ⇒ String
Immutable. Name of the plugin this time series pertain to. Such as Scalar,
Tensor, Blob
Corresponds to the JSON property pluginName
34430 34431 34432 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34430 def plugin_name @plugin_name end |
#update_time ⇒ String
Output only. Timestamp when this TensorboardTimeSeries was last updated.
Corresponds to the JSON property updateTime
34435 34436 34437 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34435 def update_time @update_time end |
#value_type ⇒ String
Required. Immutable. Type of TensorboardTimeSeries value.
Corresponds to the JSON property valueType
34440 34441 34442 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34440 def value_type @value_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34447 34448 34449 34450 34451 34452 34453 34454 34455 34456 34457 34458 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34447 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @metadata = args[:metadata] if args.key?(:metadata) @name = args[:name] if args.key?(:name) @plugin_data = args[:plugin_data] if args.key?(:plugin_data) @plugin_name = args[:plugin_name] if args.key?(:plugin_name) @update_time = args[:update_time] if args.key?(:update_time) @value_type = args[:value_type] if args.key?(:value_type) end |