Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardTimeSeries

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

TensorboardTimeSeries maps to times series produced in training runs

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1TensorboardTimeSeries

Returns a new instance of GoogleCloudAiplatformV1TensorboardTimeSeries.



27201
27202
27203
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27201

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this TensorboardTimeSeries was created. Corresponds to the JSON property createTime

Returns:

  • (String)


27149
27150
27151
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27149

def create_time
  @create_time
end

#descriptionString

Description of this TensorboardTimeSeries. Corresponds to the JSON property description

Returns:

  • (String)


27154
27155
27156
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27154

def description
  @description
end

#display_nameString

Required. User provided name of this TensorboardTimeSeries. This value should be unique among all TensorboardTimeSeries resources belonging to the same TensorboardRun resource (parent resource). Corresponds to the JSON property displayName

Returns:

  • (String)


27161
27162
27163
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27161

def display_name
  @display_name
end

#etagString

Used to perform a consistent read-modify-write updates. If not set, a blind " overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


27167
27168
27169
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27167

def etag
  @etag
end

#metadataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardTimeSeriesMetadata

Describes metadata for a TensorboardTimeSeries. Corresponds to the JSON property metadata



27172
27173
27174
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27172

def 
  @metadata
end

#nameString

Output only. Name of the TensorboardTimeSeries. Corresponds to the JSON property name

Returns:

  • (String)


27177
27178
27179
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27177

def name
  @name
end

#plugin_dataString

Data of the current plugin, with the size limited to 65KB. Corresponds to the JSON property pluginData NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


27183
27184
27185
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27183

def plugin_data
  @plugin_data
end

#plugin_nameString

Immutable. Name of the plugin this time series pertain to. Such as Scalar, Tensor, Blob Corresponds to the JSON property pluginName

Returns:

  • (String)


27189
27190
27191
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27189

def plugin_name
  @plugin_name
end

#update_timeString

Output only. Timestamp when this TensorboardTimeSeries was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


27194
27195
27196
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27194

def update_time
  @update_time
end

#value_typeString

Required. Immutable. Type of TensorboardTimeSeries value. Corresponds to the JSON property valueType

Returns:

  • (String)


27199
27200
27201
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27199

def value_type
  @value_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27206
27207
27208
27209
27210
27211
27212
27213
27214
27215
27216
27217
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27206

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @plugin_data = args[:plugin_data] if args.key?(:plugin_data)
  @plugin_name = args[:plugin_name] if args.key?(:plugin_name)
  @update_time = args[:update_time] if args.key?(:update_time)
  @value_type = args[:value_type] if args.key?(:value_type)
end