Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardTimeSeries

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

TensorboardTimeSeries maps to times series produced in training runs

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1TensorboardTimeSeries

Returns a new instance of GoogleCloudAiplatformV1TensorboardTimeSeries.



28035
28036
28037
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28035

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when this TensorboardTimeSeries was created. Corresponds to the JSON property createTime

Returns:

  • (String)


27983
27984
27985
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27983

def create_time
  @create_time
end

#descriptionString

Description of this TensorboardTimeSeries. Corresponds to the JSON property description

Returns:

  • (String)


27988
27989
27990
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27988

def description
  @description
end

#display_nameString

Required. User provided name of this TensorboardTimeSeries. This value should be unique among all TensorboardTimeSeries resources belonging to the same TensorboardRun resource (parent resource). Corresponds to the JSON property displayName

Returns:

  • (String)


27995
27996
27997
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27995

def display_name
  @display_name
end

#etagString

Used to perform a consistent read-modify-write updates. If not set, a blind " overwrite" update happens. Corresponds to the JSON property etag

Returns:

  • (String)


28001
28002
28003
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28001

def etag
  @etag
end

#metadataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardTimeSeriesMetadata

Describes metadata for a TensorboardTimeSeries. Corresponds to the JSON property metadata



28006
28007
28008
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28006

def 
  @metadata
end

#nameString

Output only. Name of the TensorboardTimeSeries. Corresponds to the JSON property name

Returns:

  • (String)


28011
28012
28013
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28011

def name
  @name
end

#plugin_dataString

Data of the current plugin, with the size limited to 65KB. Corresponds to the JSON property pluginData NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


28017
28018
28019
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28017

def plugin_data
  @plugin_data
end

#plugin_nameString

Immutable. Name of the plugin this time series pertain to. Such as Scalar, Tensor, Blob Corresponds to the JSON property pluginName

Returns:

  • (String)


28023
28024
28025
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28023

def plugin_name
  @plugin_name
end

#update_timeString

Output only. Timestamp when this TensorboardTimeSeries was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


28028
28029
28030
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28028

def update_time
  @update_time
end

#value_typeString

Required. Immutable. Type of TensorboardTimeSeries value. Corresponds to the JSON property valueType

Returns:

  • (String)


28033
28034
28035
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28033

def value_type
  @value_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28040
28041
28042
28043
28044
28045
28046
28047
28048
28049
28050
28051
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28040

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @plugin_data = args[:plugin_data] if args.key?(:plugin_data)
  @plugin_name = args[:plugin_name] if args.key?(:plugin_name)
  @update_time = args[:update_time] if args.key?(:update_time)
  @value_type = args[:value_type] if args.key?(:value_type)
end