Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardTimeSeriesMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Describes metadata for a TensorboardTimeSeries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1TensorboardTimeSeriesMetadata

Returns a new instance of GoogleCloudAiplatformV1TensorboardTimeSeriesMetadata.



26590
26591
26592
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26590

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_blob_sequence_lengthFixnum

Output only. The largest blob sequence length (number of blobs) of all data points in this time series, if its ValueType is BLOB_SEQUENCE. Corresponds to the JSON property maxBlobSequenceLength

Returns:

  • (Fixnum)


26577
26578
26579
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26577

def max_blob_sequence_length
  @max_blob_sequence_length
end

#max_stepFixnum

Output only. Max step index of all data points within a TensorboardTimeSeries. Corresponds to the JSON property maxStep

Returns:

  • (Fixnum)


26582
26583
26584
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26582

def max_step
  @max_step
end

#max_wall_timeString

Output only. Max wall clock timestamp of all data points within a TensorboardTimeSeries. Corresponds to the JSON property maxWallTime

Returns:

  • (String)


26588
26589
26590
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26588

def max_wall_time
  @max_wall_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26595
26596
26597
26598
26599
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 26595

def update!(**args)
  @max_blob_sequence_length = args[:max_blob_sequence_length] if args.key?(:max_blob_sequence_length)
  @max_step = args[:max_step] if args.key?(:max_step)
  @max_wall_time = args[:max_wall_time] if args.key?(:max_wall_time)
end