Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TimeSeriesData

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

All the data stored in a TensorboardTimeSeries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1TimeSeriesData

Returns a new instance of GoogleCloudAiplatformV1TimeSeriesData.



37851
37852
37853
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37851

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#tensorboard_time_series_idString

Required. The ID of the TensorboardTimeSeries, which will become the final component of the TensorboardTimeSeries' resource name Corresponds to the JSON property tensorboardTimeSeriesId

Returns:

  • (String)


37838
37839
37840
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37838

def tensorboard_time_series_id
  @tensorboard_time_series_id
end

#value_typeString

Required. Immutable. The value type of this time series. All the values in this time series data must match this value type. Corresponds to the JSON property valueType

Returns:

  • (String)


37844
37845
37846
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37844

def value_type
  @value_type
end

#valuesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TimeSeriesDataPoint>

Required. Data points in this time series. Corresponds to the JSON property values



37849
37850
37851
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37849

def values
  @values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37856
37857
37858
37859
37860
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37856

def update!(**args)
  @tensorboard_time_series_id = args[:tensorboard_time_series_id] if args.key?(:tensorboard_time_series_id)
  @value_type = args[:value_type] if args.key?(:value_type)
  @values = args[:values] if args.key?(:values)
end