Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TimeSeriesData

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

All the data stored in a TensorboardTimeSeries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1TimeSeriesData

Returns a new instance of GoogleCloudAiplatformV1TimeSeriesData.



36353
36354
36355
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36353

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#tensorboard_time_series_idString

Required. The ID of the TensorboardTimeSeries, which will become the final component of the TensorboardTimeSeries' resource name Corresponds to the JSON property tensorboardTimeSeriesId

Returns:

  • (String)


36340
36341
36342
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36340

def tensorboard_time_series_id
  @tensorboard_time_series_id
end

#value_typeString

Required. Immutable. The value type of this time series. All the values in this time series data must match this value type. Corresponds to the JSON property valueType

Returns:

  • (String)


36346
36347
36348
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36346

def value_type
  @value_type
end

#valuesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TimeSeriesDataPoint>

Required. Data points in this time series. Corresponds to the JSON property values



36351
36352
36353
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36351

def values
  @values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36358
36359
36360
36361
36362
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36358

def update!(**args)
  @tensorboard_time_series_id = args[:tensorboard_time_series_id] if args.key?(:tensorboard_time_series_id)
  @value_type = args[:value_type] if args.key?(:value_type)
  @values = args[:values] if args.key?(:values)
end