Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TimeSeriesDataPoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A TensorboardTimeSeries data point.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1TimeSeriesDataPoint

Returns a new instance of GoogleCloudAiplatformV1TimeSeriesDataPoint.



37893
37894
37895
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37893

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blobsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardBlobSequence

One point viewable on a blob metric plot, but mostly just a wrapper message to work around repeated fields can't be used directly within oneof fields. Corresponds to the JSON property blobs



37871
37872
37873
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37871

def blobs
  @blobs
end

#scalarGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Scalar

One point viewable on a scalar metric plot. Corresponds to the JSON property scalar



37876
37877
37878
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37876

def scalar
  @scalar
end

#stepFixnum

Step index of this data point within the run. Corresponds to the JSON property step

Returns:

  • (Fixnum)


37881
37882
37883
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37881

def step
  @step
end

#tensorGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardTensor

One point viewable on a tensor metric plot. Corresponds to the JSON property tensor



37886
37887
37888
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37886

def tensor
  @tensor
end

#wall_timeString

Wall clock timestamp when this data point is generated by the end user. Corresponds to the JSON property wallTime

Returns:

  • (String)


37891
37892
37893
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37891

def wall_time
  @wall_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37898
37899
37900
37901
37902
37903
37904
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37898

def update!(**args)
  @blobs = args[:blobs] if args.key?(:blobs)
  @scalar = args[:scalar] if args.key?(:scalar)
  @step = args[:step] if args.key?(:step)
  @tensor = args[:tensor] if args.key?(:tensor)
  @wall_time = args[:wall_time] if args.key?(:wall_time)
end