Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TimeSeriesDataPoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A TensorboardTimeSeries data point.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1TimeSeriesDataPoint

Returns a new instance of GoogleCloudAiplatformV1TimeSeriesDataPoint.



37466
37467
37468
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37466

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blobsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardBlobSequence

One point viewable on a blob metric plot, but mostly just a wrapper message to work around repeated fields can't be used directly within oneof fields. Corresponds to the JSON property blobs



37444
37445
37446
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37444

def blobs
  @blobs
end

#scalarGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Scalar

One point viewable on a scalar metric plot. Corresponds to the JSON property scalar



37449
37450
37451
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37449

def scalar
  @scalar
end

#stepFixnum

Step index of this data point within the run. Corresponds to the JSON property step

Returns:

  • (Fixnum)


37454
37455
37456
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37454

def step
  @step
end

#tensorGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardTensor

One point viewable on a tensor metric plot. Corresponds to the JSON property tensor



37459
37460
37461
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37459

def tensor
  @tensor
end

#wall_timeString

Wall clock timestamp when this data point is generated by the end user. Corresponds to the JSON property wallTime

Returns:

  • (String)


37464
37465
37466
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37464

def wall_time
  @wall_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37471
37472
37473
37474
37475
37476
37477
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37471

def update!(**args)
  @blobs = args[:blobs] if args.key?(:blobs)
  @scalar = args[:scalar] if args.key?(:scalar)
  @step = args[:step] if args.key?(:step)
  @tensor = args[:tensor] if args.key?(:tensor)
  @wall_time = args[:wall_time] if args.key?(:wall_time)
end