Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TimeSeriesDataPoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A TensorboardTimeSeries data point.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1TimeSeriesDataPoint

Returns a new instance of GoogleCloudAiplatformV1TimeSeriesDataPoint.



35488
35489
35490
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35488

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blobsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardBlobSequence

One point viewable on a blob metric plot, but mostly just a wrapper message to work around repeated fields can't be used directly within oneof fields. Corresponds to the JSON property blobs



35466
35467
35468
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35466

def blobs
  @blobs
end

#scalarGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Scalar

One point viewable on a scalar metric plot. Corresponds to the JSON property scalar



35471
35472
35473
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35471

def scalar
  @scalar
end

#stepFixnum

Step index of this data point within the run. Corresponds to the JSON property step

Returns:

  • (Fixnum)


35476
35477
35478
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35476

def step
  @step
end

#tensorGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardTensor

One point viewable on a tensor metric plot. Corresponds to the JSON property tensor



35481
35482
35483
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35481

def tensor
  @tensor
end

#wall_timeString

Wall clock timestamp when this data point is generated by the end user. Corresponds to the JSON property wallTime

Returns:

  • (String)


35486
35487
35488
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35486

def wall_time
  @wall_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35493
35494
35495
35496
35497
35498
35499
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35493

def update!(**args)
  @blobs = args[:blobs] if args.key?(:blobs)
  @scalar = args[:scalar] if args.key?(:scalar)
  @step = args[:step] if args.key?(:step)
  @tensor = args[:tensor] if args.key?(:tensor)
  @wall_time = args[:wall_time] if args.key?(:wall_time)
end