Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TimeSeriesDataPoint
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TimeSeriesDataPoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A TensorboardTimeSeries data point.
Instance Attribute Summary collapse
-
#blobs ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardBlobSequence
One point viewable on a blob metric plot, but mostly just a wrapper message to work around repeated fields can't be used directly within
oneoffields. -
#scalar ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Scalar
One point viewable on a scalar metric plot.
-
#step ⇒ Fixnum
Step index of this data point within the run.
-
#tensor ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardTensor
One point viewable on a tensor metric plot.
-
#wall_time ⇒ String
Wall clock timestamp when this data point is generated by the end user.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1TimeSeriesDataPoint
constructor
A new instance of GoogleCloudAiplatformV1TimeSeriesDataPoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1TimeSeriesDataPoint
Returns a new instance of GoogleCloudAiplatformV1TimeSeriesDataPoint.
30506 30507 30508 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30506 def initialize(**args) update!(**args) end |
Instance Attribute Details
#blobs ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardBlobSequence
One point viewable on a blob metric plot, but mostly just a wrapper message to
work around repeated fields can't be used directly within oneof fields.
Corresponds to the JSON property blobs
30484 30485 30486 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30484 def blobs @blobs end |
#scalar ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Scalar
One point viewable on a scalar metric plot.
Corresponds to the JSON property scalar
30489 30490 30491 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30489 def scalar @scalar end |
#step ⇒ Fixnum
Step index of this data point within the run.
Corresponds to the JSON property step
30494 30495 30496 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30494 def step @step end |
#tensor ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardTensor
One point viewable on a tensor metric plot.
Corresponds to the JSON property tensor
30499 30500 30501 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30499 def tensor @tensor end |
#wall_time ⇒ String
Wall clock timestamp when this data point is generated by the end user.
Corresponds to the JSON property wallTime
30504 30505 30506 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30504 def wall_time @wall_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30511 30512 30513 30514 30515 30516 30517 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30511 def update!(**args) @blobs = args[:blobs] if args.key?(:blobs) @scalar = args[:scalar] if args.key?(:scalar) @step = args[:step] if args.key?(:step) @tensor = args[:tensor] if args.key?(:tensor) @wall_time = args[:wall_time] if args.key?(:wall_time) end |