Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TimeSeriesDataPoint
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TimeSeriesDataPoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A TensorboardTimeSeries data point.
Instance Attribute Summary collapse
-
#blobs ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardBlobSequence
One point viewable on a blob metric plot, but mostly just a wrapper message to work around repeated fields can't be used directly within
oneoffields. -
#scalar ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Scalar
One point viewable on a scalar metric plot.
-
#step ⇒ Fixnum
Step index of this data point within the run.
-
#tensor ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardTensor
One point viewable on a tensor metric plot.
-
#wall_time ⇒ String
Wall clock timestamp when this data point is generated by the end user.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1TimeSeriesDataPoint
constructor
A new instance of GoogleCloudAiplatformV1TimeSeriesDataPoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1TimeSeriesDataPoint
Returns a new instance of GoogleCloudAiplatformV1TimeSeriesDataPoint.
29834 29835 29836 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29834 def initialize(**args) update!(**args) end |
Instance Attribute Details
#blobs ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardBlobSequence
One point viewable on a blob metric plot, but mostly just a wrapper message to
work around repeated fields can't be used directly within oneof fields.
Corresponds to the JSON property blobs
29812 29813 29814 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29812 def blobs @blobs end |
#scalar ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Scalar
One point viewable on a scalar metric plot.
Corresponds to the JSON property scalar
29817 29818 29819 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29817 def scalar @scalar end |
#step ⇒ Fixnum
Step index of this data point within the run.
Corresponds to the JSON property step
29822 29823 29824 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29822 def step @step end |
#tensor ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardTensor
One point viewable on a tensor metric plot.
Corresponds to the JSON property tensor
29827 29828 29829 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29827 def tensor @tensor end |
#wall_time ⇒ String
Wall clock timestamp when this data point is generated by the end user.
Corresponds to the JSON property wallTime
29832 29833 29834 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29832 def wall_time @wall_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29839 29840 29841 29842 29843 29844 29845 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29839 def update!(**args) @blobs = args[:blobs] if args.key?(:blobs) @scalar = args[:scalar] if args.key?(:scalar) @step = args[:step] if args.key?(:step) @tensor = args[:tensor] if args.key?(:tensor) @wall_time = args[:wall_time] if args.key?(:wall_time) end |