Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TimeSeriesDataPoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A TensorboardTimeSeries data point.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1TimeSeriesDataPoint

Returns a new instance of GoogleCloudAiplatformV1TimeSeriesDataPoint.



27122
27123
27124
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27122

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blobsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardBlobSequence

One point viewable on a blob metric plot, but mostly just a wrapper message to work around repeated fields can't be used directly within oneof fields. Corresponds to the JSON property blobs



27100
27101
27102
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27100

def blobs
  @blobs
end

#scalarGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Scalar

One point viewable on a scalar metric plot. Corresponds to the JSON property scalar



27105
27106
27107
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27105

def scalar
  @scalar
end

#stepFixnum

Step index of this data point within the run. Corresponds to the JSON property step

Returns:

  • (Fixnum)


27110
27111
27112
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27110

def step
  @step
end

#tensorGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TensorboardTensor

One point viewable on a tensor metric plot. Corresponds to the JSON property tensor



27115
27116
27117
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27115

def tensor
  @tensor
end

#wall_timeString

Wall clock timestamp when this data point is generated by the end user. Corresponds to the JSON property wallTime

Returns:

  • (String)


27120
27121
27122
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27120

def wall_time
  @wall_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27127
27128
27129
27130
27131
27132
27133
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27127

def update!(**args)
  @blobs = args[:blobs] if args.key?(:blobs)
  @scalar = args[:scalar] if args.key?(:scalar)
  @step = args[:step] if args.key?(:step)
  @tensor = args[:tensor] if args.key?(:tensor)
  @wall_time = args[:wall_time] if args.key?(:wall_time)
end