Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TimestampSplit
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TimestampSplit
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Assigns input data to training, validation, and test sets based on a provided timestamps. The youngest data pieces are assigned to training set, next to validation set, and the oldest to the test set. Supported only for tabular Datasets.
Instance Attribute Summary collapse
-
#key ⇒ String
Required.
-
#test_fraction ⇒ Float
The fraction of the input data that is to be used to evaluate the Model.
-
#training_fraction ⇒ Float
The fraction of the input data that is to be used to train the Model.
-
#validation_fraction ⇒ Float
The fraction of the input data that is to be used to validate the Model.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1TimestampSplit
constructor
A new instance of GoogleCloudAiplatformV1TimestampSplit.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1TimestampSplit
Returns a new instance of GoogleCloudAiplatformV1TimestampSplit.
36960 36961 36962 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36960 def initialize(**args) update!(**args) end |
Instance Attribute Details
#key ⇒ String
Required. The key is a name of one of the Dataset's data columns. The values
of the key (the values in the column) must be in RFC 3339 date-time format,
where time-offset = "Z" (e.g. 1985-04-12T23:20:50.52Z). If for a piece of
data the key is not present or has an invalid value, that piece is ignored by
the pipeline.
Corresponds to the JSON property key
36943 36944 36945 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36943 def key @key end |
#test_fraction ⇒ Float
The fraction of the input data that is to be used to evaluate the Model.
Corresponds to the JSON property testFraction
36948 36949 36950 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36948 def test_fraction @test_fraction end |
#training_fraction ⇒ Float
The fraction of the input data that is to be used to train the Model.
Corresponds to the JSON property trainingFraction
36953 36954 36955 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36953 def training_fraction @training_fraction end |
#validation_fraction ⇒ Float
The fraction of the input data that is to be used to validate the Model.
Corresponds to the JSON property validationFraction
36958 36959 36960 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36958 def validation_fraction @validation_fraction end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36965 36966 36967 36968 36969 36970 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36965 def update!(**args) @key = args[:key] if args.key?(:key) @test_fraction = args[:test_fraction] if args.key?(:test_fraction) @training_fraction = args[:training_fraction] if args.key?(:training_fraction) @validation_fraction = args[:validation_fraction] if args.key?(:validation_fraction) end |