Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TimestampSplit
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TimestampSplit
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Assigns input data to training, validation, and test sets based on a provided timestamps. The youngest data pieces are assigned to training set, next to validation set, and the oldest to the test set. Supported only for tabular Datasets.
Instance Attribute Summary collapse
-
#key ⇒ String
Required.
-
#test_fraction ⇒ Float
The fraction of the input data that is to be used to evaluate the Model.
-
#training_fraction ⇒ Float
The fraction of the input data that is to be used to train the Model.
-
#validation_fraction ⇒ Float
The fraction of the input data that is to be used to validate the Model.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1TimestampSplit
constructor
A new instance of GoogleCloudAiplatformV1TimestampSplit.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1TimestampSplit
Returns a new instance of GoogleCloudAiplatformV1TimestampSplit.
34626 34627 34628 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34626 def initialize(**args) update!(**args) end |
Instance Attribute Details
#key ⇒ String
Required. The key is a name of one of the Dataset's data columns. The values
of the key (the values in the column) must be in RFC 3339 date-time format,
where time-offset = "Z" (e.g. 1985-04-12T23:20:50.52Z). If for a piece of
data the key is not present or has an invalid value, that piece is ignored by
the pipeline.
Corresponds to the JSON property key
34609 34610 34611 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34609 def key @key end |
#test_fraction ⇒ Float
The fraction of the input data that is to be used to evaluate the Model.
Corresponds to the JSON property testFraction
34614 34615 34616 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34614 def test_fraction @test_fraction end |
#training_fraction ⇒ Float
The fraction of the input data that is to be used to train the Model.
Corresponds to the JSON property trainingFraction
34619 34620 34621 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34619 def training_fraction @training_fraction end |
#validation_fraction ⇒ Float
The fraction of the input data that is to be used to validate the Model.
Corresponds to the JSON property validationFraction
34624 34625 34626 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34624 def validation_fraction @validation_fraction end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34631 34632 34633 34634 34635 34636 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 34631 def update!(**args) @key = args[:key] if args.key?(:key) @test_fraction = args[:test_fraction] if args.key?(:test_fraction) @training_fraction = args[:training_fraction] if args.key?(:training_fraction) @validation_fraction = args[:validation_fraction] if args.key?(:validation_fraction) end |