Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TimestampSplit

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Assigns input data to training, validation, and test sets based on a provided timestamps. The youngest data pieces are assigned to training set, next to validation set, and the oldest to the test set. Supported only for tabular Datasets.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1TimestampSplit

Returns a new instance of GoogleCloudAiplatformV1TimestampSplit.



29879
29880
29881
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29879

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#keyString

Required. The key is a name of one of the Dataset's data columns. The values of the key (the values in the column) must be in RFC 3339 date-time format, where time-offset = "Z" (e.g. 1985-04-12T23:20:50.52Z). If for a piece of data the key is not present or has an invalid value, that piece is ignored by the pipeline. Corresponds to the JSON property key

Returns:

  • (String)


29862
29863
29864
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29862

def key
  @key
end

#test_fractionFloat

The fraction of the input data that is to be used to evaluate the Model. Corresponds to the JSON property testFraction

Returns:

  • (Float)


29867
29868
29869
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29867

def test_fraction
  @test_fraction
end

#training_fractionFloat

The fraction of the input data that is to be used to train the Model. Corresponds to the JSON property trainingFraction

Returns:

  • (Float)


29872
29873
29874
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29872

def training_fraction
  @training_fraction
end

#validation_fractionFloat

The fraction of the input data that is to be used to validate the Model. Corresponds to the JSON property validationFraction

Returns:

  • (Float)


29877
29878
29879
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29877

def validation_fraction
  @validation_fraction
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29884
29885
29886
29887
29888
29889
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29884

def update!(**args)
  @key = args[:key] if args.key?(:key)
  @test_fraction = args[:test_fraction] if args.key?(:test_fraction)
  @training_fraction = args[:training_fraction] if args.key?(:training_fraction)
  @validation_fraction = args[:validation_fraction] if args.key?(:validation_fraction)
end