Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TokensInfo
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TokensInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Tokens info with a list of tokens and the corresponding list of token ids.
Instance Attribute Summary collapse
-
#role ⇒ String
Optional.
-
#token_ids ⇒ Array<Fixnum>
A list of token ids from the input.
-
#tokens ⇒ Array<String>
A list of tokens from the input.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1TokensInfo
constructor
A new instance of GoogleCloudAiplatformV1TokensInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1TokensInfo
Returns a new instance of GoogleCloudAiplatformV1TokensInfo.
37970 37971 37972 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37970 def initialize(**args) update!(**args) end |
Instance Attribute Details
#role ⇒ String
Optional. Optional fields for the role from the corresponding Content.
Corresponds to the JSON property role
37958 37959 37960 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37958 def role @role end |
#token_ids ⇒ Array<Fixnum>
A list of token ids from the input.
Corresponds to the JSON property tokenIds
37963 37964 37965 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37963 def token_ids @token_ids end |
#tokens ⇒ Array<String>
A list of tokens from the input.
Corresponds to the JSON property tokens
37968 37969 37970 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37968 def tokens @tokens end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37975 37976 37977 37978 37979 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37975 def update!(**args) @role = args[:role] if args.key?(:role) @token_ids = args[:token_ids] if args.key?(:token_ids) @tokens = args[:tokens] if args.key?(:tokens) end |