Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TokensInfo
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TokensInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Tokens info with a list of tokens and the corresponding list of token ids.
Instance Attribute Summary collapse
-
#role ⇒ String
Optional.
-
#token_ids ⇒ Array<Fixnum>
A list of token ids from the input.
-
#tokens ⇒ Array<String>
A list of tokens from the input.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1TokensInfo
constructor
A new instance of GoogleCloudAiplatformV1TokensInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1TokensInfo
Returns a new instance of GoogleCloudAiplatformV1TokensInfo.
37614 37615 37616 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37614 def initialize(**args) update!(**args) end |
Instance Attribute Details
#role ⇒ String
Optional. Optional fields for the role from the corresponding Content.
Corresponds to the JSON property role
37602 37603 37604 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37602 def role @role end |
#token_ids ⇒ Array<Fixnum>
A list of token ids from the input.
Corresponds to the JSON property tokenIds
37607 37608 37609 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37607 def token_ids @token_ids end |
#tokens ⇒ Array<String>
A list of tokens from the input.
Corresponds to the JSON property tokens
37612 37613 37614 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37612 def tokens @tokens end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37619 37620 37621 37622 37623 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37619 def update!(**args) @role = args[:role] if args.key?(:role) @token_ids = args[:token_ids] if args.key?(:token_ids) @tokens = args[:tokens] if args.key?(:tokens) end |