Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TokensInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Tokens info with a list of tokens and the corresponding list of token ids.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1TokensInfo

Returns a new instance of GoogleCloudAiplatformV1TokensInfo.



37560
37561
37562
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37560

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#roleString

Optional. Optional fields for the role from the corresponding Content. Corresponds to the JSON property role

Returns:

  • (String)


37548
37549
37550
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37548

def role
  @role
end

#token_idsArray<Fixnum>

A list of token ids from the input. Corresponds to the JSON property tokenIds

Returns:

  • (Array<Fixnum>)


37553
37554
37555
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37553

def token_ids
  @token_ids
end

#tokensArray<String>

A list of tokens from the input. Corresponds to the JSON property tokens

Returns:

  • (Array<String>)


37558
37559
37560
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37558

def tokens
  @tokens
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37565
37566
37567
37568
37569
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37565

def update!(**args)
  @role = args[:role] if args.key?(:role)
  @token_ids = args[:token_ids] if args.key?(:token_ids)
  @tokens = args[:tokens] if args.key?(:tokens)
end