Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tool

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Tool details that the model may use to generate response. A Tool is a piece of code that enables the system to interact with external systems to perform an action, or set of actions, outside of knowledge and scope of the model. A Tool object should contain exactly one type of Tool (e.g FunctionDeclaration, Retrieval or GoogleSearchRetrieval).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Tool

Returns a new instance of GoogleCloudAiplatformV1Tool.



48023
48024
48025
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48023

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#code_executionGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolCodeExecution

Tool that executes code generated by the model, and automatically returns the result to the model. See also ExecutableCode and CodeExecutionResult, which are input and output to this tool. Corresponds to the JSON property codeExecution



47963
47964
47965
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47963

def code_execution
  @code_execution
end

#computer_useGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolComputerUse

Tool to support computer use. Corresponds to the JSON property computerUse



47968
47969
47970
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47968

def computer_use
  @computer_use
end

#enterprise_web_searchGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EnterpriseWebSearch

Tool to search public web data, powered by Vertex AI Search and Sec4 compliance. Corresponds to the JSON property enterpriseWebSearch



47974
47975
47976
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47974

def enterprise_web_search
  @enterprise_web_search
end

#exa_ai_searchGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolExaAiSearch

ExaAiSearch tool type. A tool that uses the Exa.ai search engine for grounding. Corresponds to the JSON property exaAiSearch



47979
47980
47981
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47979

def exa_ai_search
  @exa_ai_search
end

#function_declarationsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FunctionDeclaration>

Optional. Function tool type. One or more function declarations to be passed to the model along with the current user query. Model may decide to call a subset of these functions by populating FunctionCall in the response. User should provide a FunctionResponse for each function call in the next turn. Based on the function responses, Model will generate the final response back to the user. Maximum 512 function declarations can be provided. Corresponds to the JSON property functionDeclarations



47989
47990
47991
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47989

def function_declarations
  @function_declarations
end

#google_mapsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GoogleMaps

Tool to retrieve public maps data for grounding, powered by Google. Corresponds to the JSON property googleMaps



47994
47995
47996
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47994

def google_maps
  @google_maps
end

#google_searchGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolGoogleSearch

GoogleSearch tool type. Tool to support Google Search in Model. Powered by Google. Corresponds to the JSON property googleSearch



48000
48001
48002
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48000

def google_search
  @google_search
end

#google_search_retrievalGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GoogleSearchRetrieval

Tool to retrieve public web data for grounding, powered by Google. Corresponds to the JSON property googleSearchRetrieval



48005
48006
48007
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48005

def google_search_retrieval
  @google_search_retrieval
end

#parallel_ai_searchGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolParallelAiSearch

ParallelAiSearch tool type. A tool that uses the Parallel.ai search engine for grounding. Corresponds to the JSON property parallelAiSearch



48011
48012
48013
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48011

def parallel_ai_search
  @parallel_ai_search
end

#retrievalGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Retrieval

Defines a retrieval tool that model can call to access external knowledge. Corresponds to the JSON property retrieval



48016
48017
48018
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48016

def retrieval
  @retrieval
end

#url_contextGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1UrlContext

Tool to support URL context. Corresponds to the JSON property urlContext



48021
48022
48023
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48021

def url_context
  @url_context
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48028
48029
48030
48031
48032
48033
48034
48035
48036
48037
48038
48039
48040
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48028

def update!(**args)
  @code_execution = args[:code_execution] if args.key?(:code_execution)
  @computer_use = args[:computer_use] if args.key?(:computer_use)
  @enterprise_web_search = args[:enterprise_web_search] if args.key?(:enterprise_web_search)
  @exa_ai_search = args[:exa_ai_search] if args.key?(:exa_ai_search)
  @function_declarations = args[:function_declarations] if args.key?(:function_declarations)
  @google_maps = args[:google_maps] if args.key?(:google_maps)
  @google_search = args[:google_search] if args.key?(:google_search)
  @google_search_retrieval = args[:google_search_retrieval] if args.key?(:google_search_retrieval)
  @parallel_ai_search = args[:parallel_ai_search] if args.key?(:parallel_ai_search)
  @retrieval = args[:retrieval] if args.key?(:retrieval)
  @url_context = args[:url_context] if args.key?(:url_context)
end