Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tool
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tool
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Tool details that the model may use to generate response. A Tool is a piece
of code that enables the system to interact with external systems to perform
an action, or set of actions, outside of knowledge and scope of the model. A
Tool object should contain exactly one type of Tool (e.g FunctionDeclaration,
Retrieval or GoogleSearchRetrieval).
Instance Attribute Summary collapse
-
#code_execution ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolCodeExecution
Tool that executes code generated by the model, and automatically returns the result to the model.
-
#computer_use ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolComputerUse
Tool to support computer use.
-
#enterprise_web_search ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EnterpriseWebSearch
Tool to search public web data, powered by Vertex AI Search and Sec4 compliance.
-
#exa_ai_search ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolExaAiSearch
ExaAiSearch tool type.
-
#function_declarations ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FunctionDeclaration>
Optional.
-
#google_maps ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GoogleMaps
Tool to retrieve public maps data for grounding, powered by Google.
-
#google_search ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolGoogleSearch
GoogleSearch tool type.
-
#google_search_retrieval ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GoogleSearchRetrieval
Tool to retrieve public web data for grounding, powered by Google.
-
#parallel_ai_search ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolParallelAiSearch
ParallelAiSearch tool type.
-
#retrieval ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Retrieval
Defines a retrieval tool that model can call to access external knowledge.
-
#url_context ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1UrlContext
Tool to support URL context.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Tool
constructor
A new instance of GoogleCloudAiplatformV1Tool.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Tool
Returns a new instance of GoogleCloudAiplatformV1Tool.
47579 47580 47581 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47579 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code_execution ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolCodeExecution
Tool that executes code generated by the model, and automatically returns the
result to the model. See also ExecutableCode and CodeExecutionResult, which
are input and output to this tool.
Corresponds to the JSON property codeExecution
47519 47520 47521 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47519 def code_execution @code_execution end |
#computer_use ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolComputerUse
Tool to support computer use.
Corresponds to the JSON property computerUse
47524 47525 47526 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47524 def computer_use @computer_use end |
#enterprise_web_search ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EnterpriseWebSearch
Tool to search public web data, powered by Vertex AI Search and Sec4
compliance.
Corresponds to the JSON property enterpriseWebSearch
47530 47531 47532 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47530 def enterprise_web_search @enterprise_web_search end |
#exa_ai_search ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolExaAiSearch
ExaAiSearch tool type. A tool that uses the Exa.ai search engine for grounding.
Corresponds to the JSON property exaAiSearch
47535 47536 47537 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47535 def exa_ai_search @exa_ai_search end |
#function_declarations ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FunctionDeclaration>
Optional. Function tool type. One or more function declarations to be passed
to the model along with the current user query. Model may decide to call a
subset of these functions by populating FunctionCall in the response. User
should provide a FunctionResponse for each function call in the next turn.
Based on the function responses, Model will generate the final response back
to the user. Maximum 512 function declarations can be provided.
Corresponds to the JSON property functionDeclarations
47545 47546 47547 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47545 def function_declarations @function_declarations end |
#google_maps ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GoogleMaps
Tool to retrieve public maps data for grounding, powered by Google.
Corresponds to the JSON property googleMaps
47550 47551 47552 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47550 def google_maps @google_maps end |
#google_search ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolGoogleSearch
GoogleSearch tool type. Tool to support Google Search in Model. Powered by
Google.
Corresponds to the JSON property googleSearch
47556 47557 47558 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47556 def google_search @google_search end |
#google_search_retrieval ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1GoogleSearchRetrieval
Tool to retrieve public web data for grounding, powered by Google.
Corresponds to the JSON property googleSearchRetrieval
47561 47562 47563 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47561 def google_search_retrieval @google_search_retrieval end |
#parallel_ai_search ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolParallelAiSearch
ParallelAiSearch tool type. A tool that uses the Parallel.ai search engine for
grounding.
Corresponds to the JSON property parallelAiSearch
47567 47568 47569 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47567 def parallel_ai_search @parallel_ai_search end |
#retrieval ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Retrieval
Defines a retrieval tool that model can call to access external knowledge.
Corresponds to the JSON property retrieval
47572 47573 47574 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47572 def retrieval @retrieval end |
#url_context ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1UrlContext
Tool to support URL context.
Corresponds to the JSON property urlContext
47577 47578 47579 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47577 def url_context @url_context end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47584 47585 47586 47587 47588 47589 47590 47591 47592 47593 47594 47595 47596 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47584 def update!(**args) @code_execution = args[:code_execution] if args.key?(:code_execution) @computer_use = args[:computer_use] if args.key?(:computer_use) @enterprise_web_search = args[:enterprise_web_search] if args.key?(:enterprise_web_search) @exa_ai_search = args[:exa_ai_search] if args.key?(:exa_ai_search) @function_declarations = args[:function_declarations] if args.key?(:function_declarations) @google_maps = args[:google_maps] if args.key?(:google_maps) @google_search = args[:google_search] if args.key?(:google_search) @google_search_retrieval = args[:google_search_retrieval] if args.key?(:google_search_retrieval) @parallel_ai_search = args[:parallel_ai_search] if args.key?(:parallel_ai_search) @retrieval = args[:retrieval] if args.key?(:retrieval) @url_context = args[:url_context] if args.key?(:url_context) end |