Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tool

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Tool details that the model may use to generate response. A Tool is a piece of code that enables the system to interact with external systems to perform an action, or set of actions, outside of knowledge and scope of the model. A Tool object should contain exactly one type of Tool (e.g FunctionDeclaration, Retrieval or GoogleSearchRetrieval).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Tool

Returns a new instance of GoogleCloudAiplatformV1Tool.



37683
37684
37685
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37683

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#code_executionGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolCodeExecution

Tool that executes code generated by the model, and automatically returns the result to the model. See also [ExecutableCode]and [CodeExecutionResult] which are input and output to this tool. Corresponds to the JSON property codeExecution



37639
37640
37641
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37639

def code_execution
  @code_execution
end

#computer_useGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolComputerUse

Tool to support computer use. Corresponds to the JSON property computerUse



37644
37645
37646
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37644

def computer_use
  @computer_use
end

#enterprise_web_searchGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EnterpriseWebSearch

Tool to search public web data, powered by Vertex AI Search and Sec4 compliance. Corresponds to the JSON property enterpriseWebSearch



37650
37651
37652
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37650

def enterprise_web_search
  @enterprise_web_search
end

#function_declarationsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FunctionDeclaration>

Optional. Function tool type. One or more function declarations to be passed to the model along with the current user query. Model may decide to call a subset of these functions by populating FunctionCall in the response. User should provide a FunctionResponse for each function call in the next turn. Based on the function responses, Model will generate the final response back to the user. Maximum 128 function declarations can be provided. Corresponds to the JSON property functionDeclarations



37660
37661
37662
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37660

def function_declarations
  @function_declarations
end

#google_searchGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolGoogleSearch

GoogleSearch tool type. Tool to support Google Search in Model. Powered by Google. Corresponds to the JSON property googleSearch



37666
37667
37668
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37666

def google_search
  @google_search
end

#google_search_retrievalGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1GoogleSearchRetrieval

Tool to retrieve public web data for grounding, powered by Google. Corresponds to the JSON property googleSearchRetrieval



37671
37672
37673
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37671

def google_search_retrieval
  @google_search_retrieval
end

#retrievalGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Retrieval

Defines a retrieval tool that model can call to access external knowledge. Corresponds to the JSON property retrieval



37676
37677
37678
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37676

def retrieval
  @retrieval
end

#url_contextGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1UrlContext

Tool to support URL context. Corresponds to the JSON property urlContext



37681
37682
37683
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37681

def url_context
  @url_context
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37688
37689
37690
37691
37692
37693
37694
37695
37696
37697
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37688

def update!(**args)
  @code_execution = args[:code_execution] if args.key?(:code_execution)
  @computer_use = args[:computer_use] if args.key?(:computer_use)
  @enterprise_web_search = args[:enterprise_web_search] if args.key?(:enterprise_web_search)
  @function_declarations = args[:function_declarations] if args.key?(:function_declarations)
  @google_search = args[:google_search] if args.key?(:google_search)
  @google_search_retrieval = args[:google_search_retrieval] if args.key?(:google_search_retrieval)
  @retrieval = args[:retrieval] if args.key?(:retrieval)
  @url_context = args[:url_context] if args.key?(:url_context)
end