Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tool
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Tool
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Tool details that the model may use to generate response. A Tool is a piece
of code that enables the system to interact with external systems to perform
an action, or set of actions, outside of knowledge and scope of the model. A
Tool object should contain exactly one type of Tool (e.g FunctionDeclaration,
Retrieval or GoogleSearchRetrieval).
Instance Attribute Summary collapse
-
#function_declarations ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FunctionDeclaration>
Optional.
-
#retrieval ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Retrieval
Defines a retrieval tool that model can call to access external knowledge.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Tool
constructor
A new instance of GoogleCloudAiplatformV1Tool.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Tool
Returns a new instance of GoogleCloudAiplatformV1Tool.
28280 28281 28282 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28280 def initialize(**args) update!(**args) end |
Instance Attribute Details
#function_declarations ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1FunctionDeclaration>
Optional. Function tool type. One or more function declarations to be passed
to the model along with the current user query. Model may decide to call a
subset of these functions by populating FunctionCall in the response. User
should provide a FunctionResponse for each function call in the next turn.
Based on the function responses, Model will generate the final response back
to the user. Maximum 64 function declarations can be provided.
Corresponds to the JSON property functionDeclarations
28273 28274 28275 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28273 def function_declarations @function_declarations end |
#retrieval ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Retrieval
Defines a retrieval tool that model can call to access external knowledge.
Corresponds to the JSON property retrieval
28278 28279 28280 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28278 def retrieval @retrieval end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28285 28286 28287 28288 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28285 def update!(**args) @function_declarations = args[:function_declarations] if args.key?(:function_declarations) @retrieval = args[:retrieval] if args.key?(:retrieval) end |