Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolCodeExecution
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolCodeExecution
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Tool that executes code generated by the model, and automatically returns the result to the model. See also ExecutableCode and CodeExecutionResult, which are input and output to this tool.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ToolCodeExecution
constructor
A new instance of GoogleCloudAiplatformV1ToolCodeExecution.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ToolCodeExecution
Returns a new instance of GoogleCloudAiplatformV1ToolCodeExecution.
49203 49204 49205 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 49203 def initialize(**args) update!(**args) end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
49208 49209 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 49208 def update!(**args) end |