Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolCodeExecution

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Tool that executes code generated by the model, and automatically returns the result to the model. See also ExecutableCode and CodeExecutionResult, which are input and output to this tool.

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ToolCodeExecution

Returns a new instance of GoogleCloudAiplatformV1ToolCodeExecution.



48175
48176
48177
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48175

def initialize(**args)
   update!(**args)
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48180
48181
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48180

def update!(**args)
end