Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolComputerUse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Tool to support computer use.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ToolComputerUse

Returns a new instance of GoogleCloudAiplatformV1ToolComputerUse.



43893
43894
43895
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 43893

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#environmentString

Required. The environment being operated. Corresponds to the JSON property environment

Returns:

  • (String)


43881
43882
43883
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 43881

def environment
  @environment
end

#excluded_predefined_functionsArray<String>

Optional. By default, predefined functions are included in the final model call. Some of them can be explicitly excluded from being automatically included. This can serve two purposes: 1. Using a more restricted / different action space. 2. Improving the definitions / instructions of predefined functions. Corresponds to the JSON property excludedPredefinedFunctions

Returns:

  • (Array<String>)


43891
43892
43893
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 43891

def excluded_predefined_functions
  @excluded_predefined_functions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43898
43899
43900
43901
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 43898

def update!(**args)
  @environment = args[:environment] if args.key?(:environment)
  @excluded_predefined_functions = args[:excluded_predefined_functions] if args.key?(:excluded_predefined_functions)
end