Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolGoogleSearch
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolGoogleSearch
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
GoogleSearch tool type. Tool to support Google Search in Model. Powered by Google.
Instance Attribute Summary collapse
-
#blocking_confidence ⇒ String
Optional.
-
#exclude_domains ⇒ Array<String>
Optional.
-
#search_types ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolGoogleSearchSearchTypes
Different types of search that can be enabled on the GoogleSearch tool.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ToolGoogleSearch
constructor
A new instance of GoogleCloudAiplatformV1ToolGoogleSearch.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ToolGoogleSearch
Returns a new instance of GoogleCloudAiplatformV1ToolGoogleSearch.
45994 45995 45996 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45994 def initialize(**args) update!(**args) end |
Instance Attribute Details
#blocking_confidence ⇒ String
Optional. Sites with confidence level chosen & above this value will be
blocked from the search results.
Corresponds to the JSON property blockingConfidence
45981 45982 45983 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45981 def blocking_confidence @blocking_confidence end |
#exclude_domains ⇒ Array<String>
Optional. List of domains to be excluded from the search results. The default
limit is 2000 domains. Example: ["amazon.com", "facebook.com"].
Corresponds to the JSON property excludeDomains
45987 45988 45989 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45987 def exclude_domains @exclude_domains end |
#search_types ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolGoogleSearchSearchTypes
Different types of search that can be enabled on the GoogleSearch tool.
Corresponds to the JSON property searchTypes
45992 45993 45994 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45992 def search_types @search_types end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45999 46000 46001 46002 46003 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45999 def update!(**args) @blocking_confidence = args[:blocking_confidence] if args.key?(:blocking_confidence) @exclude_domains = args[:exclude_domains] if args.key?(:exclude_domains) @search_types = args[:search_types] if args.key?(:search_types) end |