Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolGoogleSearch

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

GoogleSearch tool type. Tool to support Google Search in Model. Powered by Google.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ToolGoogleSearch

Returns a new instance of GoogleCloudAiplatformV1ToolGoogleSearch.



44230
44231
44232
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44230

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blocking_confidenceString

Optional. Sites with confidence level chosen & above this value will be blocked from the search results. Corresponds to the JSON property blockingConfidence

Returns:

  • (String)


44222
44223
44224
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44222

def blocking_confidence
  @blocking_confidence
end

#exclude_domainsArray<String>

Optional. List of domains to be excluded from the search results. The default limit is 2000 domains. Example: ["amazon.com", "facebook.com"]. Corresponds to the JSON property excludeDomains

Returns:

  • (Array<String>)


44228
44229
44230
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44228

def exclude_domains
  @exclude_domains
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44235
44236
44237
44238
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44235

def update!(**args)
  @blocking_confidence = args[:blocking_confidence] if args.key?(:blocking_confidence)
  @exclude_domains = args[:exclude_domains] if args.key?(:exclude_domains)
end