Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolParallelAiSearch

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

ParallelAiSearch tool type. A tool that uses the Parallel.ai search engine for grounding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ToolParallelAiSearch

Returns a new instance of GoogleCloudAiplatformV1ToolParallelAiSearch.



48491
48492
48493
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48491

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_keyString

Optional. The API key for ParallelAiSearch. If an API key is not provided, the system will attempt to verify access by checking for an active Parallel.ai subscription through the Google Cloud Marketplace. See https://docs.parallel. ai/search/search-quickstart for more details. Corresponds to the JSON property apiKey

Returns:

  • (String)


48458
48459
48460
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48458

def api_key
  @api_key
end

#custom_configsHash<String,Object>

Optional. Custom configs for ParallelAiSearch. This field can be used to pass any parameter from the Parallel.ai Search API. See the Parallel.ai documentation for the full list of available parameters and their usage: https: //docs.parallel.ai/api-reference/search-beta/search Currently only source_policy, excerpts, max_results, mode, fetch_policy can be set via this field. For example: "source_policy": "include_domains": ["google. com", "wikipedia.org"], "exclude_domains": ["example.com"] , "fetch_policy": "max_age_seconds": 3600 Corresponds to the JSON property customConfigs

Returns:

  • (Hash<String,Object>)


48470
48471
48472
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48470

def custom_configs
  @custom_configs
end

#enable_data_retentionBoolean Also known as: enable_data_retention?

Optional. Deprecated: Use enable_zero_data_retention instead. Instructs Vertex Grounding to use Parallel's Zero Data Retention Marketplace product. If this value is "false" or omitted, the Parallel Web Search for Grounding standard subscription will be used. If this value is "true", the Parallel Web Search for Grounding - ZDR subscription will be used. Corresponds to the JSON property enableDataRetention

Returns:

  • (Boolean)


48479
48480
48481
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48479

def enable_data_retention
  @enable_data_retention
end

#enable_zero_data_retentionBoolean Also known as: enable_zero_data_retention?

Optional. Instructs Vertex Grounding to use Parallel's Zero Data Retention Marketplace product. If this value is "false" or omitted, the Parallel Web Search for Grounding standard subscription will be used. If this value is " true", the Parallel Web Search for Grounding - ZDR subscription will be used. Corresponds to the JSON property enableZeroDataRetention

Returns:

  • (Boolean)


48488
48489
48490
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48488

def enable_zero_data_retention
  @enable_zero_data_retention
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48496
48497
48498
48499
48500
48501
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48496

def update!(**args)
  @api_key = args[:api_key] if args.key?(:api_key)
  @custom_configs = args[:custom_configs] if args.key?(:custom_configs)
  @enable_data_retention = args[:enable_data_retention] if args.key?(:enable_data_retention)
  @enable_zero_data_retention = args[:enable_zero_data_retention] if args.key?(:enable_zero_data_retention)
end