Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolParallelAiSearch
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolParallelAiSearch
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
ParallelAiSearch tool type. A tool that uses the Parallel.ai search engine for grounding.
Instance Attribute Summary collapse
-
#api_key ⇒ String
Optional.
-
#custom_configs ⇒ Hash<String,Object>
Optional.
-
#enable_data_retention ⇒ Boolean
(also: #enable_data_retention?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ToolParallelAiSearch
constructor
A new instance of GoogleCloudAiplatformV1ToolParallelAiSearch.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ToolParallelAiSearch
Returns a new instance of GoogleCloudAiplatformV1ToolParallelAiSearch.
48050 48051 48052 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48050 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_key ⇒ String
Optional. The API key for ParallelAiSearch. If an API key is not provided, the
system will attempt to verify access by checking for an active Parallel.ai
subscription through the Google Cloud Marketplace. See https://docs.parallel.
ai/search/search-quickstart for more details.
Corresponds to the JSON property apiKey
48027 48028 48029 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48027 def api_key @api_key end |
#custom_configs ⇒ Hash<String,Object>
Optional. Custom configs for ParallelAiSearch. This field can be used to pass
any parameter from the Parallel.ai Search API. See the Parallel.ai
documentation for the full list of available parameters and their usage: https:
//docs.parallel.ai/api-reference/search-beta/search Currently only
source_policy, excerpts, max_results, mode, fetch_policy can be set
via this field. For example: "source_policy": "include_domains": ["google.
com", "wikipedia.org"], "exclude_domains": ["example.com"] , "fetch_policy":
"max_age_seconds": 3600
Corresponds to the JSON property customConfigs
48039 48040 48041 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48039 def custom_configs @custom_configs end |
#enable_data_retention ⇒ Boolean Also known as: enable_data_retention?
Optional. Instructs Vertex Grounding to use Parallel's Zero Data Retention
Marketplace product. If this value is "false" or omitted, the Parallel Web
Search for Grounding standard subscription will be used. If this value is "
true", the Parallel Web Search for Grounding - ZDR subscription will be used.
Corresponds to the JSON property enableDataRetention
48047 48048 48049 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48047 def enable_data_retention @enable_data_retention end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
48055 48056 48057 48058 48059 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48055 def update!(**args) @api_key = args[:api_key] if args.key?(:api_key) @custom_configs = args[:custom_configs] if args.key?(:custom_configs) @enable_data_retention = args[:enable_data_retention] if args.key?(:enable_data_retention) end |