Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolParallelAiSearch
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolParallelAiSearch
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
ParallelAiSearch tool type. A tool that uses the Parallel.ai search engine for grounding.
Instance Attribute Summary collapse
-
#api_key ⇒ String
Optional.
-
#custom_configs ⇒ Hash<String,Object>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1ToolParallelAiSearch
constructor
A new instance of GoogleCloudAiplatformV1ToolParallelAiSearch.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1ToolParallelAiSearch
Returns a new instance of GoogleCloudAiplatformV1ToolParallelAiSearch.
46207 46208 46209 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46207 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_key ⇒ String
Optional. The API key for ParallelAiSearch. If an API key is not provided, the
system will attempt to verify access by checking for an active Parallel.ai
subscription through the Google Cloud Marketplace. See https://docs.parallel.
ai/search/search-quickstart for more details.
Corresponds to the JSON property apiKey
46193 46194 46195 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46193 def api_key @api_key end |
#custom_configs ⇒ Hash<String,Object>
Optional. Custom configs for ParallelAiSearch. This field can be used to pass
any parameter from the Parallel.ai Search API. See the Parallel.ai
documentation for the full list of available parameters and their usage: https:
//docs.parallel.ai/api-reference/search-beta/search Currently only
source_policy, excerpts, max_results, mode, fetch_policy can be set
via this field. For example: "source_policy": "include_domains": ["google.
com", "wikipedia.org"], "exclude_domains": ["example.com"] , "fetch_policy":
"max_age_seconds": 3600
Corresponds to the JSON property customConfigs
46205 46206 46207 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46205 def custom_configs @custom_configs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46212 46213 46214 46215 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46212 def update!(**args) @api_key = args[:api_key] if args.key?(:api_key) @custom_configs = args[:custom_configs] if args.key?(:custom_configs) end |