Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ToolParallelAiSearch

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

ParallelAiSearch tool type. A tool that uses the Parallel.ai search engine for grounding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1ToolParallelAiSearch

Returns a new instance of GoogleCloudAiplatformV1ToolParallelAiSearch.



44083
44084
44085
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44083

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_keyString

Optional. The API key for ParallelAiSearch. If an API key is not provided, the system will attempt to verify access by checking for an active Parallel.ai subscription through the Google Cloud Marketplace. See https://docs.parallel. ai/search/search-quickstart for more details. Corresponds to the JSON property apiKey

Returns:

  • (String)


44069
44070
44071
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44069

def api_key
  @api_key
end

#custom_configsHash<String,Object>

Optional. Custom configs for ParallelAiSearch. This field can be used to pass any parameter from the Parallel.ai Search API. See the Parallel.ai documentation for the full list of available parameters and their usage: https: //docs.parallel.ai/api-reference/search-beta/search Currently only source_policy, excerpts, max_results, mode, fetch_policy can be set via this field. For example: "source_policy": "include_domains": ["google. com", "wikipedia.org"], "exclude_domains": ["example.com"] , "fetch_policy": "max_age_seconds": 3600 Corresponds to the JSON property customConfigs

Returns:

  • (Hash<String,Object>)


44081
44082
44083
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44081

def custom_configs
  @custom_configs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44088
44089
44090
44091
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 44088

def update!(**args)
  @api_key = args[:api_key] if args.key?(:api_key)
  @custom_configs = args[:custom_configs] if args.key?(:custom_configs)
end