Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrainingPipeline

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The TrainingPipeline orchestrates tasks associated with training a Model. It always executes the training task, and optionally may also export data from Vertex AI's Dataset which becomes the training input, upload the Model to Vertex AI, and evaluate the Model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1TrainingPipeline

Returns a new instance of GoogleCloudAiplatformV1TrainingPipeline.



37699
37700
37701
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37699

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Time when the TrainingPipeline was created. Corresponds to the JSON property createTime

Returns:

  • (String)


37588
37589
37590
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37588

def create_time
  @create_time
end

#display_nameString

Required. The user-defined name of this TrainingPipeline. Corresponds to the JSON property displayName

Returns:

  • (String)


37593
37594
37595
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37593

def display_name
  @display_name
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key spec that can be applied to a top- level resource. Corresponds to the JSON property encryptionSpec



37599
37600
37601
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37599

def encryption_spec
  @encryption_spec
end

#end_timeString

Output only. Time when the TrainingPipeline entered any of the following states: PIPELINE_STATE_SUCCEEDED, PIPELINE_STATE_FAILED, PIPELINE_STATE_CANCELLED. Corresponds to the JSON property endTime

Returns:

  • (String)


37606
37607
37608
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37606

def end_time
  @end_time
end

#errorGoogle::Apis::AiplatformV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



37616
37617
37618
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37616

def error
  @error
end

#input_data_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1InputDataConfig

Specifies Vertex AI owned input data to be used for training, and possibly evaluating, the Model. Corresponds to the JSON property inputDataConfig



37622
37623
37624
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37622

def input_data_config
  @input_data_config
end

#labelsHash<String,String>

The labels with user-defined metadata to organize TrainingPipelines. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


37631
37632
37633
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37631

def labels
  @labels
end

#model_idString

Optional. The ID to use for the uploaded Model, which will become the final component of the model resource name. This value may be up to 63 characters, and valid characters are [a-z0-9_-]. The first character cannot be a number or hyphen. Corresponds to the JSON property modelId

Returns:

  • (String)


37639
37640
37641
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37639

def model_id
  @model_id
end

#model_to_uploadGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Model

A trained machine learning Model. Corresponds to the JSON property modelToUpload



37644
37645
37646
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37644

def model_to_upload
  @model_to_upload
end

#nameString

Output only. Resource name of the TrainingPipeline. Corresponds to the JSON property name

Returns:

  • (String)


37649
37650
37651
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37649

def name
  @name
end

#parent_modelString

Optional. When specify this field, the model_to_upload will not be uploaded as a new model, instead, it will become a new version of this parent_model. Corresponds to the JSON property parentModel

Returns:

  • (String)


37655
37656
37657
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37655

def parent_model
  @parent_model
end

#start_timeString

Output only. Time when the TrainingPipeline for the first time entered the PIPELINE_STATE_RUNNING state. Corresponds to the JSON property startTime

Returns:

  • (String)


37661
37662
37663
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37661

def start_time
  @start_time
end

#stateString

Output only. The detailed state of the pipeline. Corresponds to the JSON property state

Returns:

  • (String)


37666
37667
37668
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37666

def state
  @state
end

#training_task_definitionString

Required. A Google Cloud Storage path to the YAML file that defines the training task which is responsible for producing the model artifact, and may also include additional auxiliary work. The definition files that can be used here are found in gs://google-cloud-aiplatform/schema/trainingjob/definition/. Note: The URI given on output will be immutable and probably different, including the URI scheme, than the one given on input. The output URI will point to a location where the user only has a read access. Corresponds to the JSON property trainingTaskDefinition

Returns:

  • (String)


37677
37678
37679
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37677

def training_task_definition
  @training_task_definition
end

#training_task_inputsObject

Required. The training task's parameter(s), as specified in the training_task_definition's inputs. Corresponds to the JSON property trainingTaskInputs

Returns:

  • (Object)


37683
37684
37685
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37683

def training_task_inputs
  @training_task_inputs
end

#training_task_metadataObject

Output only. The metadata information as specified in the training_task_definition's metadata. This metadata is an auxiliary runtime and final information about the training task. While the pipeline is running this information is populated only at a best effort basis. Only present if the pipeline's training_task_definition contains metadata object. Corresponds to the JSON property trainingTaskMetadata

Returns:

  • (Object)


37692
37693
37694
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37692

def 
  @training_task_metadata
end

#update_timeString

Output only. Time when the TrainingPipeline was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


37697
37698
37699
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37697

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37704
37705
37706
37707
37708
37709
37710
37711
37712
37713
37714
37715
37716
37717
37718
37719
37720
37721
37722
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37704

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @end_time = args[:end_time] if args.key?(:end_time)
  @error = args[:error] if args.key?(:error)
  @input_data_config = args[:input_data_config] if args.key?(:input_data_config)
  @labels = args[:labels] if args.key?(:labels)
  @model_id = args[:model_id] if args.key?(:model_id)
  @model_to_upload = args[:model_to_upload] if args.key?(:model_to_upload)
  @name = args[:name] if args.key?(:name)
  @parent_model = args[:parent_model] if args.key?(:parent_model)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @training_task_definition = args[:training_task_definition] if args.key?(:training_task_definition)
  @training_task_inputs = args[:training_task_inputs] if args.key?(:training_task_inputs)
  @training_task_metadata = args[:training_task_metadata] if args.key?(:training_task_metadata)
  @update_time = args[:update_time] if args.key?(:update_time)
end