Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryAnyOrderMatchInput

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Instances and metric spec for TrajectoryAnyOrderMatch metric.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1TrajectoryAnyOrderMatchInput

Returns a new instance of GoogleCloudAiplatformV1TrajectoryAnyOrderMatchInput.



38358
38359
38360
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38358

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instancesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryAnyOrderMatchInstance>

Required. Repeated TrajectoryAnyOrderMatch instance. Corresponds to the JSON property instances



38350
38351
38352
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38350

def instances
  @instances
end

#metric_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryAnyOrderMatchSpec

Spec for TrajectoryAnyOrderMatch metric - returns 1 if all tool calls in the reference trajectory appear in the predicted trajectory in any order, else 0. Corresponds to the JSON property metricSpec



38356
38357
38358
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38356

def metric_spec
  @metric_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38363
38364
38365
38366
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38363

def update!(**args)
  @instances = args[:instances] if args.key?(:instances)
  @metric_spec = args[:metric_spec] if args.key?(:metric_spec)
end