Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryAnyOrderMatchInput

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Instances and metric spec for TrajectoryAnyOrderMatch metric.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1TrajectoryAnyOrderMatchInput

Returns a new instance of GoogleCloudAiplatformV1TrajectoryAnyOrderMatchInput.



36556
36557
36558
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36556

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instancesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryAnyOrderMatchInstance>

Required. Repeated TrajectoryAnyOrderMatch instance. Corresponds to the JSON property instances



36548
36549
36550
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36548

def instances
  @instances
end

#metric_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryAnyOrderMatchSpec

Spec for TrajectoryAnyOrderMatch metric - returns 1 if all tool calls in the reference trajectory appear in the predicted trajectory in any order, else 0. Corresponds to the JSON property metricSpec



36554
36555
36556
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36554

def metric_spec
  @metric_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36561
36562
36563
36564
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36561

def update!(**args)
  @instances = args[:instances] if args.key?(:instances)
  @metric_spec = args[:metric_spec] if args.key?(:metric_spec)
end