Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryAnyOrderMatchSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Spec for TrajectoryAnyOrderMatch metric - returns 1 if all tool calls in the reference trajectory appear in the predicted trajectory in any order, else 0.

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1TrajectoryAnyOrderMatchSpec

Returns a new instance of GoogleCloudAiplatformV1TrajectoryAnyOrderMatchSpec.



37838
37839
37840
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37838

def initialize(**args)
   update!(**args)
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37843
37844
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37843

def update!(**args)
end