Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryExactMatchInput
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryExactMatchInput
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Instances and metric spec for TrajectoryExactMatch metric.
Instance Attribute Summary collapse
-
#instances ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryExactMatchInstance>
Required.
-
#metric_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryExactMatchSpec
Spec for TrajectoryExactMatch metric - returns 1 if tool calls in the reference trajectory exactly match the predicted trajectory, else 0.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1TrajectoryExactMatchInput
constructor
A new instance of GoogleCloudAiplatformV1TrajectoryExactMatchInput.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1TrajectoryExactMatchInput
Returns a new instance of GoogleCloudAiplatformV1TrajectoryExactMatchInput.
35492 35493 35494 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35492 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instances ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryExactMatchInstance>
Required. Repeated TrajectoryExactMatch instance.
Corresponds to the JSON property instances
35484 35485 35486 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35484 def instances @instances end |
#metric_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryExactMatchSpec
Spec for TrajectoryExactMatch metric - returns 1 if tool calls in the
reference trajectory exactly match the predicted trajectory, else 0.
Corresponds to the JSON property metricSpec
35490 35491 35492 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35490 def metric_spec @metric_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35497 35498 35499 35500 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35497 def update!(**args) @instances = args[:instances] if args.key?(:instances) @metric_spec = args[:metric_spec] if args.key?(:metric_spec) end |