Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryInOrderMatchInput

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Instances and metric spec for TrajectoryInOrderMatch metric.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1TrajectoryInOrderMatchInput

Returns a new instance of GoogleCloudAiplatformV1TrajectoryInOrderMatchInput.



38619
38620
38621
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38619

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instancesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryInOrderMatchInstance>

Required. Repeated TrajectoryInOrderMatch instance. Corresponds to the JSON property instances



38610
38611
38612
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38610

def instances
  @instances
end

#metric_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryInOrderMatchSpec

Spec for TrajectoryInOrderMatch metric - returns 1 if tool calls in the reference trajectory appear in the predicted trajectory in the same order, else 0. Corresponds to the JSON property metricSpec



38617
38618
38619
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38617

def metric_spec
  @metric_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38624
38625
38626
38627
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38624

def update!(**args)
  @instances = args[:instances] if args.key?(:instances)
  @metric_spec = args[:metric_spec] if args.key?(:metric_spec)
end