Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryInOrderMatchInput

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Instances and metric spec for TrajectoryInOrderMatch metric.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1TrajectoryInOrderMatchInput

Returns a new instance of GoogleCloudAiplatformV1TrajectoryInOrderMatchInput.



37213
37214
37215
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37213

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instancesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryInOrderMatchInstance>

Required. Repeated TrajectoryInOrderMatch instance. Corresponds to the JSON property instances



37204
37205
37206
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37204

def instances
  @instances
end

#metric_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryInOrderMatchSpec

Spec for TrajectoryInOrderMatch metric - returns 1 if tool calls in the reference trajectory appear in the predicted trajectory in the same order, else 0. Corresponds to the JSON property metricSpec



37211
37212
37213
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37211

def metric_spec
  @metric_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37218
37219
37220
37221
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37218

def update!(**args)
  @instances = args[:instances] if args.key?(:instances)
  @metric_spec = args[:metric_spec] if args.key?(:metric_spec)
end