Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryInOrderMatchSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectoryInOrderMatchSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Spec for TrajectoryInOrderMatch metric - returns 1 if tool calls in the reference trajectory appear in the predicted trajectory in the same order, else 0.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1TrajectoryInOrderMatchSpec
constructor
A new instance of GoogleCloudAiplatformV1TrajectoryInOrderMatchSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1TrajectoryInOrderMatchSpec
Returns a new instance of GoogleCloudAiplatformV1TrajectoryInOrderMatchSpec.
36843 36844 36845 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36843 def initialize(**args) update!(**args) end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36848 36849 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36848 def update!(**args) end |