Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectorySingleToolUseSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Spec for TrajectorySingleToolUse metric - returns 1 if tool is present in the predicted trajectory, else 0.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1TrajectorySingleToolUseSpec

Returns a new instance of GoogleCloudAiplatformV1TrajectorySingleToolUseSpec.



37333
37334
37335
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37333

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#tool_nameString

Required. Spec for tool name to be checked for in the predicted trajectory. Corresponds to the JSON property toolName

Returns:

  • (String)


37331
37332
37333
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37331

def tool_name
  @tool_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37338
37339
37340
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37338

def update!(**args)
  @tool_name = args[:tool_name] if args.key?(:tool_name)
end