Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectorySingleToolUseSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectorySingleToolUseSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Spec for TrajectorySingleToolUse metric - returns 1 if tool is present in the predicted trajectory, else 0.
Instance Attribute Summary collapse
-
#tool_name ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1TrajectorySingleToolUseSpec
constructor
A new instance of GoogleCloudAiplatformV1TrajectorySingleToolUseSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1TrajectorySingleToolUseSpec
Returns a new instance of GoogleCloudAiplatformV1TrajectorySingleToolUseSpec.
36920 36921 36922 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36920 def initialize(**args) update!(**args) end |
Instance Attribute Details
#tool_name ⇒ String
Required. Spec for tool name to be checked for in the predicted trajectory.
Corresponds to the JSON property toolName
36918 36919 36920 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36918 def tool_name @tool_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36925 36926 36927 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 36925 def update!(**args) @tool_name = args[:tool_name] if args.key?(:tool_name) end |