Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectorySingleToolUseSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrajectorySingleToolUseSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Spec for TrajectorySingleToolUse metric - returns 1 if tool is present in the predicted trajectory, else 0.
Instance Attribute Summary collapse
-
#tool_name ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1TrajectorySingleToolUseSpec
constructor
A new instance of GoogleCloudAiplatformV1TrajectorySingleToolUseSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1TrajectorySingleToolUseSpec
Returns a new instance of GoogleCloudAiplatformV1TrajectorySingleToolUseSpec.
35984 35985 35986 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35984 def initialize(**args) update!(**args) end |
Instance Attribute Details
#tool_name ⇒ String
Required. Spec for tool name to be checked for in the predicted trajectory.
Corresponds to the JSON property toolName
35982 35983 35984 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35982 def tool_name @tool_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35989 35990 35991 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 35989 def update!(**args) @tool_name = args[:tool_name] if args.key?(:tool_name) end |