Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Trial
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Trial
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A message representing a Trial. A Trial contains a unique set of Parameters that has been or will be evaluated, along with the objective metrics got by running the Trial.
Instance Attribute Summary collapse
-
#client_id ⇒ String
Output only.
-
#custom_job ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#final_measurement ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Measurement
A message representing a Measurement of a Trial.
-
#id ⇒ String
Output only.
-
#infeasible_reason ⇒ String
Output only.
-
#measurements ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Measurement>
Output only.
-
#name ⇒ String
Output only.
-
#parameters ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrialParameter>
Output only.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#web_access_uris ⇒ Hash<String,String>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Trial
constructor
A new instance of GoogleCloudAiplatformV1Trial.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Trial
Returns a new instance of GoogleCloudAiplatformV1Trial.
50214 50215 50216 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 50214 def initialize(**args) update!(**args) end |
Instance Attribute Details
#client_id ⇒ String
Output only. The identifier of the client that originally requested this Trial.
Each client is identified by a unique client_id. When a client asks for a
suggestion, Vertex AI Vizier will assign it a Trial. The client should
evaluate the Trial, complete it, and report back to Vertex AI Vizier. If
suggestion is asked again by same client_id before the Trial is completed, the
same Trial will be returned. Multiple clients with different client_ids can
ask for suggestions simultaneously, each of them will get their own Trial.
Corresponds to the JSON property clientId
50144 50145 50146 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 50144 def client_id @client_id end |
#custom_job ⇒ String
Output only. The CustomJob name linked to the Trial. It's set for a
HyperparameterTuningJob's Trial.
Corresponds to the JSON property customJob
50150 50151 50152 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 50150 def custom_job @custom_job end |
#end_time ⇒ String
Output only. Time when the Trial's status changed to SUCCEEDED or
INFEASIBLE.
Corresponds to the JSON property endTime
50156 50157 50158 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 50156 def end_time @end_time end |
#final_measurement ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Measurement
A message representing a Measurement of a Trial. A Measurement contains the
Metrics got by executing a Trial using suggested hyperparameter values.
Corresponds to the JSON property finalMeasurement
50162 50163 50164 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 50162 def final_measurement @final_measurement end |
#id ⇒ String
Output only. The identifier of the Trial assigned by the service.
Corresponds to the JSON property id
50167 50168 50169 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 50167 def id @id end |
#infeasible_reason ⇒ String
Output only. A human readable string describing why the Trial is infeasible.
This is set only if Trial state is INFEASIBLE.
Corresponds to the JSON property infeasibleReason
50173 50174 50175 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 50173 def infeasible_reason @infeasible_reason end |
#measurements ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Measurement>
Output only. A list of measurements that are strictly lexicographically
ordered by their induced tuples (steps, elapsed_duration). These are used for
early stopping computations.
Corresponds to the JSON property measurements
50180 50181 50182 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 50180 def measurements @measurements end |
#name ⇒ String
Output only. Resource name of the Trial assigned by the service.
Corresponds to the JSON property name
50185 50186 50187 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 50185 def name @name end |
#parameters ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrialParameter>
Output only. The parameters of the Trial.
Corresponds to the JSON property parameters
50190 50191 50192 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 50190 def parameters @parameters end |
#start_time ⇒ String
Output only. Time when the Trial was started.
Corresponds to the JSON property startTime
50195 50196 50197 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 50195 def start_time @start_time end |
#state ⇒ String
Output only. The detailed state of the Trial.
Corresponds to the JSON property state
50200 50201 50202 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 50200 def state @state end |
#web_access_uris ⇒ Hash<String,String>
Output only. URIs for accessing interactive shells (one URI for each
training node). Only available if this trial is part of a
HyperparameterTuningJob and the job's trial_job_spec.enable_web_access field
is true. The keys are names of each node used for the trial; for example,
workerpool0-0 for the primary node, workerpool1-0 for the first node in the
second worker pool, and workerpool1-1 for the second node in the second
worker pool. The values are the URIs for each node's interactive shell.
Corresponds to the JSON property webAccessUris
50212 50213 50214 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 50212 def web_access_uris @web_access_uris end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
50219 50220 50221 50222 50223 50224 50225 50226 50227 50228 50229 50230 50231 50232 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 50219 def update!(**args) @client_id = args[:client_id] if args.key?(:client_id) @custom_job = args[:custom_job] if args.key?(:custom_job) @end_time = args[:end_time] if args.key?(:end_time) @final_measurement = args[:final_measurement] if args.key?(:final_measurement) @id = args[:id] if args.key?(:id) @infeasible_reason = args[:infeasible_reason] if args.key?(:infeasible_reason) @measurements = args[:measurements] if args.key?(:measurements) @name = args[:name] if args.key?(:name) @parameters = args[:parameters] if args.key?(:parameters) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @web_access_uris = args[:web_access_uris] if args.key?(:web_access_uris) end |