Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Trial

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A message representing a Trial. A Trial contains a unique set of Parameters that has been or will be evaluated, along with the objective metrics got by running the Trial.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Trial

Returns a new instance of GoogleCloudAiplatformV1Trial.



47324
47325
47326
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47324

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_idString

Output only. The identifier of the client that originally requested this Trial. Each client is identified by a unique client_id. When a client asks for a suggestion, Vertex AI Vizier will assign it a Trial. The client should evaluate the Trial, complete it, and report back to Vertex AI Vizier. If suggestion is asked again by same client_id before the Trial is completed, the same Trial will be returned. Multiple clients with different client_ids can ask for suggestions simultaneously, each of them will get their own Trial. Corresponds to the JSON property clientId

Returns:

  • (String)


47254
47255
47256
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47254

def client_id
  @client_id
end

#custom_jobString

Output only. The CustomJob name linked to the Trial. It's set for a HyperparameterTuningJob's Trial. Corresponds to the JSON property customJob

Returns:

  • (String)


47260
47261
47262
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47260

def custom_job
  @custom_job
end

#end_timeString

Output only. Time when the Trial's status changed to SUCCEEDED or INFEASIBLE. Corresponds to the JSON property endTime

Returns:

  • (String)


47266
47267
47268
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47266

def end_time
  @end_time
end

#final_measurementGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Measurement

A message representing a Measurement of a Trial. A Measurement contains the Metrics got by executing a Trial using suggested hyperparameter values. Corresponds to the JSON property finalMeasurement



47272
47273
47274
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47272

def final_measurement
  @final_measurement
end

#idString

Output only. The identifier of the Trial assigned by the service. Corresponds to the JSON property id

Returns:

  • (String)


47277
47278
47279
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47277

def id
  @id
end

#infeasible_reasonString

Output only. A human readable string describing why the Trial is infeasible. This is set only if Trial state is INFEASIBLE. Corresponds to the JSON property infeasibleReason

Returns:

  • (String)


47283
47284
47285
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47283

def infeasible_reason
  @infeasible_reason
end

#measurementsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Measurement>

Output only. A list of measurements that are strictly lexicographically ordered by their induced tuples (steps, elapsed_duration). These are used for early stopping computations. Corresponds to the JSON property measurements



47290
47291
47292
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47290

def measurements
  @measurements
end

#nameString

Output only. Resource name of the Trial assigned by the service. Corresponds to the JSON property name

Returns:

  • (String)


47295
47296
47297
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47295

def name
  @name
end

#parametersArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrialParameter>

Output only. The parameters of the Trial. Corresponds to the JSON property parameters



47300
47301
47302
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47300

def parameters
  @parameters
end

#start_timeString

Output only. Time when the Trial was started. Corresponds to the JSON property startTime

Returns:

  • (String)


47305
47306
47307
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47305

def start_time
  @start_time
end

#stateString

Output only. The detailed state of the Trial. Corresponds to the JSON property state

Returns:

  • (String)


47310
47311
47312
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47310

def state
  @state
end

#web_access_urisHash<String,String>

Output only. URIs for accessing interactive shells (one URI for each training node). Only available if this trial is part of a HyperparameterTuningJob and the job's trial_job_spec.enable_web_access field is true. The keys are names of each node used for the trial; for example, workerpool0-0 for the primary node, workerpool1-0 for the first node in the second worker pool, and workerpool1-1 for the second node in the second worker pool. The values are the URIs for each node's interactive shell. Corresponds to the JSON property webAccessUris

Returns:

  • (Hash<String,String>)


47322
47323
47324
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47322

def web_access_uris
  @web_access_uris
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47329
47330
47331
47332
47333
47334
47335
47336
47337
47338
47339
47340
47341
47342
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47329

def update!(**args)
  @client_id = args[:client_id] if args.key?(:client_id)
  @custom_job = args[:custom_job] if args.key?(:custom_job)
  @end_time = args[:end_time] if args.key?(:end_time)
  @final_measurement = args[:final_measurement] if args.key?(:final_measurement)
  @id = args[:id] if args.key?(:id)
  @infeasible_reason = args[:infeasible_reason] if args.key?(:infeasible_reason)
  @measurements = args[:measurements] if args.key?(:measurements)
  @name = args[:name] if args.key?(:name)
  @parameters = args[:parameters] if args.key?(:parameters)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @web_access_uris = args[:web_access_uris] if args.key?(:web_access_uris)
end