Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Trial
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Trial
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A message representing a Trial. A Trial contains a unique set of Parameters that has been or will be evaluated, along with the objective metrics got by running the Trial.
Instance Attribute Summary collapse
-
#client_id ⇒ String
Output only.
-
#custom_job ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#final_measurement ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Measurement
A message representing a Measurement of a Trial.
-
#id ⇒ String
Output only.
-
#infeasible_reason ⇒ String
Output only.
-
#measurements ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Measurement>
Output only.
-
#name ⇒ String
Output only.
-
#parameters ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrialParameter>
Output only.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#web_access_uris ⇒ Hash<String,String>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1Trial
constructor
A new instance of GoogleCloudAiplatformV1Trial.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1Trial
Returns a new instance of GoogleCloudAiplatformV1Trial.
38387 38388 38389 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38387 def initialize(**args) update!(**args) end |
Instance Attribute Details
#client_id ⇒ String
Output only. The identifier of the client that originally requested this Trial.
Each client is identified by a unique client_id. When a client asks for a
suggestion, Vertex AI Vizier will assign it a Trial. The client should
evaluate the Trial, complete it, and report back to Vertex AI Vizier. If
suggestion is asked again by same client_id before the Trial is completed, the
same Trial will be returned. Multiple clients with different client_ids can
ask for suggestions simultaneously, each of them will get their own Trial.
Corresponds to the JSON property clientId
38317 38318 38319 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38317 def client_id @client_id end |
#custom_job ⇒ String
Output only. The CustomJob name linked to the Trial. It's set for a
HyperparameterTuningJob's Trial.
Corresponds to the JSON property customJob
38323 38324 38325 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38323 def custom_job @custom_job end |
#end_time ⇒ String
Output only. Time when the Trial's status changed to SUCCEEDED or
INFEASIBLE.
Corresponds to the JSON property endTime
38329 38330 38331 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38329 def end_time @end_time end |
#final_measurement ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Measurement
A message representing a Measurement of a Trial. A Measurement contains the
Metrics got by executing a Trial using suggested hyperparameter values.
Corresponds to the JSON property finalMeasurement
38335 38336 38337 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38335 def final_measurement @final_measurement end |
#id ⇒ String
Output only. The identifier of the Trial assigned by the service.
Corresponds to the JSON property id
38340 38341 38342 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38340 def id @id end |
#infeasible_reason ⇒ String
Output only. A human readable string describing why the Trial is infeasible.
This is set only if Trial state is INFEASIBLE.
Corresponds to the JSON property infeasibleReason
38346 38347 38348 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38346 def infeasible_reason @infeasible_reason end |
#measurements ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Measurement>
Output only. A list of measurements that are strictly lexicographically
ordered by their induced tuples (steps, elapsed_duration). These are used for
early stopping computations.
Corresponds to the JSON property measurements
38353 38354 38355 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38353 def measurements @measurements end |
#name ⇒ String
Output only. Resource name of the Trial assigned by the service.
Corresponds to the JSON property name
38358 38359 38360 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38358 def name @name end |
#parameters ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrialParameter>
Output only. The parameters of the Trial.
Corresponds to the JSON property parameters
38363 38364 38365 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38363 def parameters @parameters end |
#start_time ⇒ String
Output only. Time when the Trial was started.
Corresponds to the JSON property startTime
38368 38369 38370 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38368 def start_time @start_time end |
#state ⇒ String
Output only. The detailed state of the Trial.
Corresponds to the JSON property state
38373 38374 38375 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38373 def state @state end |
#web_access_uris ⇒ Hash<String,String>
Output only. URIs for accessing interactive shells (one URI for each
training node). Only available if this trial is part of a
HyperparameterTuningJob and the job's trial_job_spec.enable_web_access field
is true. The keys are names of each node used for the trial; for example,
workerpool0-0 for the primary node, workerpool1-0 for the first node in the
second worker pool, and workerpool1-1 for the second node in the second
worker pool. The values are the URIs for each node's interactive shell.
Corresponds to the JSON property webAccessUris
38385 38386 38387 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38385 def web_access_uris @web_access_uris end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38392 38393 38394 38395 38396 38397 38398 38399 38400 38401 38402 38403 38404 38405 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38392 def update!(**args) @client_id = args[:client_id] if args.key?(:client_id) @custom_job = args[:custom_job] if args.key?(:custom_job) @end_time = args[:end_time] if args.key?(:end_time) @final_measurement = args[:final_measurement] if args.key?(:final_measurement) @id = args[:id] if args.key?(:id) @infeasible_reason = args[:infeasible_reason] if args.key?(:infeasible_reason) @measurements = args[:measurements] if args.key?(:measurements) @name = args[:name] if args.key?(:name) @parameters = args[:parameters] if args.key?(:parameters) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @web_access_uris = args[:web_access_uris] if args.key?(:web_access_uris) end |