Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Trial

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A message representing a Trial. A Trial contains a unique set of Parameters that has been or will be evaluated, along with the objective metrics got by running the Trial.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1Trial

Returns a new instance of GoogleCloudAiplatformV1Trial.



27711
27712
27713
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27711

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_idString

Output only. The identifier of the client that originally requested this Trial. Each client is identified by a unique client_id. When a client asks for a suggestion, Vertex AI Vizier will assign it a Trial. The client should evaluate the Trial, complete it, and report back to Vertex AI Vizier. If suggestion is asked again by same client_id before the Trial is completed, the same Trial will be returned. Multiple clients with different client_ids can ask for suggestions simultaneously, each of them will get their own Trial. Corresponds to the JSON property clientId

Returns:

  • (String)


27641
27642
27643
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27641

def client_id
  @client_id
end

#custom_jobString

Output only. The CustomJob name linked to the Trial. It's set for a HyperparameterTuningJob's Trial. Corresponds to the JSON property customJob

Returns:

  • (String)


27647
27648
27649
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27647

def custom_job
  @custom_job
end

#end_timeString

Output only. Time when the Trial's status changed to SUCCEEDED or INFEASIBLE. Corresponds to the JSON property endTime

Returns:

  • (String)


27653
27654
27655
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27653

def end_time
  @end_time
end

#final_measurementGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Measurement

A message representing a Measurement of a Trial. A Measurement contains the Metrics got by executing a Trial using suggested hyperparameter values. Corresponds to the JSON property finalMeasurement



27659
27660
27661
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27659

def final_measurement
  @final_measurement
end

#idString

Output only. The identifier of the Trial assigned by the service. Corresponds to the JSON property id

Returns:

  • (String)


27664
27665
27666
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27664

def id
  @id
end

#infeasible_reasonString

Output only. A human readable string describing why the Trial is infeasible. This is set only if Trial state is INFEASIBLE. Corresponds to the JSON property infeasibleReason

Returns:

  • (String)


27670
27671
27672
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27670

def infeasible_reason
  @infeasible_reason
end

#measurementsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Measurement>

Output only. A list of measurements that are strictly lexicographically ordered by their induced tuples (steps, elapsed_duration). These are used for early stopping computations. Corresponds to the JSON property measurements



27677
27678
27679
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27677

def measurements
  @measurements
end

#nameString

Output only. Resource name of the Trial assigned by the service. Corresponds to the JSON property name

Returns:

  • (String)


27682
27683
27684
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27682

def name
  @name
end

#parametersArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrialParameter>

Output only. The parameters of the Trial. Corresponds to the JSON property parameters



27687
27688
27689
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27687

def parameters
  @parameters
end

#start_timeString

Output only. Time when the Trial was started. Corresponds to the JSON property startTime

Returns:

  • (String)


27692
27693
27694
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27692

def start_time
  @start_time
end

#stateString

Output only. The detailed state of the Trial. Corresponds to the JSON property state

Returns:

  • (String)


27697
27698
27699
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27697

def state
  @state
end

#web_access_urisHash<String,String>

Output only. URIs for accessing interactive shells (one URI for each training node). Only available if this trial is part of a HyperparameterTuningJob and the job's trial_job_spec.enable_web_access field is true. The keys are names of each node used for the trial; for example, workerpool0-0 for the primary node, workerpool1-0 for the first node in the second worker pool, and workerpool1-1 for the second node in the second worker pool. The values are the URIs for each node's interactive shell. Corresponds to the JSON property webAccessUris

Returns:

  • (Hash<String,String>)


27709
27710
27711
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27709

def web_access_uris
  @web_access_uris
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27716
27717
27718
27719
27720
27721
27722
27723
27724
27725
27726
27727
27728
27729
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 27716

def update!(**args)
  @client_id = args[:client_id] if args.key?(:client_id)
  @custom_job = args[:custom_job] if args.key?(:custom_job)
  @end_time = args[:end_time] if args.key?(:end_time)
  @final_measurement = args[:final_measurement] if args.key?(:final_measurement)
  @id = args[:id] if args.key?(:id)
  @infeasible_reason = args[:infeasible_reason] if args.key?(:infeasible_reason)
  @measurements = args[:measurements] if args.key?(:measurements)
  @name = args[:name] if args.key?(:name)
  @parameters = args[:parameters] if args.key?(:parameters)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @web_access_uris = args[:web_access_uris] if args.key?(:web_access_uris)
end