Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrialContext

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1TrialContext

Returns a new instance of GoogleCloudAiplatformV1TrialContext.



47438
47439
47440
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47438

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

A human-readable field which can store a description of this context. This will become part of the resulting Trial's description field. Corresponds to the JSON property description

Returns:

  • (String)


47425
47426
47427
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47425

def description
  @description
end

#parametersArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrialParameter>

If/when a Trial is generated or selected from this Context, its Parameters will match any parameters specified here. (I.e. if this context specifies parameter name:'a' int_value:3, then a resulting Trial will have int_value:3 for its parameter named 'a'.) Note that we first attempt to match existing REQUESTED Trials with contexts, and if there are no matches, we generate suggestions in the subspace defined by the parameters specified here. NOTE: a Context without any Parameters matches the entire feasible search space. Corresponds to the JSON property parameters



47436
47437
47438
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47436

def parameters
  @parameters
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47443
47444
47445
47446
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47443

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @parameters = args[:parameters] if args.key?(:parameters)
end