Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrialContext

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1TrialContext

Returns a new instance of GoogleCloudAiplatformV1TrialContext.



39090
39091
39092
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39090

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

A human-readable field which can store a description of this context. This will become part of the resulting Trial's description field. Corresponds to the JSON property description

Returns:

  • (String)


39077
39078
39079
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39077

def description
  @description
end

#parametersArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrialParameter>

If/when a Trial is generated or selected from this Context, its Parameters will match any parameters specified here. (I.e. if this context specifies parameter name:'a' int_value:3, then a resulting Trial will have int_value:3 for its parameter named 'a'.) Note that we first attempt to match existing REQUESTED Trials with contexts, and if there are no matches, we generate suggestions in the subspace defined by the parameters specified here. NOTE: a Context without any Parameters matches the entire feasible search space. Corresponds to the JSON property parameters



39088
39089
39090
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39088

def parameters
  @parameters
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39095
39096
39097
39098
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39095

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @parameters = args[:parameters] if args.key?(:parameters)
end