Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrialContext
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrialContext
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Instance Attribute Summary collapse
-
#description ⇒ String
A human-readable field which can store a description of this context.
-
#parameters ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrialParameter>
If/when a Trial is generated or selected from this Context, its Parameters will match any parameters specified here.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1TrialContext
constructor
A new instance of GoogleCloudAiplatformV1TrialContext.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1TrialContext
Returns a new instance of GoogleCloudAiplatformV1TrialContext.
37470 37471 37472 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37470 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
A human-readable field which can store a description of this context. This
will become part of the resulting Trial's description field.
Corresponds to the JSON property description
37457 37458 37459 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37457 def description @description end |
#parameters ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrialParameter>
If/when a Trial is generated or selected from this Context, its Parameters
will match any parameters specified here. (I.e. if this context specifies
parameter name:'a' int_value:3, then a resulting Trial will have int_value:3
for its parameter named 'a'.) Note that we first attempt to match existing
REQUESTED Trials with contexts, and if there are no matches, we generate
suggestions in the subspace defined by the parameters specified here. NOTE: a
Context without any Parameters matches the entire feasible search space.
Corresponds to the JSON property parameters
37468 37469 37470 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37468 def parameters @parameters end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37475 37476 37477 37478 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37475 def update!(**args) @description = args[:description] if args.key?(:description) @parameters = args[:parameters] if args.key?(:parameters) end |