Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TrialParameter

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A message representing a parameter to be tuned.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1TrialParameter

Returns a new instance of GoogleCloudAiplatformV1TrialParameter.



37499
37500
37501
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37499

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#parameter_idString

Output only. The ID of the parameter. The parameter should be defined in StudySpec's Parameters. Corresponds to the JSON property parameterId

Returns:

  • (String)


37489
37490
37491
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37489

def parameter_id
  @parameter_id
end

#valueObject

Output only. The value of the parameter. number_value will be set if a parameter defined in StudySpec is in type 'INTEGER', 'DOUBLE' or 'DISCRETE'. string_value will be set if a parameter defined in StudySpec is in type ' CATEGORICAL'. Corresponds to the JSON property value

Returns:

  • (Object)


37497
37498
37499
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37497

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37504
37505
37506
37507
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37504

def update!(**args)
  @parameter_id = args[:parameter_id] if args.key?(:parameter_id)
  @value = args[:value] if args.key?(:value)
end