Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TunedModel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The Model Registry Model and Online Prediction Endpoint associated with this TuningJob.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1TunedModel

Returns a new instance of GoogleCloudAiplatformV1TunedModel.



47435
47436
47437
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47435

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#checkpointsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TunedModelCheckpoint>

Output only. The checkpoints associated with this TunedModel. This field is only populated for tuning jobs that enable intermediate checkpoints. Corresponds to the JSON property checkpoints



47415
47416
47417
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47415

def checkpoints
  @checkpoints
end

#endpointString

Output only. A resource name of an Endpoint. Format: projects/project/ locations/location/endpoints/endpoint`. Corresponds to the JSON propertyendpoint`

Returns:

  • (String)


47421
47422
47423
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47421

def endpoint
  @endpoint
end

#modelString

Output only. The resource name of the TunedModel. Format: projects/project/ locations/location/models/model@version_idWhen tuning from a base model, the version ID will be 1. For continuous tuning, if the provided tuned_model_display_name is set and different from parent model's display name, the tuned model will have a new parent model with version 1. Otherwise the version id will be incremented by 1 from the last version ID in the parent model. E.g., `projects/`project`/locations/`location`/models/`model`@` last_version_id + 1 Corresponds to the JSON property model

Returns:

  • (String)


47433
47434
47435
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47433

def model
  @model
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47440
47441
47442
47443
47444
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47440

def update!(**args)
  @checkpoints = args[:checkpoints] if args.key?(:checkpoints)
  @endpoint = args[:endpoint] if args.key?(:endpoint)
  @model = args[:model] if args.key?(:model)
end