Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TunedModel
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TunedModel
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The Model Registry Model and Online Prediction Endpoint associated with this TuningJob.
Instance Attribute Summary collapse
-
#checkpoints ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TunedModelCheckpoint>
Output only.
-
#endpoint ⇒ String
Output only.
-
#model ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1TunedModel
constructor
A new instance of GoogleCloudAiplatformV1TunedModel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1TunedModel
Returns a new instance of GoogleCloudAiplatformV1TunedModel.
45591 45592 45593 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45591 def initialize(**args) update!(**args) end |
Instance Attribute Details
#checkpoints ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TunedModelCheckpoint>
Output only. The checkpoints associated with this TunedModel. This field is
only populated for tuning jobs that enable intermediate checkpoints.
Corresponds to the JSON property checkpoints
45571 45572 45573 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45571 def checkpoints @checkpoints end |
#endpoint ⇒ String
Output only. A resource name of an Endpoint. Format: projects/project/
locations/location/endpoints/endpoint`.
Corresponds to the JSON propertyendpoint`
45577 45578 45579 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45577 def endpoint @endpoint end |
#model ⇒ String
Output only. The resource name of the TunedModel. Format: projects/project/
locations/location/models/model@version_idWhen tuning from a base
model, the version ID will be 1. For continuous tuning, if the provided
tuned_model_display_name is set and different from parent model's display name,
the tuned model will have a new parent model with version 1. Otherwise the
version id will be incremented by 1 from the last version ID in the parent
model. E.g., `projects/`project`/locations/`location`/models/`model`@`
last_version_id + 1
Corresponds to the JSON property model
45589 45590 45591 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45589 def model @model end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45596 45597 45598 45599 45600 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 45596 def update!(**args) @checkpoints = args[:checkpoints] if args.key?(:checkpoints) @endpoint = args[:endpoint] if args.key?(:endpoint) @model = args[:model] if args.key?(:model) end |