Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TunedModel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The Model Registry Model and Online Prediction Endpoint associated with this TuningJob.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1TunedModel

Returns a new instance of GoogleCloudAiplatformV1TunedModel.



39136
39137
39138
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39136

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#checkpointsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TunedModelCheckpoint>

Output only. The checkpoints associated with this TunedModel. This field is only populated for tuning jobs that enable intermediate checkpoints. Corresponds to the JSON property checkpoints



39122
39123
39124
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39122

def checkpoints
  @checkpoints
end

#endpointString

Output only. A resource name of an Endpoint. Format: projects/project/ locations/location/endpoints/endpoint`. Corresponds to the JSON propertyendpoint`

Returns:

  • (String)


39128
39129
39130
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39128

def endpoint
  @endpoint
end

#modelString

Output only. The resource name of the TunedModel. Format: projects/project/ locations/location/models/model`. Corresponds to the JSON propertymodel`

Returns:

  • (String)


39134
39135
39136
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39134

def model
  @model
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39141
39142
39143
39144
39145
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39141

def update!(**args)
  @checkpoints = args[:checkpoints] if args.key?(:checkpoints)
  @endpoint = args[:endpoint] if args.key?(:endpoint)
  @model = args[:model] if args.key?(:model)
end