Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TunedModel
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TunedModel
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The Model Registry Model and Online Prediction Endpoint associated with this TuningJob.
Instance Attribute Summary collapse
-
#checkpoints ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TunedModelCheckpoint>
Output only.
-
#endpoint ⇒ String
Output only.
-
#model ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1TunedModel
constructor
A new instance of GoogleCloudAiplatformV1TunedModel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1TunedModel
Returns a new instance of GoogleCloudAiplatformV1TunedModel.
38672 38673 38674 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38672 def initialize(**args) update!(**args) end |
Instance Attribute Details
#checkpoints ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TunedModelCheckpoint>
Output only. The checkpoints associated with this TunedModel. This field is
only populated for tuning jobs that enable intermediate checkpoints.
Corresponds to the JSON property checkpoints
38658 38659 38660 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38658 def checkpoints @checkpoints end |
#endpoint ⇒ String
Output only. A resource name of an Endpoint. Format: projects/project/
locations/location/endpoints/endpoint`.
Corresponds to the JSON propertyendpoint`
38664 38665 38666 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38664 def endpoint @endpoint end |
#model ⇒ String
Output only. The resource name of the TunedModel. Format: projects/project/
locations/location/models/model`.
Corresponds to the JSON propertymodel`
38670 38671 38672 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38670 def model @model end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38677 38678 38679 38680 38681 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38677 def update!(**args) @checkpoints = args[:checkpoints] if args.key?(:checkpoints) @endpoint = args[:endpoint] if args.key?(:endpoint) @model = args[:model] if args.key?(:model) end |