Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TunedModel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The Model Registry Model and Online Prediction Endpoint associated with this TuningJob.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1TunedModel

Returns a new instance of GoogleCloudAiplatformV1TunedModel.



38097
38098
38099
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38097

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#checkpointsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TunedModelCheckpoint>

Output only. The checkpoints associated with this TunedModel. This field is only populated for tuning jobs that enable intermediate checkpoints. Corresponds to the JSON property checkpoints



38083
38084
38085
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38083

def checkpoints
  @checkpoints
end

#endpointString

Output only. A resource name of an Endpoint. Format: projects/project/ locations/location/endpoints/endpoint`. Corresponds to the JSON propertyendpoint`

Returns:

  • (String)


38089
38090
38091
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38089

def endpoint
  @endpoint
end

#modelString

Output only. The resource name of the TunedModel. Format: projects/project/ locations/location/models/model`. Corresponds to the JSON propertymodel`

Returns:

  • (String)


38095
38096
38097
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38095

def model
  @model
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38102
38103
38104
38105
38106
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38102

def update!(**args)
  @checkpoints = args[:checkpoints] if args.key?(:checkpoints)
  @endpoint = args[:endpoint] if args.key?(:endpoint)
  @model = args[:model] if args.key?(:model)
end