Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TunedModelCheckpoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

TunedModelCheckpoint for the Tuned Model of a Tuning Job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1TunedModelCheckpoint

Returns a new instance of GoogleCloudAiplatformV1TunedModelCheckpoint.



49793
49794
49795
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 49793

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#checkpoint_idString

The ID of the checkpoint. Corresponds to the JSON property checkpointId

Returns:

  • (String)


49775
49776
49777
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 49775

def checkpoint_id
  @checkpoint_id
end

#endpointString

The Endpoint resource name that the checkpoint is deployed to. Format: projects/project/locations/location/endpoints/endpoint`. Corresponds to the JSON propertyendpoint`

Returns:

  • (String)


49781
49782
49783
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 49781

def endpoint
  @endpoint
end

#epochFixnum

The epoch of the checkpoint. Corresponds to the JSON property epoch

Returns:

  • (Fixnum)


49786
49787
49788
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 49786

def epoch
  @epoch
end

#stepFixnum

The step of the checkpoint. Corresponds to the JSON property step

Returns:

  • (Fixnum)


49791
49792
49793
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 49791

def step
  @step
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49798
49799
49800
49801
49802
49803
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 49798

def update!(**args)
  @checkpoint_id = args[:checkpoint_id] if args.key?(:checkpoint_id)
  @endpoint = args[:endpoint] if args.key?(:endpoint)
  @epoch = args[:epoch] if args.key?(:epoch)
  @step = args[:step] if args.key?(:step)
end