Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TunedModelCheckpoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

TunedModelCheckpoint for the Tuned Model of a Tuning Job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1TunedModelCheckpoint

Returns a new instance of GoogleCloudAiplatformV1TunedModelCheckpoint.



47544
47545
47546
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47544

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#checkpoint_idString

The ID of the checkpoint. Corresponds to the JSON property checkpointId

Returns:

  • (String)


47526
47527
47528
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47526

def checkpoint_id
  @checkpoint_id
end

#endpointString

The Endpoint resource name that the checkpoint is deployed to. Format: projects/project/locations/location/endpoints/endpoint`. Corresponds to the JSON propertyendpoint`

Returns:

  • (String)


47532
47533
47534
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47532

def endpoint
  @endpoint
end

#epochFixnum

The epoch of the checkpoint. Corresponds to the JSON property epoch

Returns:

  • (Fixnum)


47537
47538
47539
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47537

def epoch
  @epoch
end

#stepFixnum

The step of the checkpoint. Corresponds to the JSON property step

Returns:

  • (Fixnum)


47542
47543
47544
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47542

def step
  @step
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47549
47550
47551
47552
47553
47554
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47549

def update!(**args)
  @checkpoint_id = args[:checkpoint_id] if args.key?(:checkpoint_id)
  @endpoint = args[:endpoint] if args.key?(:endpoint)
  @epoch = args[:epoch] if args.key?(:epoch)
  @step = args[:step] if args.key?(:step)
end