Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TunedModelCheckpoint
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TunedModelCheckpoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
TunedModelCheckpoint for the Tuned Model of a Tuning Job.
Instance Attribute Summary collapse
-
#checkpoint_id ⇒ String
The ID of the checkpoint.
-
#endpoint ⇒ String
The Endpoint resource name that the checkpoint is deployed to.
-
#epoch ⇒ Fixnum
The epoch of the checkpoint.
-
#step ⇒ Fixnum
The step of the checkpoint.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1TunedModelCheckpoint
constructor
A new instance of GoogleCloudAiplatformV1TunedModelCheckpoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1TunedModelCheckpoint
Returns a new instance of GoogleCloudAiplatformV1TunedModelCheckpoint.
47472 47473 47474 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47472 def initialize(**args) update!(**args) end |
Instance Attribute Details
#checkpoint_id ⇒ String
The ID of the checkpoint.
Corresponds to the JSON property checkpointId
47454 47455 47456 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47454 def checkpoint_id @checkpoint_id end |
#endpoint ⇒ String
The Endpoint resource name that the checkpoint is deployed to. Format:
projects/project/locations/location/endpoints/endpoint`.
Corresponds to the JSON propertyendpoint`
47460 47461 47462 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47460 def endpoint @endpoint end |
#epoch ⇒ Fixnum
The epoch of the checkpoint.
Corresponds to the JSON property epoch
47465 47466 47467 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47465 def epoch @epoch end |
#step ⇒ Fixnum
The step of the checkpoint.
Corresponds to the JSON property step
47470 47471 47472 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47470 def step @step end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47477 47478 47479 47480 47481 47482 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47477 def update!(**args) @checkpoint_id = args[:checkpoint_id] if args.key?(:checkpoint_id) @endpoint = args[:endpoint] if args.key?(:endpoint) @epoch = args[:epoch] if args.key?(:epoch) @step = args[:step] if args.key?(:step) end |