Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TunedModelCheckpoint
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TunedModelCheckpoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
TunedModelCheckpoint for the Tuned Model of a Tuning Job.
Instance Attribute Summary collapse
-
#checkpoint_id ⇒ String
The ID of the checkpoint.
-
#endpoint ⇒ String
The Endpoint resource name that the checkpoint is deployed to.
-
#epoch ⇒ Fixnum
The epoch of the checkpoint.
-
#step ⇒ Fixnum
The step of the checkpoint.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1TunedModelCheckpoint
constructor
A new instance of GoogleCloudAiplatformV1TunedModelCheckpoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1TunedModelCheckpoint
Returns a new instance of GoogleCloudAiplatformV1TunedModelCheckpoint.
39609 39610 39611 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39609 def initialize(**args) update!(**args) end |
Instance Attribute Details
#checkpoint_id ⇒ String
The ID of the checkpoint.
Corresponds to the JSON property checkpointId
39591 39592 39593 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39591 def checkpoint_id @checkpoint_id end |
#endpoint ⇒ String
The Endpoint resource name that the checkpoint is deployed to. Format:
projects/project/locations/location/endpoints/endpoint`.
Corresponds to the JSON propertyendpoint`
39597 39598 39599 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39597 def endpoint @endpoint end |
#epoch ⇒ Fixnum
The epoch of the checkpoint.
Corresponds to the JSON property epoch
39602 39603 39604 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39602 def epoch @epoch end |
#step ⇒ Fixnum
The step of the checkpoint.
Corresponds to the JSON property step
39607 39608 39609 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39607 def step @step end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39614 39615 39616 39617 39618 39619 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39614 def update!(**args) @checkpoint_id = args[:checkpoint_id] if args.key?(:checkpoint_id) @endpoint = args[:endpoint] if args.key?(:endpoint) @epoch = args[:epoch] if args.key?(:epoch) @step = args[:step] if args.key?(:step) end |