Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TunedModelCheckpoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

TunedModelCheckpoint for the Tuned Model of a Tuning Job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1TunedModelCheckpoint

Returns a new instance of GoogleCloudAiplatformV1TunedModelCheckpoint.



38709
38710
38711
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38709

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#checkpoint_idString

The ID of the checkpoint. Corresponds to the JSON property checkpointId

Returns:

  • (String)


38691
38692
38693
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38691

def checkpoint_id
  @checkpoint_id
end

#endpointString

The Endpoint resource name that the checkpoint is deployed to. Format: projects/project/locations/location/endpoints/endpoint`. Corresponds to the JSON propertyendpoint`

Returns:

  • (String)


38697
38698
38699
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38697

def endpoint
  @endpoint
end

#epochFixnum

The epoch of the checkpoint. Corresponds to the JSON property epoch

Returns:

  • (Fixnum)


38702
38703
38704
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38702

def epoch
  @epoch
end

#stepFixnum

The step of the checkpoint. Corresponds to the JSON property step

Returns:

  • (Fixnum)


38707
38708
38709
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38707

def step
  @step
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38714
38715
38716
38717
38718
38719
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38714

def update!(**args)
  @checkpoint_id = args[:checkpoint_id] if args.key?(:checkpoint_id)
  @endpoint = args[:endpoint] if args.key?(:endpoint)
  @epoch = args[:epoch] if args.key?(:epoch)
  @step = args[:step] if args.key?(:step)
end