Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TunedModelCheckpoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

TunedModelCheckpoint for the Tuned Model of a Tuning Job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1TunedModelCheckpoint

Returns a new instance of GoogleCloudAiplatformV1TunedModelCheckpoint.



38670
38671
38672
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38670

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#checkpoint_idString

The ID of the checkpoint. Corresponds to the JSON property checkpointId

Returns:

  • (String)


38652
38653
38654
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38652

def checkpoint_id
  @checkpoint_id
end

#endpointString

The Endpoint resource name that the checkpoint is deployed to. Format: projects/project/locations/location/endpoints/endpoint`. Corresponds to the JSON propertyendpoint`

Returns:

  • (String)


38658
38659
38660
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38658

def endpoint
  @endpoint
end

#epochFixnum

The epoch of the checkpoint. Corresponds to the JSON property epoch

Returns:

  • (Fixnum)


38663
38664
38665
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38663

def epoch
  @epoch
end

#stepFixnum

The step of the checkpoint. Corresponds to the JSON property step

Returns:

  • (Fixnum)


38668
38669
38670
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38668

def step
  @step
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38675
38676
38677
38678
38679
38680
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38675

def update!(**args)
  @checkpoint_id = args[:checkpoint_id] if args.key?(:checkpoint_id)
  @endpoint = args[:endpoint] if args.key?(:endpoint)
  @epoch = args[:epoch] if args.key?(:epoch)
  @step = args[:step] if args.key?(:step)
end