Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TunedModelCheckpoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

TunedModelCheckpoint for the Tuned Model of a Tuning Job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1TunedModelCheckpoint

Returns a new instance of GoogleCloudAiplatformV1TunedModelCheckpoint.



38591
38592
38593
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38591

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#checkpoint_idString

The ID of the checkpoint. Corresponds to the JSON property checkpointId

Returns:

  • (String)


38573
38574
38575
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38573

def checkpoint_id
  @checkpoint_id
end

#endpointString

The Endpoint resource name that the checkpoint is deployed to. Format: projects/project/locations/location/endpoints/endpoint`. Corresponds to the JSON propertyendpoint`

Returns:

  • (String)


38579
38580
38581
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38579

def endpoint
  @endpoint
end

#epochFixnum

The epoch of the checkpoint. Corresponds to the JSON property epoch

Returns:

  • (Fixnum)


38584
38585
38586
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38584

def epoch
  @epoch
end

#stepFixnum

The step of the checkpoint. Corresponds to the JSON property step

Returns:

  • (Fixnum)


38589
38590
38591
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38589

def step
  @step
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38596
38597
38598
38599
38600
38601
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38596

def update!(**args)
  @checkpoint_id = args[:checkpoint_id] if args.key?(:checkpoint_id)
  @endpoint = args[:endpoint] if args.key?(:endpoint)
  @epoch = args[:epoch] if args.key?(:epoch)
  @step = args[:step] if args.key?(:step)
end