Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TunedModelCheckpoint
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TunedModelCheckpoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
TunedModelCheckpoint for the Tuned Model of a Tuning Job.
Instance Attribute Summary collapse
-
#checkpoint_id ⇒ String
The ID of the checkpoint.
-
#endpoint ⇒ String
The Endpoint resource name that the checkpoint is deployed to.
-
#epoch ⇒ Fixnum
The epoch of the checkpoint.
-
#step ⇒ Fixnum
The step of the checkpoint.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1TunedModelCheckpoint
constructor
A new instance of GoogleCloudAiplatformV1TunedModelCheckpoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1TunedModelCheckpoint
Returns a new instance of GoogleCloudAiplatformV1TunedModelCheckpoint.
38591 38592 38593 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38591 def initialize(**args) update!(**args) end |
Instance Attribute Details
#checkpoint_id ⇒ String
The ID of the checkpoint.
Corresponds to the JSON property checkpointId
38573 38574 38575 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38573 def checkpoint_id @checkpoint_id end |
#endpoint ⇒ String
The Endpoint resource name that the checkpoint is deployed to. Format:
projects/project/locations/location/endpoints/endpoint`.
Corresponds to the JSON propertyendpoint`
38579 38580 38581 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38579 def endpoint @endpoint end |
#epoch ⇒ Fixnum
The epoch of the checkpoint.
Corresponds to the JSON property epoch
38584 38585 38586 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38584 def epoch @epoch end |
#step ⇒ Fixnum
The step of the checkpoint.
Corresponds to the JSON property step
38589 38590 38591 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38589 def step @step end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38596 38597 38598 38599 38600 38601 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38596 def update!(**args) @checkpoint_id = args[:checkpoint_id] if args.key?(:checkpoint_id) @endpoint = args[:endpoint] if args.key?(:endpoint) @epoch = args[:epoch] if args.key?(:epoch) @step = args[:step] if args.key?(:step) end |