Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TunedModelRef

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

TunedModel Reference for legacy model migration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1TunedModelRef

Returns a new instance of GoogleCloudAiplatformV1TunedModelRef.



39226
39227
39228
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39226

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#pipeline_jobString

Support migration from tuning job list page, from bison model to gemini model. Corresponds to the JSON property pipelineJob

Returns:

  • (String)


39213
39214
39215
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39213

def pipeline_job
  @pipeline_job
end

#tuned_modelString

Support migration from model registry. Corresponds to the JSON property tunedModel

Returns:

  • (String)


39218
39219
39220
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39218

def tuned_model
  @tuned_model
end

#tuning_jobString

Support migration from tuning job list page, from gemini-1.0-pro-002 to 1.5 and above. Corresponds to the JSON property tuningJob

Returns:

  • (String)


39224
39225
39226
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39224

def tuning_job
  @tuning_job
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39231
39232
39233
39234
39235
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39231

def update!(**args)
  @pipeline_job = args[:pipeline_job] if args.key?(:pipeline_job)
  @tuned_model = args[:tuned_model] if args.key?(:tuned_model)
  @tuning_job = args[:tuning_job] if args.key?(:tuning_job)
end