Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TunedModelRef
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TunedModelRef
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
TunedModel Reference for legacy model migration.
Instance Attribute Summary collapse
-
#pipeline_job ⇒ String
Support migration from tuning job list page, from bison model to gemini model.
-
#tuned_model ⇒ String
Support migration from model registry.
-
#tuning_job ⇒ String
Support migration from tuning job list page, from gemini-1.0-pro-002 to 1.5 and above.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1TunedModelRef
constructor
A new instance of GoogleCloudAiplatformV1TunedModelRef.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1TunedModelRef
Returns a new instance of GoogleCloudAiplatformV1TunedModelRef.
38562 38563 38564 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38562 def initialize(**args) update!(**args) end |
Instance Attribute Details
#pipeline_job ⇒ String
Support migration from tuning job list page, from bison model to gemini model.
Corresponds to the JSON property pipelineJob
38549 38550 38551 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38549 def pipeline_job @pipeline_job end |
#tuned_model ⇒ String
Support migration from model registry.
Corresponds to the JSON property tunedModel
38554 38555 38556 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38554 def tuned_model @tuned_model end |
#tuning_job ⇒ String
Support migration from tuning job list page, from gemini-1.0-pro-002 to 1.5
and above.
Corresponds to the JSON property tuningJob
38560 38561 38562 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38560 def tuning_job @tuning_job end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38567 38568 38569 38570 38571 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38567 def update!(**args) @pipeline_job = args[:pipeline_job] if args.key?(:pipeline_job) @tuned_model = args[:tuned_model] if args.key?(:tuned_model) @tuning_job = args[:tuning_job] if args.key?(:tuning_job) end |