Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TuningJob
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TuningJob
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Represents a TuningJob that runs with Google owned models.
Instance Attribute Summary collapse
-
#base_model ⇒ String
The base model that is being tuned.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied to a Vertex AI resource.
-
#end_time ⇒ String
Output only.
-
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#evaluate_dataset_runs ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluateDatasetRun>
Output only.
-
#experiment ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Output only.
-
#pre_tuned_model ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PreTunedModel
A pre-tuned model for continuous tuning.
-
#preference_optimization_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PreferenceOptimizationSpec
Tuning Spec for Preference Optimization.
-
#service_account ⇒ String
The service account that the tuningJob workload runs as.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#supervised_tuning_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningSpec
Tuning Spec for Supervised Tuning for first party models.
-
#tuned_model ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TunedModel
The Model Registry Model and Online Prediction Endpoint associated with this TuningJob.
-
#tuned_model_display_name ⇒ String
Optional.
-
#tuning_data_stats ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TuningDataStats
The tuning data statistic values for TuningJob.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1TuningJob
constructor
A new instance of GoogleCloudAiplatformV1TuningJob.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1TuningJob
Returns a new instance of GoogleCloudAiplatformV1TuningJob.
47672 47673 47674 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47672 def initialize(**args) update!(**args) end |
Instance Attribute Details
#base_model ⇒ String
The base model that is being tuned. See Supported models.
Corresponds to the JSON property baseModel
47551 47552 47553 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47551 def base_model @base_model end |
#create_time ⇒ String
Output only. Time when the TuningJob was created.
Corresponds to the JSON property createTime
47556 47557 47558 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47556 def create_time @create_time end |
#description ⇒ String
Optional. The description of the TuningJob.
Corresponds to the JSON property description
47561 47562 47563 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47561 def description @description end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key specification that can be applied
to a Vertex AI resource.
Corresponds to the JSON property encryptionSpec
47567 47568 47569 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47567 def encryption_spec @encryption_spec end |
#end_time ⇒ String
Output only. Time when the TuningJob entered any of the following JobStates:
JOB_STATE_SUCCEEDED, JOB_STATE_FAILED, JOB_STATE_CANCELLED,
JOB_STATE_EXPIRED.
Corresponds to the JSON property endTime
47574 47575 47576 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47574 def end_time @end_time end |
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
47584 47585 47586 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47584 def error @error end |
#evaluate_dataset_runs ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EvaluateDatasetRun>
Output only. Evaluation runs for the Tuning Job.
Corresponds to the JSON property evaluateDatasetRuns
47589 47590 47591 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47589 def evaluate_dataset_runs @evaluate_dataset_runs end |
#experiment ⇒ String
Output only. The Experiment associated with this TuningJob.
Corresponds to the JSON property experiment
47594 47595 47596 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47594 def experiment @experiment end |
#labels ⇒ Hash<String,String>
Optional. The labels with user-defined metadata to organize TuningJob and
generated resources such as Model and Endpoint. Label keys and values can be
no longer than 64 characters (Unicode codepoints), can only contain lowercase
letters, numeric characters, underscores and dashes. International characters
are allowed. See https://goo.gl/xmQnxf for more information and examples of
labels.
Corresponds to the JSON property labels
47604 47605 47606 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47604 def labels @labels end |
#name ⇒ String
Output only. Identifier. Resource name of a TuningJob. Format: projects/
project/locations/location/tuningJobs/tuning_job`
Corresponds to the JSON propertyname`
47610 47611 47612 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47610 def name @name end |
#pre_tuned_model ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PreTunedModel
A pre-tuned model for continuous tuning.
Corresponds to the JSON property preTunedModel
47615 47616 47617 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47615 def pre_tuned_model @pre_tuned_model end |
#preference_optimization_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PreferenceOptimizationSpec
Tuning Spec for Preference Optimization.
Corresponds to the JSON property preferenceOptimizationSpec
47620 47621 47622 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47620 def preference_optimization_spec @preference_optimization_spec end |
#service_account ⇒ String
The service account that the tuningJob workload runs as. If not specified, the
Vertex AI Secure Fine-Tuned Service Agent in the project will be used. See
https://cloud.google.com/iam/docs/service-agents#vertex-ai-secure-fine-tuning-
service-agent Users starting the pipeline must have the iam.serviceAccounts.
actAs permission on this service account.
Corresponds to the JSON property serviceAccount
47629 47630 47631 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47629 def service_account @service_account end |
#start_time ⇒ String
Output only. Time when the TuningJob for the first time entered the
JOB_STATE_RUNNING state.
Corresponds to the JSON property startTime
47635 47636 47637 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47635 def start_time @start_time end |
#state ⇒ String
Output only. The detailed state of the job.
Corresponds to the JSON property state
47640 47641 47642 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47640 def state @state end |
#supervised_tuning_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningSpec
Tuning Spec for Supervised Tuning for first party models.
Corresponds to the JSON property supervisedTuningSpec
47645 47646 47647 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47645 def supervised_tuning_spec @supervised_tuning_spec end |
#tuned_model ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TunedModel
The Model Registry Model and Online Prediction Endpoint associated with this
TuningJob.
Corresponds to the JSON property tunedModel
47651 47652 47653 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47651 def tuned_model @tuned_model end |
#tuned_model_display_name ⇒ String
Optional. The display name of the TunedModel. The name can be up to 128
characters long and can consist of any UTF-8 characters. For continuous tuning,
tuned_model_display_name will by default use the same display name as the pre-
tuned model. If a new display name is provided, the tuning job will create a
new model instead of a new version.
Corresponds to the JSON property tunedModelDisplayName
47660 47661 47662 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47660 def tuned_model_display_name @tuned_model_display_name end |
#tuning_data_stats ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TuningDataStats
The tuning data statistic values for TuningJob.
Corresponds to the JSON property tuningDataStats
47665 47666 47667 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47665 def tuning_data_stats @tuning_data_stats end |
#update_time ⇒ String
Output only. Time when the TuningJob was most recently updated.
Corresponds to the JSON property updateTime
47670 47671 47672 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47670 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47677 47678 47679 47680 47681 47682 47683 47684 47685 47686 47687 47688 47689 47690 47691 47692 47693 47694 47695 47696 47697 47698 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47677 def update!(**args) @base_model = args[:base_model] if args.key?(:base_model) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @end_time = args[:end_time] if args.key?(:end_time) @error = args[:error] if args.key?(:error) @evaluate_dataset_runs = args[:evaluate_dataset_runs] if args.key?(:evaluate_dataset_runs) @experiment = args[:experiment] if args.key?(:experiment) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @pre_tuned_model = args[:pre_tuned_model] if args.key?(:pre_tuned_model) @preference_optimization_spec = args[:preference_optimization_spec] if args.key?(:preference_optimization_spec) @service_account = args[:service_account] if args.key?(:service_account) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @supervised_tuning_spec = args[:supervised_tuning_spec] if args.key?(:supervised_tuning_spec) @tuned_model = args[:tuned_model] if args.key?(:tuned_model) @tuned_model_display_name = args[:tuned_model_display_name] if args.key?(:tuned_model_display_name) @tuning_data_stats = args[:tuning_data_stats] if args.key?(:tuning_data_stats) @update_time = args[:update_time] if args.key?(:update_time) end |