Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TuningJob
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TuningJob
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Represents a TuningJob that runs with Google owned models.
Instance Attribute Summary collapse
-
#base_model ⇒ String
The base model that is being tuned.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top- level resource.
-
#end_time ⇒ String
Output only.
-
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#experiment ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Output only.
-
#service_account ⇒ String
The service account that the tuningJob workload runs as.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#supervised_tuning_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningSpec
Tuning Spec for Supervised Tuning for first party models.
-
#tuned_model ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TunedModel
The Model Registry Model and Online Prediction Endpoint associated with this TuningJob.
-
#tuned_model_display_name ⇒ String
Optional.
-
#tuning_data_stats ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TuningDataStats
The tuning data statistic values for TuningJob.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1TuningJob
constructor
A new instance of GoogleCloudAiplatformV1TuningJob.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1TuningJob
Returns a new instance of GoogleCloudAiplatformV1TuningJob.
38310 38311 38312 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38310 def initialize(**args) update!(**args) end |
Instance Attribute Details
#base_model ⇒ String
The base model that is being tuned. See Supported models.
Corresponds to the JSON property baseModel
38207 38208 38209 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38207 def base_model @base_model end |
#create_time ⇒ String
Output only. Time when the TuningJob was created.
Corresponds to the JSON property createTime
38212 38213 38214 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38212 def create_time @create_time end |
#description ⇒ String
Optional. The description of the TuningJob.
Corresponds to the JSON property description
38217 38218 38219 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38217 def description @description end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top-
level resource.
Corresponds to the JSON property encryptionSpec
38223 38224 38225 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38223 def encryption_spec @encryption_spec end |
#end_time ⇒ String
Output only. Time when the TuningJob entered any of the following JobStates:
JOB_STATE_SUCCEEDED, JOB_STATE_FAILED, JOB_STATE_CANCELLED,
JOB_STATE_EXPIRED.
Corresponds to the JSON property endTime
38230 38231 38232 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38230 def end_time @end_time end |
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
38240 38241 38242 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38240 def error @error end |
#experiment ⇒ String
Output only. The Experiment associated with this TuningJob.
Corresponds to the JSON property experiment
38245 38246 38247 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38245 def experiment @experiment end |
#labels ⇒ Hash<String,String>
Optional. The labels with user-defined metadata to organize TuningJob and
generated resources such as Model and Endpoint. Label keys and values can be
no longer than 64 characters (Unicode codepoints), can only contain lowercase
letters, numeric characters, underscores and dashes. International characters
are allowed. See https://goo.gl/xmQnxf for more information and examples of
labels.
Corresponds to the JSON property labels
38255 38256 38257 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38255 def labels @labels end |
#name ⇒ String
Output only. Identifier. Resource name of a TuningJob. Format: projects/
project/locations/location/tuningJobs/tuning_job`
Corresponds to the JSON propertyname`
38261 38262 38263 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38261 def name @name end |
#service_account ⇒ String
The service account that the tuningJob workload runs as. If not specified, the
Vertex AI Secure Fine-Tuned Service Agent in the project will be used. See
https://cloud.google.com/iam/docs/service-agents#vertex-ai-secure-fine-tuning-
service-agent Users starting the pipeline must have the iam.serviceAccounts.
actAs permission on this service account.
Corresponds to the JSON property serviceAccount
38270 38271 38272 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38270 def service_account @service_account end |
#start_time ⇒ String
Output only. Time when the TuningJob for the first time entered the
JOB_STATE_RUNNING state.
Corresponds to the JSON property startTime
38276 38277 38278 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38276 def start_time @start_time end |
#state ⇒ String
Output only. The detailed state of the job.
Corresponds to the JSON property state
38281 38282 38283 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38281 def state @state end |
#supervised_tuning_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningSpec
Tuning Spec for Supervised Tuning for first party models.
Corresponds to the JSON property supervisedTuningSpec
38286 38287 38288 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38286 def supervised_tuning_spec @supervised_tuning_spec end |
#tuned_model ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TunedModel
The Model Registry Model and Online Prediction Endpoint associated with this
TuningJob.
Corresponds to the JSON property tunedModel
38292 38293 38294 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38292 def tuned_model @tuned_model end |
#tuned_model_display_name ⇒ String
Optional. The display name of the TunedModel. The name can be up to 128
characters long and can consist of any UTF-8 characters.
Corresponds to the JSON property tunedModelDisplayName
38298 38299 38300 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38298 def tuned_model_display_name @tuned_model_display_name end |
#tuning_data_stats ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TuningDataStats
The tuning data statistic values for TuningJob.
Corresponds to the JSON property tuningDataStats
38303 38304 38305 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38303 def tuning_data_stats @tuning_data_stats end |
#update_time ⇒ String
Output only. Time when the TuningJob was most recently updated.
Corresponds to the JSON property updateTime
38308 38309 38310 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38308 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38315 38316 38317 38318 38319 38320 38321 38322 38323 38324 38325 38326 38327 38328 38329 38330 38331 38332 38333 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38315 def update!(**args) @base_model = args[:base_model] if args.key?(:base_model) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @end_time = args[:end_time] if args.key?(:end_time) @error = args[:error] if args.key?(:error) @experiment = args[:experiment] if args.key?(:experiment) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @service_account = args[:service_account] if args.key?(:service_account) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @supervised_tuning_spec = args[:supervised_tuning_spec] if args.key?(:supervised_tuning_spec) @tuned_model = args[:tuned_model] if args.key?(:tuned_model) @tuned_model_display_name = args[:tuned_model_display_name] if args.key?(:tuned_model_display_name) @tuning_data_stats = args[:tuning_data_stats] if args.key?(:tuning_data_stats) @update_time = args[:update_time] if args.key?(:update_time) end |