Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TuningJob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents a TuningJob that runs with Google owned models.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1TuningJob

Returns a new instance of GoogleCloudAiplatformV1TuningJob.



38247
38248
38249
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38247

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_modelString

The base model that is being tuned. See Supported models. Corresponds to the JSON property baseModel

Returns:

  • (String)


38144
38145
38146
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38144

def base_model
  @base_model
end

#create_timeString

Output only. Time when the TuningJob was created. Corresponds to the JSON property createTime

Returns:

  • (String)


38149
38150
38151
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38149

def create_time
  @create_time
end

#descriptionString

Optional. The description of the TuningJob. Corresponds to the JSON property description

Returns:

  • (String)


38154
38155
38156
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38154

def description
  @description
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key spec that can be applied to a top- level resource. Corresponds to the JSON property encryptionSpec



38160
38161
38162
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38160

def encryption_spec
  @encryption_spec
end

#end_timeString

Output only. Time when the TuningJob entered any of the following JobStates: JOB_STATE_SUCCEEDED, JOB_STATE_FAILED, JOB_STATE_CANCELLED, JOB_STATE_EXPIRED. Corresponds to the JSON property endTime

Returns:

  • (String)


38167
38168
38169
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38167

def end_time
  @end_time
end

#errorGoogle::Apis::AiplatformV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



38177
38178
38179
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38177

def error
  @error
end

#experimentString

Output only. The Experiment associated with this TuningJob. Corresponds to the JSON property experiment

Returns:

  • (String)


38182
38183
38184
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38182

def experiment
  @experiment
end

#labelsHash<String,String>

Optional. The labels with user-defined metadata to organize TuningJob and generated resources such as Model and Endpoint. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


38192
38193
38194
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38192

def labels
  @labels
end

#nameString

Output only. Identifier. Resource name of a TuningJob. Format: projects/ project/locations/location/tuningJobs/tuning_job` Corresponds to the JSON propertyname`

Returns:

  • (String)


38198
38199
38200
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38198

def name
  @name
end

#service_accountString

The service account that the tuningJob workload runs as. If not specified, the Vertex AI Secure Fine-Tuned Service Agent in the project will be used. See https://cloud.google.com/iam/docs/service-agents#vertex-ai-secure-fine-tuning- service-agent Users starting the pipeline must have the iam.serviceAccounts. actAs permission on this service account. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


38207
38208
38209
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38207

def 
  @service_account
end

#start_timeString

Output only. Time when the TuningJob for the first time entered the JOB_STATE_RUNNING state. Corresponds to the JSON property startTime

Returns:

  • (String)


38213
38214
38215
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38213

def start_time
  @start_time
end

#stateString

Output only. The detailed state of the job. Corresponds to the JSON property state

Returns:

  • (String)


38218
38219
38220
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38218

def state
  @state
end

#supervised_tuning_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningSpec

Tuning Spec for Supervised Tuning for first party models. Corresponds to the JSON property supervisedTuningSpec



38223
38224
38225
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38223

def supervised_tuning_spec
  @supervised_tuning_spec
end

#tuned_modelGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TunedModel

The Model Registry Model and Online Prediction Endpoint associated with this TuningJob. Corresponds to the JSON property tunedModel



38229
38230
38231
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38229

def tuned_model
  @tuned_model
end

#tuned_model_display_nameString

Optional. The display name of the TunedModel. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property tunedModelDisplayName

Returns:

  • (String)


38235
38236
38237
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38235

def tuned_model_display_name
  @tuned_model_display_name
end

#tuning_data_statsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TuningDataStats

The tuning data statistic values for TuningJob. Corresponds to the JSON property tuningDataStats



38240
38241
38242
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38240

def tuning_data_stats
  @tuning_data_stats
end

#update_timeString

Output only. Time when the TuningJob was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


38245
38246
38247
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38245

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38252
38253
38254
38255
38256
38257
38258
38259
38260
38261
38262
38263
38264
38265
38266
38267
38268
38269
38270
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38252

def update!(**args)
  @base_model = args[:base_model] if args.key?(:base_model)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @end_time = args[:end_time] if args.key?(:end_time)
  @error = args[:error] if args.key?(:error)
  @experiment = args[:experiment] if args.key?(:experiment)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @service_account = args[:service_account] if args.key?(:service_account)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @supervised_tuning_spec = args[:supervised_tuning_spec] if args.key?(:supervised_tuning_spec)
  @tuned_model = args[:tuned_model] if args.key?(:tuned_model)
  @tuned_model_display_name = args[:tuned_model_display_name] if args.key?(:tuned_model_display_name)
  @tuning_data_stats = args[:tuning_data_stats] if args.key?(:tuning_data_stats)
  @update_time = args[:update_time] if args.key?(:update_time)
end