Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TuningJob
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TuningJob
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Represents a TuningJob that runs with Google owned models.
Instance Attribute Summary collapse
-
#base_model ⇒ String
The base model that is being tuned.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top- level resource.
-
#end_time ⇒ String
Output only.
-
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#experiment ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Output only.
-
#service_account ⇒ String
The service account that the tuningJob workload runs as.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#supervised_tuning_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningSpec
Tuning Spec for Supervised Tuning for first party models.
-
#tuned_model ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TunedModel
The Model Registry Model and Online Prediction Endpoint associated with this TuningJob.
-
#tuned_model_display_name ⇒ String
Optional.
-
#tuning_data_stats ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TuningDataStats
The tuning data statistic values for TuningJob.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1TuningJob
constructor
A new instance of GoogleCloudAiplatformV1TuningJob.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1TuningJob
Returns a new instance of GoogleCloudAiplatformV1TuningJob.
38125 38126 38127 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38125 def initialize(**args) update!(**args) end |
Instance Attribute Details
#base_model ⇒ String
The base model that is being tuned. See Supported models.
Corresponds to the JSON property baseModel
38022 38023 38024 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38022 def base_model @base_model end |
#create_time ⇒ String
Output only. Time when the TuningJob was created.
Corresponds to the JSON property createTime
38027 38028 38029 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38027 def create_time @create_time end |
#description ⇒ String
Optional. The description of the TuningJob.
Corresponds to the JSON property description
38032 38033 38034 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38032 def description @description end |
#encryption_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec
Represents a customer-managed encryption key spec that can be applied to a top-
level resource.
Corresponds to the JSON property encryptionSpec
38038 38039 38040 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38038 def encryption_spec @encryption_spec end |
#end_time ⇒ String
Output only. Time when the TuningJob entered any of the following JobStates:
JOB_STATE_SUCCEEDED, JOB_STATE_FAILED, JOB_STATE_CANCELLED,
JOB_STATE_EXPIRED.
Corresponds to the JSON property endTime
38045 38046 38047 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38045 def end_time @end_time end |
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
38055 38056 38057 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38055 def error @error end |
#experiment ⇒ String
Output only. The Experiment associated with this TuningJob.
Corresponds to the JSON property experiment
38060 38061 38062 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38060 def experiment @experiment end |
#labels ⇒ Hash<String,String>
Optional. The labels with user-defined metadata to organize TuningJob and
generated resources such as Model and Endpoint. Label keys and values can be
no longer than 64 characters (Unicode codepoints), can only contain lowercase
letters, numeric characters, underscores and dashes. International characters
are allowed. See https://goo.gl/xmQnxf for more information and examples of
labels.
Corresponds to the JSON property labels
38070 38071 38072 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38070 def labels @labels end |
#name ⇒ String
Output only. Identifier. Resource name of a TuningJob. Format: projects/
project/locations/location/tuningJobs/tuning_job`
Corresponds to the JSON propertyname`
38076 38077 38078 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38076 def name @name end |
#service_account ⇒ String
The service account that the tuningJob workload runs as. If not specified, the
Vertex AI Secure Fine-Tuned Service Agent in the project will be used. See
https://cloud.google.com/iam/docs/service-agents#vertex-ai-secure-fine-tuning-
service-agent Users starting the pipeline must have the iam.serviceAccounts.
actAs permission on this service account.
Corresponds to the JSON property serviceAccount
38085 38086 38087 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38085 def service_account @service_account end |
#start_time ⇒ String
Output only. Time when the TuningJob for the first time entered the
JOB_STATE_RUNNING state.
Corresponds to the JSON property startTime
38091 38092 38093 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38091 def start_time @start_time end |
#state ⇒ String
Output only. The detailed state of the job.
Corresponds to the JSON property state
38096 38097 38098 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38096 def state @state end |
#supervised_tuning_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningSpec
Tuning Spec for Supervised Tuning for first party models.
Corresponds to the JSON property supervisedTuningSpec
38101 38102 38103 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38101 def supervised_tuning_spec @supervised_tuning_spec end |
#tuned_model ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TunedModel
The Model Registry Model and Online Prediction Endpoint associated with this
TuningJob.
Corresponds to the JSON property tunedModel
38107 38108 38109 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38107 def tuned_model @tuned_model end |
#tuned_model_display_name ⇒ String
Optional. The display name of the TunedModel. The name can be up to 128
characters long and can consist of any UTF-8 characters.
Corresponds to the JSON property tunedModelDisplayName
38113 38114 38115 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38113 def tuned_model_display_name @tuned_model_display_name end |
#tuning_data_stats ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TuningDataStats
The tuning data statistic values for TuningJob.
Corresponds to the JSON property tuningDataStats
38118 38119 38120 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38118 def tuning_data_stats @tuning_data_stats end |
#update_time ⇒ String
Output only. Time when the TuningJob was most recently updated.
Corresponds to the JSON property updateTime
38123 38124 38125 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38123 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38130 38131 38132 38133 38134 38135 38136 38137 38138 38139 38140 38141 38142 38143 38144 38145 38146 38147 38148 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38130 def update!(**args) @base_model = args[:base_model] if args.key?(:base_model) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec) @end_time = args[:end_time] if args.key?(:end_time) @error = args[:error] if args.key?(:error) @experiment = args[:experiment] if args.key?(:experiment) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @service_account = args[:service_account] if args.key?(:service_account) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @supervised_tuning_spec = args[:supervised_tuning_spec] if args.key?(:supervised_tuning_spec) @tuned_model = args[:tuned_model] if args.key?(:tuned_model) @tuned_model_display_name = args[:tuned_model_display_name] if args.key?(:tuned_model_display_name) @tuning_data_stats = args[:tuning_data_stats] if args.key?(:tuning_data_stats) @update_time = args[:update_time] if args.key?(:update_time) end |