Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TuningJob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents a TuningJob that runs with Google owned models.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1TuningJob

Returns a new instance of GoogleCloudAiplatformV1TuningJob.



32968
32969
32970
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32968

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_modelString

The base model that is being tuned, e.g., "gemini-1.0-pro-002". Corresponds to the JSON property baseModel

Returns:

  • (String)


32874
32875
32876
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32874

def base_model
  @base_model
end

#create_timeString

Output only. Time when the TuningJob was created. Corresponds to the JSON property createTime

Returns:

  • (String)


32879
32880
32881
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32879

def create_time
  @create_time
end

#descriptionString

Optional. The description of the TuningJob. Corresponds to the JSON property description

Returns:

  • (String)


32884
32885
32886
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32884

def description
  @description
end

#encryption_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1EncryptionSpec

Represents a customer-managed encryption key spec that can be applied to a top- level resource. Corresponds to the JSON property encryptionSpec



32890
32891
32892
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32890

def encryption_spec
  @encryption_spec
end

#end_timeString

Output only. Time when the TuningJob entered any of the following JobStates: JOB_STATE_SUCCEEDED, JOB_STATE_FAILED, JOB_STATE_CANCELLED, JOB_STATE_EXPIRED. Corresponds to the JSON property endTime

Returns:

  • (String)


32897
32898
32899
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32897

def end_time
  @end_time
end

#errorGoogle::Apis::AiplatformV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



32907
32908
32909
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32907

def error
  @error
end

#experimentString

Output only. The Experiment associated with this TuningJob. Corresponds to the JSON property experiment

Returns:

  • (String)


32912
32913
32914
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32912

def experiment
  @experiment
end

#labelsHash<String,String>

Optional. The labels with user-defined metadata to organize TuningJob and generated resources such as Model and Endpoint. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


32922
32923
32924
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32922

def labels
  @labels
end

#nameString

Output only. Identifier. Resource name of a TuningJob. Format: projects/ project/locations/location/tuningJobs/tuning_job` Corresponds to the JSON propertyname`

Returns:

  • (String)


32928
32929
32930
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32928

def name
  @name
end

#start_timeString

Output only. Time when the TuningJob for the first time entered the JOB_STATE_RUNNING state. Corresponds to the JSON property startTime

Returns:

  • (String)


32934
32935
32936
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32934

def start_time
  @start_time
end

#stateString

Output only. The detailed state of the job. Corresponds to the JSON property state

Returns:

  • (String)


32939
32940
32941
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32939

def state
  @state
end

#supervised_tuning_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningSpec

Tuning Spec for Supervised Tuning for first party models. Corresponds to the JSON property supervisedTuningSpec



32944
32945
32946
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32944

def supervised_tuning_spec
  @supervised_tuning_spec
end

#tuned_modelGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TunedModel

The Model Registry Model and Online Prediction Endpoint assiociated with this TuningJob. Corresponds to the JSON property tunedModel



32950
32951
32952
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32950

def tuned_model
  @tuned_model
end

#tuned_model_display_nameString

Optional. The display name of the TunedModel. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property tunedModelDisplayName

Returns:

  • (String)


32956
32957
32958
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32956

def tuned_model_display_name
  @tuned_model_display_name
end

#tuning_data_statsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TuningDataStats

The tuning data statistic values for TuningJob. Corresponds to the JSON property tuningDataStats



32961
32962
32963
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32961

def tuning_data_stats
  @tuning_data_stats
end

#update_timeString

Output only. Time when the TuningJob was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


32966
32967
32968
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32966

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32973
32974
32975
32976
32977
32978
32979
32980
32981
32982
32983
32984
32985
32986
32987
32988
32989
32990
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32973

def update!(**args)
  @base_model = args[:base_model] if args.key?(:base_model)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @encryption_spec = args[:encryption_spec] if args.key?(:encryption_spec)
  @end_time = args[:end_time] if args.key?(:end_time)
  @error = args[:error] if args.key?(:error)
  @experiment = args[:experiment] if args.key?(:experiment)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @supervised_tuning_spec = args[:supervised_tuning_spec] if args.key?(:supervised_tuning_spec)
  @tuned_model = args[:tuned_model] if args.key?(:tuned_model)
  @tuned_model_display_name = args[:tuned_model_display_name] if args.key?(:tuned_model_display_name)
  @tuning_data_stats = args[:tuning_data_stats] if args.key?(:tuning_data_stats)
  @update_time = args[:update_time] if args.key?(:update_time)
end