Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TuningJob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents a TuningJob that runs with Google owned models.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1TuningJob

Returns a new instance of GoogleCloudAiplatformV1TuningJob.



28828
28829
28830
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28828

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_modelString

Model name for tuning, e.g., "gemini-1.0-pro-002". Corresponds to the JSON property baseModel

Returns:

  • (String)


28740
28741
28742
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28740

def base_model
  @base_model
end

#create_timeString

Output only. Time when the TuningJob was created. Corresponds to the JSON property createTime

Returns:

  • (String)


28745
28746
28747
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28745

def create_time
  @create_time
end

#descriptionString

Optional. The description of the TuningJob. Corresponds to the JSON property description

Returns:

  • (String)


28750
28751
28752
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28750

def description
  @description
end

#end_timeString

Output only. Time when the TuningJob entered any of the following JobStates: JOB_STATE_SUCCEEDED, JOB_STATE_FAILED, JOB_STATE_CANCELLED, JOB_STATE_EXPIRED. Corresponds to the JSON property endTime

Returns:

  • (String)


28757
28758
28759
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28757

def end_time
  @end_time
end

#errorGoogle::Apis::AiplatformV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



28767
28768
28769
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28767

def error
  @error
end

#experimentString

Output only. The Experiment associated with this TuningJob. Corresponds to the JSON property experiment

Returns:

  • (String)


28772
28773
28774
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28772

def experiment
  @experiment
end

#labelsHash<String,String>

Optional. The labels with user-defined metadata to organize TuningJob and generated resources such as Model and Endpoint. Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. See https://goo.gl/xmQnxf for more information and examples of labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


28782
28783
28784
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28782

def labels
  @labels
end

#nameString

Output only. Identifier. Resource name of a TuningJob. Format: projects/ project/locations/location/tuningJobs/tuning_job` Corresponds to the JSON propertyname`

Returns:

  • (String)


28788
28789
28790
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28788

def name
  @name
end

#start_timeString

Output only. Time when the TuningJob for the first time entered the JOB_STATE_RUNNING state. Corresponds to the JSON property startTime

Returns:

  • (String)


28794
28795
28796
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28794

def start_time
  @start_time
end

#stateString

Output only. The detailed state of the job. Corresponds to the JSON property state

Returns:

  • (String)


28799
28800
28801
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28799

def state
  @state
end

#supervised_tuning_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1SupervisedTuningSpec

Tuning Spec for Supervised Tuning. Corresponds to the JSON property supervisedTuningSpec



28804
28805
28806
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28804

def supervised_tuning_spec
  @supervised_tuning_spec
end

#tuned_modelGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TunedModel

The Model Registry Model and Online Prediction Endpoint assiociated with this TuningJob. Corresponds to the JSON property tunedModel



28810
28811
28812
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28810

def tuned_model
  @tuned_model
end

#tuned_model_display_nameString

Optional. The display name of the TunedModel. The name can be up to 128 characters long and can consist of any UTF-8 characters. Corresponds to the JSON property tunedModelDisplayName

Returns:

  • (String)


28816
28817
28818
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28816

def tuned_model_display_name
  @tuned_model_display_name
end

#tuning_data_statsGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1TuningDataStats

The tuning data statistic values for TuningJob. Corresponds to the JSON property tuningDataStats



28821
28822
28823
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28821

def tuning_data_stats
  @tuning_data_stats
end

#update_timeString

Output only. Time when the TuningJob was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


28826
28827
28828
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28826

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28833
28834
28835
28836
28837
28838
28839
28840
28841
28842
28843
28844
28845
28846
28847
28848
28849
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28833

def update!(**args)
  @base_model = args[:base_model] if args.key?(:base_model)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @end_time = args[:end_time] if args.key?(:end_time)
  @error = args[:error] if args.key?(:error)
  @experiment = args[:experiment] if args.key?(:experiment)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @supervised_tuning_spec = args[:supervised_tuning_spec] if args.key?(:supervised_tuning_spec)
  @tuned_model = args[:tuned_model] if args.key?(:tuned_model)
  @tuned_model_display_name = args[:tuned_model_display_name] if args.key?(:tuned_model_display_name)
  @tuning_data_stats = args[:tuning_data_stats] if args.key?(:tuning_data_stats)
  @update_time = args[:update_time] if args.key?(:update_time)
end