Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1UndeployModelRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1UndeployModelRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Request message for EndpointService.UndeployModel.
Instance Attribute Summary collapse
-
#deployed_model_id ⇒ String
Required.
-
#traffic_split ⇒ Hash<String,Fixnum>
If this field is provided, then the Endpoint's traffic_split will be overwritten with it.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1UndeployModelRequest
constructor
A new instance of GoogleCloudAiplatformV1UndeployModelRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1UndeployModelRequest
Returns a new instance of GoogleCloudAiplatformV1UndeployModelRequest.
32716 32717 32718 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32716 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deployed_model_id ⇒ String
Required. The ID of the DeployedModel to be undeployed from the Endpoint.
Corresponds to the JSON property deployedModelId
32704 32705 32706 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32704 def deployed_model_id @deployed_model_id end |
#traffic_split ⇒ Hash<String,Fixnum>
If this field is provided, then the Endpoint's traffic_split will be
overwritten with it. If last DeployedModel is being undeployed from the
Endpoint, the [Endpoint.traffic_split] will always end up empty when this call
returns. A DeployedModel will be successfully undeployed only if it doesn't
have any traffic assigned to it when this method executes, or if this field
unassigns any traffic to it.
Corresponds to the JSON property trafficSplit
32714 32715 32716 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32714 def traffic_split @traffic_split end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32721 32722 32723 32724 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32721 def update!(**args) @deployed_model_id = args[:deployed_model_id] if args.key?(:deployed_model_id) @traffic_split = args[:traffic_split] if args.key?(:traffic_split) end |