Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1UndeployModelRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for EndpointService.UndeployModel.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1UndeployModelRequest

Returns a new instance of GoogleCloudAiplatformV1UndeployModelRequest.



28055
28056
28057
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28055

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deployed_model_idString

Required. The ID of the DeployedModel to be undeployed from the Endpoint. Corresponds to the JSON property deployedModelId

Returns:

  • (String)


28043
28044
28045
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28043

def deployed_model_id
  @deployed_model_id
end

#traffic_splitHash<String,Fixnum>

If this field is provided, then the Endpoint's traffic_split will be overwritten with it. If last DeployedModel is being undeployed from the Endpoint, the [Endpoint.traffic_split] will always end up empty when this call returns. A DeployedModel will be successfully undeployed only if it doesn't have any traffic assigned to it when this method executes, or if this field unassigns any traffic to it. Corresponds to the JSON property trafficSplit

Returns:

  • (Hash<String,Fixnum>)


28053
28054
28055
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28053

def traffic_split
  @traffic_split
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28060
28061
28062
28063
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28060

def update!(**args)
  @deployed_model_id = args[:deployed_model_id] if args.key?(:deployed_model_id)
  @traffic_split = args[:traffic_split] if args.key?(:traffic_split)
end