Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1UnmanagedContainerModel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Contains model information necessary to perform batch prediction without requiring a full model import.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1UnmanagedContainerModel

Returns a new instance of GoogleCloudAiplatformV1UnmanagedContainerModel.



39587
39588
39589
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39587

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifact_uriString

The path to the directory containing the Model artifact and any of its supporting files. Corresponds to the JSON property artifactUri

Returns:

  • (String)


39571
39572
39573
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39571

def artifact_uri
  @artifact_uri
end

#container_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ModelContainerSpec

Specification of a container for serving predictions. Some fields in this message correspond to fields in the Kubernetes Container v1 core specification. Corresponds to the JSON property containerSpec



39579
39580
39581
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39579

def container_spec
  @container_spec
end

#predict_schemataGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PredictSchemata

Contains the schemata used in Model's predictions and explanations via PredictionService.Predict, PredictionService.Explain and BatchPredictionJob. Corresponds to the JSON property predictSchemata



39585
39586
39587
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39585

def predict_schemata
  @predict_schemata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39592
39593
39594
39595
39596
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39592

def update!(**args)
  @artifact_uri = args[:artifact_uri] if args.key?(:artifact_uri)
  @container_spec = args[:container_spec] if args.key?(:container_spec)
  @predict_schemata = args[:predict_schemata] if args.key?(:predict_schemata)
end