Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1UploadModelRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for ModelService.UploadModel.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1UploadModelRequest

Returns a new instance of GoogleCloudAiplatformV1UploadModelRequest.



46395
46396
46397
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46395

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#modelGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Model

A trained machine learning Model. Corresponds to the JSON property model



46368
46369
46370
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46368

def model
  @model
end

#model_idString

Optional. The ID to use for the uploaded Model, which will become the final component of the model resource name. This value may be up to 63 characters, and valid characters are [a-z0-9_-]. The first character cannot be a number or hyphen. Corresponds to the JSON property modelId

Returns:

  • (String)


46376
46377
46378
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46376

def model_id
  @model_id
end

#parent_modelString

Optional. The resource name of the model into which to upload the version. Only specify this field when uploading a new version. Corresponds to the JSON property parentModel

Returns:

  • (String)


46382
46383
46384
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46382

def parent_model
  @parent_model
end

#service_accountString

Optional. The user-provided custom service account to use to do the model upload. If empty, Vertex AI Service Agent will be used to access resources needed to upload the model. This account must belong to the target project where the model is uploaded to, i.e., the project specified in the parent field of this request and have necessary read permissions (to Google Cloud Storage, Artifact Registry, etc.). Corresponds to the JSON property serviceAccount

Returns:

  • (String)


46393
46394
46395
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46393

def 
  @service_account
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46400
46401
46402
46403
46404
46405
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46400

def update!(**args)
  @model = args[:model] if args.key?(:model)
  @model_id = args[:model_id] if args.key?(:model_id)
  @parent_model = args[:parent_model] if args.key?(:parent_model)
  @service_account = args[:service_account] if args.key?(:service_account)
end