Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1UploadModelRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for ModelService.UploadModel.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1UploadModelRequest

Returns a new instance of GoogleCloudAiplatformV1UploadModelRequest.



38880
38881
38882
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38880

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#modelGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1Model

A trained machine learning Model. Corresponds to the JSON property model



38853
38854
38855
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38853

def model
  @model
end

#model_idString

Optional. The ID to use for the uploaded Model, which will become the final component of the model resource name. This value may be up to 63 characters, and valid characters are [a-z0-9_-]. The first character cannot be a number or hyphen. Corresponds to the JSON property modelId

Returns:

  • (String)


38861
38862
38863
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38861

def model_id
  @model_id
end

#parent_modelString

Optional. The resource name of the model into which to upload the version. Only specify this field when uploading a new version. Corresponds to the JSON property parentModel

Returns:

  • (String)


38867
38868
38869
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38867

def parent_model
  @parent_model
end

#service_accountString

Optional. The user-provided custom service account to use to do the model upload. If empty, Vertex AI Service Agent will be used to access resources needed to upload the model. This account must belong to the target project where the model is uploaded to, i.e., the project specified in the parent field of this request and have necessary read permissions (to Google Cloud Storage, Artifact Registry, etc.). Corresponds to the JSON property serviceAccount

Returns:

  • (String)


38878
38879
38880
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38878

def 
  @service_account
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38885
38886
38887
38888
38889
38890
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38885

def update!(**args)
  @model = args[:model] if args.key?(:model)
  @model_id = args[:model_id] if args.key?(:model_id)
  @parent_model = args[:parent_model] if args.key?(:parent_model)
  @service_account = args[:service_account] if args.key?(:service_account)
end