Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1UploadModelRequest
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1UploadModelRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Request message for ModelService.UploadModel.
Instance Attribute Summary collapse
-
#model ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Model
A trained machine learning Model.
-
#model_id ⇒ String
Optional.
-
#parent_model ⇒ String
Optional.
-
#service_account ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1UploadModelRequest
constructor
A new instance of GoogleCloudAiplatformV1UploadModelRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1UploadModelRequest
Returns a new instance of GoogleCloudAiplatformV1UploadModelRequest.
33517 33518 33519 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33517 def initialize(**args) update!(**args) end |
Instance Attribute Details
#model ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1Model
A trained machine learning Model.
Corresponds to the JSON property model
33490 33491 33492 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33490 def model @model end |
#model_id ⇒ String
Optional. The ID to use for the uploaded Model, which will become the final
component of the model resource name. This value may be up to 63 characters,
and valid characters are [a-z0-9_-]. The first character cannot be a number
or hyphen.
Corresponds to the JSON property modelId
33498 33499 33500 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33498 def model_id @model_id end |
#parent_model ⇒ String
Optional. The resource name of the model into which to upload the version.
Only specify this field when uploading a new version.
Corresponds to the JSON property parentModel
33504 33505 33506 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33504 def parent_model @parent_model end |
#service_account ⇒ String
Optional. The user-provided custom service account to use to do the model
upload. If empty, Vertex AI Service Agent will be used to access resources
needed to upload the model. This account must belong to the target project
where the model is uploaded to, i.e., the project specified in the parent
field of this request and have necessary read permissions (to Google Cloud
Storage, Artifact Registry, etc.).
Corresponds to the JSON property serviceAccount
33515 33516 33517 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33515 def service_account @service_account end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33522 33523 33524 33525 33526 33527 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33522 def update!(**args) @model = args[:model] if args.key?(:model) @model_id = args[:model_id] if args.key?(:model_id) @parent_model = args[:parent_model] if args.key?(:parent_model) @service_account = args[:service_account] if args.key?(:service_account) end |