Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1UploadRagFileResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Response message for VertexRagDataService.UploadRagFile.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1UploadRagFileResponse

Returns a new instance of GoogleCloudAiplatformV1UploadRagFileResponse.



39557
39558
39559
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39557

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::AiplatformV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



39550
39551
39552
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39550

def error
  @error
end

#rag_fileGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RagFile

A RagFile contains user data for chunking, embedding and indexing. Corresponds to the JSON property ragFile



39555
39556
39557
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39555

def rag_file
  @rag_file
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39562
39563
39564
39565
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39562

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @rag_file = args[:rag_file] if args.key?(:rag_file)
end