Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1UploadRagFileResponse
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1UploadRagFileResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Response message for VertexRagDataService.UploadRagFile.
Instance Attribute Summary collapse
-
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#rag_file ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagFile
A RagFile contains user data for chunking, embedding and indexing.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1UploadRagFileResponse
constructor
A new instance of GoogleCloudAiplatformV1UploadRagFileResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1UploadRagFileResponse
Returns a new instance of GoogleCloudAiplatformV1UploadRagFileResponse.
39439 39440 39441 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39439 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
39432 39433 39434 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39432 def error @error end |
#rag_file ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagFile
A RagFile contains user data for chunking, embedding and indexing.
Corresponds to the JSON property ragFile
39437 39438 39439 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39437 def rag_file @rag_file end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39444 39445 39446 39447 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39444 def update!(**args) @error = args[:error] if args.key?(:error) @rag_file = args[:rag_file] if args.key?(:rag_file) end |