Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1UpsertDatapointsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for IndexService.UpsertDatapoints

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1UpsertDatapointsRequest

Returns a new instance of GoogleCloudAiplatformV1UpsertDatapointsRequest.



37986
37987
37988
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37986

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#datapointsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1IndexDatapoint>

A list of datapoints to be created/updated. Corresponds to the JSON property datapoints



37976
37977
37978
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37976

def datapoints
  @datapoints
end

#update_maskString

Optional. Update mask is used to specify the fields to be overwritten in the datapoints by the update. The fields specified in the update_mask are relative to each IndexDatapoint inside datapoints, not the full request. Updatable fields: * Use all_restricts to update both restricts and numeric_restricts. Corresponds to the JSON property updateMask

Returns:

  • (String)


37984
37985
37986
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37984

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37991
37992
37993
37994
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 37991

def update!(**args)
  @datapoints = args[:datapoints] if args.key?(:datapoints)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end