Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1UserScenario

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Output of user scenario generation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1UserScenario

Returns a new instance of GoogleCloudAiplatformV1UserScenario.



51975
51976
51977
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 51975

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversation_planString

Conversation plan to drive multi-turn agent run and get simulated agent eval dataset. Corresponds to the JSON property conversationPlan

Returns:

  • (String)


51962
51963
51964
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 51962

def conversation_plan
  @conversation_plan
end

#starting_promptString

Starting prompt for the conversation between simulated user and agent under the test. Corresponds to the JSON property startingPrompt

Returns:

  • (String)


51968
51969
51970
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 51968

def starting_prompt
  @starting_prompt
end

#test_case_titleString

Represents a short 3-5 word title for eval test case. Corresponds to the JSON property testCaseTitle

Returns:

  • (String)


51973
51974
51975
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 51973

def test_case_title
  @test_case_title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51980
51981
51982
51983
51984
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 51980

def update!(**args)
  @conversation_plan = args[:conversation_plan] if args.key?(:conversation_plan)
  @starting_prompt = args[:starting_prompt] if args.key?(:starting_prompt)
  @test_case_title = args[:test_case_title] if args.key?(:test_case_title)
end