Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1UserScenario
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1UserScenario
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Output of user scenario generation.
Instance Attribute Summary collapse
-
#conversation_plan ⇒ String
Conversation plan to drive multi-turn agent run and get simulated agent eval dataset.
-
#starting_prompt ⇒ String
Starting prompt for the conversation between simulated user and agent under the test.
-
#test_case_title ⇒ String
Represents a short 3-5 word title for eval test case.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1UserScenario
constructor
A new instance of GoogleCloudAiplatformV1UserScenario.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1UserScenario
Returns a new instance of GoogleCloudAiplatformV1UserScenario.
50934 50935 50936 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 50934 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conversation_plan ⇒ String
Conversation plan to drive multi-turn agent run and get simulated agent eval
dataset.
Corresponds to the JSON property conversationPlan
50921 50922 50923 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 50921 def conversation_plan @conversation_plan end |
#starting_prompt ⇒ String
Starting prompt for the conversation between simulated user and agent under
the test.
Corresponds to the JSON property startingPrompt
50927 50928 50929 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 50927 def starting_prompt @starting_prompt end |
#test_case_title ⇒ String
Represents a short 3-5 word title for eval test case.
Corresponds to the JSON property testCaseTitle
50932 50933 50934 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 50932 def test_case_title @test_case_title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
50939 50940 50941 50942 50943 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 50939 def update!(**args) @conversation_plan = args[:conversation_plan] if args.key?(:conversation_plan) @starting_prompt = args[:starting_prompt] if args.key?(:starting_prompt) @test_case_title = args[:test_case_title] if args.key?(:test_case_title) end |