Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1UserScenario

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Output of user scenario generation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1UserScenario

Returns a new instance of GoogleCloudAiplatformV1UserScenario.



50492
50493
50494
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 50492

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conversation_planString

Conversation plan to drive multi-turn agent run and get simulated agent eval dataset. Corresponds to the JSON property conversationPlan

Returns:

  • (String)


50479
50480
50481
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 50479

def conversation_plan
  @conversation_plan
end

#starting_promptString

Starting prompt for the conversation between simulated user and agent under the test. Corresponds to the JSON property startingPrompt

Returns:

  • (String)


50485
50486
50487
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 50485

def starting_prompt
  @starting_prompt
end

#test_case_titleString

Represents a short 3-5 word title for eval test case. Corresponds to the JSON property testCaseTitle

Returns:

  • (String)


50490
50491
50492
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 50490

def test_case_title
  @test_case_title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50497
50498
50499
50500
50501
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 50497

def update!(**args)
  @conversation_plan = args[:conversation_plan] if args.key?(:conversation_plan)
  @starting_prompt = args[:starting_prompt] if args.key?(:starting_prompt)
  @test_case_title = args[:test_case_title] if args.key?(:test_case_title)
end