Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexAiSearch
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexAiSearch
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Retrieve from Vertex AI Search datastore or engine for grounding. datastore and engine are mutually exclusive. See https://cloud.google.com/products/agent- builder
Instance Attribute Summary collapse
-
#data_store_specs ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexAiSearchDataStoreSpec>
Specifications that define the specific DataStores to be searched, along with configurations for those data stores.
-
#datastore ⇒ String
Optional.
-
#engine ⇒ String
Optional.
-
#filter ⇒ String
Optional.
-
#max_results ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1VertexAiSearch
constructor
A new instance of GoogleCloudAiplatformV1VertexAiSearch.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1VertexAiSearch
Returns a new instance of GoogleCloudAiplatformV1VertexAiSearch.
52312 52313 52314 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 52312 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_store_specs ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexAiSearchDataStoreSpec>
Specifications that define the specific DataStores to be searched, along with
configurations for those data stores. This is only considered for Engines with
multiple data stores. It should only be set if engine is used.
Corresponds to the JSON property dataStoreSpecs
52285 52286 52287 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 52285 def data_store_specs @data_store_specs end |
#datastore ⇒ String
Optional. Fully-qualified Vertex AI Search data store resource ID. Format:
projects/project/locations/location/collections/collection/dataStores/
dataStore`
Corresponds to the JSON propertydatastore`
52292 52293 52294 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 52292 def datastore @datastore end |
#engine ⇒ String
Optional. Fully-qualified Vertex AI Search engine resource ID. Format:
projects/project/locations/location/collections/collection/engines/
engine`
Corresponds to the JSON propertyengine`
52299 52300 52301 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 52299 def engine @engine end |
#filter ⇒ String
Optional. Filter strings to be passed to the search API.
Corresponds to the JSON property filter
52304 52305 52306 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 52304 def filter @filter end |
#max_results ⇒ Fixnum
Optional. Number of search results to return per query. The default value is
- The maximumm allowed value is 10.
Corresponds to the JSON property
maxResults
52310 52311 52312 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 52310 def max_results @max_results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52317 52318 52319 52320 52321 52322 52323 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 52317 def update!(**args) @data_store_specs = args[:data_store_specs] if args.key?(:data_store_specs) @datastore = args[:datastore] if args.key?(:datastore) @engine = args[:engine] if args.key?(:engine) @filter = args[:filter] if args.key?(:filter) @max_results = args[:max_results] if args.key?(:max_results) end |