Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexAiSearch
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexAiSearch
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Retrieve from Vertex AI Search datastore or engine for grounding. datastore and engine are mutually exclusive. See https://cloud.google.com/products/agent- builder
Instance Attribute Summary collapse
-
#data_store_specs ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexAiSearchDataStoreSpec>
Specifications that define the specific DataStores to be searched, along with configurations for those data stores.
-
#datastore ⇒ String
Optional.
-
#engine ⇒ String
Optional.
-
#filter ⇒ String
Optional.
-
#max_results ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1VertexAiSearch
constructor
A new instance of GoogleCloudAiplatformV1VertexAiSearch.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1VertexAiSearch
Returns a new instance of GoogleCloudAiplatformV1VertexAiSearch.
48727 48728 48729 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48727 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_store_specs ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexAiSearchDataStoreSpec>
Specifications that define the specific DataStores to be searched, along with
configurations for those data stores. This is only considered for Engines with
multiple data stores. It should only be set if engine is used.
Corresponds to the JSON property dataStoreSpecs
48700 48701 48702 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48700 def data_store_specs @data_store_specs end |
#datastore ⇒ String
Optional. Fully-qualified Vertex AI Search data store resource ID. Format:
projects/project/locations/location/collections/collection/dataStores/
dataStore`
Corresponds to the JSON propertydatastore`
48707 48708 48709 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48707 def datastore @datastore end |
#engine ⇒ String
Optional. Fully-qualified Vertex AI Search engine resource ID. Format:
projects/project/locations/location/collections/collection/engines/
engine`
Corresponds to the JSON propertyengine`
48714 48715 48716 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48714 def engine @engine end |
#filter ⇒ String
Optional. Filter strings to be passed to the search API.
Corresponds to the JSON property filter
48719 48720 48721 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48719 def filter @filter end |
#max_results ⇒ Fixnum
Optional. Number of search results to return per query. The default value is
- The maximumm allowed value is 10.
Corresponds to the JSON property
maxResults
48725 48726 48727 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48725 def max_results @max_results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
48732 48733 48734 48735 48736 48737 48738 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48732 def update!(**args) @data_store_specs = args[:data_store_specs] if args.key?(:data_store_specs) @datastore = args[:datastore] if args.key?(:datastore) @engine = args[:engine] if args.key?(:engine) @filter = args[:filter] if args.key?(:filter) @max_results = args[:max_results] if args.key?(:max_results) end |