Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexAiSearch

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Retrieve from Vertex AI Search datastore or engine for grounding. datastore and engine are mutually exclusive. See https://cloud.google.com/products/agent- builder

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1VertexAiSearch

Returns a new instance of GoogleCloudAiplatformV1VertexAiSearch.



46521
46522
46523
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46521

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_store_specsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexAiSearchDataStoreSpec>

Specifications that define the specific DataStores to be searched, along with configurations for those data stores. This is only considered for Engines with multiple data stores. It should only be set if engine is used. Corresponds to the JSON property dataStoreSpecs



46494
46495
46496
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46494

def data_store_specs
  @data_store_specs
end

#datastoreString

Optional. Fully-qualified Vertex AI Search data store resource ID. Format: projects/project/locations/location/collections/collection/dataStores/ dataStore` Corresponds to the JSON propertydatastore`

Returns:

  • (String)


46501
46502
46503
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46501

def datastore
  @datastore
end

#engineString

Optional. Fully-qualified Vertex AI Search engine resource ID. Format: projects/project/locations/location/collections/collection/engines/ engine` Corresponds to the JSON propertyengine`

Returns:

  • (String)


46508
46509
46510
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46508

def engine
  @engine
end

#filterString

Optional. Filter strings to be passed to the search API. Corresponds to the JSON property filter

Returns:

  • (String)


46513
46514
46515
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46513

def filter
  @filter
end

#max_resultsFixnum

Optional. Number of search results to return per query. The default value is

  1. The maximumm allowed value is 10. Corresponds to the JSON property maxResults

Returns:

  • (Fixnum)


46519
46520
46521
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46519

def max_results
  @max_results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46526
46527
46528
46529
46530
46531
46532
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46526

def update!(**args)
  @data_store_specs = args[:data_store_specs] if args.key?(:data_store_specs)
  @datastore = args[:datastore] if args.key?(:datastore)
  @engine = args[:engine] if args.key?(:engine)
  @filter = args[:filter] if args.key?(:filter)
  @max_results = args[:max_results] if args.key?(:max_results)
end