Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexAiSearch

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Retrieve from Vertex AI Search datastore or engine for grounding. datastore and engine are mutually exclusive. See https://cloud.google.com/products/agent- builder

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1VertexAiSearch

Returns a new instance of GoogleCloudAiplatformV1VertexAiSearch.



40672
40673
40674
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40672

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_store_specsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexAiSearchDataStoreSpec>

Specifications that define the specific DataStores to be searched, along with configurations for those data stores. This is only considered for Engines with multiple data stores. It should only be set if engine is used. Corresponds to the JSON property dataStoreSpecs



40645
40646
40647
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40645

def data_store_specs
  @data_store_specs
end

#datastoreString

Optional. Fully-qualified Vertex AI Search data store resource ID. Format: projects/project/locations/location/collections/collection/dataStores/ dataStore` Corresponds to the JSON propertydatastore`

Returns:

  • (String)


40652
40653
40654
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40652

def datastore
  @datastore
end

#engineString

Optional. Fully-qualified Vertex AI Search engine resource ID. Format: projects/project/locations/location/collections/collection/engines/ engine` Corresponds to the JSON propertyengine`

Returns:

  • (String)


40659
40660
40661
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40659

def engine
  @engine
end

#filterString

Optional. Filter strings to be passed to the search API. Corresponds to the JSON property filter

Returns:

  • (String)


40664
40665
40666
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40664

def filter
  @filter
end

#max_resultsFixnum

Optional. Number of search results to return per query. The default value is

  1. The maximumm allowed value is 10. Corresponds to the JSON property maxResults

Returns:

  • (Fixnum)


40670
40671
40672
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40670

def max_results
  @max_results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40677
40678
40679
40680
40681
40682
40683
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40677

def update!(**args)
  @data_store_specs = args[:data_store_specs] if args.key?(:data_store_specs)
  @datastore = args[:datastore] if args.key?(:datastore)
  @engine = args[:engine] if args.key?(:engine)
  @filter = args[:filter] if args.key?(:filter)
  @max_results = args[:max_results] if args.key?(:max_results)
end