Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexAiSearchDataStoreSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexAiSearchDataStoreSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Define data stores within engine to filter on in a search call and configurations for those data stores. For more information, see https://cloud. google.com/generative-ai-app-builder/docs/reference/rpc/google.cloud. discoveryengine.v1#datastorespec
Instance Attribute Summary collapse
-
#data_store ⇒ String
Full resource name of DataStore, such as Format:
projects/project/locations/location/collections/collection/dataStores/dataStore`Corresponds to the JSON propertydataStore`. -
#filter ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1VertexAiSearchDataStoreSpec
constructor
A new instance of GoogleCloudAiplatformV1VertexAiSearchDataStoreSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1VertexAiSearchDataStoreSpec
Returns a new instance of GoogleCloudAiplatformV1VertexAiSearchDataStoreSpec.
40290 40291 40292 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40290 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_store ⇒ String
Full resource name of DataStore, such as Format: projects/project/locations/
location/collections/collection/dataStores/dataStore`
Corresponds to the JSON propertydataStore`
40281 40282 40283 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40281 def data_store @data_store end |
#filter ⇒ String
Optional. Filter specification to filter documents in the data store specified
by data_store field. For more information on filtering, see Filtering
Corresponds to the JSON property filter
40288 40289 40290 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40288 def filter @filter end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40295 40296 40297 40298 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40295 def update!(**args) @data_store = args[:data_store] if args.key?(:data_store) @filter = args[:filter] if args.key?(:filter) end |