Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexAiSearchDataStoreSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Define data stores within engine to filter on in a search call and configurations for those data stores. For more information, see https://cloud. google.com/generative-ai-app-builder/docs/reference/rpc/google.cloud. discoveryengine.v1#datastorespec

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1VertexAiSearchDataStoreSpec

Returns a new instance of GoogleCloudAiplatformV1VertexAiSearchDataStoreSpec.



39762
39763
39764
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39762

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_storeString

Full resource name of DataStore, such as Format: projects/project/locations/ location/collections/collection/dataStores/dataStore` Corresponds to the JSON propertydataStore`

Returns:

  • (String)


39753
39754
39755
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39753

def data_store
  @data_store
end

#filterString

Optional. Filter specification to filter documents in the data store specified by data_store field. For more information on filtering, see Filtering Corresponds to the JSON property filter

Returns:

  • (String)


39760
39761
39762
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39760

def filter
  @filter
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39767
39768
39769
39770
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39767

def update!(**args)
  @data_store = args[:data_store] if args.key?(:data_store)
  @filter = args[:filter] if args.key?(:filter)
end