Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexRagStore
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexRagStore
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Retrieve from Vertex RAG Store for grounding.
Instance Attribute Summary collapse
-
#rag_resources ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexRagStoreRagResource>
Optional.
-
#rag_retrieval_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagRetrievalConfig
Specifies the context retrieval config.
-
#similarity_top_k ⇒ Fixnum
Optional.
-
#vector_distance_threshold ⇒ Float
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1VertexRagStore
constructor
A new instance of GoogleCloudAiplatformV1VertexRagStore.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1VertexRagStore
Returns a new instance of GoogleCloudAiplatformV1VertexRagStore.
48866 48867 48868 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48866 def initialize(**args) update!(**args) end |
Instance Attribute Details
#rag_resources ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexRagStoreRagResource>
Optional. The representation of the rag source. It can be used to specify
corpus only or ragfiles. Currently only support one corpus or multiple files
from one corpus. In the future we may open up multiple corpora support.
Corresponds to the JSON property ragResources
48849 48850 48851 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48849 def rag_resources @rag_resources end |
#rag_retrieval_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagRetrievalConfig
Specifies the context retrieval config.
Corresponds to the JSON property ragRetrievalConfig
48854 48855 48856 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48854 def rag_retrieval_config @rag_retrieval_config end |
#similarity_top_k ⇒ Fixnum
Optional. Number of top k results to return from the selected corpora.
Corresponds to the JSON property similarityTopK
48859 48860 48861 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48859 def similarity_top_k @similarity_top_k end |
#vector_distance_threshold ⇒ Float
Optional. Only return results with vector distance smaller than the threshold.
Corresponds to the JSON property vectorDistanceThreshold
48864 48865 48866 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48864 def vector_distance_threshold @vector_distance_threshold end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
48871 48872 48873 48874 48875 48876 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48871 def update!(**args) @rag_resources = args[:rag_resources] if args.key?(:rag_resources) @rag_retrieval_config = args[:rag_retrieval_config] if args.key?(:rag_retrieval_config) @similarity_top_k = args[:similarity_top_k] if args.key?(:similarity_top_k) @vector_distance_threshold = args[:vector_distance_threshold] if args.key?(:vector_distance_threshold) end |