Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexRagStore
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexRagStore
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Retrieve from Vertex RAG Store for grounding.
Instance Attribute Summary collapse
-
#rag_resources ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexRagStoreRagResource>
Optional.
-
#rag_retrieval_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagRetrievalConfig
Specifies the context retrieval config.
-
#similarity_top_k ⇒ Fixnum
Optional.
-
#vector_distance_threshold ⇒ Float
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1VertexRagStore
constructor
A new instance of GoogleCloudAiplatformV1VertexRagStore.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1VertexRagStore
Returns a new instance of GoogleCloudAiplatformV1VertexRagStore.
39119 39120 39121 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39119 def initialize(**args) update!(**args) end |
Instance Attribute Details
#rag_resources ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexRagStoreRagResource>
Optional. The representation of the rag source. It can be used to specify
corpus only or ragfiles. Currently only support one corpus or multiple files
from one corpus. In the future we may open up multiple corpora support.
Corresponds to the JSON property ragResources
39102 39103 39104 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39102 def rag_resources @rag_resources end |
#rag_retrieval_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1RagRetrievalConfig
Specifies the context retrieval config.
Corresponds to the JSON property ragRetrievalConfig
39107 39108 39109 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39107 def rag_retrieval_config @rag_retrieval_config end |
#similarity_top_k ⇒ Fixnum
Optional. Number of top k results to return from the selected corpora.
Corresponds to the JSON property similarityTopK
39112 39113 39114 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39112 def similarity_top_k @similarity_top_k end |
#vector_distance_threshold ⇒ Float
Optional. Only return results with vector distance smaller than the threshold.
Corresponds to the JSON property vectorDistanceThreshold
39117 39118 39119 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39117 def vector_distance_threshold @vector_distance_threshold end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39124 39125 39126 39127 39128 39129 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39124 def update!(**args) @rag_resources = args[:rag_resources] if args.key?(:rag_resources) @rag_retrieval_config = args[:rag_retrieval_config] if args.key?(:rag_retrieval_config) @similarity_top_k = args[:similarity_top_k] if args.key?(:similarity_top_k) @vector_distance_threshold = args[:vector_distance_threshold] if args.key?(:vector_distance_threshold) end |