Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexRagStore

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Retrieve from Vertex RAG Store for grounding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1VertexRagStore

Returns a new instance of GoogleCloudAiplatformV1VertexRagStore.



38126
38127
38128
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38126

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#rag_resourcesArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexRagStoreRagResource>

Optional. The representation of the rag source. It can be used to specify corpus only or ragfiles. Currently only support one corpus or multiple files from one corpus. In the future we may open up multiple corpora support. Corresponds to the JSON property ragResources



38109
38110
38111
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38109

def rag_resources
  @rag_resources
end

#rag_retrieval_configGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1RagRetrievalConfig

Specifies the context retrieval config. Corresponds to the JSON property ragRetrievalConfig



38114
38115
38116
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38114

def rag_retrieval_config
  @rag_retrieval_config
end

#similarity_top_kFixnum

Optional. Number of top k results to return from the selected corpora. Corresponds to the JSON property similarityTopK

Returns:

  • (Fixnum)


38119
38120
38121
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38119

def similarity_top_k
  @similarity_top_k
end

#vector_distance_thresholdFloat

Optional. Only return results with vector distance smaller than the threshold. Corresponds to the JSON property vectorDistanceThreshold

Returns:

  • (Float)


38124
38125
38126
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38124

def vector_distance_threshold
  @vector_distance_threshold
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38131
38132
38133
38134
38135
38136
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 38131

def update!(**args)
  @rag_resources = args[:rag_resources] if args.key?(:rag_resources)
  @rag_retrieval_config = args[:rag_retrieval_config] if args.key?(:rag_retrieval_config)
  @similarity_top_k = args[:similarity_top_k] if args.key?(:similarity_top_k)
  @vector_distance_threshold = args[:vector_distance_threshold] if args.key?(:vector_distance_threshold)
end