Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexRagStore
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexRagStore
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Retrieve from Vertex RAG Store for grounding.
Instance Attribute Summary collapse
-
#rag_corpora ⇒ Array<String>
Optional.
-
#rag_resources ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexRagStoreRagResource>
Optional.
-
#similarity_top_k ⇒ Fixnum
Optional.
-
#vector_distance_threshold ⇒ Float
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1VertexRagStore
constructor
A new instance of GoogleCloudAiplatformV1VertexRagStore.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1VertexRagStore
Returns a new instance of GoogleCloudAiplatformV1VertexRagStore.
33347 33348 33349 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33347 def initialize(**args) update!(**args) end |
Instance Attribute Details
#rag_corpora ⇒ Array<String>
Optional. Deprecated. Please use rag_resources instead.
Corresponds to the JSON property ragCorpora
33328 33329 33330 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33328 def rag_corpora @rag_corpora end |
#rag_resources ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VertexRagStoreRagResource>
Optional. The representation of the rag source. It can be used to specify
corpus only or ragfiles. Currently only support one corpus or multiple files
from one corpus. In the future we may open up multiple corpora support.
Corresponds to the JSON property ragResources
33335 33336 33337 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33335 def rag_resources @rag_resources end |
#similarity_top_k ⇒ Fixnum
Optional. Number of top k results to return from the selected corpora.
Corresponds to the JSON property similarityTopK
33340 33341 33342 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33340 def similarity_top_k @similarity_top_k end |
#vector_distance_threshold ⇒ Float
Optional. Only return results with vector distance smaller than the threshold.
Corresponds to the JSON property vectorDistanceThreshold
33345 33346 33347 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33345 def vector_distance_threshold @vector_distance_threshold end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33352 33353 33354 33355 33356 33357 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33352 def update!(**args) @rag_corpora = args[:rag_corpora] if args.key?(:rag_corpora) @rag_resources = args[:rag_resources] if args.key?(:rag_resources) @similarity_top_k = args[:similarity_top_k] if args.key?(:similarity_top_k) @vector_distance_threshold = args[:vector_distance_threshold] if args.key?(:vector_distance_threshold) end |