Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VideoMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Provides metadata for a video, including the start and end offsets for clipping and the frame rate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1VideoMetadata

Returns a new instance of GoogleCloudAiplatformV1VideoMetadata.



48855
48856
48857
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48855

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_offsetString

Optional. The end offset of the video. Corresponds to the JSON property endOffset

Returns:

  • (String)


48842
48843
48844
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48842

def end_offset
  @end_offset
end

#fpsFloat

Optional. The frame rate of the video sent to the model. If not specified, the default value is 1.0. The valid range is (0.0, 24.0]. Corresponds to the JSON property fps

Returns:

  • (Float)


48848
48849
48850
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48848

def fps
  @fps
end

#start_offsetString

Optional. The start offset of the video. Corresponds to the JSON property startOffset

Returns:

  • (String)


48853
48854
48855
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48853

def start_offset
  @start_offset
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48860
48861
48862
48863
48864
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48860

def update!(**args)
  @end_offset = args[:end_offset] if args.key?(:end_offset)
  @fps = args[:fps] if args.key?(:fps)
  @start_offset = args[:start_offset] if args.key?(:start_offset)
end