Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1VideoMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Metadata describes the input video content.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1VideoMetadata

Returns a new instance of GoogleCloudAiplatformV1VideoMetadata.



40823
40824
40825
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40823

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_offsetString

Optional. The end offset of the video. Corresponds to the JSON property endOffset

Returns:

  • (String)


40810
40811
40812
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40810

def end_offset
  @end_offset
end

#fpsFloat

Optional. The frame rate of the video sent to the model. If not specified, the default value will be 1.0. The fps range is (0.0, 24.0]. Corresponds to the JSON property fps

Returns:

  • (Float)


40816
40817
40818
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40816

def fps
  @fps
end

#start_offsetString

Optional. The start offset of the video. Corresponds to the JSON property startOffset

Returns:

  • (String)


40821
40822
40823
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40821

def start_offset
  @start_offset
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40828
40829
40830
40831
40832
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40828

def update!(**args)
  @end_offset = args[:end_offset] if args.key?(:end_offset)
  @fps = args[:fps] if args.key?(:fps)
  @start_offset = args[:start_offset] if args.key?(:start_offset)
end