Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1WorkerPoolSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents the spec of a worker pool in a job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1WorkerPoolSpec

Returns a new instance of GoogleCloudAiplatformV1WorkerPoolSpec.



50929
50930
50931
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 50929

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#container_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ContainerSpec

The spec of a Container. Corresponds to the JSON property containerSpec



50897
50898
50899
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 50897

def container_spec
  @container_spec
end

#disk_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1DiskSpec

Represents the spec of disk options. Corresponds to the JSON property diskSpec



50902
50903
50904
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 50902

def disk_spec
  @disk_spec
end

#lustre_mountsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1LustreMount>

Optional. List of Lustre mounts. Corresponds to the JSON property lustreMounts



50907
50908
50909
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 50907

def lustre_mounts
  @lustre_mounts
end

#machine_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1MachineSpec

Specification of a single machine. Corresponds to the JSON property machineSpec



50912
50913
50914
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 50912

def machine_spec
  @machine_spec
end

#nfs_mountsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NfsMount>

Optional. List of NFS mount spec. Corresponds to the JSON property nfsMounts



50917
50918
50919
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 50917

def nfs_mounts
  @nfs_mounts
end

#python_package_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PythonPackageSpec

The spec of a Python packaged code. Corresponds to the JSON property pythonPackageSpec



50922
50923
50924
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 50922

def python_package_spec
  @python_package_spec
end

#replica_countFixnum

Optional. The number of worker replicas to use for this worker pool. Corresponds to the JSON property replicaCount

Returns:

  • (Fixnum)


50927
50928
50929
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 50927

def replica_count
  @replica_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50934
50935
50936
50937
50938
50939
50940
50941
50942
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 50934

def update!(**args)
  @container_spec = args[:container_spec] if args.key?(:container_spec)
  @disk_spec = args[:disk_spec] if args.key?(:disk_spec)
  @lustre_mounts = args[:lustre_mounts] if args.key?(:lustre_mounts)
  @machine_spec = args[:machine_spec] if args.key?(:machine_spec)
  @nfs_mounts = args[:nfs_mounts] if args.key?(:nfs_mounts)
  @python_package_spec = args[:python_package_spec] if args.key?(:python_package_spec)
  @replica_count = args[:replica_count] if args.key?(:replica_count)
end