Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1WorkerPoolSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents the spec of a worker pool in a job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1WorkerPoolSpec

Returns a new instance of GoogleCloudAiplatformV1WorkerPoolSpec.



48953
48954
48955
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48953

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#container_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ContainerSpec

The spec of a Container. Corresponds to the JSON property containerSpec



48921
48922
48923
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48921

def container_spec
  @container_spec
end

#disk_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1DiskSpec

Represents the spec of disk options. Corresponds to the JSON property diskSpec



48926
48927
48928
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48926

def disk_spec
  @disk_spec
end

#lustre_mountsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1LustreMount>

Optional. List of Lustre mounts. Corresponds to the JSON property lustreMounts



48931
48932
48933
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48931

def lustre_mounts
  @lustre_mounts
end

#machine_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1MachineSpec

Specification of a single machine. Corresponds to the JSON property machineSpec



48936
48937
48938
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48936

def machine_spec
  @machine_spec
end

#nfs_mountsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NfsMount>

Optional. List of NFS mount spec. Corresponds to the JSON property nfsMounts



48941
48942
48943
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48941

def nfs_mounts
  @nfs_mounts
end

#python_package_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PythonPackageSpec

The spec of a Python packaged code. Corresponds to the JSON property pythonPackageSpec



48946
48947
48948
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48946

def python_package_spec
  @python_package_spec
end

#replica_countFixnum

Optional. The number of worker replicas to use for this worker pool. Corresponds to the JSON property replicaCount

Returns:

  • (Fixnum)


48951
48952
48953
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48951

def replica_count
  @replica_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48958
48959
48960
48961
48962
48963
48964
48965
48966
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48958

def update!(**args)
  @container_spec = args[:container_spec] if args.key?(:container_spec)
  @disk_spec = args[:disk_spec] if args.key?(:disk_spec)
  @lustre_mounts = args[:lustre_mounts] if args.key?(:lustre_mounts)
  @machine_spec = args[:machine_spec] if args.key?(:machine_spec)
  @nfs_mounts = args[:nfs_mounts] if args.key?(:nfs_mounts)
  @python_package_spec = args[:python_package_spec] if args.key?(:python_package_spec)
  @replica_count = args[:replica_count] if args.key?(:replica_count)
end