Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1WorkerPoolSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1WorkerPoolSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Represents the spec of a worker pool in a job.
Instance Attribute Summary collapse
-
#container_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ContainerSpec
The spec of a Container.
-
#disk_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DiskSpec
Represents the spec of disk options.
-
#lustre_mounts ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1LustreMount>
Optional.
-
#machine_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MachineSpec
Specification of a single machine.
-
#nfs_mounts ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NfsMount>
Optional.
-
#python_package_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PythonPackageSpec
The spec of a Python packaged code.
-
#replica_count ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1WorkerPoolSpec
constructor
A new instance of GoogleCloudAiplatformV1WorkerPoolSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1WorkerPoolSpec
Returns a new instance of GoogleCloudAiplatformV1WorkerPoolSpec.
48931 48932 48933 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48931 def initialize(**args) update!(**args) end |
Instance Attribute Details
#container_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ContainerSpec
The spec of a Container.
Corresponds to the JSON property containerSpec
48899 48900 48901 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48899 def container_spec @container_spec end |
#disk_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DiskSpec
Represents the spec of disk options.
Corresponds to the JSON property diskSpec
48904 48905 48906 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48904 def disk_spec @disk_spec end |
#lustre_mounts ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1LustreMount>
Optional. List of Lustre mounts.
Corresponds to the JSON property lustreMounts
48909 48910 48911 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48909 def lustre_mounts @lustre_mounts end |
#machine_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MachineSpec
Specification of a single machine.
Corresponds to the JSON property machineSpec
48914 48915 48916 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48914 def machine_spec @machine_spec end |
#nfs_mounts ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NfsMount>
Optional. List of NFS mount spec.
Corresponds to the JSON property nfsMounts
48919 48920 48921 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48919 def nfs_mounts @nfs_mounts end |
#python_package_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PythonPackageSpec
The spec of a Python packaged code.
Corresponds to the JSON property pythonPackageSpec
48924 48925 48926 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48924 def python_package_spec @python_package_spec end |
#replica_count ⇒ Fixnum
Optional. The number of worker replicas to use for this worker pool.
Corresponds to the JSON property replicaCount
48929 48930 48931 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48929 def replica_count @replica_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
48936 48937 48938 48939 48940 48941 48942 48943 48944 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 48936 def update!(**args) @container_spec = args[:container_spec] if args.key?(:container_spec) @disk_spec = args[:disk_spec] if args.key?(:disk_spec) @lustre_mounts = args[:lustre_mounts] if args.key?(:lustre_mounts) @machine_spec = args[:machine_spec] if args.key?(:machine_spec) @nfs_mounts = args[:nfs_mounts] if args.key?(:nfs_mounts) @python_package_spec = args[:python_package_spec] if args.key?(:python_package_spec) @replica_count = args[:replica_count] if args.key?(:replica_count) end |