Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1WorkerPoolSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents the spec of a worker pool in a job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1WorkerPoolSpec

Returns a new instance of GoogleCloudAiplatformV1WorkerPoolSpec.



47081
47082
47083
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47081

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#container_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ContainerSpec

The spec of a Container. Corresponds to the JSON property containerSpec



47049
47050
47051
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47049

def container_spec
  @container_spec
end

#disk_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1DiskSpec

Represents the spec of disk options. Corresponds to the JSON property diskSpec



47054
47055
47056
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47054

def disk_spec
  @disk_spec
end

#lustre_mountsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1LustreMount>

Optional. List of Lustre mounts. Corresponds to the JSON property lustreMounts



47059
47060
47061
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47059

def lustre_mounts
  @lustre_mounts
end

#machine_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1MachineSpec

Specification of a single machine. Corresponds to the JSON property machineSpec



47064
47065
47066
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47064

def machine_spec
  @machine_spec
end

#nfs_mountsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NfsMount>

Optional. List of NFS mount spec. Corresponds to the JSON property nfsMounts



47069
47070
47071
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47069

def nfs_mounts
  @nfs_mounts
end

#python_package_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PythonPackageSpec

The spec of a Python packaged code. Corresponds to the JSON property pythonPackageSpec



47074
47075
47076
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47074

def python_package_spec
  @python_package_spec
end

#replica_countFixnum

Optional. The number of worker replicas to use for this worker pool. Corresponds to the JSON property replicaCount

Returns:

  • (Fixnum)


47079
47080
47081
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47079

def replica_count
  @replica_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47086
47087
47088
47089
47090
47091
47092
47093
47094
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 47086

def update!(**args)
  @container_spec = args[:container_spec] if args.key?(:container_spec)
  @disk_spec = args[:disk_spec] if args.key?(:disk_spec)
  @lustre_mounts = args[:lustre_mounts] if args.key?(:lustre_mounts)
  @machine_spec = args[:machine_spec] if args.key?(:machine_spec)
  @nfs_mounts = args[:nfs_mounts] if args.key?(:nfs_mounts)
  @python_package_spec = args[:python_package_spec] if args.key?(:python_package_spec)
  @replica_count = args[:replica_count] if args.key?(:replica_count)
end