Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1WorkerPoolSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents the spec of a worker pool in a job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1WorkerPoolSpec

Returns a new instance of GoogleCloudAiplatformV1WorkerPoolSpec.



46797
46798
46799
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46797

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#container_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ContainerSpec

The spec of a Container. Corresponds to the JSON property containerSpec



46765
46766
46767
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46765

def container_spec
  @container_spec
end

#disk_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1DiskSpec

Represents the spec of disk options. Corresponds to the JSON property diskSpec



46770
46771
46772
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46770

def disk_spec
  @disk_spec
end

#lustre_mountsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1LustreMount>

Optional. List of Lustre mounts. Corresponds to the JSON property lustreMounts



46775
46776
46777
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46775

def lustre_mounts
  @lustre_mounts
end

#machine_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1MachineSpec

Specification of a single machine. Corresponds to the JSON property machineSpec



46780
46781
46782
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46780

def machine_spec
  @machine_spec
end

#nfs_mountsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NfsMount>

Optional. List of NFS mount spec. Corresponds to the JSON property nfsMounts



46785
46786
46787
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46785

def nfs_mounts
  @nfs_mounts
end

#python_package_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PythonPackageSpec

The spec of a Python packaged code. Corresponds to the JSON property pythonPackageSpec



46790
46791
46792
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46790

def python_package_spec
  @python_package_spec
end

#replica_countFixnum

Optional. The number of worker replicas to use for this worker pool. Corresponds to the JSON property replicaCount

Returns:

  • (Fixnum)


46795
46796
46797
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46795

def replica_count
  @replica_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46802
46803
46804
46805
46806
46807
46808
46809
46810
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46802

def update!(**args)
  @container_spec = args[:container_spec] if args.key?(:container_spec)
  @disk_spec = args[:disk_spec] if args.key?(:disk_spec)
  @lustre_mounts = args[:lustre_mounts] if args.key?(:lustre_mounts)
  @machine_spec = args[:machine_spec] if args.key?(:machine_spec)
  @nfs_mounts = args[:nfs_mounts] if args.key?(:nfs_mounts)
  @python_package_spec = args[:python_package_spec] if args.key?(:python_package_spec)
  @replica_count = args[:replica_count] if args.key?(:replica_count)
end