Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1WorkerPoolSpec
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1WorkerPoolSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Represents the spec of a worker pool in a job.
Instance Attribute Summary collapse
-
#container_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ContainerSpec
The spec of a Container.
-
#disk_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DiskSpec
Represents the spec of disk options.
-
#machine_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MachineSpec
Specification of a single machine.
-
#nfs_mounts ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NfsMount>
Optional.
-
#python_package_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PythonPackageSpec
The spec of a Python packaged code.
-
#replica_count ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1WorkerPoolSpec
constructor
A new instance of GoogleCloudAiplatformV1WorkerPoolSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1WorkerPoolSpec
Returns a new instance of GoogleCloudAiplatformV1WorkerPoolSpec.
40468 40469 40470 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40468 def initialize(**args) update!(**args) end |
Instance Attribute Details
#container_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1ContainerSpec
The spec of a Container.
Corresponds to the JSON property containerSpec
40441 40442 40443 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40441 def container_spec @container_spec end |
#disk_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1DiskSpec
Represents the spec of disk options.
Corresponds to the JSON property diskSpec
40446 40447 40448 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40446 def disk_spec @disk_spec end |
#machine_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1MachineSpec
Specification of a single machine.
Corresponds to the JSON property machineSpec
40451 40452 40453 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40451 def machine_spec @machine_spec end |
#nfs_mounts ⇒ Array<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NfsMount>
Optional. List of NFS mount spec.
Corresponds to the JSON property nfsMounts
40456 40457 40458 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40456 def nfs_mounts @nfs_mounts end |
#python_package_spec ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1PythonPackageSpec
The spec of a Python packaged code.
Corresponds to the JSON property pythonPackageSpec
40461 40462 40463 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40461 def python_package_spec @python_package_spec end |
#replica_count ⇒ Fixnum
Optional. The number of worker replicas to use for this worker pool.
Corresponds to the JSON property replicaCount
40466 40467 40468 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40466 def replica_count @replica_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40473 40474 40475 40476 40477 40478 40479 40480 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40473 def update!(**args) @container_spec = args[:container_spec] if args.key?(:container_spec) @disk_spec = args[:disk_spec] if args.key?(:disk_spec) @machine_spec = args[:machine_spec] if args.key?(:machine_spec) @nfs_mounts = args[:nfs_mounts] if args.key?(:nfs_mounts) @python_package_spec = args[:python_package_spec] if args.key?(:python_package_spec) @replica_count = args[:replica_count] if args.key?(:replica_count) end |