Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1WorkerPoolSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents the spec of a worker pool in a job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1WorkerPoolSpec

Returns a new instance of GoogleCloudAiplatformV1WorkerPoolSpec.



39888
39889
39890
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39888

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#container_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ContainerSpec

The spec of a Container. Corresponds to the JSON property containerSpec



39861
39862
39863
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39861

def container_spec
  @container_spec
end

#disk_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1DiskSpec

Represents the spec of disk options. Corresponds to the JSON property diskSpec



39866
39867
39868
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39866

def disk_spec
  @disk_spec
end

#machine_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1MachineSpec

Specification of a single machine. Corresponds to the JSON property machineSpec



39871
39872
39873
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39871

def machine_spec
  @machine_spec
end

#nfs_mountsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NfsMount>

Optional. List of NFS mount spec. Corresponds to the JSON property nfsMounts



39876
39877
39878
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39876

def nfs_mounts
  @nfs_mounts
end

#python_package_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PythonPackageSpec

The spec of a Python packaged code. Corresponds to the JSON property pythonPackageSpec



39881
39882
39883
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39881

def python_package_spec
  @python_package_spec
end

#replica_countFixnum

Optional. The number of worker replicas to use for this worker pool. Corresponds to the JSON property replicaCount

Returns:

  • (Fixnum)


39886
39887
39888
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39886

def replica_count
  @replica_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39893
39894
39895
39896
39897
39898
39899
39900
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39893

def update!(**args)
  @container_spec = args[:container_spec] if args.key?(:container_spec)
  @disk_spec = args[:disk_spec] if args.key?(:disk_spec)
  @machine_spec = args[:machine_spec] if args.key?(:machine_spec)
  @nfs_mounts = args[:nfs_mounts] if args.key?(:nfs_mounts)
  @python_package_spec = args[:python_package_spec] if args.key?(:python_package_spec)
  @replica_count = args[:replica_count] if args.key?(:replica_count)
end