Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1WorkerPoolSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Represents the spec of a worker pool in a job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1WorkerPoolSpec

Returns a new instance of GoogleCloudAiplatformV1WorkerPoolSpec.



33446
33447
33448
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33446

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#container_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1ContainerSpec

The spec of a Container. Corresponds to the JSON property containerSpec



33419
33420
33421
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33419

def container_spec
  @container_spec
end

#disk_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1DiskSpec

Represents the spec of disk options. Corresponds to the JSON property diskSpec



33424
33425
33426
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33424

def disk_spec
  @disk_spec
end

#machine_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1MachineSpec

Specification of a single machine. Corresponds to the JSON property machineSpec



33429
33430
33431
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33429

def machine_spec
  @machine_spec
end

#nfs_mountsArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1NfsMount>

Optional. List of NFS mount spec. Corresponds to the JSON property nfsMounts



33434
33435
33436
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33434

def nfs_mounts
  @nfs_mounts
end

#python_package_specGoogle::Apis::AiplatformV1::GoogleCloudAiplatformV1PythonPackageSpec

The spec of a Python packaged code. Corresponds to the JSON property pythonPackageSpec



33439
33440
33441
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33439

def python_package_spec
  @python_package_spec
end

#replica_countFixnum

Optional. The number of worker replicas to use for this worker pool. Corresponds to the JSON property replicaCount

Returns:

  • (Fixnum)


33444
33445
33446
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33444

def replica_count
  @replica_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33451
33452
33453
33454
33455
33456
33457
33458
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33451

def update!(**args)
  @container_spec = args[:container_spec] if args.key?(:container_spec)
  @disk_spec = args[:disk_spec] if args.key?(:disk_spec)
  @machine_spec = args[:machine_spec] if args.key?(:machine_spec)
  @nfs_mounts = args[:nfs_mounts] if args.key?(:nfs_mounts)
  @python_package_spec = args[:python_package_spec] if args.key?(:python_package_spec)
  @replica_count = args[:replica_count] if args.key?(:replica_count)
end