Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1WriteTensorboardRunDataRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for TensorboardService.WriteTensorboardRunData.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1WriteTensorboardRunDataRequest

Returns a new instance of GoogleCloudAiplatformV1WriteTensorboardRunDataRequest.



49081
49082
49083
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 49081

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#tensorboard_runString

Required. The resource name of the TensorboardRun to write data to. Format: projects/project/locations/location/tensorboards/tensorboard/experiments/ experiment/runs/run` Corresponds to the JSON propertytensorboardRun`

Returns:

  • (String)


49071
49072
49073
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 49071

def tensorboard_run
  @tensorboard_run
end

#time_series_dataArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TimeSeriesData>

Required. The TensorboardTimeSeries data to write. Values with in a time series are indexed by their step value. Repeated writes to the same step will overwrite the existing value for that step. The upper limit of data points per write request is 5000. Corresponds to the JSON property timeSeriesData



49079
49080
49081
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 49079

def time_series_data
  @time_series_data
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49086
49087
49088
49089
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 49086

def update!(**args)
  @tensorboard_run = args[:tensorboard_run] if args.key?(:tensorboard_run)
  @time_series_data = args[:time_series_data] if args.key?(:time_series_data)
end