Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1WriteTensorboardRunDataRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Request message for TensorboardService.WriteTensorboardRunData.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAiplatformV1WriteTensorboardRunDataRequest

Returns a new instance of GoogleCloudAiplatformV1WriteTensorboardRunDataRequest.



39440
39441
39442
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39440

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#tensorboard_runString

Required. The resource name of the TensorboardRun to write data to. Format: projects/project/locations/location/tensorboards/tensorboard/experiments/ experiment/runs/run` Corresponds to the JSON propertytensorboardRun`

Returns:

  • (String)


39430
39431
39432
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39430

def tensorboard_run
  @tensorboard_run
end

#time_series_dataArray<Google::Apis::AiplatformV1::GoogleCloudAiplatformV1TimeSeriesData>

Required. The TensorboardTimeSeries data to write. Values with in a time series are indexed by their step value. Repeated writes to the same step will overwrite the existing value for that step. The upper limit of data points per write request is 5000. Corresponds to the JSON property timeSeriesData



39438
39439
39440
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39438

def time_series_data
  @time_series_data
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39445
39446
39447
39448
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39445

def update!(**args)
  @tensorboard_run = args[:tensorboard_run] if args.key?(:tensorboard_run)
  @time_series_data = args[:time_series_data] if args.key?(:time_series_data)
end