Class: Google::Apis::AiplatformV1::GoogleCloudAiplatformV1XraiAttribution
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudAiplatformV1XraiAttribution
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
An explanation method that redistributes Integrated Gradients attributions to segmented regions, taking advantage of the model's fully differentiable structure. Refer to this paper for more details: https://arxiv.org/abs/1906. 02825 Supported only by image Models.
Instance Attribute Summary collapse
-
#blur_baseline_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BlurBaselineConfig
Config for blur baseline.
-
#smooth_grad_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SmoothGradConfig
Config for SmoothGrad approximation of gradients.
-
#step_count ⇒ Fixnum
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudAiplatformV1XraiAttribution
constructor
A new instance of GoogleCloudAiplatformV1XraiAttribution.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudAiplatformV1XraiAttribution
Returns a new instance of GoogleCloudAiplatformV1XraiAttribution.
46980 46981 46982 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46980 def initialize(**args) update!(**args) end |
Instance Attribute Details
#blur_baseline_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1BlurBaselineConfig
Config for blur baseline. When enabled, a linear path from the maximally
blurred image to the input image is created. Using a blurred baseline instead
of zero (black image) is motivated by the BlurIG approach explained here:
https://arxiv.org/abs/2004.03383
Corresponds to the JSON property blurBaselineConfig
46962 46963 46964 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46962 def blur_baseline_config @blur_baseline_config end |
#smooth_grad_config ⇒ Google::Apis::AiplatformV1::GoogleCloudAiplatformV1SmoothGradConfig
Config for SmoothGrad approximation of gradients. When enabled, the gradients
are approximated by averaging the gradients from noisy samples in the vicinity
of the inputs. Adding noise can help improve the computed gradients. Refer to
this paper for more details: https://arxiv.org/pdf/1706.03825.pdf
Corresponds to the JSON property smoothGradConfig
46970 46971 46972 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46970 def smooth_grad_config @smooth_grad_config end |
#step_count ⇒ Fixnum
Required. The number of steps for approximating the path integral. A good
value to start is 50 and gradually increase until the sum to diff property is
met within the desired error range. Valid range of its value is [1, 100],
inclusively.
Corresponds to the JSON property stepCount
46978 46979 46980 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46978 def step_count @step_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46985 46986 46987 46988 46989 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 46985 def update!(**args) @blur_baseline_config = args[:blur_baseline_config] if args.key?(:blur_baseline_config) @smooth_grad_config = args[:smooth_grad_config] if args.key?(:smooth_grad_config) @step_count = args[:step_count] if args.key?(:step_count) end |