Class: Google::Apis::AiplatformV1::GoogleCloudLocationLocation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A resource that represents a Google Cloud location.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudLocationLocation

Returns a new instance of GoogleCloudLocationLocation.



49256
49257
49258
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 49256

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

The friendly name for this location, typically a nearby city name. For example, "Tokyo". Corresponds to the JSON property displayName

Returns:

  • (String)


49231
49232
49233
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 49231

def display_name
  @display_name
end

#labelsHash<String,String>

Cross-service attributes for the location. For example "cloud.googleapis.com/ region": "us-east1" Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


49237
49238
49239
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 49237

def labels
  @labels
end

#location_idString

The canonical id for this location. For example: "us-east1". Corresponds to the JSON property locationId

Returns:

  • (String)


49242
49243
49244
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 49242

def location_id
  @location_id
end

#metadataHash<String,Object>

Service-specific metadata. For example the available capacity at the given location. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,Object>)


49248
49249
49250
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 49248

def 
  @metadata
end

#nameString

Resource name for the location, which may vary between implementations. For example: "projects/example-project/locations/us-east1" Corresponds to the JSON property name

Returns:

  • (String)


49254
49255
49256
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 49254

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49261
49262
49263
49264
49265
49266
49267
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 49261

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @labels = args[:labels] if args.key?(:labels)
  @location_id = args[:location_id] if args.key?(:location_id)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
end