Class: Google::Apis::AiplatformV1::GoogleCloudLocationLocation
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudLocationLocation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A resource that represents a Google Cloud location.
Instance Attribute Summary collapse
-
#display_name ⇒ String
The friendly name for this location, typically a nearby city name.
-
#labels ⇒ Hash<String,String>
Cross-service attributes for the location.
-
#location_id ⇒ String
The canonical id for this location.
-
#metadata ⇒ Hash<String,Object>
Service-specific metadata.
-
#name ⇒ String
Resource name for the location, which may vary between implementations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudLocationLocation
constructor
A new instance of GoogleCloudLocationLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudLocationLocation
Returns a new instance of GoogleCloudLocationLocation.
40774 40775 40776 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40774 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
The friendly name for this location, typically a nearby city name. For example,
"Tokyo".
Corresponds to the JSON property displayName
40749 40750 40751 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40749 def display_name @display_name end |
#labels ⇒ Hash<String,String>
Cross-service attributes for the location. For example "cloud.googleapis.com/
region": "us-east1"
Corresponds to the JSON property labels
40755 40756 40757 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40755 def labels @labels end |
#location_id ⇒ String
The canonical id for this location. For example: "us-east1".
Corresponds to the JSON property locationId
40760 40761 40762 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40760 def location_id @location_id end |
#metadata ⇒ Hash<String,Object>
Service-specific metadata. For example the available capacity at the given
location.
Corresponds to the JSON property metadata
40766 40767 40768 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40766 def @metadata end |
#name ⇒ String
Resource name for the location, which may vary between implementations. For
example: "projects/example-project/locations/us-east1"
Corresponds to the JSON property name
40772 40773 40774 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40772 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40779 40780 40781 40782 40783 40784 40785 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40779 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @labels = args[:labels] if args.key?(:labels) @location_id = args[:location_id] if args.key?(:location_id) @metadata = args[:metadata] if args.key?(:metadata) @name = args[:name] if args.key?(:name) end |