Class: Google::Apis::AiplatformV1::GoogleCloudLocationLocation
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleCloudLocationLocation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
A resource that represents a Google Cloud location.
Instance Attribute Summary collapse
-
#display_name ⇒ String
The friendly name for this location, typically a nearby city name.
-
#labels ⇒ Hash<String,String>
Cross-service attributes for the location.
-
#location_id ⇒ String
The canonical id for this location.
-
#metadata ⇒ Hash<String,Object>
Service-specific metadata.
-
#name ⇒ String
Resource name for the location, which may vary between implementations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudLocationLocation
constructor
A new instance of GoogleCloudLocationLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudLocationLocation
Returns a new instance of GoogleCloudLocationLocation.
39999 40000 40001 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39999 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
The friendly name for this location, typically a nearby city name. For example,
"Tokyo".
Corresponds to the JSON property displayName
39974 39975 39976 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39974 def display_name @display_name end |
#labels ⇒ Hash<String,String>
Cross-service attributes for the location. For example "cloud.googleapis.com/
region": "us-east1"
Corresponds to the JSON property labels
39980 39981 39982 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39980 def labels @labels end |
#location_id ⇒ String
The canonical id for this location. For example: "us-east1".
Corresponds to the JSON property locationId
39985 39986 39987 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39985 def location_id @location_id end |
#metadata ⇒ Hash<String,Object>
Service-specific metadata. For example the available capacity at the given
location.
Corresponds to the JSON property metadata
39991 39992 39993 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39991 def @metadata end |
#name ⇒ String
Resource name for the location, which may vary between implementations. For
example: "projects/example-project/locations/us-east1"
Corresponds to the JSON property name
39997 39998 39999 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 39997 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40004 40005 40006 40007 40008 40009 40010 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 40004 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @labels = args[:labels] if args.key?(:labels) @location_id = args[:location_id] if args.key?(:location_id) @metadata = args[:metadata] if args.key?(:metadata) @name = args[:name] if args.key?(:name) end |