Class: Google::Apis::AiplatformV1::GoogleCloudLocationLocation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

A resource that represents a Google Cloud location.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudLocationLocation

Returns a new instance of GoogleCloudLocationLocation.



32579
32580
32581
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32579

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

The friendly name for this location, typically a nearby city name. For example, "Tokyo". Corresponds to the JSON property displayName

Returns:

  • (String)


32554
32555
32556
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32554

def display_name
  @display_name
end

#labelsHash<String,String>

Cross-service attributes for the location. For example "cloud.googleapis.com/ region": "us-east1" Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


32560
32561
32562
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32560

def labels
  @labels
end

#location_idString

The canonical id for this location. For example: "us-east1". Corresponds to the JSON property locationId

Returns:

  • (String)


32565
32566
32567
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32565

def location_id
  @location_id
end

#metadataHash<String,Object>

Service-specific metadata. For example the available capacity at the given location. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,Object>)


32571
32572
32573
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32571

def 
  @metadata
end

#nameString

Resource name for the location, which may vary between implementations. For example: "projects/example-project/locations/us-east1" Corresponds to the JSON property name

Returns:

  • (String)


32577
32578
32579
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32577

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32584
32585
32586
32587
32588
32589
32590
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32584

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @labels = args[:labels] if args.key?(:labels)
  @location_id = args[:location_id] if args.key?(:location_id)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
end