Class: Google::Apis::AiplatformV1::GoogleLongrunningOperation
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::GoogleLongrunningOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
This resource represents a long-running operation that is the result of a network API call.
Instance Attribute Summary collapse
-
#done ⇒ Boolean
(also: #done?)
If the value is
false, it means the operation is still in progress. -
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#metadata ⇒ Hash<String,Object>
Service-specific metadata associated with the operation.
-
#name ⇒ String
The server-assigned name, which is only unique within the same service that originally returns it.
-
#response ⇒ Hash<String,Object>
The normal, successful response of the operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleLongrunningOperation
constructor
A new instance of GoogleLongrunningOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleLongrunningOperation
Returns a new instance of GoogleLongrunningOperation.
28433 28434 28435 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28433 def initialize(**args) update!(**args) end |
Instance Attribute Details
#done ⇒ Boolean Also known as: done?
If the value is false, it means the operation is still in progress. If true
, the operation is completed, and either error or response is available.
Corresponds to the JSON property done
28394 28395 28396 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28394 def done @done end |
#error ⇒ Google::Apis::AiplatformV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
28405 28406 28407 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28405 def error @error end |
#metadata ⇒ Hash<String,Object>
Service-specific metadata associated with the operation. It typically contains
progress information and common metadata such as create time. Some services
might not provide such metadata. Any method that returns a long-running
operation should document the metadata type, if any.
Corresponds to the JSON property metadata
28413 28414 28415 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28413 def @metadata end |
#name ⇒ String
The server-assigned name, which is only unique within the same service that
originally returns it. If you use the default HTTP mapping, the name should
be a resource name ending with operations/unique_id`.
Corresponds to the JSON propertyname`
28420 28421 28422 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28420 def name @name end |
#response ⇒ Hash<String,Object>
The normal, successful response of the operation. If the original method
returns no data on success, such as Delete, the response is google.protobuf.
Empty. If the original method is standard Get/Create/Update, the
response should be the resource. For other methods, the response should have
the type XxxResponse, where Xxx is the original method name. For example,
if the original method name is TakeSnapshot(), the inferred response type is
TakeSnapshotResponse.
Corresponds to the JSON property response
28431 28432 28433 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28431 def response @response end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28438 28439 28440 28441 28442 28443 28444 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28438 def update!(**args) @done = args[:done] if args.key?(:done) @error = args[:error] if args.key?(:error) @metadata = args[:metadata] if args.key?(:metadata) @name = args[:name] if args.key?(:name) @response = args[:response] if args.key?(:response) end |