Class: Google::Apis::AiplatformV1::LanguageLabsAidaTrustRecitationProtoDocAttribution
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::LanguageLabsAidaTrustRecitationProtoDocAttribution
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The proto defines the attribution information for a document using whatever fields are most applicable for that document's datasource. For example, a Wikipedia article's attribution is in the form of its article title, a website is in the form of a URL, and a Github repo is in the form of a repo name. Next id: 30
Instance Attribute Summary collapse
-
#amarna_id ⇒ String
Corresponds to the JSON property
amarnaId. -
#arxiv_id ⇒ String
Corresponds to the JSON property
arxivId. -
#author ⇒ String
Corresponds to the JSON property
author. -
#bibkey ⇒ String
Corresponds to the JSON property
bibkey. -
#biorxiv_id ⇒ String
ID of the paper in bioarxiv like ddoi.org/
biorxiv_ideg: https://doi.org/10. -
#book_title ⇒ String
Corresponds to the JSON property
bookTitle. -
#book_volume_id ⇒ Fixnum
The Oceanographers full-view books dataset uses a 'volume id' as the unique ID of a book.
-
#category ⇒ String
Corresponds to the JSON property
category. -
#conversation_id ⇒ String
Corresponds to the JSON property
conversationId. -
#dataset ⇒ String
The dataset this document comes from.
-
#filepath ⇒ String
Corresponds to the JSON property
filepath. -
#gemini_id ⇒ String
Corresponds to the JSON property
geminiId. -
#gnews_article_title ⇒ String
Corresponds to the JSON property
gnewsArticleTitle. -
#goodall_example_id ⇒ String
Corresponds to the JSON property
goodallExampleId. -
#is_opt_out ⇒ Boolean
(also: #is_opt_out?)
Whether the document is opted out.
-
#is_prompt ⇒ Boolean
(also: #is_prompt?)
Corresponds to the JSON property
isPrompt. -
#lamda_example_id ⇒ String
Corresponds to the JSON property
lamdaExampleId. -
#license ⇒ String
Corresponds to the JSON property
license. -
#meena_conversation_id ⇒ String
Corresponds to the JSON property
meenaConversationId. -
#natural_language_code ⇒ String
Natural (not programming) language of the document.
-
#no_attribution ⇒ Boolean
(also: #no_attribution?)
True if this doc has no attribution information available.
-
#podcast_utterance_id ⇒ String
Corresponds to the JSON property
podcastUtteranceId. -
#publication_date ⇒ Google::Apis::AiplatformV1::GoogleTypeDate
Represents a whole or partial calendar date, such as a birthday.
-
#quality_score_experiment_only ⇒ Float
This field is for opt-out experiment only, MUST never be used during actual production/serving.
-
#repo ⇒ String
Github repository Corresponds to the JSON property
repo. -
#url ⇒ String
URL of a webdoc Corresponds to the JSON property
url. -
#volume_id ⇒ String
Corresponds to the JSON property
volumeId. -
#wikipedia_article_title ⇒ String
Wikipedia article title.
-
#youtube_video_id ⇒ String
The unique video id from Youtube.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LanguageLabsAidaTrustRecitationProtoDocAttribution
constructor
A new instance of LanguageLabsAidaTrustRecitationProtoDocAttribution.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LanguageLabsAidaTrustRecitationProtoDocAttribution
Returns a new instance of LanguageLabsAidaTrustRecitationProtoDocAttribution.
30732 30733 30734 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30732 def initialize(**args) update!(**args) end |
Instance Attribute Details
#amarna_id ⇒ String
Corresponds to the JSON property amarnaId
30564 30565 30566 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30564 def amarna_id @amarna_id end |
#arxiv_id ⇒ String
Corresponds to the JSON property arxivId
30569 30570 30571 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30569 def arxiv_id @arxiv_id end |
#author ⇒ String
Corresponds to the JSON property author
30574 30575 30576 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30574 def @author end |
#bibkey ⇒ String
Corresponds to the JSON property bibkey
30579 30580 30581 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30579 def bibkey @bibkey end |
#biorxiv_id ⇒ String
ID of the paper in bioarxiv like ddoi.org/biorxiv_id eg: https://doi.org/10.
1101/343517
Corresponds to the JSON property biorxivId
30585 30586 30587 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30585 def biorxiv_id @biorxiv_id end |
#book_title ⇒ String
Corresponds to the JSON property bookTitle
30590 30591 30592 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30590 def book_title @book_title end |
#book_volume_id ⇒ Fixnum
The Oceanographers full-view books dataset uses a 'volume id' as the unique ID
of a book. There is a deterministic function from a volume id to a URL under
the books.google.com domain. Marked as 'optional' since a volume ID of zero is
potentially possible and we want to distinguish that from the volume ID not
being set.
Corresponds to the JSON property bookVolumeId
30599 30600 30601 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30599 def book_volume_id @book_volume_id end |
#category ⇒ String
Corresponds to the JSON property category
30604 30605 30606 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30604 def category @category end |
#conversation_id ⇒ String
Corresponds to the JSON property conversationId
30609 30610 30611 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30609 def conversation_id @conversation_id end |
#dataset ⇒ String
The dataset this document comes from.
Corresponds to the JSON property dataset
30614 30615 30616 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30614 def dataset @dataset end |
#filepath ⇒ String
Corresponds to the JSON property filepath
30619 30620 30621 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30619 def filepath @filepath end |
#gemini_id ⇒ String
Corresponds to the JSON property geminiId
30624 30625 30626 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30624 def gemini_id @gemini_id end |
#gnews_article_title ⇒ String
Corresponds to the JSON property gnewsArticleTitle
30629 30630 30631 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30629 def gnews_article_title @gnews_article_title end |
#goodall_example_id ⇒ String
Corresponds to the JSON property goodallExampleId
30634 30635 30636 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30634 def goodall_example_id @goodall_example_id end |
#is_opt_out ⇒ Boolean Also known as: is_opt_out?
Whether the document is opted out.
Corresponds to the JSON property isOptOut
30639 30640 30641 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30639 def is_opt_out @is_opt_out end |
#is_prompt ⇒ Boolean Also known as: is_prompt?
Corresponds to the JSON property isPrompt
30645 30646 30647 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30645 def is_prompt @is_prompt end |
#lamda_example_id ⇒ String
Corresponds to the JSON property lamdaExampleId
30651 30652 30653 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30651 def lamda_example_id @lamda_example_id end |
#license ⇒ String
Corresponds to the JSON property license
30656 30657 30658 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30656 def license @license end |
#meena_conversation_id ⇒ String
Corresponds to the JSON property meenaConversationId
30661 30662 30663 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30661 def meena_conversation_id @meena_conversation_id end |
#natural_language_code ⇒ String
Natural (not programming) language of the document. Language code as defined
by http://www.unicode.org/reports/tr35/#Identifiers and https://tools.ietf.org/
html/bcp47. Currently applicable to full-view books. Use docinfo-util.h to set
& read language fields. See go/iii.
Corresponds to the JSON property naturalLanguageCode
30669 30670 30671 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30669 def natural_language_code @natural_language_code end |
#no_attribution ⇒ Boolean Also known as: no_attribution?
True if this doc has no attribution information available. We use an explicit
field for this instead of just implicitly leaving all the DocAttribution
fields blank to distinguish a case where a bug/oversight has left the
attribution information empty vs when we really have no attribution
information available.
Corresponds to the JSON property noAttribution
30678 30679 30680 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30678 def no_attribution @no_attribution end |
#podcast_utterance_id ⇒ String
Corresponds to the JSON property podcastUtteranceId
30684 30685 30686 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30684 def podcast_utterance_id @podcast_utterance_id end |
#publication_date ⇒ Google::Apis::AiplatformV1::GoogleTypeDate
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property publicationDate
30696 30697 30698 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30696 def publication_date @publication_date end |
#quality_score_experiment_only ⇒ Float
This field is for opt-out experiment only, MUST never be used during actual
production/serving.
Corresponds to the JSON property qualityScoreExperimentOnly
30702 30703 30704 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30702 def quality_score_experiment_only @quality_score_experiment_only end |
#repo ⇒ String
Github repository
Corresponds to the JSON property repo
30707 30708 30709 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30707 def repo @repo end |
#url ⇒ String
URL of a webdoc
Corresponds to the JSON property url
30712 30713 30714 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30712 def url @url end |
#volume_id ⇒ String
Corresponds to the JSON property volumeId
30717 30718 30719 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30717 def volume_id @volume_id end |
#wikipedia_article_title ⇒ String
Wikipedia article title. The Wikipedia TFDS dataset includes article titles
but not URLs. While a URL is to the best of our knowledge a deterministic
function of the title, we store the original title to reflect the information
in the original dataset.
Corresponds to the JSON property wikipediaArticleTitle
30725 30726 30727 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30725 def wikipedia_article_title @wikipedia_article_title end |
#youtube_video_id ⇒ String
The unique video id from Youtube. Example: AkoGsW52Ir0
Corresponds to the JSON property youtubeVideoId
30730 30731 30732 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30730 def youtube_video_id @youtube_video_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30737 30738 30739 30740 30741 30742 30743 30744 30745 30746 30747 30748 30749 30750 30751 30752 30753 30754 30755 30756 30757 30758 30759 30760 30761 30762 30763 30764 30765 30766 30767 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30737 def update!(**args) @amarna_id = args[:amarna_id] if args.key?(:amarna_id) @arxiv_id = args[:arxiv_id] if args.key?(:arxiv_id) @author = args[:author] if args.key?(:author) @bibkey = args[:bibkey] if args.key?(:bibkey) @biorxiv_id = args[:biorxiv_id] if args.key?(:biorxiv_id) @book_title = args[:book_title] if args.key?(:book_title) @book_volume_id = args[:book_volume_id] if args.key?(:book_volume_id) @category = args[:category] if args.key?(:category) @conversation_id = args[:conversation_id] if args.key?(:conversation_id) @dataset = args[:dataset] if args.key?(:dataset) @filepath = args[:filepath] if args.key?(:filepath) @gemini_id = args[:gemini_id] if args.key?(:gemini_id) @gnews_article_title = args[:gnews_article_title] if args.key?(:gnews_article_title) @goodall_example_id = args[:goodall_example_id] if args.key?(:goodall_example_id) @is_opt_out = args[:is_opt_out] if args.key?(:is_opt_out) @is_prompt = args[:is_prompt] if args.key?(:is_prompt) @lamda_example_id = args[:lamda_example_id] if args.key?(:lamda_example_id) @license = args[:license] if args.key?(:license) @meena_conversation_id = args[:meena_conversation_id] if args.key?(:meena_conversation_id) @natural_language_code = args[:natural_language_code] if args.key?(:natural_language_code) @no_attribution = args[:no_attribution] if args.key?(:no_attribution) @podcast_utterance_id = args[:podcast_utterance_id] if args.key?(:podcast_utterance_id) @publication_date = args[:publication_date] if args.key?(:publication_date) @quality_score_experiment_only = args[:quality_score_experiment_only] if args.key?(:quality_score_experiment_only) @repo = args[:repo] if args.key?(:repo) @url = args[:url] if args.key?(:url) @volume_id = args[:volume_id] if args.key?(:volume_id) @wikipedia_article_title = args[:wikipedia_article_title] if args.key?(:wikipedia_article_title) @youtube_video_id = args[:youtube_video_id] if args.key?(:youtube_video_id) end |