Class: Google::Apis::AiplatformV1::LanguageLabsAidaTrustRecitationProtoDocAttribution

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The proto defines the attribution information for a document using whatever fields are most applicable for that document's datasource. For example, a Wikipedia article's attribution is in the form of its article title, a website is in the form of a URL, and a Github repo is in the form of a repo name. Next id: 30

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LanguageLabsAidaTrustRecitationProtoDocAttribution

Returns a new instance of LanguageLabsAidaTrustRecitationProtoDocAttribution.



30679
30680
30681
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30679

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#amarna_idString

Corresponds to the JSON property amarnaId

Returns:

  • (String)


30511
30512
30513
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30511

def amarna_id
  @amarna_id
end

#arxiv_idString

Corresponds to the JSON property arxivId

Returns:

  • (String)


30516
30517
30518
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30516

def arxiv_id
  @arxiv_id
end

#authorString

Corresponds to the JSON property author

Returns:

  • (String)


30521
30522
30523
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30521

def author
  @author
end

#bibkeyString

Corresponds to the JSON property bibkey

Returns:

  • (String)


30526
30527
30528
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30526

def bibkey
  @bibkey
end

#biorxiv_idString

ID of the paper in bioarxiv like ddoi.org/biorxiv_id eg: https://doi.org/10. 1101/343517 Corresponds to the JSON property biorxivId

Returns:

  • (String)


30532
30533
30534
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30532

def biorxiv_id
  @biorxiv_id
end

#book_titleString

Corresponds to the JSON property bookTitle

Returns:

  • (String)


30537
30538
30539
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30537

def book_title
  @book_title
end

#book_volume_idFixnum

The Oceanographers full-view books dataset uses a 'volume id' as the unique ID of a book. There is a deterministic function from a volume id to a URL under the books.google.com domain. Marked as 'optional' since a volume ID of zero is potentially possible and we want to distinguish that from the volume ID not being set. Corresponds to the JSON property bookVolumeId

Returns:

  • (Fixnum)


30546
30547
30548
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30546

def book_volume_id
  @book_volume_id
end

#categoryString

Corresponds to the JSON property category

Returns:

  • (String)


30551
30552
30553
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30551

def category
  @category
end

#conversation_idString

Corresponds to the JSON property conversationId

Returns:

  • (String)


30556
30557
30558
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30556

def conversation_id
  @conversation_id
end

#datasetString

The dataset this document comes from. Corresponds to the JSON property dataset

Returns:

  • (String)


30561
30562
30563
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30561

def dataset
  @dataset
end

#filepathString

Corresponds to the JSON property filepath

Returns:

  • (String)


30566
30567
30568
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30566

def filepath
  @filepath
end

#gemini_idString

Corresponds to the JSON property geminiId

Returns:

  • (String)


30571
30572
30573
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30571

def gemini_id
  @gemini_id
end

#gnews_article_titleString

Corresponds to the JSON property gnewsArticleTitle

Returns:

  • (String)


30576
30577
30578
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30576

def gnews_article_title
  @gnews_article_title
end

#goodall_example_idString

Corresponds to the JSON property goodallExampleId

Returns:

  • (String)


30581
30582
30583
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30581

def goodall_example_id
  @goodall_example_id
end

#is_opt_outBoolean Also known as: is_opt_out?

Whether the document is opted out. Corresponds to the JSON property isOptOut

Returns:

  • (Boolean)


30586
30587
30588
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30586

def is_opt_out
  @is_opt_out
end

#is_promptBoolean Also known as: is_prompt?

Corresponds to the JSON property isPrompt

Returns:

  • (Boolean)


30592
30593
30594
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30592

def is_prompt
  @is_prompt
end

#lamda_example_idString

Corresponds to the JSON property lamdaExampleId

Returns:

  • (String)


30598
30599
30600
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30598

def lamda_example_id
  @lamda_example_id
end

#licenseString

Corresponds to the JSON property license

Returns:

  • (String)


30603
30604
30605
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30603

def license
  @license
end

#meena_conversation_idString

Corresponds to the JSON property meenaConversationId

Returns:

  • (String)


30608
30609
30610
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30608

def meena_conversation_id
  @meena_conversation_id
end

#natural_language_codeString

Natural (not programming) language of the document. Language code as defined by http://www.unicode.org/reports/tr35/#Identifiers and https://tools.ietf.org/ html/bcp47. Currently applicable to full-view books. Use docinfo-util.h to set & read language fields. See go/iii. Corresponds to the JSON property naturalLanguageCode

Returns:

  • (String)


30616
30617
30618
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30616

def natural_language_code
  @natural_language_code
end

#no_attributionBoolean Also known as: no_attribution?

True if this doc has no attribution information available. We use an explicit field for this instead of just implicitly leaving all the DocAttribution fields blank to distinguish a case where a bug/oversight has left the attribution information empty vs when we really have no attribution information available. Corresponds to the JSON property noAttribution

Returns:

  • (Boolean)


30625
30626
30627
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30625

def no_attribution
  @no_attribution
end

#podcast_utterance_idString

Corresponds to the JSON property podcastUtteranceId

Returns:

  • (String)


30631
30632
30633
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30631

def podcast_utterance_id
  @podcast_utterance_id
end

#publication_dateGoogle::Apis::AiplatformV1::GoogleTypeDate

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property publicationDate



30643
30644
30645
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30643

def publication_date
  @publication_date
end

#quality_score_experiment_onlyFloat

This field is for opt-out experiment only, MUST never be used during actual production/serving. Corresponds to the JSON property qualityScoreExperimentOnly

Returns:

  • (Float)


30649
30650
30651
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30649

def quality_score_experiment_only
  @quality_score_experiment_only
end

#repoString

Github repository Corresponds to the JSON property repo

Returns:

  • (String)


30654
30655
30656
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30654

def repo
  @repo
end

#urlString

URL of a webdoc Corresponds to the JSON property url

Returns:

  • (String)


30659
30660
30661
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30659

def url
  @url
end

#volume_idString

Corresponds to the JSON property volumeId

Returns:

  • (String)


30664
30665
30666
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30664

def volume_id
  @volume_id
end

#wikipedia_article_titleString

Wikipedia article title. The Wikipedia TFDS dataset includes article titles but not URLs. While a URL is to the best of our knowledge a deterministic function of the title, we store the original title to reflect the information in the original dataset. Corresponds to the JSON property wikipediaArticleTitle

Returns:

  • (String)


30672
30673
30674
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30672

def wikipedia_article_title
  @wikipedia_article_title
end

#youtube_video_idString

The unique video id from Youtube. Example: AkoGsW52Ir0 Corresponds to the JSON property youtubeVideoId

Returns:

  • (String)


30677
30678
30679
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30677

def youtube_video_id
  @youtube_video_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30684
30685
30686
30687
30688
30689
30690
30691
30692
30693
30694
30695
30696
30697
30698
30699
30700
30701
30702
30703
30704
30705
30706
30707
30708
30709
30710
30711
30712
30713
30714
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30684

def update!(**args)
  @amarna_id = args[:amarna_id] if args.key?(:amarna_id)
  @arxiv_id = args[:arxiv_id] if args.key?(:arxiv_id)
  @author = args[:author] if args.key?(:author)
  @bibkey = args[:bibkey] if args.key?(:bibkey)
  @biorxiv_id = args[:biorxiv_id] if args.key?(:biorxiv_id)
  @book_title = args[:book_title] if args.key?(:book_title)
  @book_volume_id = args[:book_volume_id] if args.key?(:book_volume_id)
  @category = args[:category] if args.key?(:category)
  @conversation_id = args[:conversation_id] if args.key?(:conversation_id)
  @dataset = args[:dataset] if args.key?(:dataset)
  @filepath = args[:filepath] if args.key?(:filepath)
  @gemini_id = args[:gemini_id] if args.key?(:gemini_id)
  @gnews_article_title = args[:gnews_article_title] if args.key?(:gnews_article_title)
  @goodall_example_id = args[:goodall_example_id] if args.key?(:goodall_example_id)
  @is_opt_out = args[:is_opt_out] if args.key?(:is_opt_out)
  @is_prompt = args[:is_prompt] if args.key?(:is_prompt)
  @lamda_example_id = args[:lamda_example_id] if args.key?(:lamda_example_id)
  @license = args[:license] if args.key?(:license)
  @meena_conversation_id = args[:meena_conversation_id] if args.key?(:meena_conversation_id)
  @natural_language_code = args[:natural_language_code] if args.key?(:natural_language_code)
  @no_attribution = args[:no_attribution] if args.key?(:no_attribution)
  @podcast_utterance_id = args[:podcast_utterance_id] if args.key?(:podcast_utterance_id)
  @publication_date = args[:publication_date] if args.key?(:publication_date)
  @quality_score_experiment_only = args[:quality_score_experiment_only] if args.key?(:quality_score_experiment_only)
  @repo = args[:repo] if args.key?(:repo)
  @url = args[:url] if args.key?(:url)
  @volume_id = args[:volume_id] if args.key?(:volume_id)
  @wikipedia_article_title = args[:wikipedia_article_title] if args.key?(:wikipedia_article_title)
  @youtube_video_id = args[:youtube_video_id] if args.key?(:youtube_video_id)
end