Class: Google::Apis::AiplatformV1::LanguageLabsAidaTrustRecitationProtoDocAttribution

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The proto defines the attribution information for a document using whatever fields are most applicable for that document's datasource. For example, a Wikipedia article's attribution is in the form of its article title, a website is in the form of a URL, and a Github repo is in the form of a repo name. Next id: 30

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LanguageLabsAidaTrustRecitationProtoDocAttribution

Returns a new instance of LanguageLabsAidaTrustRecitationProtoDocAttribution.



29461
29462
29463
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29461

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#amarna_idString

Corresponds to the JSON property amarnaId

Returns:

  • (String)


29293
29294
29295
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29293

def amarna_id
  @amarna_id
end

#arxiv_idString

Corresponds to the JSON property arxivId

Returns:

  • (String)


29298
29299
29300
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29298

def arxiv_id
  @arxiv_id
end

#authorString

Corresponds to the JSON property author

Returns:

  • (String)


29303
29304
29305
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29303

def author
  @author
end

#bibkeyString

Corresponds to the JSON property bibkey

Returns:

  • (String)


29308
29309
29310
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29308

def bibkey
  @bibkey
end

#biorxiv_idString

ID of the paper in bioarxiv like ddoi.org/biorxiv_id eg: https://doi.org/10. 1101/343517 Corresponds to the JSON property biorxivId

Returns:

  • (String)


29314
29315
29316
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29314

def biorxiv_id
  @biorxiv_id
end

#book_titleString

Corresponds to the JSON property bookTitle

Returns:

  • (String)


29319
29320
29321
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29319

def book_title
  @book_title
end

#book_volume_idFixnum

The Oceanographers full-view books dataset uses a 'volume id' as the unique ID of a book. There is a deterministic function from a volume id to a URL under the books.google.com domain. Marked as 'optional' since a volume ID of zero is potentially possible and we want to distinguish that from the volume ID not being set. Corresponds to the JSON property bookVolumeId

Returns:

  • (Fixnum)


29328
29329
29330
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29328

def book_volume_id
  @book_volume_id
end

#categoryString

Corresponds to the JSON property category

Returns:

  • (String)


29333
29334
29335
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29333

def category
  @category
end

#conversation_idString

Corresponds to the JSON property conversationId

Returns:

  • (String)


29338
29339
29340
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29338

def conversation_id
  @conversation_id
end

#datasetString

The dataset this document comes from. Corresponds to the JSON property dataset

Returns:

  • (String)


29343
29344
29345
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29343

def dataset
  @dataset
end

#filepathString

Corresponds to the JSON property filepath

Returns:

  • (String)


29348
29349
29350
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29348

def filepath
  @filepath
end

#gemini_idString

Corresponds to the JSON property geminiId

Returns:

  • (String)


29353
29354
29355
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29353

def gemini_id
  @gemini_id
end

#gnews_article_titleString

Corresponds to the JSON property gnewsArticleTitle

Returns:

  • (String)


29358
29359
29360
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29358

def gnews_article_title
  @gnews_article_title
end

#goodall_example_idString

Corresponds to the JSON property goodallExampleId

Returns:

  • (String)


29363
29364
29365
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29363

def goodall_example_id
  @goodall_example_id
end

#is_opt_outBoolean Also known as: is_opt_out?

Whether the document is opted out. Corresponds to the JSON property isOptOut

Returns:

  • (Boolean)


29368
29369
29370
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29368

def is_opt_out
  @is_opt_out
end

#is_promptBoolean Also known as: is_prompt?

Corresponds to the JSON property isPrompt

Returns:

  • (Boolean)


29374
29375
29376
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29374

def is_prompt
  @is_prompt
end

#lamda_example_idString

Corresponds to the JSON property lamdaExampleId

Returns:

  • (String)


29380
29381
29382
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29380

def lamda_example_id
  @lamda_example_id
end

#licenseString

Corresponds to the JSON property license

Returns:

  • (String)


29385
29386
29387
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29385

def license
  @license
end

#meena_conversation_idString

Corresponds to the JSON property meenaConversationId

Returns:

  • (String)


29390
29391
29392
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29390

def meena_conversation_id
  @meena_conversation_id
end

#natural_language_codeString

Natural (not programming) language of the document. Language code as defined by http://www.unicode.org/reports/tr35/#Identifiers and https://tools.ietf.org/ html/bcp47. Currently applicable to full-view books. Use docinfo-util.h to set & read language fields. See go/iii. Corresponds to the JSON property naturalLanguageCode

Returns:

  • (String)


29398
29399
29400
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29398

def natural_language_code
  @natural_language_code
end

#no_attributionBoolean Also known as: no_attribution?

True if this doc has no attribution information available. We use an explicit field for this instead of just implicitly leaving all the DocAttribution fields blank to distinguish a case where a bug/oversight has left the attribution information empty vs when we really have no attribution information available. Corresponds to the JSON property noAttribution

Returns:

  • (Boolean)


29407
29408
29409
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29407

def no_attribution
  @no_attribution
end

#podcast_utterance_idString

Corresponds to the JSON property podcastUtteranceId

Returns:

  • (String)


29413
29414
29415
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29413

def podcast_utterance_id
  @podcast_utterance_id
end

#publication_dateGoogle::Apis::AiplatformV1::GoogleTypeDate

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property publicationDate



29425
29426
29427
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29425

def publication_date
  @publication_date
end

#quality_score_experiment_onlyFloat

This field is for opt-out experiment only, MUST never be used during actual production/serving. Corresponds to the JSON property qualityScoreExperimentOnly

Returns:

  • (Float)


29431
29432
29433
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29431

def quality_score_experiment_only
  @quality_score_experiment_only
end

#repoString

Github repository Corresponds to the JSON property repo

Returns:

  • (String)


29436
29437
29438
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29436

def repo
  @repo
end

#urlString

URL of a webdoc Corresponds to the JSON property url

Returns:

  • (String)


29441
29442
29443
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29441

def url
  @url
end

#volume_idString

Corresponds to the JSON property volumeId

Returns:

  • (String)


29446
29447
29448
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29446

def volume_id
  @volume_id
end

#wikipedia_article_titleString

Wikipedia article title. The Wikipedia TFDS dataset includes article titles but not URLs. While a URL is to the best of our knowledge a deterministic function of the title, we store the original title to reflect the information in the original dataset. Corresponds to the JSON property wikipediaArticleTitle

Returns:

  • (String)


29454
29455
29456
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29454

def wikipedia_article_title
  @wikipedia_article_title
end

#youtube_video_idString

The unique video id from Youtube. Example: AkoGsW52Ir0 Corresponds to the JSON property youtubeVideoId

Returns:

  • (String)


29459
29460
29461
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29459

def youtube_video_id
  @youtube_video_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29466
29467
29468
29469
29470
29471
29472
29473
29474
29475
29476
29477
29478
29479
29480
29481
29482
29483
29484
29485
29486
29487
29488
29489
29490
29491
29492
29493
29494
29495
29496
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29466

def update!(**args)
  @amarna_id = args[:amarna_id] if args.key?(:amarna_id)
  @arxiv_id = args[:arxiv_id] if args.key?(:arxiv_id)
  @author = args[:author] if args.key?(:author)
  @bibkey = args[:bibkey] if args.key?(:bibkey)
  @biorxiv_id = args[:biorxiv_id] if args.key?(:biorxiv_id)
  @book_title = args[:book_title] if args.key?(:book_title)
  @book_volume_id = args[:book_volume_id] if args.key?(:book_volume_id)
  @category = args[:category] if args.key?(:category)
  @conversation_id = args[:conversation_id] if args.key?(:conversation_id)
  @dataset = args[:dataset] if args.key?(:dataset)
  @filepath = args[:filepath] if args.key?(:filepath)
  @gemini_id = args[:gemini_id] if args.key?(:gemini_id)
  @gnews_article_title = args[:gnews_article_title] if args.key?(:gnews_article_title)
  @goodall_example_id = args[:goodall_example_id] if args.key?(:goodall_example_id)
  @is_opt_out = args[:is_opt_out] if args.key?(:is_opt_out)
  @is_prompt = args[:is_prompt] if args.key?(:is_prompt)
  @lamda_example_id = args[:lamda_example_id] if args.key?(:lamda_example_id)
  @license = args[:license] if args.key?(:license)
  @meena_conversation_id = args[:meena_conversation_id] if args.key?(:meena_conversation_id)
  @natural_language_code = args[:natural_language_code] if args.key?(:natural_language_code)
  @no_attribution = args[:no_attribution] if args.key?(:no_attribution)
  @podcast_utterance_id = args[:podcast_utterance_id] if args.key?(:podcast_utterance_id)
  @publication_date = args[:publication_date] if args.key?(:publication_date)
  @quality_score_experiment_only = args[:quality_score_experiment_only] if args.key?(:quality_score_experiment_only)
  @repo = args[:repo] if args.key?(:repo)
  @url = args[:url] if args.key?(:url)
  @volume_id = args[:volume_id] if args.key?(:volume_id)
  @wikipedia_article_title = args[:wikipedia_article_title] if args.key?(:wikipedia_article_title)
  @youtube_video_id = args[:youtube_video_id] if args.key?(:youtube_video_id)
end