Class: Google::Apis::AiplatformV1::LanguageLabsAidaTrustRecitationProtoDocAttribution

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The proto defines the attribution information for a document using whatever fields are most applicable for that document's datasource. For example, a Wikipedia article's attribution is in the form of its article title, a website is in the form of a URL, and a Github repo is in the form of a repo name. Next id: 30

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LanguageLabsAidaTrustRecitationProtoDocAttribution

Returns a new instance of LanguageLabsAidaTrustRecitationProtoDocAttribution.



29026
29027
29028
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29026

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#amarna_idString

Corresponds to the JSON property amarnaId

Returns:

  • (String)


28858
28859
28860
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28858

def amarna_id
  @amarna_id
end

#arxiv_idString

Corresponds to the JSON property arxivId

Returns:

  • (String)


28863
28864
28865
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28863

def arxiv_id
  @arxiv_id
end

#authorString

Corresponds to the JSON property author

Returns:

  • (String)


28868
28869
28870
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28868

def author
  @author
end

#bibkeyString

Corresponds to the JSON property bibkey

Returns:

  • (String)


28873
28874
28875
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28873

def bibkey
  @bibkey
end

#biorxiv_idString

ID of the paper in bioarxiv like ddoi.org/biorxiv_id eg: https://doi.org/10. 1101/343517 Corresponds to the JSON property biorxivId

Returns:

  • (String)


28879
28880
28881
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28879

def biorxiv_id
  @biorxiv_id
end

#book_titleString

Corresponds to the JSON property bookTitle

Returns:

  • (String)


28884
28885
28886
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28884

def book_title
  @book_title
end

#book_volume_idFixnum

The Oceanographers full-view books dataset uses a 'volume id' as the unique ID of a book. There is a deterministic function from a volume id to a URL under the books.google.com domain. Marked as 'optional' since a volume ID of zero is potentially possible and we want to distinguish that from the volume ID not being set. Corresponds to the JSON property bookVolumeId

Returns:

  • (Fixnum)


28893
28894
28895
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28893

def book_volume_id
  @book_volume_id
end

#categoryString

Corresponds to the JSON property category

Returns:

  • (String)


28898
28899
28900
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28898

def category
  @category
end

#conversation_idString

Corresponds to the JSON property conversationId

Returns:

  • (String)


28903
28904
28905
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28903

def conversation_id
  @conversation_id
end

#datasetString

The dataset this document comes from. Corresponds to the JSON property dataset

Returns:

  • (String)


28908
28909
28910
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28908

def dataset
  @dataset
end

#filepathString

Corresponds to the JSON property filepath

Returns:

  • (String)


28913
28914
28915
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28913

def filepath
  @filepath
end

#gemini_idString

Corresponds to the JSON property geminiId

Returns:

  • (String)


28918
28919
28920
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28918

def gemini_id
  @gemini_id
end

#gnews_article_titleString

Corresponds to the JSON property gnewsArticleTitle

Returns:

  • (String)


28923
28924
28925
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28923

def gnews_article_title
  @gnews_article_title
end

#goodall_example_idString

Corresponds to the JSON property goodallExampleId

Returns:

  • (String)


28928
28929
28930
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28928

def goodall_example_id
  @goodall_example_id
end

#is_opt_outBoolean Also known as: is_opt_out?

Whether the document is opted out. Corresponds to the JSON property isOptOut

Returns:

  • (Boolean)


28933
28934
28935
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28933

def is_opt_out
  @is_opt_out
end

#is_promptBoolean Also known as: is_prompt?

Corresponds to the JSON property isPrompt

Returns:

  • (Boolean)


28939
28940
28941
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28939

def is_prompt
  @is_prompt
end

#lamda_example_idString

Corresponds to the JSON property lamdaExampleId

Returns:

  • (String)


28945
28946
28947
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28945

def lamda_example_id
  @lamda_example_id
end

#licenseString

Corresponds to the JSON property license

Returns:

  • (String)


28950
28951
28952
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28950

def license
  @license
end

#meena_conversation_idString

Corresponds to the JSON property meenaConversationId

Returns:

  • (String)


28955
28956
28957
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28955

def meena_conversation_id
  @meena_conversation_id
end

#natural_language_codeString

Natural (not programming) language of the document. Language code as defined by http://www.unicode.org/reports/tr35/#Identifiers and https://tools.ietf.org/ html/bcp47. Currently applicable to full-view books. Use docinfo-util.h to set & read language fields. See go/iii. Corresponds to the JSON property naturalLanguageCode

Returns:

  • (String)


28963
28964
28965
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28963

def natural_language_code
  @natural_language_code
end

#no_attributionBoolean Also known as: no_attribution?

True if this doc has no attribution information available. We use an explicit field for this instead of just implicitly leaving all the DocAttribution fields blank to distinguish a case where a bug/oversight has left the attribution information empty vs when we really have no attribution information available. Corresponds to the JSON property noAttribution

Returns:

  • (Boolean)


28972
28973
28974
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28972

def no_attribution
  @no_attribution
end

#podcast_utterance_idString

Corresponds to the JSON property podcastUtteranceId

Returns:

  • (String)


28978
28979
28980
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28978

def podcast_utterance_id
  @podcast_utterance_id
end

#publication_dateGoogle::Apis::AiplatformV1::GoogleTypeDate

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property publicationDate



28990
28991
28992
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28990

def publication_date
  @publication_date
end

#quality_score_experiment_onlyFloat

This field is for opt-out experiment only, MUST never be used during actual production/serving. Corresponds to the JSON property qualityScoreExperimentOnly

Returns:

  • (Float)


28996
28997
28998
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 28996

def quality_score_experiment_only
  @quality_score_experiment_only
end

#repoString

Github repository Corresponds to the JSON property repo

Returns:

  • (String)


29001
29002
29003
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29001

def repo
  @repo
end

#urlString

URL of a webdoc Corresponds to the JSON property url

Returns:

  • (String)


29006
29007
29008
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29006

def url
  @url
end

#volume_idString

Corresponds to the JSON property volumeId

Returns:

  • (String)


29011
29012
29013
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29011

def volume_id
  @volume_id
end

#wikipedia_article_titleString

Wikipedia article title. The Wikipedia TFDS dataset includes article titles but not URLs. While a URL is to the best of our knowledge a deterministic function of the title, we store the original title to reflect the information in the original dataset. Corresponds to the JSON property wikipediaArticleTitle

Returns:

  • (String)


29019
29020
29021
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29019

def wikipedia_article_title
  @wikipedia_article_title
end

#youtube_video_idString

The unique video id from Youtube. Example: AkoGsW52Ir0 Corresponds to the JSON property youtubeVideoId

Returns:

  • (String)


29024
29025
29026
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29024

def youtube_video_id
  @youtube_video_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29031
29032
29033
29034
29035
29036
29037
29038
29039
29040
29041
29042
29043
29044
29045
29046
29047
29048
29049
29050
29051
29052
29053
29054
29055
29056
29057
29058
29059
29060
29061
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29031

def update!(**args)
  @amarna_id = args[:amarna_id] if args.key?(:amarna_id)
  @arxiv_id = args[:arxiv_id] if args.key?(:arxiv_id)
  @author = args[:author] if args.key?(:author)
  @bibkey = args[:bibkey] if args.key?(:bibkey)
  @biorxiv_id = args[:biorxiv_id] if args.key?(:biorxiv_id)
  @book_title = args[:book_title] if args.key?(:book_title)
  @book_volume_id = args[:book_volume_id] if args.key?(:book_volume_id)
  @category = args[:category] if args.key?(:category)
  @conversation_id = args[:conversation_id] if args.key?(:conversation_id)
  @dataset = args[:dataset] if args.key?(:dataset)
  @filepath = args[:filepath] if args.key?(:filepath)
  @gemini_id = args[:gemini_id] if args.key?(:gemini_id)
  @gnews_article_title = args[:gnews_article_title] if args.key?(:gnews_article_title)
  @goodall_example_id = args[:goodall_example_id] if args.key?(:goodall_example_id)
  @is_opt_out = args[:is_opt_out] if args.key?(:is_opt_out)
  @is_prompt = args[:is_prompt] if args.key?(:is_prompt)
  @lamda_example_id = args[:lamda_example_id] if args.key?(:lamda_example_id)
  @license = args[:license] if args.key?(:license)
  @meena_conversation_id = args[:meena_conversation_id] if args.key?(:meena_conversation_id)
  @natural_language_code = args[:natural_language_code] if args.key?(:natural_language_code)
  @no_attribution = args[:no_attribution] if args.key?(:no_attribution)
  @podcast_utterance_id = args[:podcast_utterance_id] if args.key?(:podcast_utterance_id)
  @publication_date = args[:publication_date] if args.key?(:publication_date)
  @quality_score_experiment_only = args[:quality_score_experiment_only] if args.key?(:quality_score_experiment_only)
  @repo = args[:repo] if args.key?(:repo)
  @url = args[:url] if args.key?(:url)
  @volume_id = args[:volume_id] if args.key?(:volume_id)
  @wikipedia_article_title = args[:wikipedia_article_title] if args.key?(:wikipedia_article_title)
  @youtube_video_id = args[:youtube_video_id] if args.key?(:youtube_video_id)
end