Class: Google::Apis::AiplatformV1::LanguageLabsAidaTrustRecitationProtoSegmentResult
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::LanguageLabsAidaTrustRecitationProtoSegmentResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The recitation result for each segment in a given input.
Instance Attribute Summary collapse
-
#attribution_dataset ⇒ String
The dataset the segment came from.
-
#display_attribution_message ⇒ String
human-friendly string that contains information from doc_attribution which could be shown by clients Corresponds to the JSON property
displayAttributionMessage. -
#doc_attribution ⇒ Google::Apis::AiplatformV1::LanguageLabsAidaTrustRecitationProtoDocAttribution
The proto defines the attribution information for a document using whatever fields are most applicable for that document's datasource.
-
#doc_occurrences ⇒ Fixnum
number of documents that contained this segment Corresponds to the JSON property
docOccurrences. -
#end_index ⇒ Fixnum
Corresponds to the JSON property
endIndex. -
#raw_text ⇒ String
The raw text in the given input that is corresponding to the segment.
-
#segment_recitation_action ⇒ String
Corresponds to the JSON property
segmentRecitationAction. -
#start_index ⇒ Fixnum
The segment boundary start (inclusive) and end index (exclusive) in the given text.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LanguageLabsAidaTrustRecitationProtoSegmentResult
constructor
A new instance of LanguageLabsAidaTrustRecitationProtoSegmentResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LanguageLabsAidaTrustRecitationProtoSegmentResult
Returns a new instance of LanguageLabsAidaTrustRecitationProtoSegmentResult.
29150 29151 29152 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29150 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attribution_dataset ⇒ String
The dataset the segment came from.
Corresponds to the JSON property attributionDataset
29104 29105 29106 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29104 def attribution_dataset @attribution_dataset end |
#display_attribution_message ⇒ String
human-friendly string that contains information from doc_attribution which
could be shown by clients
Corresponds to the JSON property displayAttributionMessage
29110 29111 29112 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29110 def @display_attribution_message end |
#doc_attribution ⇒ Google::Apis::AiplatformV1::LanguageLabsAidaTrustRecitationProtoDocAttribution
The proto defines the attribution information for a document using whatever
fields are most applicable for that document's datasource. For example, a
Wikipedia article's attribution is in the form of its article title, a website
is in the form of a URL, and a Github repo is in the form of a repo name. Next
id: 30
Corresponds to the JSON property docAttribution
29119 29120 29121 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29119 def doc_attribution @doc_attribution end |
#doc_occurrences ⇒ Fixnum
number of documents that contained this segment
Corresponds to the JSON property docOccurrences
29124 29125 29126 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29124 def doc_occurrences @doc_occurrences end |
#end_index ⇒ Fixnum
Corresponds to the JSON property endIndex
29129 29130 29131 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29129 def end_index @end_index end |
#raw_text ⇒ String
The raw text in the given input that is corresponding to the segment. It will
be available only when 'return_segment_raw_text' is enabled in the request
options.
Corresponds to the JSON property rawText
29136 29137 29138 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29136 def raw_text @raw_text end |
#segment_recitation_action ⇒ String
Corresponds to the JSON property segmentRecitationAction
29141 29142 29143 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29141 def segment_recitation_action @segment_recitation_action end |
#start_index ⇒ Fixnum
The segment boundary start (inclusive) and end index (exclusive) in the given
text. In the streaming RPC, the indexes always start from the beginning of the
first text in the entire stream. The indexes are measured in UTF-16 code units.
Corresponds to the JSON property startIndex
29148 29149 29150 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29148 def start_index @start_index end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29155 29156 29157 29158 29159 29160 29161 29162 29163 29164 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29155 def update!(**args) @attribution_dataset = args[:attribution_dataset] if args.key?(:attribution_dataset) @display_attribution_message = args[:display_attribution_message] if args.key?(:display_attribution_message) @doc_attribution = args[:doc_attribution] if args.key?(:doc_attribution) @doc_occurrences = args[:doc_occurrences] if args.key?(:doc_occurrences) @end_index = args[:end_index] if args.key?(:end_index) @raw_text = args[:raw_text] if args.key?(:raw_text) @segment_recitation_action = args[:segment_recitation_action] if args.key?(:segment_recitation_action) @start_index = args[:start_index] if args.key?(:start_index) end |