Class: Google::Apis::AiplatformV1::LearningGenaiRecitationDocAttribution
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::LearningGenaiRecitationDocAttribution
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The proto defines the attribution information for a document using whatever fields are most applicable for that document's datasource. For example, a Wikipedia article's attribution is in the form of its article title, a website is in the form of a URL, and a Github repo is in the form of a repo name. Next id: 30
Instance Attribute Summary collapse
-
#amarna_id ⇒ String
Corresponds to the JSON property
amarnaId. -
#arxiv_id ⇒ String
Corresponds to the JSON property
arxivId. -
#author ⇒ String
Corresponds to the JSON property
author. -
#bibkey ⇒ String
Corresponds to the JSON property
bibkey. -
#biorxiv_id ⇒ String
ID of the paper in bioarxiv like ddoi.org/
biorxiv_ideg: https://doi.org/10. -
#book_title ⇒ String
Corresponds to the JSON property
bookTitle. -
#book_volume_id ⇒ Fixnum
The Oceanographers full-view books dataset uses a 'volume id' as the unique ID of a book.
-
#conversation_id ⇒ String
Corresponds to the JSON property
conversationId. -
#dataset ⇒ String
The dataset this document comes from.
-
#filepath ⇒ String
Corresponds to the JSON property
filepath. -
#gemini_id ⇒ String
Corresponds to the JSON property
geminiId. -
#gnews_article_title ⇒ String
Corresponds to the JSON property
gnewsArticleTitle. -
#goodall_example_id ⇒ String
Corresponds to the JSON property
goodallExampleId. -
#is_opt_out ⇒ Boolean
(also: #is_opt_out?)
Whether the document is opted out.
-
#is_prompt ⇒ Boolean
(also: #is_prompt?)
When true, this attribution came from the user's prompt.
-
#lamda_example_id ⇒ String
Corresponds to the JSON property
lamdaExampleId. -
#license ⇒ String
Corresponds to the JSON property
license. -
#meena_conversation_id ⇒ String
Corresponds to the JSON property
meenaConversationId. -
#natural_language_code ⇒ String
Natural (not programming) language of the document.
-
#no_attribution ⇒ Boolean
(also: #no_attribution?)
True if this doc has no attribution information available.
-
#podcast_utterance_id ⇒ String
Corresponds to the JSON property
podcastUtteranceId. -
#publication_date ⇒ Google::Apis::AiplatformV1::GoogleTypeDate
Represents a whole or partial calendar date, such as a birthday.
-
#quality_score_experiment_only ⇒ Float
This field is for opt-out experiment only, MUST never be used during actual production/serving.
-
#repo ⇒ String
Github repository Corresponds to the JSON property
repo. -
#url ⇒ String
URL of a webdoc Corresponds to the JSON property
url. -
#volume_id ⇒ String
Corresponds to the JSON property
volumeId. -
#wikipedia_article_title ⇒ String
Wikipedia article title.
-
#youtube_video_id ⇒ String
Corresponds to the JSON property
youtubeVideoId.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LearningGenaiRecitationDocAttribution
constructor
A new instance of LearningGenaiRecitationDocAttribution.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LearningGenaiRecitationDocAttribution
Returns a new instance of LearningGenaiRecitationDocAttribution.
31035 31036 31037 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31035 def initialize(**args) update!(**args) end |
Instance Attribute Details
#amarna_id ⇒ String
Corresponds to the JSON property amarnaId
30872 30873 30874 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30872 def amarna_id @amarna_id end |
#arxiv_id ⇒ String
Corresponds to the JSON property arxivId
30877 30878 30879 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30877 def arxiv_id @arxiv_id end |
#author ⇒ String
Corresponds to the JSON property author
30882 30883 30884 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30882 def @author end |
#bibkey ⇒ String
Corresponds to the JSON property bibkey
30887 30888 30889 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30887 def bibkey @bibkey end |
#biorxiv_id ⇒ String
ID of the paper in bioarxiv like ddoi.org/biorxiv_id eg: https://doi.org/10.
1101/343517
Corresponds to the JSON property biorxivId
30893 30894 30895 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30893 def biorxiv_id @biorxiv_id end |
#book_title ⇒ String
Corresponds to the JSON property bookTitle
30898 30899 30900 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30898 def book_title @book_title end |
#book_volume_id ⇒ Fixnum
The Oceanographers full-view books dataset uses a 'volume id' as the unique ID
of a book. There is a deterministic function from a volume id to a URL under
the books.google.com domain. Marked as 'optional' since a volume ID of zero is
potentially possible and we want to distinguish that from the volume ID not
being set.
Corresponds to the JSON property bookVolumeId
30907 30908 30909 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30907 def book_volume_id @book_volume_id end |
#conversation_id ⇒ String
Corresponds to the JSON property conversationId
30912 30913 30914 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30912 def conversation_id @conversation_id end |
#dataset ⇒ String
The dataset this document comes from.
Corresponds to the JSON property dataset
30917 30918 30919 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30917 def dataset @dataset end |
#filepath ⇒ String
Corresponds to the JSON property filepath
30922 30923 30924 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30922 def filepath @filepath end |
#gemini_id ⇒ String
Corresponds to the JSON property geminiId
30927 30928 30929 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30927 def gemini_id @gemini_id end |
#gnews_article_title ⇒ String
Corresponds to the JSON property gnewsArticleTitle
30932 30933 30934 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30932 def gnews_article_title @gnews_article_title end |
#goodall_example_id ⇒ String
Corresponds to the JSON property goodallExampleId
30937 30938 30939 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30937 def goodall_example_id @goodall_example_id end |
#is_opt_out ⇒ Boolean Also known as: is_opt_out?
Whether the document is opted out.
Corresponds to the JSON property isOptOut
30942 30943 30944 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30942 def is_opt_out @is_opt_out end |
#is_prompt ⇒ Boolean Also known as: is_prompt?
When true, this attribution came from the user's prompt.
Corresponds to the JSON property isPrompt
30948 30949 30950 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30948 def is_prompt @is_prompt end |
#lamda_example_id ⇒ String
Corresponds to the JSON property lamdaExampleId
30954 30955 30956 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30954 def lamda_example_id @lamda_example_id end |
#license ⇒ String
Corresponds to the JSON property license
30959 30960 30961 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30959 def license @license end |
#meena_conversation_id ⇒ String
Corresponds to the JSON property meenaConversationId
30964 30965 30966 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30964 def meena_conversation_id @meena_conversation_id end |
#natural_language_code ⇒ String
Natural (not programming) language of the document. Language code as defined
by http://www.unicode.org/reports/tr35/#Identifiers and https://tools.ietf.org/
html/bcp47. Currently applicable to full-view books. Use docinfo-util.h to set
& read language fields. See go/iii.
Corresponds to the JSON property naturalLanguageCode
30972 30973 30974 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30972 def natural_language_code @natural_language_code end |
#no_attribution ⇒ Boolean Also known as: no_attribution?
True if this doc has no attribution information available. We use an explicit
field for this instead of just implicitly leaving all the DocAttribution
fields blank to distinguish a case where a bug/oversight has left the
attribution information empty vs when we really have no attribution
information available.
Corresponds to the JSON property noAttribution
30981 30982 30983 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30981 def no_attribution @no_attribution end |
#podcast_utterance_id ⇒ String
Corresponds to the JSON property podcastUtteranceId
30987 30988 30989 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30987 def podcast_utterance_id @podcast_utterance_id end |
#publication_date ⇒ Google::Apis::AiplatformV1::GoogleTypeDate
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property publicationDate
30999 31000 31001 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30999 def publication_date @publication_date end |
#quality_score_experiment_only ⇒ Float
This field is for opt-out experiment only, MUST never be used during actual
production/serving.
Corresponds to the JSON property qualityScoreExperimentOnly
31005 31006 31007 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31005 def quality_score_experiment_only @quality_score_experiment_only end |
#repo ⇒ String
Github repository
Corresponds to the JSON property repo
31010 31011 31012 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31010 def repo @repo end |
#url ⇒ String
URL of a webdoc
Corresponds to the JSON property url
31015 31016 31017 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31015 def url @url end |
#volume_id ⇒ String
Corresponds to the JSON property volumeId
31020 31021 31022 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31020 def volume_id @volume_id end |
#wikipedia_article_title ⇒ String
Wikipedia article title. The Wikipedia TFDS dataset includes article titles
but not URLs. While a URL is to the best of our knowledge a deterministic
function of the title, we store the original title to reflect the information
in the original dataset.
Corresponds to the JSON property wikipediaArticleTitle
31028 31029 31030 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31028 def wikipedia_article_title @wikipedia_article_title end |
#youtube_video_id ⇒ String
Corresponds to the JSON property youtubeVideoId
31033 31034 31035 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31033 def youtube_video_id @youtube_video_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31040 31041 31042 31043 31044 31045 31046 31047 31048 31049 31050 31051 31052 31053 31054 31055 31056 31057 31058 31059 31060 31061 31062 31063 31064 31065 31066 31067 31068 31069 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31040 def update!(**args) @amarna_id = args[:amarna_id] if args.key?(:amarna_id) @arxiv_id = args[:arxiv_id] if args.key?(:arxiv_id) @author = args[:author] if args.key?(:author) @bibkey = args[:bibkey] if args.key?(:bibkey) @biorxiv_id = args[:biorxiv_id] if args.key?(:biorxiv_id) @book_title = args[:book_title] if args.key?(:book_title) @book_volume_id = args[:book_volume_id] if args.key?(:book_volume_id) @conversation_id = args[:conversation_id] if args.key?(:conversation_id) @dataset = args[:dataset] if args.key?(:dataset) @filepath = args[:filepath] if args.key?(:filepath) @gemini_id = args[:gemini_id] if args.key?(:gemini_id) @gnews_article_title = args[:gnews_article_title] if args.key?(:gnews_article_title) @goodall_example_id = args[:goodall_example_id] if args.key?(:goodall_example_id) @is_opt_out = args[:is_opt_out] if args.key?(:is_opt_out) @is_prompt = args[:is_prompt] if args.key?(:is_prompt) @lamda_example_id = args[:lamda_example_id] if args.key?(:lamda_example_id) @license = args[:license] if args.key?(:license) @meena_conversation_id = args[:meena_conversation_id] if args.key?(:meena_conversation_id) @natural_language_code = args[:natural_language_code] if args.key?(:natural_language_code) @no_attribution = args[:no_attribution] if args.key?(:no_attribution) @podcast_utterance_id = args[:podcast_utterance_id] if args.key?(:podcast_utterance_id) @publication_date = args[:publication_date] if args.key?(:publication_date) @quality_score_experiment_only = args[:quality_score_experiment_only] if args.key?(:quality_score_experiment_only) @repo = args[:repo] if args.key?(:repo) @url = args[:url] if args.key?(:url) @volume_id = args[:volume_id] if args.key?(:volume_id) @wikipedia_article_title = args[:wikipedia_article_title] if args.key?(:wikipedia_article_title) @youtube_video_id = args[:youtube_video_id] if args.key?(:youtube_video_id) end |