Class: Google::Apis::AiplatformV1::LearningGenaiRecitationDocAttribution
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::LearningGenaiRecitationDocAttribution
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The proto defines the attribution information for a document using whatever fields are most applicable for that document's datasource. For example, a Wikipedia article's attribution is in the form of its article title, a website is in the form of a URL, and a Github repo is in the form of a repo name. Next id: 30
Instance Attribute Summary collapse
-
#amarna_id ⇒ String
Corresponds to the JSON property
amarnaId. -
#arxiv_id ⇒ String
Corresponds to the JSON property
arxivId. -
#author ⇒ String
Corresponds to the JSON property
author. -
#bibkey ⇒ String
Corresponds to the JSON property
bibkey. -
#biorxiv_id ⇒ String
ID of the paper in bioarxiv like ddoi.org/
biorxiv_ideg: https://doi.org/10. -
#book_title ⇒ String
Corresponds to the JSON property
bookTitle. -
#book_volume_id ⇒ Fixnum
The Oceanographers full-view books dataset uses a 'volume id' as the unique ID of a book.
-
#conversation_id ⇒ String
Corresponds to the JSON property
conversationId. -
#dataset ⇒ String
The dataset this document comes from.
-
#filepath ⇒ String
Corresponds to the JSON property
filepath. -
#gemini_id ⇒ String
Corresponds to the JSON property
geminiId. -
#gnews_article_title ⇒ String
Corresponds to the JSON property
gnewsArticleTitle. -
#goodall_example_id ⇒ String
Corresponds to the JSON property
goodallExampleId. -
#is_opt_out ⇒ Boolean
(also: #is_opt_out?)
Whether the document is opted out.
-
#is_prompt ⇒ Boolean
(also: #is_prompt?)
When true, this attribution came from the user's prompt.
-
#lamda_example_id ⇒ String
Corresponds to the JSON property
lamdaExampleId. -
#license ⇒ String
Corresponds to the JSON property
license. -
#meena_conversation_id ⇒ String
Corresponds to the JSON property
meenaConversationId. -
#natural_language_code ⇒ String
Natural (not programming) language of the document.
-
#no_attribution ⇒ Boolean
(also: #no_attribution?)
True if this doc has no attribution information available.
-
#podcast_utterance_id ⇒ String
Corresponds to the JSON property
podcastUtteranceId. -
#publication_date ⇒ Google::Apis::AiplatformV1::GoogleTypeDate
Represents a whole or partial calendar date, such as a birthday.
-
#quality_score_experiment_only ⇒ Float
This field is for opt-out experiment only, MUST never be used during actual production/serving.
-
#repo ⇒ String
Github repository Corresponds to the JSON property
repo. -
#url ⇒ String
URL of a webdoc Corresponds to the JSON property
url. -
#volume_id ⇒ String
Corresponds to the JSON property
volumeId. -
#wikipedia_article_title ⇒ String
Wikipedia article title.
-
#youtube_video_id ⇒ String
Corresponds to the JSON property
youtubeVideoId.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LearningGenaiRecitationDocAttribution
constructor
A new instance of LearningGenaiRecitationDocAttribution.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LearningGenaiRecitationDocAttribution
Returns a new instance of LearningGenaiRecitationDocAttribution.
29817 29818 29819 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29817 def initialize(**args) update!(**args) end |
Instance Attribute Details
#amarna_id ⇒ String
Corresponds to the JSON property amarnaId
29654 29655 29656 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29654 def amarna_id @amarna_id end |
#arxiv_id ⇒ String
Corresponds to the JSON property arxivId
29659 29660 29661 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29659 def arxiv_id @arxiv_id end |
#author ⇒ String
Corresponds to the JSON property author
29664 29665 29666 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29664 def @author end |
#bibkey ⇒ String
Corresponds to the JSON property bibkey
29669 29670 29671 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29669 def bibkey @bibkey end |
#biorxiv_id ⇒ String
ID of the paper in bioarxiv like ddoi.org/biorxiv_id eg: https://doi.org/10.
1101/343517
Corresponds to the JSON property biorxivId
29675 29676 29677 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29675 def biorxiv_id @biorxiv_id end |
#book_title ⇒ String
Corresponds to the JSON property bookTitle
29680 29681 29682 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29680 def book_title @book_title end |
#book_volume_id ⇒ Fixnum
The Oceanographers full-view books dataset uses a 'volume id' as the unique ID
of a book. There is a deterministic function from a volume id to a URL under
the books.google.com domain. Marked as 'optional' since a volume ID of zero is
potentially possible and we want to distinguish that from the volume ID not
being set.
Corresponds to the JSON property bookVolumeId
29689 29690 29691 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29689 def book_volume_id @book_volume_id end |
#conversation_id ⇒ String
Corresponds to the JSON property conversationId
29694 29695 29696 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29694 def conversation_id @conversation_id end |
#dataset ⇒ String
The dataset this document comes from.
Corresponds to the JSON property dataset
29699 29700 29701 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29699 def dataset @dataset end |
#filepath ⇒ String
Corresponds to the JSON property filepath
29704 29705 29706 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29704 def filepath @filepath end |
#gemini_id ⇒ String
Corresponds to the JSON property geminiId
29709 29710 29711 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29709 def gemini_id @gemini_id end |
#gnews_article_title ⇒ String
Corresponds to the JSON property gnewsArticleTitle
29714 29715 29716 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29714 def gnews_article_title @gnews_article_title end |
#goodall_example_id ⇒ String
Corresponds to the JSON property goodallExampleId
29719 29720 29721 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29719 def goodall_example_id @goodall_example_id end |
#is_opt_out ⇒ Boolean Also known as: is_opt_out?
Whether the document is opted out.
Corresponds to the JSON property isOptOut
29724 29725 29726 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29724 def is_opt_out @is_opt_out end |
#is_prompt ⇒ Boolean Also known as: is_prompt?
When true, this attribution came from the user's prompt.
Corresponds to the JSON property isPrompt
29730 29731 29732 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29730 def is_prompt @is_prompt end |
#lamda_example_id ⇒ String
Corresponds to the JSON property lamdaExampleId
29736 29737 29738 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29736 def lamda_example_id @lamda_example_id end |
#license ⇒ String
Corresponds to the JSON property license
29741 29742 29743 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29741 def license @license end |
#meena_conversation_id ⇒ String
Corresponds to the JSON property meenaConversationId
29746 29747 29748 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29746 def meena_conversation_id @meena_conversation_id end |
#natural_language_code ⇒ String
Natural (not programming) language of the document. Language code as defined
by http://www.unicode.org/reports/tr35/#Identifiers and https://tools.ietf.org/
html/bcp47. Currently applicable to full-view books. Use docinfo-util.h to set
& read language fields. See go/iii.
Corresponds to the JSON property naturalLanguageCode
29754 29755 29756 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29754 def natural_language_code @natural_language_code end |
#no_attribution ⇒ Boolean Also known as: no_attribution?
True if this doc has no attribution information available. We use an explicit
field for this instead of just implicitly leaving all the DocAttribution
fields blank to distinguish a case where a bug/oversight has left the
attribution information empty vs when we really have no attribution
information available.
Corresponds to the JSON property noAttribution
29763 29764 29765 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29763 def no_attribution @no_attribution end |
#podcast_utterance_id ⇒ String
Corresponds to the JSON property podcastUtteranceId
29769 29770 29771 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29769 def podcast_utterance_id @podcast_utterance_id end |
#publication_date ⇒ Google::Apis::AiplatformV1::GoogleTypeDate
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property publicationDate
29781 29782 29783 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29781 def publication_date @publication_date end |
#quality_score_experiment_only ⇒ Float
This field is for opt-out experiment only, MUST never be used during actual
production/serving.
Corresponds to the JSON property qualityScoreExperimentOnly
29787 29788 29789 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29787 def quality_score_experiment_only @quality_score_experiment_only end |
#repo ⇒ String
Github repository
Corresponds to the JSON property repo
29792 29793 29794 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29792 def repo @repo end |
#url ⇒ String
URL of a webdoc
Corresponds to the JSON property url
29797 29798 29799 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29797 def url @url end |
#volume_id ⇒ String
Corresponds to the JSON property volumeId
29802 29803 29804 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29802 def volume_id @volume_id end |
#wikipedia_article_title ⇒ String
Wikipedia article title. The Wikipedia TFDS dataset includes article titles
but not URLs. While a URL is to the best of our knowledge a deterministic
function of the title, we store the original title to reflect the information
in the original dataset.
Corresponds to the JSON property wikipediaArticleTitle
29810 29811 29812 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29810 def wikipedia_article_title @wikipedia_article_title end |
#youtube_video_id ⇒ String
Corresponds to the JSON property youtubeVideoId
29815 29816 29817 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29815 def youtube_video_id @youtube_video_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29822 29823 29824 29825 29826 29827 29828 29829 29830 29831 29832 29833 29834 29835 29836 29837 29838 29839 29840 29841 29842 29843 29844 29845 29846 29847 29848 29849 29850 29851 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29822 def update!(**args) @amarna_id = args[:amarna_id] if args.key?(:amarna_id) @arxiv_id = args[:arxiv_id] if args.key?(:arxiv_id) @author = args[:author] if args.key?(:author) @bibkey = args[:bibkey] if args.key?(:bibkey) @biorxiv_id = args[:biorxiv_id] if args.key?(:biorxiv_id) @book_title = args[:book_title] if args.key?(:book_title) @book_volume_id = args[:book_volume_id] if args.key?(:book_volume_id) @conversation_id = args[:conversation_id] if args.key?(:conversation_id) @dataset = args[:dataset] if args.key?(:dataset) @filepath = args[:filepath] if args.key?(:filepath) @gemini_id = args[:gemini_id] if args.key?(:gemini_id) @gnews_article_title = args[:gnews_article_title] if args.key?(:gnews_article_title) @goodall_example_id = args[:goodall_example_id] if args.key?(:goodall_example_id) @is_opt_out = args[:is_opt_out] if args.key?(:is_opt_out) @is_prompt = args[:is_prompt] if args.key?(:is_prompt) @lamda_example_id = args[:lamda_example_id] if args.key?(:lamda_example_id) @license = args[:license] if args.key?(:license) @meena_conversation_id = args[:meena_conversation_id] if args.key?(:meena_conversation_id) @natural_language_code = args[:natural_language_code] if args.key?(:natural_language_code) @no_attribution = args[:no_attribution] if args.key?(:no_attribution) @podcast_utterance_id = args[:podcast_utterance_id] if args.key?(:podcast_utterance_id) @publication_date = args[:publication_date] if args.key?(:publication_date) @quality_score_experiment_only = args[:quality_score_experiment_only] if args.key?(:quality_score_experiment_only) @repo = args[:repo] if args.key?(:repo) @url = args[:url] if args.key?(:url) @volume_id = args[:volume_id] if args.key?(:volume_id) @wikipedia_article_title = args[:wikipedia_article_title] if args.key?(:wikipedia_article_title) @youtube_video_id = args[:youtube_video_id] if args.key?(:youtube_video_id) end |