Class: Google::Apis::AiplatformV1::LearningGenaiRecitationSegmentResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The recitation result for each segment in a given input.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LearningGenaiRecitationSegmentResult

Returns a new instance of LearningGenaiRecitationSegmentResult.



31159
31160
31161
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31159

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attribution_datasetString

The dataset the segment came from. Corresponds to the JSON property attributionDataset

Returns:

  • (String)


31113
31114
31115
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31113

def attribution_dataset
  @attribution_dataset
end

#display_attribution_messageString

human-friendly string that contains information from doc_attribution which could be shown by clients Corresponds to the JSON property displayAttributionMessage

Returns:

  • (String)


31119
31120
31121
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31119

def display_attribution_message
  @display_attribution_message
end

#doc_attributionGoogle::Apis::AiplatformV1::LearningGenaiRecitationDocAttribution

The proto defines the attribution information for a document using whatever fields are most applicable for that document's datasource. For example, a Wikipedia article's attribution is in the form of its article title, a website is in the form of a URL, and a Github repo is in the form of a repo name. Next id: 30 Corresponds to the JSON property docAttribution



31128
31129
31130
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31128

def doc_attribution
  @doc_attribution
end

#doc_occurrencesFixnum

number of documents that contained this segment Corresponds to the JSON property docOccurrences

Returns:

  • (Fixnum)


31133
31134
31135
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31133

def doc_occurrences
  @doc_occurrences
end

#end_indexFixnum

Corresponds to the JSON property endIndex

Returns:

  • (Fixnum)


31138
31139
31140
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31138

def end_index
  @end_index
end

#raw_textString

The raw text in the given input that is corresponding to the segment. It will be available only when 'return_segment_raw_text' is enabled in the request options. Corresponds to the JSON property rawText

Returns:

  • (String)


31145
31146
31147
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31145

def raw_text
  @raw_text
end

#segment_recitation_actionString

Corresponds to the JSON property segmentRecitationAction

Returns:

  • (String)


31150
31151
31152
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31150

def segment_recitation_action
  @segment_recitation_action
end

#start_indexFixnum

The segment boundary start (inclusive) and end index (exclusive) in the given text. In the streaming RPC, the indexes always start from the beginning of the first text in the entire stream. The indexes are measured in UTF-16 code units. Corresponds to the JSON property startIndex

Returns:

  • (Fixnum)


31157
31158
31159
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31157

def start_index
  @start_index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31164
31165
31166
31167
31168
31169
31170
31171
31172
31173
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31164

def update!(**args)
  @attribution_dataset = args[:attribution_dataset] if args.key?(:attribution_dataset)
  @display_attribution_message = args[:display_attribution_message] if args.key?(:display_attribution_message)
  @doc_attribution = args[:doc_attribution] if args.key?(:doc_attribution)
  @doc_occurrences = args[:doc_occurrences] if args.key?(:doc_occurrences)
  @end_index = args[:end_index] if args.key?(:end_index)
  @raw_text = args[:raw_text] if args.key?(:raw_text)
  @segment_recitation_action = args[:segment_recitation_action] if args.key?(:segment_recitation_action)
  @start_index = args[:start_index] if args.key?(:start_index)
end