Class: Google::Apis::AiplatformV1::LearningGenaiRecitationSegmentResult
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::LearningGenaiRecitationSegmentResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The recitation result for each segment in a given input.
Instance Attribute Summary collapse
-
#attribution_dataset ⇒ String
The dataset the segment came from.
-
#display_attribution_message ⇒ String
human-friendly string that contains information from doc_attribution which could be shown by clients Corresponds to the JSON property
displayAttributionMessage. -
#doc_attribution ⇒ Google::Apis::AiplatformV1::LearningGenaiRecitationDocAttribution
The proto defines the attribution information for a document using whatever fields are most applicable for that document's datasource.
-
#doc_occurrences ⇒ Fixnum
number of documents that contained this segment Corresponds to the JSON property
docOccurrences. -
#end_index ⇒ Fixnum
Corresponds to the JSON property
endIndex. -
#raw_text ⇒ String
The raw text in the given input that is corresponding to the segment.
-
#segment_recitation_action ⇒ String
Corresponds to the JSON property
segmentRecitationAction. -
#start_index ⇒ Fixnum
The segment boundary start (inclusive) and end index (exclusive) in the given text.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LearningGenaiRecitationSegmentResult
constructor
A new instance of LearningGenaiRecitationSegmentResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LearningGenaiRecitationSegmentResult
Returns a new instance of LearningGenaiRecitationSegmentResult.
29941 29942 29943 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29941 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attribution_dataset ⇒ String
The dataset the segment came from.
Corresponds to the JSON property attributionDataset
29895 29896 29897 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29895 def attribution_dataset @attribution_dataset end |
#display_attribution_message ⇒ String
human-friendly string that contains information from doc_attribution which
could be shown by clients
Corresponds to the JSON property displayAttributionMessage
29901 29902 29903 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29901 def @display_attribution_message end |
#doc_attribution ⇒ Google::Apis::AiplatformV1::LearningGenaiRecitationDocAttribution
The proto defines the attribution information for a document using whatever
fields are most applicable for that document's datasource. For example, a
Wikipedia article's attribution is in the form of its article title, a website
is in the form of a URL, and a Github repo is in the form of a repo name. Next
id: 30
Corresponds to the JSON property docAttribution
29910 29911 29912 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29910 def doc_attribution @doc_attribution end |
#doc_occurrences ⇒ Fixnum
number of documents that contained this segment
Corresponds to the JSON property docOccurrences
29915 29916 29917 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29915 def doc_occurrences @doc_occurrences end |
#end_index ⇒ Fixnum
Corresponds to the JSON property endIndex
29920 29921 29922 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29920 def end_index @end_index end |
#raw_text ⇒ String
The raw text in the given input that is corresponding to the segment. It will
be available only when 'return_segment_raw_text' is enabled in the request
options.
Corresponds to the JSON property rawText
29927 29928 29929 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29927 def raw_text @raw_text end |
#segment_recitation_action ⇒ String
Corresponds to the JSON property segmentRecitationAction
29932 29933 29934 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29932 def segment_recitation_action @segment_recitation_action end |
#start_index ⇒ Fixnum
The segment boundary start (inclusive) and end index (exclusive) in the given
text. In the streaming RPC, the indexes always start from the beginning of the
first text in the entire stream. The indexes are measured in UTF-16 code units.
Corresponds to the JSON property startIndex
29939 29940 29941 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29939 def start_index @start_index end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29946 29947 29948 29949 29950 29951 29952 29953 29954 29955 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29946 def update!(**args) @attribution_dataset = args[:attribution_dataset] if args.key?(:attribution_dataset) @display_attribution_message = args[:display_attribution_message] if args.key?(:display_attribution_message) @doc_attribution = args[:doc_attribution] if args.key?(:doc_attribution) @doc_occurrences = args[:doc_occurrences] if args.key?(:doc_occurrences) @end_index = args[:end_index] if args.key?(:end_index) @raw_text = args[:raw_text] if args.key?(:raw_text) @segment_recitation_action = args[:segment_recitation_action] if args.key?(:segment_recitation_action) @start_index = args[:start_index] if args.key?(:start_index) end |