Class: Google::Apis::AiplatformV1::LearningGenaiRecitationSegmentResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

The recitation result for each segment in a given input.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LearningGenaiRecitationSegmentResult

Returns a new instance of LearningGenaiRecitationSegmentResult.



29749
29750
29751
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29749

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attribution_datasetString

The dataset the segment came from. Corresponds to the JSON property attributionDataset

Returns:

  • (String)


29703
29704
29705
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29703

def attribution_dataset
  @attribution_dataset
end

#display_attribution_messageString

human-friendly string that contains information from doc_attribution which could be shown by clients Corresponds to the JSON property displayAttributionMessage

Returns:

  • (String)


29709
29710
29711
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29709

def display_attribution_message
  @display_attribution_message
end

#doc_attributionGoogle::Apis::AiplatformV1::LearningGenaiRecitationDocAttribution

The proto defines the attribution information for a document using whatever fields are most applicable for that document's datasource. For example, a Wikipedia article's attribution is in the form of its article title, a website is in the form of a URL, and a Github repo is in the form of a repo name. Next id: 30 Corresponds to the JSON property docAttribution



29718
29719
29720
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29718

def doc_attribution
  @doc_attribution
end

#doc_occurrencesFixnum

number of documents that contained this segment Corresponds to the JSON property docOccurrences

Returns:

  • (Fixnum)


29723
29724
29725
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29723

def doc_occurrences
  @doc_occurrences
end

#end_indexFixnum

Corresponds to the JSON property endIndex

Returns:

  • (Fixnum)


29728
29729
29730
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29728

def end_index
  @end_index
end

#raw_textString

The raw text in the given input that is corresponding to the segment. It will be available only when 'return_segment_raw_text' is enabled in the request options. Corresponds to the JSON property rawText

Returns:

  • (String)


29735
29736
29737
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29735

def raw_text
  @raw_text
end

#segment_recitation_actionString

Corresponds to the JSON property segmentRecitationAction

Returns:

  • (String)


29740
29741
29742
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29740

def segment_recitation_action
  @segment_recitation_action
end

#start_indexFixnum

The segment boundary start (inclusive) and end index (exclusive) in the given text. In the streaming RPC, the indexes always start from the beginning of the first text in the entire stream. The indexes are measured in UTF-16 code units. Corresponds to the JSON property startIndex

Returns:

  • (Fixnum)


29747
29748
29749
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29747

def start_index
  @start_index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29754
29755
29756
29757
29758
29759
29760
29761
29762
29763
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29754

def update!(**args)
  @attribution_dataset = args[:attribution_dataset] if args.key?(:attribution_dataset)
  @display_attribution_message = args[:display_attribution_message] if args.key?(:display_attribution_message)
  @doc_attribution = args[:doc_attribution] if args.key?(:doc_attribution)
  @doc_occurrences = args[:doc_occurrences] if args.key?(:doc_occurrences)
  @end_index = args[:end_index] if args.key?(:end_index)
  @raw_text = args[:raw_text] if args.key?(:raw_text)
  @segment_recitation_action = args[:segment_recitation_action] if args.key?(:segment_recitation_action)
  @start_index = args[:start_index] if args.key?(:start_index)
end