Class: Google::Apis::AiplatformV1::LearningGenaiRecitationSegmentResult
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::LearningGenaiRecitationSegmentResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
The recitation result for each segment in a given input.
Instance Attribute Summary collapse
-
#attribution_dataset ⇒ String
The dataset the segment came from.
-
#display_attribution_message ⇒ String
human-friendly string that contains information from doc_attribution which could be shown by clients Corresponds to the JSON property
displayAttributionMessage. -
#doc_attribution ⇒ Google::Apis::AiplatformV1::LearningGenaiRecitationDocAttribution
The proto defines the attribution information for a document using whatever fields are most applicable for that document's datasource.
-
#doc_occurrences ⇒ Fixnum
number of documents that contained this segment Corresponds to the JSON property
docOccurrences. -
#end_index ⇒ Fixnum
Corresponds to the JSON property
endIndex. -
#raw_text ⇒ String
The raw text in the given input that is corresponding to the segment.
-
#segment_recitation_action ⇒ String
Corresponds to the JSON property
segmentRecitationAction. -
#start_index ⇒ Fixnum
The segment boundary start (inclusive) and end index (exclusive) in the given text.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LearningGenaiRecitationSegmentResult
constructor
A new instance of LearningGenaiRecitationSegmentResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LearningGenaiRecitationSegmentResult
Returns a new instance of LearningGenaiRecitationSegmentResult.
29504 29505 29506 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29504 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attribution_dataset ⇒ String
The dataset the segment came from.
Corresponds to the JSON property attributionDataset
29458 29459 29460 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29458 def attribution_dataset @attribution_dataset end |
#display_attribution_message ⇒ String
human-friendly string that contains information from doc_attribution which
could be shown by clients
Corresponds to the JSON property displayAttributionMessage
29464 29465 29466 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29464 def @display_attribution_message end |
#doc_attribution ⇒ Google::Apis::AiplatformV1::LearningGenaiRecitationDocAttribution
The proto defines the attribution information for a document using whatever
fields are most applicable for that document's datasource. For example, a
Wikipedia article's attribution is in the form of its article title, a website
is in the form of a URL, and a Github repo is in the form of a repo name. Next
id: 30
Corresponds to the JSON property docAttribution
29473 29474 29475 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29473 def doc_attribution @doc_attribution end |
#doc_occurrences ⇒ Fixnum
number of documents that contained this segment
Corresponds to the JSON property docOccurrences
29478 29479 29480 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29478 def doc_occurrences @doc_occurrences end |
#end_index ⇒ Fixnum
Corresponds to the JSON property endIndex
29483 29484 29485 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29483 def end_index @end_index end |
#raw_text ⇒ String
The raw text in the given input that is corresponding to the segment. It will
be available only when 'return_segment_raw_text' is enabled in the request
options.
Corresponds to the JSON property rawText
29490 29491 29492 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29490 def raw_text @raw_text end |
#segment_recitation_action ⇒ String
Corresponds to the JSON property segmentRecitationAction
29495 29496 29497 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29495 def segment_recitation_action @segment_recitation_action end |
#start_index ⇒ Fixnum
The segment boundary start (inclusive) and end index (exclusive) in the given
text. In the streaming RPC, the indexes always start from the beginning of the
first text in the entire stream. The indexes are measured in UTF-16 code units.
Corresponds to the JSON property startIndex
29502 29503 29504 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29502 def start_index @start_index end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29509 29510 29511 29512 29513 29514 29515 29516 29517 29518 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 29509 def update!(**args) @attribution_dataset = args[:attribution_dataset] if args.key?(:attribution_dataset) @display_attribution_message = args[:display_attribution_message] if args.key?(:display_attribution_message) @doc_attribution = args[:doc_attribution] if args.key?(:doc_attribution) @doc_occurrences = args[:doc_occurrences] if args.key?(:doc_occurrences) @end_index = args[:end_index] if args.key?(:end_index) @raw_text = args[:raw_text] if args.key?(:raw_text) @segment_recitation_action = args[:segment_recitation_action] if args.key?(:segment_recitation_action) @start_index = args[:start_index] if args.key?(:start_index) end |