Class: Google::Apis::AiplatformV1::LearningGenaiRootCodeyGenerationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::LearningGenaiRootCodeyGenerationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Stores all metadata relating to GenerateCode.
Instance Attribute Summary collapse
-
#output ⇒ String
Last state of the sample before getting dropped/returned.
-
#post_inference_step ⇒ String
Last Codey postprocessing step for this sample before getting dropped/returned.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LearningGenaiRootCodeyGenerationMetadata
constructor
A new instance of LearningGenaiRootCodeyGenerationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LearningGenaiRootCodeyGenerationMetadata
Returns a new instance of LearningGenaiRootCodeyGenerationMetadata.
31379 31380 31381 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31379 def initialize(**args) update!(**args) end |
Instance Attribute Details
#output ⇒ String
Last state of the sample before getting dropped/returned.
Corresponds to the JSON property output
31372 31373 31374 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31372 def output @output end |
#post_inference_step ⇒ String
Last Codey postprocessing step for this sample before getting dropped/returned.
Corresponds to the JSON property postInferenceStep
31377 31378 31379 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31377 def post_inference_step @post_inference_step end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31384 31385 31386 31387 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31384 def update!(**args) @output = args[:output] if args.key?(:output) @post_inference_step = args[:post_inference_step] if args.key?(:post_inference_step) end |