Class: Google::Apis::AiplatformV1::LearningGenaiRootGroundingMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::LearningGenaiRootGroundingMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Instance Attribute Summary collapse
-
#citations ⇒ Array<Google::Apis::AiplatformV1::LearningGenaiRootGroundingMetadataCitation>
Corresponds to the JSON property
citations. -
#grounding_cancelled ⇒ Boolean
(also: #grounding_cancelled?)
True if grounding is cancelled, for example, no facts being retrieved.
-
#search_queries ⇒ Array<String>
Corresponds to the JSON property
searchQueries.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LearningGenaiRootGroundingMetadata
constructor
A new instance of LearningGenaiRootGroundingMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LearningGenaiRootGroundingMetadata
Returns a new instance of LearningGenaiRootGroundingMetadata.
31695 31696 31697 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31695 def initialize(**args) update!(**args) end |
Instance Attribute Details
#citations ⇒ Array<Google::Apis::AiplatformV1::LearningGenaiRootGroundingMetadataCitation>
Corresponds to the JSON property citations
31682 31683 31684 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31682 def citations @citations end |
#grounding_cancelled ⇒ Boolean Also known as: grounding_cancelled?
True if grounding is cancelled, for example, no facts being retrieved.
Corresponds to the JSON property groundingCancelled
31687 31688 31689 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31687 def grounding_cancelled @grounding_cancelled end |
#search_queries ⇒ Array<String>
Corresponds to the JSON property searchQueries
31693 31694 31695 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31693 def search_queries @search_queries end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31700 31701 31702 31703 31704 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31700 def update!(**args) @citations = args[:citations] if args.key?(:citations) @grounding_cancelled = args[:grounding_cancelled] if args.key?(:grounding_cancelled) @search_queries = args[:search_queries] if args.key?(:search_queries) end |