Class: Google::Apis::AiplatformV1::LearningGenaiRootGroundingMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::LearningGenaiRootGroundingMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Instance Attribute Summary collapse
-
#citations ⇒ Array<Google::Apis::AiplatformV1::LearningGenaiRootGroundingMetadataCitation>
Corresponds to the JSON property
citations. -
#grounding_cancelled ⇒ Boolean
(also: #grounding_cancelled?)
True if grounding is cancelled, for example, no facts being retrieved.
-
#search_queries ⇒ Array<String>
Corresponds to the JSON property
searchQueries.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LearningGenaiRootGroundingMetadata
constructor
A new instance of LearningGenaiRootGroundingMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LearningGenaiRootGroundingMetadata
Returns a new instance of LearningGenaiRootGroundingMetadata.
30173 30174 30175 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30173 def initialize(**args) update!(**args) end |
Instance Attribute Details
#citations ⇒ Array<Google::Apis::AiplatformV1::LearningGenaiRootGroundingMetadataCitation>
Corresponds to the JSON property citations
30160 30161 30162 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30160 def citations @citations end |
#grounding_cancelled ⇒ Boolean Also known as: grounding_cancelled?
True if grounding is cancelled, for example, no facts being retrieved.
Corresponds to the JSON property groundingCancelled
30165 30166 30167 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30165 def grounding_cancelled @grounding_cancelled end |
#search_queries ⇒ Array<String>
Corresponds to the JSON property searchQueries
30171 30172 30173 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30171 def search_queries @search_queries end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30178 30179 30180 30181 30182 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30178 def update!(**args) @citations = args[:citations] if args.key?(:citations) @grounding_cancelled = args[:grounding_cancelled] if args.key?(:grounding_cancelled) @search_queries = args[:search_queries] if args.key?(:search_queries) end |