Class: Google::Apis::AiplatformV1::LearningGenaiRootHarm
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::LearningGenaiRootHarm
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Instance Attribute Summary collapse
-
#contextual_dangerous ⇒ Boolean
(also: #contextual_dangerous?)
Please do not use, this is still under development.
-
#csam ⇒ Boolean
(also: #csam?)
Corresponds to the JSON property
csam. -
#fringe ⇒ Boolean
(also: #fringe?)
Corresponds to the JSON property
fringe. -
#grail_image_harm_type ⇒ Google::Apis::AiplatformV1::LearningGenaiRootHarmGrailImageHarmType
Harm type for images Corresponds to the JSON property
grailImageHarmType. -
#grail_text_harm_type ⇒ Google::Apis::AiplatformV1::LearningGenaiRootHarmGrailTextHarmType
Harm type for text Corresponds to the JSON property
grailTextHarmType. -
#image_child ⇒ Boolean
(also: #image_child?)
Corresponds to the JSON property
imageChild. -
#image_csam ⇒ Boolean
(also: #image_csam?)
Corresponds to the JSON property
imageCsam. -
#image_pedo ⇒ Boolean
(also: #image_pedo?)
Corresponds to the JSON property
imagePedo. -
#image_porn ⇒ Boolean
(also: #image_porn?)
Image signals Corresponds to the JSON property
imagePorn. -
#image_violence ⇒ Boolean
(also: #image_violence?)
Corresponds to the JSON property
imageViolence. -
#pqc ⇒ Boolean
(also: #pqc?)
Corresponds to the JSON property
pqc. -
#safetycat ⇒ Google::Apis::AiplatformV1::LearningGenaiRootHarmSafetyCatCategories
Corresponds to the JSON property
safetycat. -
#spii ⇒ Google::Apis::AiplatformV1::LearningGenaiRootHarmSpiiFilter
Spii Filter uses buckets http://google3/google/privacy/dlp/v2/storage.proto;l= 77;rcl=584719820 to classify the input.
-
#threshold ⇒ Float
Corresponds to the JSON property
threshold. -
#video_frame_child ⇒ Boolean
(also: #video_frame_child?)
Corresponds to the JSON property
videoFrameChild. -
#video_frame_csam ⇒ Boolean
(also: #video_frame_csam?)
Corresponds to the JSON property
videoFrameCsam. -
#video_frame_pedo ⇒ Boolean
(also: #video_frame_pedo?)
Corresponds to the JSON property
videoFramePedo. -
#video_frame_porn ⇒ Boolean
(also: #video_frame_porn?)
Video frame signals Corresponds to the JSON property
videoFramePorn. -
#video_frame_violence ⇒ Boolean
(also: #video_frame_violence?)
Corresponds to the JSON property
videoFrameViolence.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LearningGenaiRootHarm
constructor
A new instance of LearningGenaiRootHarm.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LearningGenaiRootHarm
Returns a new instance of LearningGenaiRootHarm.
31863 31864 31865 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31863 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contextual_dangerous ⇒ Boolean Also known as: contextual_dangerous?
Please do not use, this is still under development.
Corresponds to the JSON property contextualDangerous
31755 31756 31757 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31755 def contextual_dangerous @contextual_dangerous end |
#csam ⇒ Boolean Also known as: csam?
Corresponds to the JSON property csam
31761 31762 31763 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31761 def csam @csam end |
#fringe ⇒ Boolean Also known as: fringe?
Corresponds to the JSON property fringe
31767 31768 31769 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31767 def fringe @fringe end |
#grail_image_harm_type ⇒ Google::Apis::AiplatformV1::LearningGenaiRootHarmGrailImageHarmType
Harm type for images
Corresponds to the JSON property grailImageHarmType
31773 31774 31775 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31773 def grail_image_harm_type @grail_image_harm_type end |
#grail_text_harm_type ⇒ Google::Apis::AiplatformV1::LearningGenaiRootHarmGrailTextHarmType
Harm type for text
Corresponds to the JSON property grailTextHarmType
31778 31779 31780 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31778 def grail_text_harm_type @grail_text_harm_type end |
#image_child ⇒ Boolean Also known as: image_child?
Corresponds to the JSON property imageChild
31783 31784 31785 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31783 def image_child @image_child end |
#image_csam ⇒ Boolean Also known as: image_csam?
Corresponds to the JSON property imageCsam
31789 31790 31791 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31789 def image_csam @image_csam end |
#image_pedo ⇒ Boolean Also known as: image_pedo?
Corresponds to the JSON property imagePedo
31795 31796 31797 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31795 def image_pedo @image_pedo end |
#image_porn ⇒ Boolean Also known as: image_porn?
Image signals
Corresponds to the JSON property imagePorn
31801 31802 31803 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31801 def image_porn @image_porn end |
#image_violence ⇒ Boolean Also known as: image_violence?
Corresponds to the JSON property imageViolence
31807 31808 31809 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31807 def image_violence @image_violence end |
#pqc ⇒ Boolean Also known as: pqc?
Corresponds to the JSON property pqc
31813 31814 31815 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31813 def pqc @pqc end |
#safetycat ⇒ Google::Apis::AiplatformV1::LearningGenaiRootHarmSafetyCatCategories
Corresponds to the JSON property safetycat
31819 31820 31821 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31819 def safetycat @safetycat end |
#spii ⇒ Google::Apis::AiplatformV1::LearningGenaiRootHarmSpiiFilter
Spii Filter uses buckets http://google3/google/privacy/dlp/v2/storage.proto;l=
77;rcl=584719820 to classify the input. LMRoot converts the bucket into double
score. For example the score for "POSSIBLE" is 3 / 5 = 0.6 .
Corresponds to the JSON property spii
31826 31827 31828 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31826 def spii @spii end |
#threshold ⇒ Float
Corresponds to the JSON property threshold
31831 31832 31833 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31831 def threshold @threshold end |
#video_frame_child ⇒ Boolean Also known as: video_frame_child?
Corresponds to the JSON property videoFrameChild
31836 31837 31838 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31836 def video_frame_child @video_frame_child end |
#video_frame_csam ⇒ Boolean Also known as: video_frame_csam?
Corresponds to the JSON property videoFrameCsam
31842 31843 31844 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31842 def video_frame_csam @video_frame_csam end |
#video_frame_pedo ⇒ Boolean Also known as: video_frame_pedo?
Corresponds to the JSON property videoFramePedo
31848 31849 31850 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31848 def video_frame_pedo @video_frame_pedo end |
#video_frame_porn ⇒ Boolean Also known as: video_frame_porn?
Video frame signals
Corresponds to the JSON property videoFramePorn
31854 31855 31856 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31854 def video_frame_porn @video_frame_porn end |
#video_frame_violence ⇒ Boolean Also known as: video_frame_violence?
Corresponds to the JSON property videoFrameViolence
31860 31861 31862 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31860 def video_frame_violence @video_frame_violence end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31868 31869 31870 31871 31872 31873 31874 31875 31876 31877 31878 31879 31880 31881 31882 31883 31884 31885 31886 31887 31888 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31868 def update!(**args) @contextual_dangerous = args[:contextual_dangerous] if args.key?(:contextual_dangerous) @csam = args[:csam] if args.key?(:csam) @fringe = args[:fringe] if args.key?(:fringe) @grail_image_harm_type = args[:grail_image_harm_type] if args.key?(:grail_image_harm_type) @grail_text_harm_type = args[:grail_text_harm_type] if args.key?(:grail_text_harm_type) @image_child = args[:image_child] if args.key?(:image_child) @image_csam = args[:image_csam] if args.key?(:image_csam) @image_pedo = args[:image_pedo] if args.key?(:image_pedo) @image_porn = args[:image_porn] if args.key?(:image_porn) @image_violence = args[:image_violence] if args.key?(:image_violence) @pqc = args[:pqc] if args.key?(:pqc) @safetycat = args[:safetycat] if args.key?(:safetycat) @spii = args[:spii] if args.key?(:spii) @threshold = args[:threshold] if args.key?(:threshold) @video_frame_child = args[:video_frame_child] if args.key?(:video_frame_child) @video_frame_csam = args[:video_frame_csam] if args.key?(:video_frame_csam) @video_frame_pedo = args[:video_frame_pedo] if args.key?(:video_frame_pedo) @video_frame_porn = args[:video_frame_porn] if args.key?(:video_frame_porn) @video_frame_violence = args[:video_frame_violence] if args.key?(:video_frame_violence) end |