Class: Google::Apis::AiplatformV1::LearningGenaiRootRoutingDecisionMetadataScoreBased

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

If we are routing using scored based configuration, then the metadata about that is available in this proto.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LearningGenaiRootRoutingDecisionMetadataScoreBased

Returns a new instance of LearningGenaiRootRoutingDecisionMetadataScoreBased.



32308
32309
32310
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32308

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#matched_ruleGoogle::Apis::AiplatformV1::LearningGenaiRootScoreBasedRoutingConfigRule

The rule that was matched. Corresponds to the JSON property matchedRule



32295
32296
32297
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32295

def matched_rule
  @matched_rule
end

#scoreGoogle::Apis::AiplatformV1::LearningGenaiRootScore

The score that was generated by the router i.e. the model. Corresponds to the JSON property score



32300
32301
32302
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32300

def score
  @score
end

#used_default_fallbackBoolean Also known as: used_default_fallback?

No rules were matched & therefore used the default fallback. Corresponds to the JSON property usedDefaultFallback

Returns:

  • (Boolean)


32305
32306
32307
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32305

def used_default_fallback
  @used_default_fallback
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32313
32314
32315
32316
32317
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32313

def update!(**args)
  @matched_rule = args[:matched_rule] if args.key?(:matched_rule)
  @score = args[:score] if args.key?(:score)
  @used_default_fallback = args[:used_default_fallback] if args.key?(:used_default_fallback)
end