Class: Google::Apis::AiplatformV1::LearningGenaiRootRoutingDecisionMetadataTokenLengthBasedModelInputTokenMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::LearningGenaiRootRoutingDecisionMetadataTokenLengthBasedModelInputTokenMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Instance Attribute Summary collapse
-
#computed_input_token_length ⇒ Fixnum
The length computed by backends using the formatter & tokenizer specific to the model Corresponds to the JSON property
computedInputTokenLength. -
#model_id ⇒ String
Corresponds to the JSON property
modelId. -
#picked_as_fallback ⇒ Boolean
(also: #picked_as_fallback?)
If true, the model was selected as a fallback, since no model met requirements.
-
#selected ⇒ Boolean
(also: #selected?)
If true, the model was selected since it met the requriements.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LearningGenaiRootRoutingDecisionMetadataTokenLengthBasedModelInputTokenMetadata
constructor
A new instance of LearningGenaiRootRoutingDecisionMetadataTokenLengthBasedModelInputTokenMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LearningGenaiRootRoutingDecisionMetadataTokenLengthBasedModelInputTokenMetadata
Returns a new instance of LearningGenaiRootRoutingDecisionMetadataTokenLengthBasedModelInputTokenMetadata.
32372 32373 32374 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32372 def initialize(**args) update!(**args) end |
Instance Attribute Details
#computed_input_token_length ⇒ Fixnum
The length computed by backends using the formatter & tokenizer specific to
the model
Corresponds to the JSON property computedInputTokenLength
32353 32354 32355 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32353 def computed_input_token_length @computed_input_token_length end |
#model_id ⇒ String
Corresponds to the JSON property modelId
32358 32359 32360 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32358 def model_id @model_id end |
#picked_as_fallback ⇒ Boolean Also known as: picked_as_fallback?
If true, the model was selected as a fallback, since no model met requirements.
Corresponds to the JSON property pickedAsFallback
32363 32364 32365 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32363 def picked_as_fallback @picked_as_fallback end |
#selected ⇒ Boolean Also known as: selected?
If true, the model was selected since it met the requriements.
Corresponds to the JSON property selected
32369 32370 32371 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32369 def selected @selected end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32377 32378 32379 32380 32381 32382 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32377 def update!(**args) @computed_input_token_length = args[:computed_input_token_length] if args.key?(:computed_input_token_length) @model_id = args[:model_id] if args.key?(:model_id) @picked_as_fallback = args[:picked_as_fallback] if args.key?(:picked_as_fallback) @selected = args[:selected] if args.key?(:selected) end |