Class: Google::Apis::AiplatformV1::LearningGenaiRootRoutingDecisionMetadataTokenLengthBasedModelInputTokenMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LearningGenaiRootRoutingDecisionMetadataTokenLengthBasedModelInputTokenMetadata

Returns a new instance of LearningGenaiRootRoutingDecisionMetadataTokenLengthBasedModelInputTokenMetadata.



32340
32341
32342
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32340

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#computed_input_token_lengthFixnum

The length computed by backends using the formatter & tokenizer specific to the model Corresponds to the JSON property computedInputTokenLength

Returns:

  • (Fixnum)


32321
32322
32323
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32321

def computed_input_token_length
  @computed_input_token_length
end

#model_idString

Corresponds to the JSON property modelId

Returns:

  • (String)


32326
32327
32328
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32326

def model_id
  @model_id
end

#picked_as_fallbackBoolean Also known as: picked_as_fallback?

If true, the model was selected as a fallback, since no model met requirements. Corresponds to the JSON property pickedAsFallback

Returns:

  • (Boolean)


32331
32332
32333
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32331

def picked_as_fallback
  @picked_as_fallback
end

#selectedBoolean Also known as: selected?

If true, the model was selected since it met the requriements. Corresponds to the JSON property selected

Returns:

  • (Boolean)


32337
32338
32339
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32337

def selected
  @selected
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32345
32346
32347
32348
32349
32350
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32345

def update!(**args)
  @computed_input_token_length = args[:computed_input_token_length] if args.key?(:computed_input_token_length)
  @model_id = args[:model_id] if args.key?(:model_id)
  @picked_as_fallback = args[:picked_as_fallback] if args.key?(:picked_as_fallback)
  @selected = args[:selected] if args.key?(:selected)
end