Class: Google::Apis::AiplatformV1::LearningGenaiRootScoreBasedRoutingConfigRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LearningGenaiRootScoreBasedRoutingConfigRule

Returns a new instance of LearningGenaiRootScoreBasedRoutingConfigRule.



31091
31092
31093
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31091

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#equal_or_greater_thanGoogle::Apis::AiplatformV1::LearningGenaiRootScore

NOTE: Hardest examples have smaller values in their routing scores. Corresponds to the JSON property equalOrGreaterThan



31077
31078
31079
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31077

def equal_or_greater_than
  @equal_or_greater_than
end

#less_thanGoogle::Apis::AiplatformV1::LearningGenaiRootScore

Corresponds to the JSON property lessThan



31082
31083
31084
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31082

def less_than
  @less_than
end

#model_config_idString

This model_config_id points to ModelConfig::id which allows us to find the ModelConfig to route to. This is part of the banks specified in the ModelBankConfig. Corresponds to the JSON property modelConfigId

Returns:

  • (String)


31089
31090
31091
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31089

def model_config_id
  @model_config_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31096
31097
31098
31099
31100
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31096

def update!(**args)
  @equal_or_greater_than = args[:equal_or_greater_than] if args.key?(:equal_or_greater_than)
  @less_than = args[:less_than] if args.key?(:less_than)
  @model_config_id = args[:model_config_id] if args.key?(:model_config_id)
end