Class: Google::Apis::AiplatformV1::LearningGenaiRootScoreBasedRoutingConfigRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LearningGenaiRootScoreBasedRoutingConfigRule

Returns a new instance of LearningGenaiRootScoreBasedRoutingConfigRule.



30535
30536
30537
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30535

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#equal_or_greater_thanGoogle::Apis::AiplatformV1::LearningGenaiRootScore

NOTE: Hardest examples have smaller values in their routing scores. Corresponds to the JSON property equalOrGreaterThan



30521
30522
30523
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30521

def equal_or_greater_than
  @equal_or_greater_than
end

#less_thanGoogle::Apis::AiplatformV1::LearningGenaiRootScore

Corresponds to the JSON property lessThan



30526
30527
30528
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30526

def less_than
  @less_than
end

#model_config_idString

This model_config_id points to ModelConfig::id which allows us to find the ModelConfig to route to. This is part of the banks specified in the ModelBankConfig. Corresponds to the JSON property modelConfigId

Returns:

  • (String)


30533
30534
30535
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30533

def model_config_id
  @model_config_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30540
30541
30542
30543
30544
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30540

def update!(**args)
  @equal_or_greater_than = args[:equal_or_greater_than] if args.key?(:equal_or_greater_than)
  @less_than = args[:less_than] if args.key?(:less_than)
  @model_config_id = args[:model_config_id] if args.key?(:model_config_id)
end