Class: Google::Apis::AiplatformV1::LearningGenaiRootScoredSimilarityTakedownPhrase
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::LearningGenaiRootScoredSimilarityTakedownPhrase
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Proto containing the results from the Universal Sentence Encoder / Other models
Instance Attribute Summary collapse
-
#phrase ⇒ Google::Apis::AiplatformV1::LearningGenaiRootSimilarityTakedownPhrase
Each SimilarityTakedownPhrase treats a logical group of blocked and allowed phrases together along with a corresponding punt If the closest matching response is of the allowed type, we allow the response If the closest matching response is of the blocked type, we block the response.
-
#similarity_score ⇒ Float
Corresponds to the JSON property
similarityScore.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LearningGenaiRootScoredSimilarityTakedownPhrase
constructor
A new instance of LearningGenaiRootScoredSimilarityTakedownPhrase.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LearningGenaiRootScoredSimilarityTakedownPhrase
Returns a new instance of LearningGenaiRootScoredSimilarityTakedownPhrase.
32507 32508 32509 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32507 def initialize(**args) update!(**args) end |
Instance Attribute Details
#phrase ⇒ Google::Apis::AiplatformV1::LearningGenaiRootSimilarityTakedownPhrase
Each SimilarityTakedownPhrase treats a logical group of blocked and allowed
phrases together along with a corresponding punt If the closest matching
response is of the allowed type, we allow the response If the closest matching
response is of the blocked type, we block the response. eg: Blocked phrase - "
All lives matter"
Corresponds to the JSON property phrase
32500 32501 32502 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32500 def phrase @phrase end |
#similarity_score ⇒ Float
Corresponds to the JSON property similarityScore
32505 32506 32507 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32505 def similarity_score @similarity_score end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32512 32513 32514 32515 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32512 def update!(**args) @phrase = args[:phrase] if args.key?(:phrase) @similarity_score = args[:similarity_score] if args.key?(:similarity_score) end |