Class: Google::Apis::AiplatformV1::LearningGenaiRootScoredSimilarityTakedownPhrase
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::LearningGenaiRootScoredSimilarityTakedownPhrase
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Proto containing the results from the Universal Sentence Encoder / Other models
Instance Attribute Summary collapse
-
#phrase ⇒ Google::Apis::AiplatformV1::LearningGenaiRootSimilarityTakedownPhrase
Each SimilarityTakedownPhrase treats a logical group of blocked and allowed phrases together along with a corresponding punt If the closest matching response is of the allowed type, we allow the response If the closest matching response is of the blocked type, we block the response.
-
#similarity_score ⇒ Float
Corresponds to the JSON property
similarityScore.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LearningGenaiRootScoredSimilarityTakedownPhrase
constructor
A new instance of LearningGenaiRootScoredSimilarityTakedownPhrase.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LearningGenaiRootScoredSimilarityTakedownPhrase
Returns a new instance of LearningGenaiRootScoredSimilarityTakedownPhrase.
30566 30567 30568 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30566 def initialize(**args) update!(**args) end |
Instance Attribute Details
#phrase ⇒ Google::Apis::AiplatformV1::LearningGenaiRootSimilarityTakedownPhrase
Each SimilarityTakedownPhrase treats a logical group of blocked and allowed
phrases together along with a corresponding punt If the closest matching
response is of the allowed type, we allow the response If the closest matching
response is of the blocked type, we block the response. eg: Blocked phrase - "
All lives matter"
Corresponds to the JSON property phrase
30559 30560 30561 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30559 def phrase @phrase end |
#similarity_score ⇒ Float
Corresponds to the JSON property similarityScore
30564 30565 30566 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30564 def similarity_score @similarity_score end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30571 30572 30573 30574 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30571 def update!(**args) @phrase = args[:phrase] if args.key?(:phrase) @similarity_score = args[:similarity_score] if args.key?(:similarity_score) end |