Class: Google::Apis::AiplatformV1::LearningGenaiRootSimilarityTakedownPhrase
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::LearningGenaiRootSimilarityTakedownPhrase
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Each SimilarityTakedownPhrase treats a logical group of blocked and allowed phrases together along with a corresponding punt If the closest matching response is of the allowed type, we allow the response If the closest matching response is of the blocked type, we block the response. eg: Blocked phrase - " All lives matter"
Instance Attribute Summary collapse
-
#blocked_phrase ⇒ String
Corresponds to the JSON property
blockedPhrase.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LearningGenaiRootSimilarityTakedownPhrase
constructor
A new instance of LearningGenaiRootSimilarityTakedownPhrase.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LearningGenaiRootSimilarityTakedownPhrase
Returns a new instance of LearningGenaiRootSimilarityTakedownPhrase.
32596 32597 32598 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32596 def initialize(**args) update!(**args) end |
Instance Attribute Details
#blocked_phrase ⇒ String
Corresponds to the JSON property blockedPhrase
32594 32595 32596 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32594 def blocked_phrase @blocked_phrase end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32601 32602 32603 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 32601 def update!(**args) @blocked_phrase = args[:blocked_phrase] if args.key?(:blocked_phrase) end |