Class: Google::Apis::AiplatformV1::LearningGenaiRootTakedownResult
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::LearningGenaiRootTakedownResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Instance Attribute Summary collapse
-
#allowed ⇒ Boolean
(also: #allowed?)
False when query or response should be taken down by any of the takedown rules, true otherwise.
-
#regex_takedown_result ⇒ Google::Apis::AiplatformV1::LearningGenaiRootRegexTakedownResult
Corresponds to the JSON property
regexTakedownResult. -
#request_response_takedown_result ⇒ Google::Apis::AiplatformV1::LearningGenaiRootRequestResponseTakedownResult
Corresponds to the JSON property
requestResponseTakedownResult. -
#similarity_takedown_result ⇒ Google::Apis::AiplatformV1::LearningGenaiRootSimilarityTakedownResult
Corresponds to the JSON property
similarityTakedownResult.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LearningGenaiRootTakedownResult
constructor
A new instance of LearningGenaiRootTakedownResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LearningGenaiRootTakedownResult
Returns a new instance of LearningGenaiRootTakedownResult.
30686 30687 30688 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30686 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowed ⇒ Boolean Also known as: allowed?
False when query or response should be taken down by any of the takedown rules,
true otherwise.
Corresponds to the JSON property allowed
30668 30669 30670 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30668 def allowed @allowed end |
#regex_takedown_result ⇒ Google::Apis::AiplatformV1::LearningGenaiRootRegexTakedownResult
Corresponds to the JSON property regexTakedownResult
30674 30675 30676 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30674 def regex_takedown_result @regex_takedown_result end |
#request_response_takedown_result ⇒ Google::Apis::AiplatformV1::LearningGenaiRootRequestResponseTakedownResult
Corresponds to the JSON property requestResponseTakedownResult
30679 30680 30681 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30679 def request_response_takedown_result @request_response_takedown_result end |
#similarity_takedown_result ⇒ Google::Apis::AiplatformV1::LearningGenaiRootSimilarityTakedownResult
Corresponds to the JSON property similarityTakedownResult
30684 30685 30686 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30684 def similarity_takedown_result @similarity_takedown_result end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30691 30692 30693 30694 30695 30696 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30691 def update!(**args) @allowed = args[:allowed] if args.key?(:allowed) @regex_takedown_result = args[:regex_takedown_result] if args.key?(:regex_takedown_result) @request_response_takedown_result = args[:request_response_takedown_result] if args.key?(:request_response_takedown_result) @similarity_takedown_result = args[:similarity_takedown_result] if args.key?(:similarity_takedown_result) end |