Class: Google::Apis::AiplatformV1::LearningServingLlmMessageMetadata
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::LearningServingLlmMessageMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
LINT.IfChange This metadata contains additional information required for debugging.
Instance Attribute Summary collapse
-
#classifier_summary ⇒ Google::Apis::AiplatformV1::LearningGenaiRootClassifierOutputSummary
Summary of classifier output.
-
#codey_output ⇒ Google::Apis::AiplatformV1::LearningGenaiRootCodeyOutput
Top-level wrapper used to store all things codey-related.
-
#current_stream_text_length ⇒ Fixnum
Corresponds to the JSON property
currentStreamTextLength. -
#deleted ⇒ Boolean
(also: #deleted?)
Whether the corresponding message has been deleted.
-
#filter_meta ⇒ Array<Google::Apis::AiplatformV1::LearningGenaiRootFilterMetadata>
Metadata for filters that triggered.
-
#final_message_score ⇒ Google::Apis::AiplatformV1::LearningGenaiRootScore
This score is finally used for ranking the message.
-
#finish_reason ⇒ String
NOT YET IMPLEMENTED.
-
#grounding_metadata ⇒ Google::Apis::AiplatformV1::LearningGenaiRootGroundingMetadata
Corresponds to the JSON property
groundingMetadata. -
#is_code ⇒ Boolean
(also: #is_code?)
Applies to streaming response message only.
-
#is_fallback ⇒ Boolean
(also: #is_fallback?)
Applies to Response message only.
-
#langid_result ⇒ Google::Apis::AiplatformV1::NlpSaftLangIdResult
Result from nlp_saft DetectLanguage method.
-
#language ⇒ String
Detected language.
-
#lm_prefix ⇒ String
The LM prefix used to generate this response.
-
#original_text ⇒ String
The original text generated by LLM.
-
#per_stream_decoded_token_count ⇒ Fixnum
NOT YET IMPLEMENTED.
-
#rai_outputs ⇒ Array<Google::Apis::AiplatformV1::LearningGenaiRootRaiOutput>
Results of running RAI on the query or this response candidate.
-
#recitation_result ⇒ Google::Apis::AiplatformV1::LearningGenaiRecitationRecitationResult
The recitation result for one input Corresponds to the JSON property
recitationResult. -
#return_token_count ⇒ Fixnum
NOT YET IMPLEMENTED.
-
#scores ⇒ Array<Google::Apis::AiplatformV1::LearningGenaiRootScore>
All the different scores for a message are logged here.
-
#stream_terminated ⇒ Boolean
(also: #stream_terminated?)
Whether the response is terminated during streaming return.
-
#total_decoded_token_count ⇒ Fixnum
NOT YET IMPLEMENTED.
-
#translated_user_prompts ⇒ Array<String>
Translated user-prompt used for RAI post processing.
-
#vertex_rai_result ⇒ Google::Apis::AiplatformV1::CloudAiNlLlmProtoServiceRaiResult
The RAI results for a given text.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LearningServingLlmMessageMetadata
constructor
A new instance of LearningServingLlmMessageMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LearningServingLlmMessageMetadata
Returns a new instance of LearningServingLlmMessageMetadata.
31543 31544 31545 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31543 def initialize(**args) update!(**args) end |
Instance Attribute Details
#classifier_summary ⇒ Google::Apis::AiplatformV1::LearningGenaiRootClassifierOutputSummary
Summary of classifier output. We attach this to all messages regardless of
whether classification rules triggered or not.
Corresponds to the JSON property classifierSummary
31413 31414 31415 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31413 def classifier_summary @classifier_summary end |
#codey_output ⇒ Google::Apis::AiplatformV1::LearningGenaiRootCodeyOutput
Top-level wrapper used to store all things codey-related.
Corresponds to the JSON property codeyOutput
31418 31419 31420 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31418 def codey_output @codey_output end |
#current_stream_text_length ⇒ Fixnum
Corresponds to the JSON property currentStreamTextLength
31423 31424 31425 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31423 def current_stream_text_length @current_stream_text_length end |
#deleted ⇒ Boolean Also known as: deleted?
Whether the corresponding message has been deleted.
Corresponds to the JSON property deleted
31428 31429 31430 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31428 def deleted @deleted end |
#filter_meta ⇒ Array<Google::Apis::AiplatformV1::LearningGenaiRootFilterMetadata>
Metadata for filters that triggered.
Corresponds to the JSON property filterMeta
31434 31435 31436 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31434 def @filter_meta end |
#final_message_score ⇒ Google::Apis::AiplatformV1::LearningGenaiRootScore
This score is finally used for ranking the message. This will be same as the
score present in Message.score field.
Corresponds to the JSON property finalMessageScore
31440 31441 31442 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31440 def @final_message_score end |
#finish_reason ⇒ String
NOT YET IMPLEMENTED.
Corresponds to the JSON property finishReason
31445 31446 31447 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31445 def finish_reason @finish_reason end |
#grounding_metadata ⇒ Google::Apis::AiplatformV1::LearningGenaiRootGroundingMetadata
Corresponds to the JSON property groundingMetadata
31450 31451 31452 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31450 def @grounding_metadata end |
#is_code ⇒ Boolean Also known as: is_code?
Applies to streaming response message only. Whether the message is a code.
Corresponds to the JSON property isCode
31455 31456 31457 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31455 def is_code @is_code end |
#is_fallback ⇒ Boolean Also known as: is_fallback?
Applies to Response message only. Indicates whether the message is a fallback
and the response would have otherwise been empty.
Corresponds to the JSON property isFallback
31462 31463 31464 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31462 def is_fallback @is_fallback end |
#langid_result ⇒ Google::Apis::AiplatformV1::NlpSaftLangIdResult
Result from nlp_saft DetectLanguage method. Currently the predicted language
code and language probability is used.
Corresponds to the JSON property langidResult
31469 31470 31471 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31469 def langid_result @langid_result end |
#language ⇒ String
Detected language.
Corresponds to the JSON property language
31474 31475 31476 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31474 def language @language end |
#lm_prefix ⇒ String
The LM prefix used to generate this response.
Corresponds to the JSON property lmPrefix
31479 31480 31481 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31479 def lm_prefix @lm_prefix end |
#original_text ⇒ String
The original text generated by LLM. This is the raw output for debugging
purposes.
Corresponds to the JSON property originalText
31485 31486 31487 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31485 def original_text @original_text end |
#per_stream_decoded_token_count ⇒ Fixnum
NOT YET IMPLEMENTED. Applies to streaming only. Number of tokens decoded /
emitted by the model as part of this stream. This may be different from
token_count, which contains number of tokens returned in this response after
any response rewriting / truncation.
Corresponds to the JSON property perStreamDecodedTokenCount
31493 31494 31495 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31493 def per_stream_decoded_token_count @per_stream_decoded_token_count end |
#rai_outputs ⇒ Array<Google::Apis::AiplatformV1::LearningGenaiRootRaiOutput>
Results of running RAI on the query or this response candidate. One output per
rai_config. It will be populated regardless of whether the threshold is
exceeded or not.
Corresponds to the JSON property raiOutputs
31500 31501 31502 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31500 def rai_outputs @rai_outputs end |
#recitation_result ⇒ Google::Apis::AiplatformV1::LearningGenaiRecitationRecitationResult
The recitation result for one input
Corresponds to the JSON property recitationResult
31505 31506 31507 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31505 def recitation_result @recitation_result end |
#return_token_count ⇒ Fixnum
NOT YET IMPLEMENTED. Number of tokens returned as part of this candidate.
Corresponds to the JSON property returnTokenCount
31510 31511 31512 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31510 def return_token_count @return_token_count end |
#scores ⇒ Array<Google::Apis::AiplatformV1::LearningGenaiRootScore>
All the different scores for a message are logged here.
Corresponds to the JSON property scores
31515 31516 31517 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31515 def scores @scores end |
#stream_terminated ⇒ Boolean Also known as: stream_terminated?
Whether the response is terminated during streaming return. Only used for
streaming requests.
Corresponds to the JSON property streamTerminated
31521 31522 31523 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31521 def stream_terminated @stream_terminated end |
#total_decoded_token_count ⇒ Fixnum
NOT YET IMPLEMENTED. Aggregated number of total tokens decoded so far. For
streaming, this is sum of all the tokens decoded so far i.e. aggregated count.
Corresponds to the JSON property totalDecodedTokenCount
31528 31529 31530 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31528 def total_decoded_token_count @total_decoded_token_count end |
#translated_user_prompts ⇒ Array<String>
Translated user-prompt used for RAI post processing. This is for internal
processing only. We will translate in pre-processor and pass the translated
text to the post processor using this field. It will be empty if non of the
signals requested need translation.
Corresponds to the JSON property translatedUserPrompts
31536 31537 31538 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31536 def translated_user_prompts @translated_user_prompts end |
#vertex_rai_result ⇒ Google::Apis::AiplatformV1::CloudAiNlLlmProtoServiceRaiResult
The RAI results for a given text.
Corresponds to the JSON property vertexRaiResult
31541 31542 31543 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31541 def vertex_rai_result @vertex_rai_result end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31548 31549 31550 31551 31552 31553 31554 31555 31556 31557 31558 31559 31560 31561 31562 31563 31564 31565 31566 31567 31568 31569 31570 31571 31572 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31548 def update!(**args) @classifier_summary = args[:classifier_summary] if args.key?(:classifier_summary) @codey_output = args[:codey_output] if args.key?(:codey_output) @current_stream_text_length = args[:current_stream_text_length] if args.key?(:current_stream_text_length) @deleted = args[:deleted] if args.key?(:deleted) @filter_meta = args[:filter_meta] if args.key?(:filter_meta) @final_message_score = args[:final_message_score] if args.key?(:final_message_score) @finish_reason = args[:finish_reason] if args.key?(:finish_reason) @grounding_metadata = args[:grounding_metadata] if args.key?(:grounding_metadata) @is_code = args[:is_code] if args.key?(:is_code) @is_fallback = args[:is_fallback] if args.key?(:is_fallback) @langid_result = args[:langid_result] if args.key?(:langid_result) @language = args[:language] if args.key?(:language) @lm_prefix = args[:lm_prefix] if args.key?(:lm_prefix) @original_text = args[:original_text] if args.key?(:original_text) @per_stream_decoded_token_count = args[:per_stream_decoded_token_count] if args.key?(:per_stream_decoded_token_count) @rai_outputs = args[:rai_outputs] if args.key?(:rai_outputs) @recitation_result = args[:recitation_result] if args.key?(:recitation_result) @return_token_count = args[:return_token_count] if args.key?(:return_token_count) @scores = args[:scores] if args.key?(:scores) @stream_terminated = args[:stream_terminated] if args.key?(:stream_terminated) @total_decoded_token_count = args[:total_decoded_token_count] if args.key?(:total_decoded_token_count) @translated_user_prompts = args[:translated_user_prompts] if args.key?(:translated_user_prompts) @vertex_rai_result = args[:vertex_rai_result] if args.key?(:vertex_rai_result) end |