Class: Google::Apis::AiplatformV1::LearningServingLlmMessageMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

LINT.IfChange This metadata contains additional information required for debugging.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LearningServingLlmMessageMetadata

Returns a new instance of LearningServingLlmMessageMetadata.



30976
30977
30978
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30976

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#classifier_summaryGoogle::Apis::AiplatformV1::LearningGenaiRootClassifierOutputSummary

Summary of classifier output. We attach this to all messages regardless of whether classification rules triggered or not. Corresponds to the JSON property classifierSummary



30857
30858
30859
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30857

def classifier_summary
  @classifier_summary
end

#current_stream_text_lengthFixnum

Corresponds to the JSON property currentStreamTextLength

Returns:

  • (Fixnum)


30862
30863
30864
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30862

def current_stream_text_length
  @current_stream_text_length
end

#deletedBoolean Also known as: deleted?

Whether the corresponding message has been deleted. Corresponds to the JSON property deleted

Returns:

  • (Boolean)


30867
30868
30869
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30867

def deleted
  @deleted
end

#filter_metaArray<Google::Apis::AiplatformV1::LearningGenaiRootFilterMetadata>

Metadata for filters that triggered. Corresponds to the JSON property filterMeta



30873
30874
30875
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30873

def filter_meta
  @filter_meta
end

#final_message_scoreGoogle::Apis::AiplatformV1::LearningGenaiRootScore

This score is finally used for ranking the message. This will be same as the score present in Message.score field. Corresponds to the JSON property finalMessageScore



30879
30880
30881
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30879

def final_message_score
  @final_message_score
end

#finish_reasonString

NOT YET IMPLEMENTED. Corresponds to the JSON property finishReason

Returns:

  • (String)


30884
30885
30886
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30884

def finish_reason
  @finish_reason
end

#grounding_metadataGoogle::Apis::AiplatformV1::LearningGenaiRootGroundingMetadata

Corresponds to the JSON property groundingMetadata



30889
30890
30891
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30889

def 
  @grounding_metadata
end

#is_fallbackBoolean Also known as: is_fallback?

Applies to Response message only. Indicates whether the message is a fallback and the response would have otherwise been empty. Corresponds to the JSON property isFallback

Returns:

  • (Boolean)


30895
30896
30897
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30895

def is_fallback
  @is_fallback
end

#langid_resultGoogle::Apis::AiplatformV1::NlpSaftLangIdResult

Result from nlp_saft DetectLanguage method. Currently the predicted language code and language probability is used. Corresponds to the JSON property langidResult



30902
30903
30904
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30902

def langid_result
  @langid_result
end

#languageString

Detected language. Corresponds to the JSON property language

Returns:

  • (String)


30907
30908
30909
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30907

def language
  @language
end

#lm_prefixString

The LM prefix used to generate this response. Corresponds to the JSON property lmPrefix

Returns:

  • (String)


30912
30913
30914
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30912

def lm_prefix
  @lm_prefix
end

#original_textString

The original text generated by LLM. This is the raw output for debugging purposes. Corresponds to the JSON property originalText

Returns:

  • (String)


30918
30919
30920
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30918

def original_text
  @original_text
end

#per_stream_decoded_token_countFixnum

NOT YET IMPLEMENTED. Applies to streaming only. Number of tokens decoded / emitted by the model as part of this stream. This may be different from token_count, which contains number of tokens returned in this response after any response rewriting / truncation. Corresponds to the JSON property perStreamDecodedTokenCount

Returns:

  • (Fixnum)


30926
30927
30928
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30926

def per_stream_decoded_token_count
  @per_stream_decoded_token_count
end

#rai_outputsArray<Google::Apis::AiplatformV1::LearningGenaiRootRaiOutput>

Results of running RAI on the query or this response candidate. One output per rai_config. It will be populated regardless of whether the threshold is exceeded or not. Corresponds to the JSON property raiOutputs



30933
30934
30935
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30933

def rai_outputs
  @rai_outputs
end

#recitation_resultGoogle::Apis::AiplatformV1::LearningGenaiRecitationRecitationResult

The recitation result for one input Corresponds to the JSON property recitationResult



30938
30939
30940
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30938

def recitation_result
  @recitation_result
end

#return_token_countFixnum

NOT YET IMPLEMENTED. Number of tokens returned as part of this candidate. Corresponds to the JSON property returnTokenCount

Returns:

  • (Fixnum)


30943
30944
30945
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30943

def return_token_count
  @return_token_count
end

#scoresArray<Google::Apis::AiplatformV1::LearningGenaiRootScore>

All the different scores for a message are logged here. Corresponds to the JSON property scores



30948
30949
30950
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30948

def scores
  @scores
end

#stream_terminatedBoolean Also known as: stream_terminated?

Whether the response is terminated during streaming return. Only used for streaming requests. Corresponds to the JSON property streamTerminated

Returns:

  • (Boolean)


30954
30955
30956
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30954

def stream_terminated
  @stream_terminated
end

#total_decoded_token_countFixnum

NOT YET IMPLEMENTED. Aggregated number of total tokens decoded so far. For streaming, this is sum of all the tokens decoded so far i.e. aggregated count. Corresponds to the JSON property totalDecodedTokenCount

Returns:

  • (Fixnum)


30961
30962
30963
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30961

def total_decoded_token_count
  @total_decoded_token_count
end

#translated_user_promptsArray<String>

Translated user-prompt used for RAI post processing. This is for internal processing only. We will translate in pre-processor and pass the translated text to the post processor using this field. It will be empty if non of the signals requested need translation. Corresponds to the JSON property translatedUserPrompts

Returns:

  • (Array<String>)


30969
30970
30971
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30969

def translated_user_prompts
  @translated_user_prompts
end

#vertex_rai_resultGoogle::Apis::AiplatformV1::CloudAiNlLlmProtoServiceRaiResult

The RAI results for a given text. Corresponds to the JSON property vertexRaiResult



30974
30975
30976
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30974

def vertex_rai_result
  @vertex_rai_result
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30981
30982
30983
30984
30985
30986
30987
30988
30989
30990
30991
30992
30993
30994
30995
30996
30997
30998
30999
31000
31001
31002
31003
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 30981

def update!(**args)
  @classifier_summary = args[:classifier_summary] if args.key?(:classifier_summary)
  @current_stream_text_length = args[:current_stream_text_length] if args.key?(:current_stream_text_length)
  @deleted = args[:deleted] if args.key?(:deleted)
  @filter_meta = args[:filter_meta] if args.key?(:filter_meta)
  @final_message_score = args[:final_message_score] if args.key?(:final_message_score)
  @finish_reason = args[:finish_reason] if args.key?(:finish_reason)
  @grounding_metadata = args[:grounding_metadata] if args.key?(:grounding_metadata)
  @is_fallback = args[:is_fallback] if args.key?(:is_fallback)
  @langid_result = args[:langid_result] if args.key?(:langid_result)
  @language = args[:language] if args.key?(:language)
  @lm_prefix = args[:lm_prefix] if args.key?(:lm_prefix)
  @original_text = args[:original_text] if args.key?(:original_text)
  @per_stream_decoded_token_count = args[:per_stream_decoded_token_count] if args.key?(:per_stream_decoded_token_count)
  @rai_outputs = args[:rai_outputs] if args.key?(:rai_outputs)
  @recitation_result = args[:recitation_result] if args.key?(:recitation_result)
  @return_token_count = args[:return_token_count] if args.key?(:return_token_count)
  @scores = args[:scores] if args.key?(:scores)
  @stream_terminated = args[:stream_terminated] if args.key?(:stream_terminated)
  @total_decoded_token_count = args[:total_decoded_token_count] if args.key?(:total_decoded_token_count)
  @translated_user_prompts = args[:translated_user_prompts] if args.key?(:translated_user_prompts)
  @vertex_rai_result = args[:vertex_rai_result] if args.key?(:vertex_rai_result)
end