Class: Google::Apis::AiplatformV1::NlpSaftLangIdResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NlpSaftLangIdResult

Returns a new instance of NlpSaftLangIdResult.



31644
31645
31646
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31644

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#model_versionString

The version of the model used to create these annotations. Corresponds to the JSON property modelVersion

Returns:

  • (String)


31626
31627
31628
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31626

def model_version
  @model_version
end

#predictionsArray<Google::Apis::AiplatformV1::NlpSaftLanguageSpan>

This field stores the n-best list of possible BCP 47 language code strings for a given input sorted in descending order according to each code's respective probability. Corresponds to the JSON property predictions



31633
31634
31635
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31633

def predictions
  @predictions
end

#span_predictionsArray<Google::Apis::AiplatformV1::NlpSaftLanguageSpanSequence>

This field stores language predictions of subspans of the input, when available. Each LanguageSpanSequence is a sequence of LanguageSpans. A particular sequence of LanguageSpans has an associated probability, and need not necessarily cover the entire input. If no language could be predicted for any span, then this field may be empty. Corresponds to the JSON property spanPredictions



31642
31643
31644
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31642

def span_predictions
  @span_predictions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31649
31650
31651
31652
31653
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31649

def update!(**args)
  @model_version = args[:model_version] if args.key?(:model_version)
  @predictions = args[:predictions] if args.key?(:predictions)
  @span_predictions = args[:span_predictions] if args.key?(:span_predictions)
end