Class: Google::Apis::AiplatformV1::NlpSaftLanguageSpanSequence
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::NlpSaftLanguageSpanSequence
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Instance Attribute Summary collapse
-
#language_spans ⇒ Array<Google::Apis::AiplatformV1::NlpSaftLanguageSpan>
A sequence of LanguageSpan objects, each assigning a language to a subspan of the input.
-
#probability ⇒ Float
The probability of this sequence of LanguageSpans.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NlpSaftLanguageSpanSequence
constructor
A new instance of NlpSaftLanguageSpanSequence.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NlpSaftLanguageSpanSequence
Returns a new instance of NlpSaftLanguageSpanSequence.
31718 31719 31720 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31718 def initialize(**args) update!(**args) end |
Instance Attribute Details
#language_spans ⇒ Array<Google::Apis::AiplatformV1::NlpSaftLanguageSpan>
A sequence of LanguageSpan objects, each assigning a language to a subspan of
the input.
Corresponds to the JSON property languageSpans
31711 31712 31713 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31711 def language_spans @language_spans end |
#probability ⇒ Float
The probability of this sequence of LanguageSpans.
Corresponds to the JSON property probability
31716 31717 31718 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31716 def probability @probability end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31723 31724 31725 31726 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31723 def update!(**args) @language_spans = args[:language_spans] if args.key?(:language_spans) @probability = args[:probability] if args.key?(:probability) end |