Class: Google::Apis::AiplatformV1::UtilStatusProto
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::UtilStatusProto
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Wire-format for a Status object
Instance Attribute Summary collapse
-
#canonical_code ⇒ Fixnum
The canonical error code (see codes.proto) that most closely corresponds to this status.
-
#code ⇒ Fixnum
Numeric code drawn from the space specified below.
-
#message ⇒ String
Detail message Corresponds to the JSON property
message. -
#message_set ⇒ Google::Apis::AiplatformV1::Proto2BridgeMessageSet
This is proto2's version of MessageSet.
-
#space ⇒ String
The following are usually only present when code != 0 Space to which this status belongs Corresponds to the JSON property
space.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UtilStatusProto
constructor
A new instance of UtilStatusProto.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UtilStatusProto
Returns a new instance of UtilStatusProto.
33291 33292 33293 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33291 def initialize(**args) update!(**args) end |
Instance Attribute Details
#canonical_code ⇒ Fixnum
The canonical error code (see codes.proto) that most closely corresponds to
this status. This may be missing, and in the common case of the generic space,
it definitely will be.
Corresponds to the JSON property canonicalCode
33267 33268 33269 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33267 def canonical_code @canonical_code end |
#code ⇒ Fixnum
Numeric code drawn from the space specified below. Often, this is the
canonical error space, and code is drawn from google3/util/task/codes.proto
Corresponds to the JSON property code
33273 33274 33275 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33273 def code @code end |
#message ⇒ String
Detail message
Corresponds to the JSON property message
33278 33279 33280 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33278 def @message end |
#message_set ⇒ Google::Apis::AiplatformV1::Proto2BridgeMessageSet
This is proto2's version of MessageSet.
Corresponds to the JSON property messageSet
33283 33284 33285 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33283 def @message_set end |
#space ⇒ String
The following are usually only present when code != 0 Space to which this
status belongs
Corresponds to the JSON property space
33289 33290 33291 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33289 def space @space end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33296 33297 33298 33299 33300 33301 33302 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33296 def update!(**args) @canonical_code = args[:canonical_code] if args.key?(:canonical_code) @code = args[:code] if args.key?(:code) @message = args[:message] if args.key?(:message) @message_set = args[:message_set] if args.key?(:message_set) @space = args[:space] if args.key?(:space) end |