Class: Google::Apis::AiplatformV1::UtilStatusProto
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::UtilStatusProto
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Wire-format for a Status object
Instance Attribute Summary collapse
-
#canonical_code ⇒ Fixnum
The canonical error code (see codes.proto) that most closely corresponds to this status.
-
#code ⇒ Fixnum
Numeric code drawn from the space specified below.
-
#message ⇒ String
Detail message Corresponds to the JSON property
message. -
#message_set ⇒ Google::Apis::AiplatformV1::Proto2BridgeMessageSet
This is proto2's version of MessageSet.
-
#space ⇒ String
The following are usually only present when code != 0 Space to which this status belongs Corresponds to the JSON property
space.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UtilStatusProto
constructor
A new instance of UtilStatusProto.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UtilStatusProto
Returns a new instance of UtilStatusProto.
33221 33222 33223 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33221 def initialize(**args) update!(**args) end |
Instance Attribute Details
#canonical_code ⇒ Fixnum
The canonical error code (see codes.proto) that most closely corresponds to
this status. This may be missing, and in the common case of the generic space,
it definitely will be.
Corresponds to the JSON property canonicalCode
33197 33198 33199 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33197 def canonical_code @canonical_code end |
#code ⇒ Fixnum
Numeric code drawn from the space specified below. Often, this is the
canonical error space, and code is drawn from google3/util/task/codes.proto
Corresponds to the JSON property code
33203 33204 33205 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33203 def code @code end |
#message ⇒ String
Detail message
Corresponds to the JSON property message
33208 33209 33210 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33208 def @message end |
#message_set ⇒ Google::Apis::AiplatformV1::Proto2BridgeMessageSet
This is proto2's version of MessageSet.
Corresponds to the JSON property messageSet
33213 33214 33215 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33213 def @message_set end |
#space ⇒ String
The following are usually only present when code != 0 Space to which this
status belongs
Corresponds to the JSON property space
33219 33220 33221 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33219 def space @space end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33226 33227 33228 33229 33230 33231 33232 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33226 def update!(**args) @canonical_code = args[:canonical_code] if args.key?(:canonical_code) @code = args[:code] if args.key?(:code) @message = args[:message] if args.key?(:message) @message_set = args[:message_set] if args.key?(:message_set) @space = args[:space] if args.key?(:space) end |