Class: Google::Apis::AiplatformV1::UtilStatusProto

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Wire-format for a Status object

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UtilStatusProto

Returns a new instance of UtilStatusProto.



33189
33190
33191
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33189

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#canonical_codeFixnum

The canonical error code (see codes.proto) that most closely corresponds to this status. This may be missing, and in the common case of the generic space, it definitely will be. Corresponds to the JSON property canonicalCode

Returns:

  • (Fixnum)


33165
33166
33167
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33165

def canonical_code
  @canonical_code
end

#codeFixnum

Numeric code drawn from the space specified below. Often, this is the canonical error space, and code is drawn from google3/util/task/codes.proto Corresponds to the JSON property code

Returns:

  • (Fixnum)


33171
33172
33173
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33171

def code
  @code
end

#messageString

Detail message Corresponds to the JSON property message

Returns:

  • (String)


33176
33177
33178
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33176

def message
  @message
end

#message_setGoogle::Apis::AiplatformV1::Proto2BridgeMessageSet

This is proto2's version of MessageSet. Corresponds to the JSON property messageSet



33181
33182
33183
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33181

def message_set
  @message_set
end

#spaceString

The following are usually only present when code != 0 Space to which this status belongs Corresponds to the JSON property space

Returns:

  • (String)


33187
33188
33189
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33187

def space
  @space
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33194
33195
33196
33197
33198
33199
33200
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 33194

def update!(**args)
  @canonical_code = args[:canonical_code] if args.key?(:canonical_code)
  @code = args[:code] if args.key?(:code)
  @message = args[:message] if args.key?(:message)
  @message_set = args[:message_set] if args.key?(:message_set)
  @space = args[:space] if args.key?(:space)
end