Class: Google::Apis::AiplatformV1::UtilStatusProto

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb

Overview

Wire-format for a Status object

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UtilStatusProto

Returns a new instance of UtilStatusProto.



31583
31584
31585
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31583

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#canonical_codeFixnum

The canonical error code (see codes.proto) that most closely corresponds to this status. This may be missing, and in the common case of the generic space, it definitely will be. Corresponds to the JSON property canonicalCode

Returns:

  • (Fixnum)


31559
31560
31561
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31559

def canonical_code
  @canonical_code
end

#codeFixnum

Numeric code drawn from the space specified below. Often, this is the canonical error space, and code is drawn from google3/util/task/codes.proto Corresponds to the JSON property code

Returns:

  • (Fixnum)


31565
31566
31567
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31565

def code
  @code
end

#messageString

Detail message Corresponds to the JSON property message

Returns:

  • (String)


31570
31571
31572
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31570

def message
  @message
end

#message_setGoogle::Apis::AiplatformV1::Proto2BridgeMessageSet

This is proto2's version of MessageSet. Corresponds to the JSON property messageSet



31575
31576
31577
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31575

def message_set
  @message_set
end

#spaceString

The following are usually only present when code != 0 Space to which this status belongs Corresponds to the JSON property space

Returns:

  • (String)


31581
31582
31583
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31581

def space
  @space
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31588
31589
31590
31591
31592
31593
31594
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31588

def update!(**args)
  @canonical_code = args[:canonical_code] if args.key?(:canonical_code)
  @code = args[:code] if args.key?(:code)
  @message = args[:message] if args.key?(:message)
  @message_set = args[:message_set] if args.key?(:message_set)
  @space = args[:space] if args.key?(:space)
end