Class: Google::Apis::AiplatformV1::UtilStatusProto
- Inherits:
-
Object
- Object
- Google::Apis::AiplatformV1::UtilStatusProto
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/aiplatform_v1/classes.rb,
lib/google/apis/aiplatform_v1/representations.rb,
lib/google/apis/aiplatform_v1/representations.rb
Overview
Wire-format for a Status object
Instance Attribute Summary collapse
-
#canonical_code ⇒ Fixnum
The canonical error code (see codes.proto) that most closely corresponds to this status.
-
#code ⇒ Fixnum
Numeric code drawn from the space specified below.
-
#message ⇒ String
Detail message Corresponds to the JSON property
message. -
#message_set ⇒ Google::Apis::AiplatformV1::Proto2BridgeMessageSet
This is proto2's version of MessageSet.
-
#space ⇒ String
The following are usually only present when code != 0 Space to which this status belongs Corresponds to the JSON property
space.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UtilStatusProto
constructor
A new instance of UtilStatusProto.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UtilStatusProto
Returns a new instance of UtilStatusProto.
31206 31207 31208 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31206 def initialize(**args) update!(**args) end |
Instance Attribute Details
#canonical_code ⇒ Fixnum
The canonical error code (see codes.proto) that most closely corresponds to
this status. This may be missing, and in the common case of the generic space,
it definitely will be.
Corresponds to the JSON property canonicalCode
31182 31183 31184 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31182 def canonical_code @canonical_code end |
#code ⇒ Fixnum
Numeric code drawn from the space specified below. Often, this is the
canonical error space, and code is drawn from google3/util/task/codes.proto
Corresponds to the JSON property code
31188 31189 31190 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31188 def code @code end |
#message ⇒ String
Detail message
Corresponds to the JSON property message
31193 31194 31195 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31193 def @message end |
#message_set ⇒ Google::Apis::AiplatformV1::Proto2BridgeMessageSet
This is proto2's version of MessageSet.
Corresponds to the JSON property messageSet
31198 31199 31200 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31198 def @message_set end |
#space ⇒ String
The following are usually only present when code != 0 Space to which this
status belongs
Corresponds to the JSON property space
31204 31205 31206 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31204 def space @space end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31211 31212 31213 31214 31215 31216 31217 |
# File 'lib/google/apis/aiplatform_v1/classes.rb', line 31211 def update!(**args) @canonical_code = args[:canonical_code] if args.key?(:canonical_code) @code = args[:code] if args.key?(:code) @message = args[:message] if args.key?(:message) @message_set = args[:message_set] if args.key?(:message_set) @space = args[:space] if args.key?(:space) end |